@@ -323,11 +323,13 @@ use GCUtils;
         my $labelName = new Gtk2::Label($self->{parent}->{lang}->{BorrowersName});
         $table->attach($labelName, 0, 1, 0, 1, 'expand', 'fill', 5, 5);
         my $name = new Gtk2::Entry;
+        $name->signal_connect('activate' => sub {$dialog->response('ok')});
         $table->attach($name, 1, 2, 0, 1, 'expand', 'fill', 5, 5);
  
         my $labelEmail = new Gtk2::Label($self->{parent}->{lang}->{BorrowersEmail});
         $table->attach($labelEmail, 0, 1, 1, 2, 'expand', 'fill', 5, 5);
         my $email = new Gtk2::Entry;
+        $email->signal_connect('activate' => sub {$dialog->response('ok')});
         $table->attach($email, 1, 2, 1, 2, 'expand', 'fill', 5, 5);
        
         $dialog->vbox->pack_start($table,1,1,0);
@@ -453,50 +455,97 @@ use GCUtils;
 
     sub setList
     {
-        my ($self, $movies) = @_;
+        my ($self, $data, $model) = @_;
 
-        $self->{moviesList} = [];
-        @{$self->{items}->{data}} = ();
-        
-        foreach (@{$movies})
+        $self->setModel($model);
+        my $items = $data->getItemsList;
+        $self->{data} = $data;
+ 
+        $self->{itemsList} = [];
+        $self->{listModel}->clear;
+        my ($listId, $dataId) = (-1, -1);
+        foreach (@{$items})
         {
+            $dataId++;
             next if (!$_->{$self->{borrowerField}}) || ($_->{$self->{borrowerField}} eq 'none');
+            $listId++;
             my $borrower = $_->{$self->{borrowerField}};
             $borrower = $self->{parent}->{model}->getDisplayedText('PanelUnknown')
                 if $borrower eq 'unknown';
-            my @infos = [ $_->{$self->{titleField}},
-                          $borrower,
-                          $_->{$self->{lendDateField}} ];
-            push @{$self->{items}->{data}}, @infos;
-            push @{$self->{moviesList}}, {
+            my $lendDate = GCUtils::timeToStr($_->{$self->{lendDateField}},
+                                              $self->{parent}->{options}->dateFormat);
+            push @{$self->{itemsList}}, {
                 $self->{titleField} => $_->{$self->{titleField}},
                 $self->{borrowerField} => $borrower,
                 $self->{lendDateField} => $_->{$self->{lendDateField}}
             };
+            $self->{listModel}->set($self->{listModel}->append,
+                                    0 => $_->{$self->{titleField}},
+                                    1 => $borrower,
+                                    2 => $lendDate,
+                                    3 => $listId,
+                                    4 => $dataId);
         }
         
-        $self->{items}->select(0);
-        $self->{items}->columns_autosize;
-
+        $self->{listView}->columns_autosize;
+        return if $listId == -1;
+        $self->{listView}->get_selection->select_iter($self->{listModel}->get_iter_first);
     }
     
     sub show
     {
         my $self = shift;
 
-        for my $i (0..2)
-        {
-            $self->{items}->get_column($i)->set_sort_indicator(0);
-        }
-        $self->{order} = 1;
-        $self->{sort} = -1;
-
         $self->SUPER::show();
         $self->show_all;
         $self->run;
         $self->hide;
     }
 
+    sub setModel
+    {
+        my ($self, $model) = @_;
+        $self->{titleField} = $model->{commonFields}->{title};
+        $self->{borrowerField} = $model->{commonFields}->{borrower}->{name};
+        $self->{lendDateField} = $model->{commonFields}->{borrower}->{date};
+        $self->{historyField} = $model->{commonFields}->{borrower}->{history};
+ 
+        $self->{titleColumn}->set_title($model->getDisplayedItems);
+    }
+
+    sub displayItem
+    {
+        my ($self, $idx) = @_;
+        $self->{data}->display($idx);
+        $self->{data}->select($idx);
+    }
+
+    sub returnItem
+    {
+        my $self = shift;
+        my $current = $self->{data}->getCurrent;
+        my $iter = $self->{listView}->get_selection->get_selected;
+        my $idx = $self->{listModel}->get($iter, 4);
+        $self->displayItem($idx);
+        if ($self->{data}->{panel}->itemBack)
+        {
+            $self->{listModel}->remove($iter);
+        }
+        $self->displayItem($current);
+        return;
+    }
+
+    sub showHistory
+    {
+        my $self = shift;
+        my $iter = $self->{listView}->get_selection->get_selected;
+        return if !$iter;
+        my $idx = $self->{listModel}->get($iter, 4);
+        $self->{history}->setValue(
+            $self->{data}->getValue($idx, $self->{historyField})
+        );
+    }
+
     sub new
     {
         my ($proto, $parent) = @_;
@@ -511,12 +560,8 @@ use GCUtils;
         
         $self->{parent} = $parent;
 
-        $self->{titleField} = $parent->{model}->{commonFields}->{title};
-        $self->{borrowerField} = $parent->{model}->{commonFields}->{borrower}->{name};
-        $self->{lendDateField} = $parent->{model}->{commonFields}->{borrower}->{date};
- 
         $self->set_modal(1);
-		$self->set_position('center');
+        $self->set_position('center');
         $self->set_default_size(400,400);
 
         $self->{parent} = $parent;
@@ -524,94 +569,94 @@ use GCUtils;
 
         my $hbox = new Gtk2::HBox(0,0);
         
-        $self->{items} = new Gtk2::SimpleList(
-                $parent->{model}->getDisplayedItems => "text",
-                $parent->{lang}->{PanelBorrower} => "text",
-                $parent->{lang}->{BorrowedDate} => "text");
+        $self->{listModel} = new Gtk2::ListStore('Glib::String', 'Glib::String', 'Glib::String',
+                                                 'Glib::Int', 'Glib::Int');
+        $self->{listView} = Gtk2::TreeView->new_with_model($self->{listModel});
+        $self->{listView}->set_rules_hint(1);
+        $self->{listView}->set_headers_clickable(1);
 
-        $self->{items}->set_rules_hint(1);
-        $self->{items}->set_headers_clickable(1);
-        
-        $self->{order} = 1;
-        $self->{sort} = -1;
+        my @columns;
+        push @columns, Gtk2::TreeViewColumn->new_with_attributes('',
+                                                                 Gtk2::CellRendererText->new, 
+                                                                 'text' => 0);
+        push @columns, Gtk2::TreeViewColumn->new_with_attributes($parent->{lang}->{PanelBorrower},
+                                                                 Gtk2::CellRendererText->new, 
+                                                                 'text' => 1);
+        push @columns, Gtk2::TreeViewColumn->new_with_attributes($parent->{lang}->{BorrowedDate},
+                                                                 Gtk2::CellRendererText->new, 
+                                                                 'text' => 2);
+        $self->{titleColumn} = $columns[0];
         for my $i (0..2)
         {
-            $self->{items}->get_column($i)->set_sort_indicator(0);
-            #$self->{items}->get_column($i)->set_resizable(1);
-            $self->{items}->get_column($i)->signal_connect('clicked' => sub {
-                    $self->sort($i);
-                });
+            $columns[$i]->set_resizable(1);
+            $columns[$i]->set_sort_column_id($i);
+            $columns[$i]->set_reorderable(1);
+            $self->{listView}->append_column($columns[$i]);
         }
+        $self->{listModel}->set_sort_func(2, sub {
+            my ($model, $a, $b) = @_;
+            my ($day, $month, $year) = split m/\//, 
+                $self->{itemsList}->[$model->get($a, 3)]->{$self->{lendDateField}};
+            my $dateA = join "_", $year, $month, $day;
+            ($day, $month, $year) = split m/\//, 
+                $self->{itemsList}->[$model->get($b, 3)]->{$self->{lendDateField}};
+            my $dateB = join "_", $year, $month, $day;
+            return $dateA cmp $dateB;
+            
+        });
+
+        $self->{listView}->get_selection->signal_connect ('changed' => sub {
+            $self->showHistory;
+        });
 
         my $scrollPanelList = new Gtk2::ScrolledWindow;
         $scrollPanelList->set_policy ('never', 'automatic');
         $scrollPanelList->set_shadow_type('etched-in');
         $scrollPanelList->set_border_width($GCUtils::margin);
-        $scrollPanelList->add($self->{items});
+        $scrollPanelList->add($self->{listView});
+
+        $self->{context} = new Gtk2::Menu;
+        my $returned = Gtk2::MenuItem->new($parent->{lang}->{PanelReturned});
+        $returned->signal_connect('activate', sub {
+            $self->returnItem;
+        });
+        $self->{context}->append($returned);
+        my $display = Gtk2::MenuItem->new($parent->{lang}->{BorrowedDisplayInPanel});
+        $display->signal_connect('activate', sub {
+            my $iter = $self->{listView}->get_selection->get_selected;
+            my $idx = $self->{listModel}->get($iter, 4);
+            $self->displayItem($idx);
+        });
+        $self->{context}->append($display);
+        $self->{context}->show_all;
+
+        $self->{listView}->signal_connect('button_press_event' => sub {
+            my ($widget, $event) = @_;
+            return 0 if $event->button ne 3;
+            $self->{context}->popup(undef, undef, undef, undef, $event->button, $event->time);
+            return 0;
+        });
+
+        my $historyExpander = new GCExpander($parent->{lang}->{PanelHistory});
+        $historyExpander->setValue($parent->{lang}->{PanelHistory});
+
+        my @labels = ($parent->{lang}->{PanelBorrower},
+                      $parent->{lang}->{PanelLendDate},
+                      $parent->{lang}->{PanelReturnDate});
+        $self->{history} = new GCMultipleList($self, 3, \@labels, 0, 2);
+
+        my $historyBox = new Gtk2::VBox(0,0);
+        $historyBox->set_border_width($GCUtils::margin);
+        $historyBox->pack_start($self->{history}, 1, 1, 0);
+
+        $historyExpander->add($historyBox);
+        $historyExpander->show_all;
 
         $self->vbox->pack_start($scrollPanelList,1,1,0);
+        $self->vbox->pack_start($historyExpander,0,0, $GCUtils::halfMargin);
  
         return $self;
     }
-    
-    sub sort
-    {
-        my ($self, $col) = @_;
-
-        #my @movies = @{$self->{moviesList}};
-
-        for my $i (0..2)
-        {
-            $self->{items}->get_column($i)->set_sort_indicator(0);
-        }
-        
-        if ($self->{sort} == $col)
-        {
-            $self->{order} = 1 - $self->{order}
-        }
-        else
-        {
-            $self->{order} = 1;
-        }
-        
-        my $compare;
-        if ($col < 2)
-        {
-            use locale;
-            $compare = sub {
-                return $a->{$self->{titleField}}
-                   cmp $b->{$self->{titleField}};
-            };
-        }
-        elsif ($col == 1)
-        {
-            use locale;
-            $compare = sub {
-                return $a->{$self->{borrowerField}}
-                   cmp $b->{$self->{borrowerField}};
-            };
-        }
-        else
-        {
-            $compare = sub {
-                my ($day, $month, $year) = split m/\//, $a->{$self->{lendDateField}};
-                my $dateA = join "_", $year, $month, $day;
-                ($day, $month, $year) = split m/\//, $b->{$self->{lendDateField}};
-                my $dateB = join "_", $year, $month, $day;
-                return $dateA cmp $dateB;
-            };
-        }
-
-        @{$self->{moviesList}} = sort $compare @{$self->{moviesList}};
-
-
-        $self->{items}->get_column($col)->set_sort_indicator(1);
-        @{$self->{moviesList}} = reverse @{$self->{moviesList}} if ! $self->{order};
-        $self->{items}->get_column($col)->set_sort_order($self->{order} ? 'ascending' : 'descending');
-        $self->setList($self->{moviesList});
-        $self->{sort} = $col;
-    }
-
 }
 
-1;
\ No newline at end of file
+1;
