@@ -50,8 +50,7 @@ use strict;
     sub setCurrentModel
     {
         my ($self, $model) = @_;
-
-        $self->{parent}->setModel($model);
+        return $self->{parent}->setModel($model);
     }
 
     sub transformTitle
@@ -137,6 +136,7 @@ use strict;
             GCImport::loadImporters;
             foreach (@importersArray)
             {
+                $_->setLangName($options->lang);
                 if ($_->getName =~ /\Q$import/)
                 {
                     $self->{importer} = $_;
@@ -156,6 +156,7 @@ use strict;
             GCExport::loadExporters;
             foreach (@exportersArray)
             {
+                $_->setLangName($options->lang);
                 if ($_->getName eq $export)
                 {
                     $self->{exporter} = $_;
@@ -164,7 +165,6 @@ use strict;
             }
             $self->leave("Export plugin $export doesn't exist") if $export && (!$self->{exporter});
             $self->{exporter}->setModel($self->{model});
-            $self->{exporter}->setLangName($options->lang);
             $self->{exportOptions} = {
                                          lang => $self->{lang}
                                      };
@@ -229,13 +229,14 @@ use strict;
                 $self->{importOptions}->{$_->{name}} = $_->{default};
             }
         }
+        return 1;
     }
     
     sub setFields
     {
         my ($self, $fieldsFile) = @_;
 
-        $self->{fields} = [];        
+        $self->{fields} = [];
         open FIELDS, '<'.$fieldsFile;
         my $model = <FIELDS>;
         chop $model;
@@ -312,6 +313,7 @@ use strict;
     {
         my ($self, $file) = @_;
         $self->{data}->load($file, undef, undef, 1);
+        $self->{original} = $file;
     }
 
     sub import
@@ -332,12 +334,16 @@ use strict;
     {
         my ($self, $prefs) = @_;
 
+        if (!scalar $self->{fields})
+        {
+            $self->{fields} = $self->{model}->{fieldsNames};
+        }
         $self->{exportOptions}->{parent} = $self->{parent};
         $self->{exportOptions}->{fields} = $self->{fields};
         $self->{exportOptions}->{originalList} = $self->{data};
         $self->{exportOptions}->{withPictures} = 1;
         $self->{exportOptions}->{file} = $self->{file};
-        $self->{exportOptions}->{collection} = $self->{file};
+        $self->{exportOptions}->{collection} = $self->{original};
         $self->{exportOptions}->{fieldsInfo} = $self->{model}->{fieldsInfo};
         $self->{exportOptions}->{items} = $self->{data}->getItemsList;
         $self->{exportOptions}->{defaultImage} = $ENV{GCS_SHARE_DIR}.'/logos/no.png';
