@@ -90,7 +90,7 @@ use strict;
 
     sub updateCurrent
     {
-        my ($self, $withSelect) = @_;
+        my ($self, $withSelect, $forced) = @_;
         my $selectedChanged = 0;
         my $filtered = 0;
         return $selectedChanged if $self->{currentItem} == -1;
@@ -133,7 +133,10 @@ use strict;
             $self->{parent}->{menubar}->checkFilter($field);
         }
 
-        $self->{panel}->dataChanged($info);
+        if ($forced)
+        {
+            $previous->{$_} = 'GCS_FORCED' foreach @$forced;
+        }
         if ($changed)
         {
             if ($self->{multipleMode})
@@ -148,6 +151,7 @@ use strict;
                     {
                         $item->{$field} = $info->{$field};
                     }
+                    $self->{panel}->dataChanged($item, 1);
                     $newIdx = $self->{parent}->{itemsView}->changeItem($_, $previous, $item);
                     if ($newIdx != $_)
                     {
@@ -163,6 +167,7 @@ use strict;
             }
             else
             {
+                $self->{panel}->dataChanged($info);
                 my $current = $self->{parent}->{itemsView}->changeCurrent($previous,
                                                                           $info,
                                                                           $self->{currentItem},
@@ -250,7 +255,8 @@ use strict;
         for my $field (@{$self->{model}->{fieldsNotFormatted}})
         {
             $panel->$field($info->{$field});
-            $panel->{$field}->resetChanged;
+            $panel->{$field}->resetChanged
+                if $panel->{$field};
         }
         
         $panel->dataChanged;
@@ -264,6 +270,7 @@ use strict;
         my $number;
         my $multipleMode;
         my $withSelect = 0;
+        my $noUpdate = 0;
         if ($#numbers > 0)
         {
             $multipleMode = 1;
@@ -273,13 +280,17 @@ use strict;
         {
             $multipleMode = 0;
             $number = $numbers[0];
-            $number = 0 if $number == -1;
+            if ($number == -1)
+            {
+                $number = 0;
+                $noUpdate = 1;
+            }
             # We want a selection if user clicked on the same one
             $withSelect = ($number == $self->{currentItem});
         }
         my ($selectedHasChanged, $filtered) = (0, 0);
 
-        if (($self->{currentItem} > -1) && !($self->{hasBeenDeleted}))
+        if ((!$noUpdate) && ($self->{currentItem} > -1) && !($self->{hasBeenDeleted}))
         {
             ($selectedHasChanged, $filtered) = $self->updateCurrent($withSelect);
         }
@@ -326,7 +337,7 @@ use strict;
     sub setValue
     {
         my ($self, $idx, $field, $value) = @_;
-        
+
         ($self->getItemsList)->[$idx]->{$field} = $value;
         if ($idx == $self->{currentItem})
         {
@@ -458,11 +469,7 @@ use strict;
             foreach (@{$self->{model}->{managedImages}})
             {
                 my $image = $self->{itemArray}->[$actualNumber]->{$_};
-                my $imagePrefix = $self->{parent}->{imagePrefix};
-                if ($image =~ /(\/|\\)$imagePrefix[0-9]*\./)
-                {
-                    $self->markToBeRemoved($image);
-                }
+                $self->{parent}->checkPictureToBeRemoved($image);
             }
 
             splice @{$self->{itemArray}}, $actualNumber, 1;
@@ -529,7 +536,6 @@ use strict;
     sub markToBeRemoved
     {
         my ($self, $image) = @_;
-
         push @{$self->{imagesToBeRemoved}}, $image;
     }
 
@@ -592,10 +598,37 @@ use strict;
 
     sub queryReplace
     {
-        my ($self, $field, $old, $new) = @_;
+        my ($self, $field, $old, $new, $caseSensitive) = @_;
         foreach (@{$self->{itemArray}})
         {
-            $_->{$field} =~ s/$old/$new/gi;
+            if (ref($_->{$field}) eq 'ARRAY')
+            {
+                foreach my $subval(@{$_->{$field}})
+                {
+                    foreach my $val(@$subval)
+                    {
+                        if ($caseSensitive)
+                        {
+                            $val =~ s/$old/$new/g;
+                        }
+                        else
+                        {
+                            $val =~ s/$old/$new/gi;
+                        }
+                    }
+                }
+            }
+            else
+            {
+                if ($caseSensitive)
+                {
+                   $_->{$field} =~ s/$old/$new/g;
+                }
+                else
+                {
+                   $_->{$field} =~ s/$old/$new/gi;
+                }
+            }
         }
         $self->displayCurrent;
         $self->reloadList;
@@ -645,7 +678,22 @@ use strict;
         return $self->{loaded}->{information}->{locked};
     }
 
-    my $globalInstance;
+    sub getBackend
+    {
+        my ($self, $file) = @_;
+        $self->{backend} = new GCBackend::GCBeXmlParser($self->{parent})
+           if !$self->{backend};
+        $self->{backend}->setParameters(file => $file,
+                                        version => $self->{parent}->{version});
+        return $self->{backend};
+    }
+
+    sub getVersion
+    {
+        my ($self, $file) = @_;
+        
+        return $self->getBackend($file)->getVersion;
+    }
 
     sub load
     {
@@ -671,14 +719,12 @@ use strict;
         $self->clearList;
         $self->{block} = 0;
         $self->{splash} = $splash;
-
+        my $backend;
         eval
         {
-            $self->{backend} = new GCBackend::GCBeXmlParser($self->{parent});
+            $backend = $self->getBackend($file);
             
-            $self->{backend}->setParameters($file);
-            
-            $self->{loaded} = $self->{backend}->load($splash);
+            $self->{loaded} = $backend->load($splash);
             # We keep a direct access to this one
             $self->{itemArray} = $self->{loaded}->{data};
         };
@@ -805,6 +851,8 @@ use strict;
         $self->addMarkedPictures;
         $self->removeMarkedPictures;
 
+        my $backend = $self->getBackend($self->{options}->file);
+
         # We re-generate histories to give it to backend
         # Deactivated for the moment
 #        if ($self->{panel})
@@ -814,17 +862,12 @@ use strict;
 #            {
 #                $histories{$hfield} = $self->{panel}->{$hfield}->getValues;
 #            }
-#            $self->{backend}->setHistories(\%histories);
+#            $backend->setHistories(\%histories);
 #        }
 
-        $self->{backend} = new GCBackend::GCBeXmlParser($self->{parent})
-            if !$self->{backend};
-
-        $self->{backend}->setParameters($self->{options}->file);
-
-        my $result = $self->{backend}->save($self->{itemArray},
-                                            $self->{loaded}->{information},
-                                            $splash);
+        my $result = $backend->save($self->{itemArray},
+                                    $self->{loaded}->{information},
+                                    $splash);
 
         $self->{parent}->endProgress;
         if ($result->{error})
