@@ -61,6 +61,7 @@ $hasAboutDialog = 0 if $@;
     sub new
     {
         my ($proto, $parent, $title, $okLabel, $extraAfter, @extraButtons) = @_;
+        $title =~ s/_//g;
         my $class = ref($proto) || $proto;
         my @buttons;
         if ((defined $okLabel) && ($okLabel =~ /^gtk-/))
@@ -497,7 +498,7 @@ $hasAboutDialog = 0 if $@;
 
 {
     package GCDateSelectionDialog;
-    use base "Gtk2::Dialog";
+    use base "GCModalDialog";
 
     sub show
     {
@@ -534,13 +535,10 @@ $hasAboutDialog = 0 if $@;
     
     sub new
     {
-        my ($proto, $parent) = @_;
+        my ($proto, $parent, $title) = @_;
         my $class = ref($proto) || $proto;
-        my $self  = $class->SUPER::new($parent->{lang}->{PanelDateSelect},
-                              $parent,
-                              [qw/modal destroy-with-parent/],
-                              @GCDialogs::okCancelButtons
-                              );
+        my $self  = $class->SUPER::new($parent,
+                                       $title || $parent->{lang}->{PanelDateSelect});
 
         $self->{calendar} = new Gtk2::Calendar;
         $self->{calendar}->signal_connect('day-selected-double-click' => sub {
@@ -559,7 +557,12 @@ $hasAboutDialog = 0 if $@;
 
 {
     package GCPropertiesDialog;
-    use base "GCModalDialog";
+
+    use Glib::Object::Subclass
+                Gtk2::Dialog::
+    ;
+    
+    @GCPropertiesDialog::ISA = ('GCModalDialog');
     
     sub checkValues
     {
@@ -632,66 +635,88 @@ $hasAboutDialog = 0 if $@;
 
         $self->{parent} = $parent;
                               
-        my $table = new Gtk2::Table(12,4,0);
+        my $table = new Gtk2::Table(14,4,0);
         $table->set_row_spacings($GCUtils::halfMargin);
         $table->set_col_spacings($GCUtils::halfMargin);
         $table->set_border_width($GCUtils::margin);
 
+        my $line = 0;
 
         my $fileGroupLabel = new GCHeaderLabel($parent->{lang}->{PropertiesFile});
-        $table->attach($fileGroupLabel, 0, 4, 0, 1, 'fill', 'fill', 0, 0);
+        $table->attach($fileGroupLabel, 0, 4, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $line++;
 
         my $fileLabel = new GCLabel($parent->{lang}->{PropertiesFilePath});
         $self->{info}->{file} = new GCShortText;
         $self->{info}->{file}->lock(1);
-        $table->attach($fileLabel, 2, 3, 1, 2, 'fill', 'fill', 0, 0);
-        $table->attach($self->{info}->{file}, 3, 4, 1, 2, ['expand', 'fill'], 'fill', 0, 0);
+        $table->attach($fileLabel, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{info}->{file}, 3, 4, $line, $line + 1, ['expand', 'fill'], 'fill', 0, 0);
+        $line++;
         
         my $itemsLabel = new GCLabel($parent->{lang}->{PropertiesItemsNumber});
         $self->{info}->{items} = new GCShortText;
         $self->{info}->{items}->lock(1);
-        $table->attach($itemsLabel, 2, 3, 2, 3, 'fill', 'fill', 0, 0);
-        $table->attach($self->{info}->{items}, 3, 4, 2, 3, ['expand', 'fill'], 'fill', 0, 0);
+        $table->attach($itemsLabel, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{info}->{items}, 3, 4, $line, $line + 1, ['expand', 'fill'], 'fill', 0, 0);
+        $line++;
         
         my $sizeLabel = new GCLabel($parent->{lang}->{PropertiesFileSize});
         $self->{info}->{size} = new GCShortText;
         $self->{info}->{size}->lock(1);
-        $table->attach($sizeLabel, 2, 3, 3, 4, 'fill', 'fill', 0, 0);
+        $table->attach($sizeLabel, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
         $table->attach($self->{info}->{size}, 3, 4, 3, 4, ['expand', 'fill'], 'fill', 0, 0);
                 
+        $line += 3;
 
         my $collectionGroupLabel = new GCHeaderLabel($parent->{lang}->{PropertiesCollection});
-        $table->attach($collectionGroupLabel, 0, 4, 6, 7, 'fill', 'fill', 0, 0);
+        $table->attach($collectionGroupLabel, 0, 4, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $line++;
 
         my $nameLabel = new GCLabel($parent->{lang}->{PropertiesName});
         $self->{properties}->{name} = new GCShortText;
-        $table->attach($nameLabel, 2, 3, 7, 8, 'fill', 'fill', 0, 0);
-        $table->attach($self->{properties}->{name}, 3, 4, 7, 8, ['expand', 'fill'], 'fill', 0, 0);
+        $table->attach($nameLabel, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{name}, 3, 4, $line, $line + 1, ['expand', 'fill'], 'fill', 0, 0);
+        $line++;
+
+        my $langLabel = new GCLabel($parent->{lang}->{PropertiesLang});
+        $self->{properties}->{lang} = new GCHistoryText;
+        my @langValues;
+        push @langValues, "$_ (".$GCLang::langs{$_}->{LangName}.')'
+            foreach (keys %GCLang::langs);
+        @langValues = sort @langValues;
+        $self->{properties}->{lang}->setValues(\@langValues);
+        $table->attach($langLabel, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{lang}, 3, 4, $line, $line + 1, ['expand', 'fill'], 'fill', 0, 0);
+        $line++;
 
         my $ownerLabel = new GCLabel($parent->{lang}->{PropertiesOwner});
         $self->{properties}->{owner} = new GCShortText;
-        $table->attach($ownerLabel, 2, 3, 8, 9, 'fill', 'fill', 0, 0);
-        $table->attach($self->{properties}->{owner}, 3, 4, 8, 9, ['expand', 'fill'], 'fill', 0, 0);
+        $table->attach($ownerLabel, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{owner}, 3, 4, $line, $line + 1, ['expand', 'fill'], 'fill', 0, 0);
+        $line++;
 
         my $emailLabel = new GCLabel($parent->{lang}->{PropertiesEmail});
         $self->{properties}->{email} = new GCShortText;
-        $table->attach($emailLabel, 2, 3, 9, 10, 'fill', 'fill', 0, 0);
-        $table->attach($self->{properties}->{email}, 3, 4, 9, 10, ['expand', 'fill'], 'fill', 0, 0);
+        $table->attach($emailLabel, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{email}, 3, 4, $line, $line + 1, ['expand', 'fill'], 'fill', 0, 0);
+        $line++;
 
         my $descriptionLabel = new GCLabel($parent->{lang}->{PropertiesDescription});
         $self->{properties}->{description} = new GCLongText;
-        $table->attach($descriptionLabel, 2, 3, 10, 11, 'fill', 'fill', 0, 0);
-        $table->attach($self->{properties}->{description}, 3, 4, 10, 11, ['expand', 'fill'], ['expand', 'fill'], 0, 0);
+        $table->attach($descriptionLabel, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{description}, 3, 4, $line, $line + 1, ['expand', 'fill'], ['expand', 'fill'], 0, 0);
+        $line++;
 
         my $picturesDirLabel = new GCLabel($parent->{lang}->{OptionsImages});
-        $self->{properties}->{images} = new GCFile($self, $parent->{lang}->{OptionsImagesTitle}, 'select-folder');
-        $table->attach($picturesDirLabel, 2, 3, 11, 12, 'fill', 'fill', 0, 0);
-        $table->attach($self->{properties}->{images}, 3, 4, 11, 12, ['expand', 'fill'], ['fill'], 0, 0);
-#
-#        $self->{labelPicturesWorkingDir} = new GCLabel($parent->{lang}->{OptionsPicturesWorkingDir});
-#        $table->attach($self->{labelPicturesWorkingDir}, 2, 4, 12, 13, 'fill', 'fill', 2*$GCUtils::margin, 0);
-#        $self->{labelPicturesFileBase} = new GCLabel($parent->{lang}->{OptionsPicturesFileBase});
-#        $table->attach($self->{labelPicturesFileBase}, 2, 4, 13, 14, 'fill', 'fill', 2*$GCUtils::margin, 0);
+        $self->{properties}->{images} = new GCFile($self, $parent->{lang}->{FileChooserOpenDirectory}, 'select-folder');
+        $table->attach($picturesDirLabel, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{images}, 3, 4, $line, $line + 1, ['expand', 'fill'], ['fill'], 0, 0);
+        $line++;
+
+        my $defaultImageLabel = new GCLabel($parent->{lang}->{PropertiesDefaultPicture});
+        $self->{properties}->{defaultImage} = new GCFile($self, $parent->{lang}->{FileChooserOpenFile}, 'open');
+        $table->attach($defaultImageLabel, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{defaultImage}, 3, 4, $line, $line + 1, ['expand', 'fill'], ['fill'], 0, 0);
 
         $self->vbox->pack_start($table, 1, 1, 5);
         $self->vbox->show_all;
@@ -713,8 +738,9 @@ $hasAboutDialog = 0 if $@;
         $self->show_all;
         my $response = $self->run;
         $self->{field} = $self->{fieldsOption}->getValue;
-        $self->{oldValue} = $self->{old}->get_text;
-        $self->{newValue} = $self->{new}->get_text;
+        $self->{oldValue} = $self->{old}->getValue;
+        $self->{newValue} = $self->{new}->getValue;
+        $self->{caseSensitive} = $self->{useCase}->getValue;
         $self->hide;
         return ($response eq 'ok');
     }
@@ -724,16 +750,28 @@ $hasAboutDialog = 0 if $@;
         my ($self, $model) = @_;
 
         $self->{model} = $model;
-        my @values;
-        foreach (@{$model->{fields}})
-        {
-            my $label = $model->getDisplayedText($_->{label});
-            next if ! $label;
-            push @values, {value => $_->{value}, displayed => $label};
-        }
-		$self->{fieldsOption}->setValues(\@values);
+        $self->{fieldsOption}->setModel($model);
     }
     
+    sub updateFields
+    {
+        my $self = shift;
+
+        $self->{layoutTable}->remove($self->{old});
+        ($self->{old}, undef) = $self->{fieldsOption}->createEntryWidget($self, 'eq', $self->{old});
+        $self->{old}->signal_connect('activate' => sub {$self->response('ok')} )
+            if $self->{old}->isa('GCShortText');
+        $self->{layoutTable}->attach($self->{old}, 1, 2, 1, 2, 'fill', 'expand', 0, 0);
+        $self->{old}->show_all;
+
+        $self->{layoutTable}->remove($self->{new});
+        ($self->{new}, undef) = $self->{fieldsOption}->createEntryWidget($self, 'eq', $self->{new});
+        $self->{new}->signal_connect('activate' => sub {$self->response('ok')} )
+            if $self->{new}->isa('GCShortText');
+        $self->{layoutTable}->attach($self->{new}, 1, 2, 2, 3, 'fill', 'expand', 0, 0);
+        $self->{new}->show_all;
+    }
+
     sub new
     {
         my ($proto, $parent) = @_;
@@ -746,31 +784,42 @@ $hasAboutDialog = 0 if $@;
                                       );
 
         $self->{parent} = $parent;
+
+        # These ones are required for createWidget        
+        $self->{lang} = $parent->{lang};
+        $self->{options} = $parent->{options};
                               
-        my $table = new Gtk2::Table(3,2,0);
-        $table->set_row_spacings(10);
-        $table->set_col_spacings(10);
-        $table->set_border_width(20);
+        $self->{layoutTable} = new Gtk2::Table(4,2,0);
+        $self->{layoutTable}->set_row_spacings($GCUtils::halfMargin);
+        $self->{layoutTable}->set_col_spacings($GCUtils::margin);
+        $self->{layoutTable}->set_border_width($GCUtils::margin);
 
         my $fieldLabel = new Gtk2::Label($parent->{lang}->{QueryReplaceField});
         $fieldLabel->set_alignment(0,0.5);
-        $self->{fieldsOption} = new GCMenuList;
-        $table->attach($fieldLabel, 0, 1, 0, 1, 'fill', 'fill', 0, 0);
-        $table->attach($self->{fieldsOption}, 1, 2, 0, 1, 'fill', 'expand', 0, 0);
+        $self->{fieldsOption} = new GCFieldSelector(0, undef, 0);
+        $self->{fieldsOption}->signal_connect('changed' => sub {
+            $self->updateFields;
+        });
+        $self->{layoutTable}->attach($fieldLabel, 0, 1, 0, 1, 'fill', 'fill', 0, 0);
+        $self->{layoutTable}->attach($self->{fieldsOption}, 1, 2, 0, 1, 'fill', 'expand', 0, 0);
 
         my $oldLabel = new Gtk2::Label($parent->{lang}->{QueryReplaceOld});
         $oldLabel->set_alignment(0,0.5);
-        $self->{old} = new Gtk2::Entry;
-        $table->attach($oldLabel, 0, 1, 1, 2, 'fill', 'fill', 0, 0);
-        $table->attach($self->{old}, 1, 2, 1, 2, 'fill', 'expand', 0, 0);
+
+        $self->{old} = new GCShortText;
+        $self->{layoutTable}->attach($oldLabel, 0, 1, 1, 2, 'fill', 'fill', 0, 0);
+        $self->{layoutTable}->attach($self->{old}, 1, 2, 1, 2, 'fill', 'expand', 0, 0);
                               
         my $newLabel = new Gtk2::Label($parent->{lang}->{QueryReplaceNew});
         $newLabel->set_alignment(0,0.5);
-        $self->{new} = new Gtk2::Entry;
-        $table->attach($newLabel, 0, 1, 2, 3, 'fill', 'fill', 0, 0);
-        $table->attach($self->{new}, 1, 2, 2, 3, 'fill', 'expand', 0, 0);
-        
-        $self->vbox->pack_start($table, 1, 1, 5);
+        $self->{new} = new GCShortText;
+        $self->{layoutTable}->attach($newLabel, 0, 1, 2, 3, 'fill', 'fill', 0, 0);
+        $self->{layoutTable}->attach($self->{new}, 1, 2, 2, 3, 'fill', 'expand', 0, 0);
+
+        $self->{useCase} = new GCCheckBox($parent->{lang}->{AdvancedSearchUseCase});
+        $self->{layoutTable}->attach($self->{useCase}, 0, 2, 3, 4, 'fill', 'fill', 0, 0);
+
+        $self->vbox->pack_start($self->{layoutTable}, 1, 1, 5);
         $self->vbox->show_all;
 
         bless ($self, $class);
@@ -803,7 +852,7 @@ $hasAboutDialog = 0 if $@;
 
         $self->setListData($self->getData);
 
-	    $self->SUPER::show();
+        $self->SUPER::show();
         $self->show_all;
         $self->hideExtra;
         
@@ -817,12 +866,33 @@ $hasAboutDialog = 0 if $@;
         return $response;
     }
     
-    
+    sub compareItems
+    {
+        my ($self, $item1, $item2) = @_;
+        if ($self->{withPixbuf} && (ref $item1 eq 'ARRAY'))
+        {
+            return $item1->[1] cmp $item2->[1];
+        }
+        else
+        {
+            return $item1 cmp $item2;
+        }
+    }
+
     sub moveFromTo
     {
         my ($self, $from, $to) = @_;
         my $fromId = ($self->{$from}->get_selected_indices)[0];
-        my $fromString = $self->{$from.'Array'}->[$fromId];
+        my $fromItem = $self->{$from.'Array'}->[$fromId];
+        my $fromString;
+        if ($self->{withPixbuf})
+        {
+            $fromString = $fromItem->[1];
+        }
+        else
+        {
+            $fromString = $fromItem;
+        }
         return if !$fromString;
         my $toId = ($self->{$to}->get_selected_indices)[0];
         my $toTotal = scalar @{$self->{$to.'Array'}};
@@ -830,17 +900,22 @@ $hasAboutDialog = 0 if $@;
         $toId++ if $toId < $toTotal;
         $toId = 0 if ($toId < 0);
 
-        if (!$self->{permanent}->{$fromString})
+        if (($to eq 'unused') || (!$self->{permanent}->{$fromString}))
         {
             splice(@{$self->{$from}->{data}}, $fromId, 1);
             splice(@{$self->{$from.'Array'}}, $fromId, 1);
         }
-        splice(@{$self->{$to}->{data}}, $toId, 0, $fromString);
-        splice(@{$self->{$to.'Array'}}, $toId, 0, $fromString);
+        if (($to eq 'used') || (!$self->{permanent}->{$fromString}))
+        {
+            splice(@{$self->{$to}->{data}}, $toId, 0, $fromItem);
+            splice(@{$self->{$to.'Array'}}, $toId, 0, $fromItem);
+        }
         
         if ($to eq 'unused')
         {
-            my @tmpSortedArray = sort @{$self->{unusedArray}};
+            my @tmpSortedArray = sort 
+                {$self->compareItems($a, $b)}
+                @{$self->{unusedArray}};
             $self->{unusedArray} = \@tmpSortedArray;
             @{$self->{unused}->{data}} = ();
             my $i = 0;
@@ -848,7 +923,7 @@ $hasAboutDialog = 0 if $@;
             foreach (@tmpSortedArray)
             {
                 $toId = $i if $_ eq $fromString;
-                my @item = [$_];
+                my @item = ($self->{withPixbuf} ? $_ : [$_]);
                 push @{$self->{unused}->{data}}, @item;
                 $i++;
             }
@@ -869,8 +944,14 @@ $hasAboutDialog = 0 if $@;
         @{$self->{used}->{data}} = ();
         foreach (@{$self->{usedArray}})
         {
-            my @item = [$_];
-            push @{$self->{used}->{data}}, @item;
+            if ($self->{withPixbuf})
+            {
+                push @{$self->{used}->{data}}, $_;               
+            }
+            else
+            {
+                push @{$self->{used}->{data}}, [$_];               
+            }
         }
         $self->{used}->select($newId);
     }
@@ -881,16 +962,33 @@ $hasAboutDialog = 0 if $@;
         my $initial = $self->getInitData;
         $self->{initialized} = 1;
         my %tmpMap;
-        $tmpMap{$_} = 1 foreach (@$initial);
+        if ($self->{withPixbuf})
+        {
+            $tmpMap{$_->[1]} = $_ foreach (@$initial);
+        }
+        else
+        {
+            $tmpMap{$_} = 1 foreach (@$initial);
+        }
         $self->{usedArray} = $new;
+        my $label;
         foreach (@$new)
         {
-            delete $tmpMap{$_} if !$self->{permanent}->{$_};
+            my $label = ($self->{withPixbuf} ? $_->[1] : $_);
+            delete $tmpMap{$label} if !$self->{permanent}->{$label};
+        }
+        my @tmpArray = sort {$self->compareItems($a, $b)} keys %tmpMap;
+        if ($self->{withPixbuf})
+        {
+            my @unusedArray = map {$tmpMap{$_}} @tmpArray;
+            $self->{unusedArray} = \@unusedArray;
+        }
+        else
+        {
+            $self->{unusedArray} = \@tmpArray;
         }
-        my @tmpArray = sort keys %tmpMap;
-        $self->{unusedArray} = \@tmpArray;
-        
         @{$self->{unused}->{data}} = ();
+        
         push @{$self->{unused}->{data}}, $_ foreach (@{$self->{unusedArray}});
         @{$self->{used}->{data}} = ();
         push @{$self->{used}->{data}}, $_ foreach (@{$self->{usedArray}});
@@ -916,7 +1014,8 @@ $hasAboutDialog = 0 if $@;
     sub fillList
     {
         my $self = shift;
-        my @array = grep !$self->{permanent}->{$_}, sort @{$self->getInitData};
+        my @array = grep !$self->{permanent}->{$_},
+                         sort {$self->compareItems($a, $b)} @{$self->getInitData};
         $self->setListData(\@array);
     }
 
@@ -934,7 +1033,7 @@ $hasAboutDialog = 0 if $@;
             
     sub new
     {
-        my ($proto, $parent, $title) = @_;
+        my ($proto, $parent, $title, $withPixbuf) = @_;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new($parent, $title);
 
@@ -943,13 +1042,30 @@ $hasAboutDialog = 0 if $@;
         $self->{options} = $parent->{options};
 
         $self->{initialized} = 0;
+        $self->{withPixbuf} = $withPixbuf;
 
         my $hboxMain = new Gtk2::HBox(0,0);
 
-        #list containing unused items
-        $self->{unused} = new Gtk2::SimpleList(
-            $self->getUnusedLabel => "text"
-        );
+        if ($withPixbuf)
+        {
+            $self->{unused} = new Gtk2::SimpleList(
+                '' => 'pixbuf',
+                $self->getUnusedLabel => 'text'
+            );
+            $self->{used} = new Gtk2::SimpleList(
+                '' => 'pixbuf',
+                $self->getUsedLabel => 'text'
+            );
+        }
+        else
+        {
+            $self->{unused} = new Gtk2::SimpleList(
+                $self->getUnusedLabel => "text"
+            );
+            $self->{used} = new Gtk2::SimpleList(
+                $self->getUsedLabel => "text"
+            );
+        }
         $self->{scrollPanelUnused} = new Gtk2::ScrolledWindow;
         $self->{scrollPanelUnused}->set_policy ('never', 'automatic');
         $self->{scrollPanelUnused}->set_shadow_type('etched-in');
@@ -975,10 +1091,6 @@ $hasAboutDialog = 0 if $@;
         $tmpVbox->pack_start($toLeft,0,0,$GCUtils::margin);
         $vboxChange->pack_start($tmpVbox,1,0,0);
         
-        #list containing used items
-        $self->{used} = new Gtk2::SimpleList(
-            $self->getUsedLabel => "text"
-        );
         $self->{scrollPanelUsed} = new Gtk2::ScrolledWindow;
         $self->{scrollPanelUsed}->set_policy ('never', 'automatic');
         $self->{scrollPanelUsed}->set_shadow_type('etched-in');
@@ -1016,14 +1128,12 @@ $hasAboutDialog = 0 if $@;
         $hboxMain->pack_start($self->{vboxRight},0,0,$GCUtils::halfMargin);
         $hboxMain->pack_start(new Gtk2::HBox,0,0,$GCUtils::quarterMargin);
         
-#        $self->{hboxAction} = new Gtk2::HBox(1,0);
-        
         $self->{marginBox} = new Gtk2::VBox;
         $self->vbox->pack_start($self->{marginBox}, 0, 0, $GCUtils::halfMargin);
         $self->vbox->pack_start($hboxMain, 1, 1, 0);
-#        $self->vbox->pack_start($self->{hboxAction}, 0, 0, $GCUtils::halfMargin);
         
-        $self->set_default_size(-1,400);
+        # Without some default size, everything will be shrinked as there are some scrollers
+        $self->set_default_size(200,400);
         $self->{scrollPanelUnused}->set_size_request(150,-1);
         $self->{scrollPanelUsed}->set_size_request(150,-1);
         
@@ -1142,6 +1252,22 @@ $hasAboutDialog = 0 if $@;
         $fileDialog->destroy;
     }
 
+    sub compareItems
+    {
+        my ($self, $item1, $item2) = @_;
+        use locale;
+        my @values1 = split $self->{separator}, $item1;
+        my @values2 = split $self->{separator}, $item2;
+        if ($values1[0] eq $values2[0])
+        {
+            return $values1[1] cmp $values2[1];
+        }
+        else
+        {
+            return $self->{groupsOrder}->{$values1[0]} <=> $self->{groupsOrder}->{$values2[0]};
+        }
+    }
+
     sub new
     {
         my ($proto, $parent, $title, $preList, $isIdList, $ignoreField) = @_;
@@ -1192,20 +1318,27 @@ $hasAboutDialog = 0 if $@;
         $self->{vboxRight}->pack_start($saveButton, 0, 0, $GCUtils::halfMargin);
         
         $self->{fieldNameToId} = {};
+        $self->{groupsOrder} = {};
 
         my $model = $self->{parent}->{parent}->{model};
         if ($model)
         {
             my $groups = $model->getGroups;
+            $self->{separator} = $model->getDisplayedText('Separator');
             while (my ($key, $value) = each %{$model->{fieldsInfo}})
             {
                 next if !$value->{displayed};
                 my $displayed = $groups->{$value->{group}}->{displayed}
-                              . $model->getDisplayedText('Separator')
+                              . $self->{separator}
                               . $value->{displayed};
                 $self->{fieldNameToId}->{$displayed} = $key;
                 $self->{fieldIdToName}->{$key} = $displayed;
             }
+            my $order = 0;
+            foreach (@{$model->{groups}})
+            {
+                $self->{groupsOrder}->{$groups->{$_->{id}}->{displayed}} = $order++;
+            }
             $self->{model} = $model;
         }
         $self->{scrollPanelUnused}->set_size_request(200,-1);
@@ -1254,7 +1387,8 @@ $hasAboutDialog = 0 if $@;
         $self->{parent} = $parent;
         $self->{ignoreFilter} = 1;
         $self->{autoAppend} = 0;
-        eval { my $dialog = new Gtk2::FileChooserDialog($title, $parent, $action) };
+        my $dialog;
+        eval { $dialog = new Gtk2::FileChooserDialog($title, $parent, $action, @GCDialogs::okCancelButtons) };
         if ($@)
         {
             $self->{dialog}  = new Gtk2::FileSelection($title);
@@ -1277,7 +1411,13 @@ $hasAboutDialog = 0 if $@;
         }
         else
         {
-            $self->{dialog} = new Gtk2::FileChooserDialog($title, $parent, $action, @GCDialogs::okCancelButtons);
+            $self->{dialog} = $dialog;
+            if ($action eq 'save')
+            {
+                $self->{requireOverwriteConfirmation} = 0;
+                eval { $dialog->set_do_overwrite_confirmation(1) };
+                $self->{requireOverwriteConfirmation} = 1 if $@;
+            }
             $self->{type} = 'new';
             if ($withFilter)
             {
@@ -1294,11 +1434,18 @@ $hasAboutDialog = 0 if $@;
                     $self->{filters} = [];
                 }
             }
+            $self->{dialog}->set_default_response ('ok');
         }
         bless ($self, $class);
         return $self;
     }
 
+    sub setTitle
+    {
+        my ($self, $title) = @_;
+        $self->{dialog}->set_title($title);
+    }
+
     sub transformFilename
     {
         my ($self, $file) = @_;
@@ -1347,6 +1494,7 @@ $hasAboutDialog = 0 if $@;
         $file =~ s/\//\\/g if ($^O =~ /win32/i);
         $file = Cwd::realpath($file)
             if -e $file;
+        $empty = 1 if $file eq '';
         eval {
             $self->{dialog}->set_filename($file) if (!$empty && !(-d $file));
             $self->{dialog}->set_current_folder($file.'/')
@@ -1387,7 +1535,9 @@ $hasAboutDialog = 0 if $@;
     sub run
     {
         my $self = shift;
-        return $self->{dialog}->run if ($self->{action} ne 'save');
+        return $self->{dialog}->run if ($self->{action} ne 'save')
+                                    || (($self->{action} eq 'save')
+                                     && (!$self->{requireOverwriteConfirmation}));
         my $response;
         while (1)
         {
@@ -1400,7 +1550,7 @@ $hasAboutDialog = 0 if $@;
                                                        [qw/modal destroy-with-parent/],
                                                        'question',
                                                        'yes-no',
-                                                       $self->{parent}->{lang}->{FileOverwrite});
+                                                       $self->{parent}->{lang}->{FileChooserOverwrite});
 
                 $dialog->set_position('center-on-parent');
                 my $overwrite = $dialog->run;
@@ -1426,7 +1576,7 @@ $hasAboutDialog = 0 if $@;
 
         if ($value)
         {
-            $self->{preview} = new GCItemImage($self->{parent}->{options}, $self->{parent}->{defaultImage},1);
+            $self->{preview} = new GCItemImage($self->{parent}->{options}, $self->{parent},1);
             $self->{preview}->setImmediate;
             if ($self->{type} eq 'new')
             {
@@ -1495,9 +1645,10 @@ $hasAboutDialog = 0 if $@;
     {
         my ($proto, $parent, $title, @extraButtons) = @_;
         my $class = ref($proto) || $proto;
-        my $self = $class->SUPER::new($parent, 'GCstar - '.$title, '', 1, @extraButtons);
+        my $self = $class->SUPER::new($parent, '', '', 1, @extraButtons);
         bless ($self, $class);
         
+        $self->set_position('none');
         my $options = new GCOptionLoader;
         #$options->lockPanel(0);
         $options->file($parent->{options}->file);
@@ -1524,9 +1675,16 @@ $hasAboutDialog = 0 if $@;
         $self->{panel}->disableAutoUpdate;
 
         $self->set_default_size($parent->{options}->itemWindowWidth,$parent->{options}->itemWindowHeight);
-        
+        $self->setTitle($title);
         return $self;
     }
+
+    sub setTitle
+    {
+        my ($self, $title) = @_;
+        $self->set_title($title.' - GCstar');
+    }
+
 }
 
 {
