@@ -28,6 +28,9 @@ use GCUtils;
 {
     package GCFilterSearch;
 
+    # Used to remove diacritics in test
+    use Unicode::Normalize 'NFKD';
+
     sub compareExact
     {
         my ($field, $value) = @_;
@@ -37,7 +40,19 @@ use GCUtils;
     sub compareContain
     {
         my ($field, $value) = @_;
-        return $field =~ m/$value/i;
+        return $field =~ m/\Q$value\E/;
+    }
+
+    sub compareNotContain
+    {
+        my ($field, $value) = @_;
+        return $field !~ m/\Q$value\E/;
+    }
+
+    sub compareRegexp
+    {
+        my ($field, $value) = @_;
+        return $field =~ m/$value/;
     }
 
     sub compareLessStrings
@@ -120,6 +135,8 @@ use GCUtils;
         $self->{info} = $info if $info;
         $self->clear if !$info;
         $self->setMode;
+        $self->setCase(0);
+        $self->setIgnoreDiacritics(0);
         return $self;
     }
 
@@ -130,8 +147,9 @@ use GCUtils;
         $self->{cleared} = 1;
 
         $self->{info} = {};
+        $self->{currentSearch} = [];
     }
-    
+
     sub getComparisonFunction
     {
         my ($self, $type) = @_;
@@ -145,6 +163,10 @@ use GCUtils;
         {
             return \&compareContain;
         }
+        elsif ($comparison eq 'notcontain')
+        {
+            return \&compareNotContain;
+        }
         elsif ($comparison eq 'lt')
         {
             return \&compareLessStrings if ($numeric ne 'true');
@@ -170,6 +192,10 @@ use GCUtils;
             return \&compareRangeStrings if ($numeric ne 'true');
             return \&compareRangeNumbers if ($numeric eq 'true');
         }
+        elsif ($comparison eq 'regexp')
+        {
+            return \&compareRegexp;
+        }
     }
     
     sub setFilter
@@ -213,6 +239,11 @@ use GCUtils;
             {
                 $self->{info}->{$filter} = [$info];
             }
+            push @{$self->{currentSearch}}, {
+                field  => $filter,
+                value  => $value,
+                filter => $type
+            };
         }
     }
     
@@ -274,13 +305,34 @@ use GCUtils;
                         $value = $preProcess->($value);
                     };
                 }
-                if ($testAnd)
+                my $reference;
+
+                if ($self->{ignoreDiacritics})
                 {
-                    return 0 if ! $filter->{comp}->($value, $filter->{value});
+                    # Transform diacritics into single characters
+                    # e.g. é -> e; ç -> c
+                    # First it normalizes the string to have 2 characters
+                    # instead of only one. And then it removes the modifiers
+                    ($reference = NFKD($filter->{value})) =~ s/\pm//g;
+                    ($value = NFKD($value)) =~ s/\pm//g;
                 }
                 else
                 {
-                    return 1 if $filter->{comp}->($value, $filter->{value});
+                    $reference = $filter->{value};
+                }
+                if (!$self->{case})
+                {
+                    $reference = uc $reference;
+                    $value = uc $value;
+                }
+
+                if ($testAnd)
+                {
+                    return 0 if ! $filter->{comp}->($value, $reference);
+                }
+                else
+                {
+                    return 1 if $filter->{comp}->($value, $reference);
                 }
             }
         }
@@ -295,7 +347,28 @@ use GCUtils;
         #*test = \&testOr if $mode eq 'or';
         $self->{mode} = $mode;
     }
-    
+
+    sub setCase
+    {
+        my ($self, $case) = @_;
+        $self->{case} = $case;
+    }
+
+    sub setIgnoreDiacritics
+    {
+        my ($self, $id) = @_;
+        $self->{ignoreDiacritics} = $id;
+    }
+
+    sub getCurrentSearch
+    {
+        my $self = shift;
+        return {mode => $self->{mode},
+                info => $self->{currentSearch},
+                case => $self->{case},
+                ignoreDiacritics => $self->{ignoreDiacritics}};
+    }
+
     sub isEmpty
     {
         my $self = shift;
@@ -380,8 +453,14 @@ use Gtk2;
 
                 $self->{search} = \%info;
             }
-            $ended = 1 if ($response eq 'ok') || ($response eq 'cancel') || ($response eq 'delete-event');
-            $self->clear if ($response eq 'reject');
+            if (($response eq 'ok') || ($response eq 'cancel') || ($response eq 'delete-event'))
+            {
+                $ended = 1
+            }
+            elsif ($response eq 'reject')
+            {
+                $self->clear;
+            }
         }
         $self->hide;
     }
@@ -404,17 +483,35 @@ use Gtk2;
     
     sub new
     {
-        my ($proto, $parent) = @_;
+        my ($proto, $parent, $specialOK, @extraButtons) = @_;
         my $class = ref($proto) || $proto;
-        my $self  = $class->SUPER::new($parent,
+        my $self;
+        if ($specialOK)
+        {
+            $self = $class->SUPER::new($parent,
+                                       $parent->{lang}->{SearchTitle},
+                                       $specialOK,
+                                      );
+        }
+        else
+        {
+            $self = $class->SUPER::new($parent,
                                        $parent->{lang}->{SearchTitle},
                                        'gtk-find',
                                        0,
+                                       @extraButtons,
                                        'gtk-clear' => 'reject',
                                       );
+        }
         bless ($self, $class);
         $self->set_position('center-on-parent');
         $self->{parent} = $parent;
+
+        # These ones are required for createWidget
+        $self->{lang} = $parent->{lang};
+        $self->{options} = $parent->{options};
+        $self->{window} = $self;
+
         $self->{comparisonConvertor} = new GCComparisonSelector($parent);
         $self->{layoutTable} = new Gtk2::Table(1,3,0);
         $self->{layoutTable}->set_row_spacings($GCUtils::halfMargin);
@@ -425,100 +522,6 @@ use Gtk2;
         return $self;
     }
     
-    sub createWidget
-    {
-        my ($self, $info, $comparison) = @_;
-        my $widget;
-        my $withComparisonLabel = 1;
-
-        if ($info->{type} eq 'short text')
-        {
-            if ($comparison eq 'range')
-            {
-                $widget = new GCRange('text', $self->{parent}->{lang});
-                $widget->setWidth(16);
-                $withComparisonLabel = 0;
-            }
-            else
-            {
-                $widget = new GCShortText;
-            }
-            $widget->signal_connect('activate' => sub {$self->response('ok')} );
-        }
-        elsif ($info->{type} eq 'number')
-        {
-            #If we want to have values that are less to the specified one,
-            #we use max as default to be sure everything will be returned
-            #in that case.
-            my $default = $info->{min};
-            $default = $info->{max}
-                if $comparison =~ /^l/;
-            if (exists $info->{min})
-            {
-                if ($comparison eq 'range')
-                {
-                    $widget = new GCRange('number',
-                                          $self->{parent}->{lang},
-                                          $info->{min},
-                                          $info->{max},
-                                          $info->{step});
-                    $widget->setWidth(16);
-                    $withComparisonLabel = 0;
-                }
-                else
-                {
-                    $widget = new GCNumeric($default,
-                                            $info->{min},
-                                            $info->{max},
-                                            $info->{step});
-                }
-            }
-            else
-            {
-                if ($comparison eq 'range')
-                {
-                    $widget = new GCRange('numeric text', $self->{parent}->{lang});
-                    $widget->setWidth(16);
-                    $withComparisonLabel = 0;
-                }
-                else
-                {
-                    $widget = new GCCheckedText('0-9.');
-                }
-            }
-        }
-        elsif ($info->{type} eq 'checked text')
-        {
-            $widget = new GCCheckedText($info->{format});
-        }
-        elsif (($info->{type} eq 'history text')
-            || (($info->{type} =~ /list/)
-             && ($info->{history} ne 'false')))
-        {
-            $widget = new GCHistoryText;
-        }
-        elsif ($info->{type} eq 'options')
-        {
-            $widget = new GCMenuList;
-            $widget->setValues($self->{model}->getValues($info->{values}), $info->{separator});
-        }
-        elsif ($info->{type} eq 'yesno')
-        {
-            $widget = new GCCheckBoxWithIgnore($self->{parent});
-            $withComparisonLabel = 0;
-        }
-        elsif ($info->{type} eq 'date')
-        {
-            $widget = new GCDate($self, $self->{parent}->{lang}, 1);
-        }
-        else
-        {
-            $widget = new GCShortText;
-        }
-        
-        return ($widget, $withComparisonLabel);
-    }
-    
     sub setModel
     {
         my ($self, $model) = @_;
@@ -559,8 +562,10 @@ use Gtk2;
                     $self->{layoutTable}->attach($label, 0, 1, $row, $row + 1, 'fill', 'fill', 2 * $GCUtils::margin, 0);
 
                     ($self->{$field}, $withComparisonLabel) = 
-                        $self->createWidget($fieldsInfo->{$field},
-                                            $filter->{comparison});
+                        GCGraphicComponents::createWidget($self, $fieldsInfo->{$field},
+                                                          $filter->{comparison});
+                    $self->{$field}->signal_connect('activate' => sub {$self->response('ok')} )
+                        if $self->{$field}->isa('GCShortText');
                     if ($withComparisonLabel
                     && ($filter->{comparison} ne 'eq'))
                     {
@@ -597,16 +602,20 @@ use Gtk2;
         $self->{layoutTable}->resize($self->{nbFields} + 1, 3);
         my $field = new GCFieldSelector(0, $self->{model}, 0, 1);
         $field->{number} = $self->{nbFields};
-        $field->signal_connect('changed' => sub {
-            my $fs = shift;
-            $self->updateField($fs->{number}, $fs->getValue);
-        });
         push @{$self->{fields}}, $field;
         $self->{layoutTable}->attach($field, 0, 1, $self->{nbFields}, $self->{nbFields}+1,
                                      ['expand', 'fill'], 'fill', 0, 0);
         $field->show_all;
 
         my $comp = new GCComparisonSelector($self->{parent});
+        $field->signal_connect('changed' => sub {
+            my ($fs, $cs) = @_;
+            $self->updateField($fs, $cs->getValue);
+        }, $comp);
+        $comp->signal_connect('changed' => sub {
+            my ($cs, $fs) = @_;
+            $self->updateField($fs, $cs->getValue);
+        }, $field);
         push @{$self->{comps}}, $comp;
         $self->{layoutTable}->attach($comp, 1, 2, $self->{nbFields}, $self->{nbFields}+1,
                                      ['expand', 'fill'], 'fill', 0, 0);
@@ -631,6 +640,46 @@ use Gtk2;
         $self->{remove}->set_sensitive(0) if $self->{nbFields} < 2;
     }
 
+    sub generateSearch
+    {
+        my $self = shift;
+        my @info;
+        my $i = 0;
+        foreach (@{$self->{fields}})
+        {
+            my $field = $_->getValue;
+            next if !$field;
+            push @info, {
+                field => $field,
+                value => $self->{values}->[$i]->getValue,
+                filter => [$self->{comps}->[$i]->getValue,
+                           $self->{model}->{fieldsInfo}->{$field}->{type} eq 'number',
+                           undef]
+            }
+                if ! $self->{values}->[$i]->isEmpty;
+            $i++;
+        }
+        $self->{search} = \@info;        
+    }
+
+    sub initSearch
+    {
+        my ($self, $filter) = @_;
+        $self->{testAnd}->set_active(($filter->{mode} eq 'and') ? 1 : 0);
+        $self->{useCase}->set_active($filter->{case});
+        $self->{ignoreDiacritics}->set_active($filter->{ignoreDiacritics});
+        $self->removeItem while $self->{nbFields} > 1;
+        my $first = 1;
+        foreach my $line(@{$filter->{info}})
+        {
+            $self->addItem if !$first;
+            $first = 0;
+            $self->{fields}->[-1]->setValue($line->{field});
+            $self->{comps}->[-1]->setValue($line->{filter}->[0]);
+            $self->{values}->[-1]->setValue($line->{value});
+        }
+    }
+
     sub show
     {
         my $self = shift;
@@ -643,25 +692,22 @@ use Gtk2;
             my $response = $self->run;
             if ($response eq 'ok')
             {
-                my @info;
-                my $i = 0;
-                foreach (@{$self->{fields}})
+                if ($self->{userFilter})
                 {
-                    my $field = $_->getValue;
-                    push @info, {
-                        field => $field,
-                        value => $self->{values}->[$i]->getValue,
-                        filter => [$self->{comps}->[$i]->getValue,
-                                   $self->{model}->{fieldsInfo}->{$field}->{type} eq 'number',
-                                   undef]
-                    }
-                        if ! $self->{values}->[$i]->isEmpty;
-                    $i++;
+                    $self->saveSearch;
                 }
-                $self->{search} = \@info;
+                else
+                {
+                    $self->generateSearch;
+                }
+            }
+            else
+            {
+                $self->{search} = undef;
             }
             $ended = 1 if ($response eq 'ok') || ($response eq 'cancel') || ($response eq 'delete-event');
             $self->clear if ($response eq 'reject');
+            $self->saveSearch if ($response eq 'accept');
         }
         $self->hide;
     }
@@ -669,21 +715,108 @@ use Gtk2;
     sub getMode
     {
         my $self = shift;
-        
         return ($self->{testAnd}->get_active ? 'and' : 'or');
     }
 
+    sub getCase
+    {
+        my $self = shift;
+        return ($self->{useCase}->get_active ? 1 : 0);
+    }
+
+    sub getIgnoreDiacritics
+    {
+        my $self = shift;
+        return ($self->{ignoreDiacritics}->get_active ? 1 : 0);
+    }
+
+    sub saveSearch
+    {
+        my $self = shift;
+        
+        my $response;
+        my $name;
+        if ($self->{userFilter} eq 'edit')
+        {
+            $response = 'ok';
+            $name = '';
+        }
+        else
+        {
+            my $dialog = new Gtk2::Dialog($self->{parent}->{lang}->{AdvancedSearchSaveTitle},
+                                          $self,
+                                          [qw/modal destroy-with-parent/],
+                                          @GCDialogs::okCancelButtons
+                                          );
+    
+            my $hbox = Gtk2::HBox->new(0, $GCUtils::halfMargin);
+            my $label = Gtk2::Label->new($self->{parent}->{lang}->{AdvancedSearchSaveName});
+            $hbox->pack_start($label, 0, 0, 0);
+            my $entry = Gtk2::Entry->new;
+            $hbox->pack_start($entry, 1, 1, 0);
+            $hbox->show_all;
+            $dialog->vbox->pack_start($hbox, 1, 1, $GCUtils::margin);
+            $dialog->set_default_response('ok');
+            $entry->set_activates_default(1);
+            while (1)
+            {
+                $response = $dialog->run;
+                if ($response eq 'ok')
+                {
+                    $name = $entry->get_text;
+                    if ($self->{model}->existsUserFilter($name))
+                    {
+                        my $errorDialog = Gtk2::MessageDialog->new($self,
+                           [qw/modal destroy-with-parent/],
+                           'error',
+                           'ok',
+                           $self->{parent}->{lang}->{AdvancedSearchSaveOverwrite});
+                           $dialog->set_position('center-on-parent');
+                        $errorDialog->run;
+                        $errorDialog->destroy;
+                        next;
+                    }
+                    last;
+                }
+                last;
+            }
+            $dialog->destroy;
+        }
+
+        if ($response eq 'ok')
+        {
+            $self->generateSearch;
+            my $info = {
+                'name' => $name,
+                'mode' => $self->getMode,
+                'case' => $self->getCase,
+                'ignoreDiacritics' => $self->getIgnoreDiacritics,
+                'info' => $self->{search}
+            };
+            $self->{parent}->addUserFilter($info);
+        }
+    }
+
     sub new
     {
-        my ($proto, $parent) = @_;
+        my ($proto, $parent, $userFilter) = @_;
         my $class = ref($proto) || $proto;
-        my $self  = $class->SUPER::new($parent);
+        my $self;
+        if ($userFilter)
+        {
+            $self = $class->SUPER::new($parent, 'gtk-save');
+        }
+        else
+        {
+            $self = $class->SUPER::new($parent, undef, 'gtk-save' => 'accept',);
+        }
         bless ($self, $class);
 
         $self->{parent} = $parent;
+        $self->{userFilter} = $userFilter;
         $self->vbox->remove($self->{layoutTable});
 
-        my $allTable = new Gtk2::Table(7,3,0);
+        my $allTable = new Gtk2::Table(11,3,0);
         $allTable->set_row_spacings($GCUtils::halfMargin);
         $allTable->set_col_spacings($GCUtils::margin);
         $allTable->set_border_width($GCUtils::margin);
@@ -692,9 +825,20 @@ use Gtk2;
         $self->{testAnd} = new Gtk2::RadioButton(undef, $parent->{lang}->{AdvancedSearchTypeAnd});
         $self->{testOr} = new Gtk2::RadioButton($self->{testAnd}->get_group, $parent->{lang}->{AdvancedSearchTypeOr});
 
-        $allTable->attach($labelType, 0, 3, 0, 1, 'fill', 'fill', 0, 0);
-        $allTable->attach($self->{testAnd}, 2, 3, 1, 2, 'fill', 'fill', 0, 0);
-        $allTable->attach($self->{testOr}, 2, 3, 2, 3, 'fill', 'fill', 0, 0);
+        my $prefStock = Gtk2::Stock->lookup('gtk-preferences');
+        (my $prefLabel = $prefStock->{label}) =~ s/_//;
+        my $labelPreferences = new GCHeaderLabel($prefLabel);
+        $self->{useCase} = new GCCheckBox($parent->{lang}->{AdvancedSearchUseCase});
+        $self->{ignoreDiacritics} = new GCCheckBox($parent->{lang}->{AdvancedSearchIgnoreDiacritics});
+
+        my $offset1 = 0;
+        $offset1 = 4;
+        $allTable->attach($labelType, 0, 3, $offset1 + 0, $offset1 + 1, 'fill', 'fill', 0, 0);
+        $allTable->attach($self->{testAnd}, 2, 3, $offset1 + 1, $offset1 + 2, 'fill', 'fill', 0, 0);
+        $allTable->attach($self->{testOr}, 2, 3, $offset1 + 2, $offset1 + 3, 'fill', 'fill', 0, 0);
+        $allTable->attach($labelPreferences, 0, 3, $offset1 + 4, $offset1 + 5, 'fill', 'fill', 0, 0);
+        $allTable->attach($self->{useCase}, 2, 3, $offset1 + 5, $offset1 + 6, 'fill', 'fill', 0, 0);
+        $allTable->attach($self->{ignoreDiacritics}, 2, 3, $offset1 + 6, $offset1 + 7, 'fill', 'fill', 0, 0);
 
         my $labelCriteria = new GCHeaderLabel($parent->{lang}->{AdvancedSearchCriteria});
         my $scrolled = new Gtk2::ScrolledWindow;
@@ -703,8 +847,10 @@ use Gtk2;
         $scrolled->set_shadow_type('none');
         $scrolled->add_with_viewport($self->{layoutTable});
 
-        $allTable->attach($labelCriteria, 0, 3, 4, 5, 'fill', 'fill', 0, 0);
-        $allTable->attach($scrolled, 2, 3, 5, 6, ['expand', 'fill'], ['expand', 'fill'], 0, 0);
+        my $offset2 = 8;
+        $offset2 = 0;
+        $allTable->attach($labelCriteria, 0, 3, $offset2 + 0, $offset2 + 1, 'fill', 'fill', 0, 0);
+        $allTable->attach($scrolled, 2, 3, $offset2 + 1, $offset2 + 2, ['expand', 'fill'], ['expand', 'fill'], 0, 0);
 
         my $hboxAction = new Gtk2::HBox(0,0);
         $self->{add} = Gtk2::Button->new_from_stock('gtk-add');
@@ -717,12 +863,19 @@ use Gtk2;
             $self->removeItem;
         });
         $hboxAction->pack_start($self->{remove}, 0, 0, $GCUtils::margin);
-        $allTable->attach($hboxAction, 2, 3, 6, 7, 'fill', 'fill', 0, 0);
+#        if (!$userFilter)
+#        {
+#            $self->{save} = Gtk2::Button->new_from_stock('gtk-save');
+#            $self->{save}->signal_connect('clicked' => sub {
+#                $self->saveSearch;
+#            });
+#            $hboxAction->pack_end($self->{save}, 0, 0, 0);
+#        }
+        $allTable->attach($hboxAction, 2, 3, $offset2 + 2, $offset2 + 3, 'fill', 'fill', 0, 0);
 
         $self->vbox->pack_start($allTable,1,1,0);
-        #$self->vbox->pack_start(Gtk2::HBox->new(0,0), 0, 0, $GCUtils::halfMargin);
         
-        $self->set_size_request(-1, 400);
+        $self->set_size_request(-1, 450);
         return $self;
     }
     
@@ -753,53 +906,197 @@ use Gtk2;
 
     sub updateField
     {
-        my ($self, $idx, $field) = @_;
+        my ($self, $fs, $comparison) = @_;
+        my $idx = $fs->{number};
         my $widget = $self->{values}->[$idx];
         $self->{layoutTable}->remove($widget);
-        $widget->destroy;
 
         my $newWidget;
-        my $info = $self->{model}->{fieldsInfo}->{$field};
-        ($newWidget, undef) = $self->createWidget($info);
-#        my $type = $self->{model}->{fieldsInfo}->{$field}->{type};
-#        if ($type eq 'history text')
-#        {
-#            $newWidget = new GCHistoryText;
-#            $newWidget->setValues($self->{parent}->{panel}->getValues($field));
-#        }
-#        elsif  ($type eq 'single list')
-#        {
-#            $newWidget = new GCHistoryText;
-#            $newWidget->setValues($self->{parent}->{panel}->getValues($field)->[0]);            
-#        }
-#        elsif ($type eq 'number')
-#        {
-#            $newWidget = new GCCheckedText('0-9.');
-#        }
-#        elsif ($type eq 'date')
-#        {
-#            $newWidget = new GCDate($self, $self->{parent}->{lang}, 1);
-#            $newWidget->setFormat($self->{parent}->{options}->dateFormat)
-#                if $self->{parent}->{options}->dateFormat;
-#        }
-#        else
-#        {
-#            $newWidget = new GCShortText;
-#        }
+        ($newWidget, undef) = $fs->createEntryWidget($self, $comparison, $widget);
+        $newWidget->signal_connect('activate' => sub {$self->response('ok')} )
+            if $newWidget->isa('GCShortText');
 
-        if ($info->{type} eq 'history text')
-        {
-            $newWidget->setValues($self->{parent}->{panel}->getValues($field));
-        }
-        elsif ($info->{type} eq 'single list')
-        {
-            $newWidget->setValues($self->{parent}->{panel}->getValues($field)->[0]);            
-        }
+         $self->{values}->[$idx] = $newWidget;
+         $self->{layoutTable}->attach($newWidget, 2, 3, $idx, $idx+1,
+                                      ['expand', 'fill'], 'fill', 0, 0);
+         $newWidget->show_all;
+    }
+}
 
-        $self->{values}->[$idx] = $newWidget;
-        $self->{layoutTable}->attach($newWidget, 2, 3, $idx, $idx+1,
-                                     ['expand', 'fill'], 'fill', 0, 0);
-        $newWidget->show_all;
+{
+    package GCUserFiltersDialog;
+    
+    use GCGraphicComponents;
+    use Storable;
+    use base 'GCModalDialog';
+
+    sub setModel
+    {
+        my ($self, $model) = @_;
+        $self->{model} = $model;
+        $self->{filters} = Storable::dclone($model->getUserFilters);
+        $self->initList(1);
+        $self->{deletedFilters} = [];
+    }
+
+    sub initList
+    {
+        my ($self, $saved) = shift;
+        @{$self->{filtersList}->{data}} = ();
+        $self->{initializing} = 1;
+        $self->{filters} = $self->getUserFilters;
+        #my @sorted = sort {uc($a->{name}) cmp uc($b->{name})} @{$self->{filters}};
+        #$self->{filters} = \@sorted;
+        foreach(@{$self->{filters}})
+        {
+            push @{$self->{filtersList}->{data}}, $_->{name};
+            # All of them should be already saved
+            $_->{saved} = 1 if $saved;
+        }
+        $self->{initializing} = 0;
+    }
+
+    sub getUserFilters
+    {
+        my $self = shift;
+        my @sorted = sort {uc($a->{name}) cmp uc($b->{name})} @{$self->{filters}};
+        return \@sorted;
+        return $self->{filters};
+    }
+
+    sub getDeletedFilters
+    {
+        my $self = shift;
+        return $self->{deletedFilters};
+    }
+
+    sub show
+    {
+        my $self = shift;
+
+        $self->SUPER::show();
+        $self->show_all;
+        my $response = $self->run;
+        $self->hide;
+        return ($response eq 'ok');
+    }
+
+    # Callbacked by advanced search dialog
+    sub addUserFilter
+    {
+        my ($self, $filter) = @_;
+        $filter->{saved} = 0;
+        if ($self->{mode} eq 'new')
+        {
+            push (@{$self->{filters}}, $filter);
+            push @{$self->{filtersList}->{data}}, $filter->{name};
+        }
+        else
+        {
+            my $selected = ($self->{filtersList}->get_selected_indices)[0];
+            $filter->{name} = $self->{filters}->[$selected]->{name};
+            $self->{filters}->[$selected] = $filter;
+        }
+    }
+
+    sub newFilter
+    {
+        my $self = shift;
+        $self->{mode} = 'new';
+        $self->{panel} = $self->{parent}->{panel};
+        my $dialog = new GCAdvancedSearchDialog($self, $self->{mode});
+        $dialog->setModel($self->{model});
+        $dialog->show;
+        # To avoid unwanted reference if the panel is changed
+        delete $self->{panel};
+    }
+
+    sub editFilter
+    {
+        my $self = shift;
+        $self->{mode} = 'edit';
+        my $selected = ($self->{filtersList}->get_selected_indices)[0];
+        $self->{panel} = $self->{parent}->{panel};
+        my $dialog = new GCAdvancedSearchDialog($self, $self->{mode});
+        $dialog->setModel($self->{model});
+        $dialog->initSearch($self->{filters}->[$selected]);
+        $dialog->show;
+        # To avoid unwanted reference if the panel is changed
+        delete $self->{panel};
+    }
+
+    sub deleteFilter
+    {
+        my $self = shift;
+        my $selected = ($self->{filtersList}->get_selected_indices)[0];
+        push @{$self->{deletedFilters}}, $self->{filters}->[$selected]->{name};
+        splice @{$self->{filters}}, $selected, 1;
+        splice (@{$self->{filtersList}->{data}}, $selected, 1);
+        $self->{filtersList}->select(0);
+    }
+    
+    sub renameFilter
+    {
+        my $self = shift;
+        my $selected = ($self->{filtersList}->get_selected_indices)[0];
+        my $oldName = $self->{filters}->[$selected]->{name};
+        my $newName = $self->{filtersList}->{data}->[$selected]->[0];
+        return if $newName eq $oldName;
+        $self->{filters}->[$selected]->{name} = $newName;
+        $self->{filters}->[$selected]->{saved} = 0;
+        push @{$self->{deletedFilters}}, $oldName;
+        $self->initList(0);
+    }
+
+    sub new
+    {
+        my ($proto, $parent) = @_;
+        my $class = ref($proto) || $proto;
+        my $self  = $class->SUPER::new($parent,
+                                       $parent->{lang}->{MenuSavedSearchesEdit});
+        bless ($self, $class);
+        $self->set_position('center-on-parent');
+        $self->{parent} = $parent;
+        $self->{lang} = $parent->{lang};
+        my $hBox = new Gtk2::HBox(0,0);
+        $hBox->set_border_width($GCUtils::margin);
+        my $buttonBox = new Gtk2::VBox(0,0);
+        
+        my $editButton = new Gtk2::Button->new_from_stock('gtk-edit');
+        $editButton->signal_connect('clicked' => sub {
+            $self->editFilter;
+        });
+        my $newButton = new Gtk2::Button->new_from_stock('gtk-new');
+        $newButton->signal_connect('clicked' => sub {
+            $self->newFilter;
+        });
+        my $deleteButton = new Gtk2::Button->new_from_stock('gtk-delete');
+        $deleteButton->signal_connect('clicked' => sub {
+            $self->deleteFilter;
+        });
+
+        $buttonBox->pack_start($newButton, 0, 0, $GCUtils::halfMargin);
+        $buttonBox->pack_start($deleteButton, 0, 0, $GCUtils::halfMargin);
+        $buttonBox->pack_start($editButton, 0, 0, $GCUtils::halfMargin);
+
+        $self->{filtersList} = new Gtk2::SimpleList($parent->{lang}->{MenuSavedSearches} => 'text');
+        $self->{filtersList}->set_column_editable(0, 1);
+        $self->{filtersList}->get_model->signal_connect("row-changed" => sub {
+            return if $self->{initializing};
+            $self->renameFilter;
+        });
+
+        my $scroller = new Gtk2::ScrolledWindow;
+        $scroller->set_policy ('automatic', 'automatic');
+        $scroller->set_shadow_type('etched-in');
+        $scroller->add($self->{filtersList});
+
+        $hBox->pack_start($scroller, 1, 1, $GCUtils::margin);
+        $hBox->pack_start($buttonBox, 0, 0, $GCUtils::margin);
+
+        $self->vbox->pack_start($hBox, 1, 1, 0);
+        $self->set_default_size(400, 400);
+        return $self;
     }
 }
 
