@@ -77,13 +77,6 @@ use GCExport::GCExportBase;
         my $self = shift;
         
         return [];
-#        my @models;
-#        foreach (glob $ENV{GCS_SHARE_DIR}.'/html_models/GC*')
-#        {
-#            /.*?(GC\w*)$/;
-#            push @models, $1;
-#        }
-#        return \@models;
     }
 
     sub setModelsDir
@@ -109,12 +102,29 @@ use GCExport::GCExportBase;
         $self->setModelsDir;
 
         my $defaultModel = '';
+        $self->{isGeneric} = {};
         foreach (glob $self->{modelsDir}.'/*')
         {
             next if ($_ =~ /\/CVS$/) || ($_ =~ /\.png$/);
             (my $mod = basename($_)) =~ s/_/ /g;
             $self->{modelsFiles} .= $mod.',';
             $defaultModel = $mod if !$defaultModel;
+            $self->{isGeneric}->{$mod} = $self->{genericModels};
+        }
+        $self->{genericAdded} = 0;
+        if (!$self->{genericModels})
+        {
+            # Previous one was specific, we also add the generic ones.
+            foreach (glob $self->{genericModelsDir}.'/*')
+            {
+                next if ($_ =~ /\/CVS$/) || ($_ =~ /\.png$/);
+                (my $mod = basename($_)) =~ s/_/ /g;
+                
+                next if exists $self->{isGeneric}->{$mod};
+                $self->{modelsFiles} .= $mod.',';
+                $self->{isGeneric}->{$mod} = 1;
+                $self->{genericAdded} = 1;
+            }
         }
         $self->{modelsFiles} .= 'UseFile,';
         return [
@@ -170,12 +180,21 @@ use GCExport::GCExportBase;
         ]
     }
     
+    sub getNewPictureHeight
+    {
+        my $self = shift;
+        return $self->{options}->{imgHeight};
+    }
+
     sub checkFileField
     {
         my ($self, $data) = @_;
         my ($parent, $list) = @{$data};
         return if ! $parent->{options}->{modelFile};
-        $parent->{options}->{modelFile}->set_sensitive($list->getValue eq 'UseFile');
+        my $model = $list->getValue ;
+        $parent->{options}->{modelFile}->set_sensitive($model eq 'UseFile');
+        $parent->{fieldsSelection}->set_sensitive($self->{isGeneric}->{$model})
+            if $parent->{fieldsSelection};
     }
 
     sub preview
@@ -189,7 +208,15 @@ use GCExport::GCExportBase;
                                       'gtk-ok' => 'ok',
                                      );
                                              
-        my $picFile = $self->{modelsDir}.'/'.$template.'.png';
+        my $picFile;
+        if ($self->{isGeneric}->{$template})
+        {
+            $picFile = $self->{genericModelsDir}.'/'.$template.'.png';
+        }
+        else
+        {
+            $picFile = $self->{modelsDir}.'/'.$template.'.png';
+        }
         if (-f $picFile)
         {
             my $image = Gtk2::Image->new_from_file($picFile);
@@ -211,7 +238,8 @@ use GCExport::GCExportBase;
     sub wantsFieldsSelection
     {
         my $self = shift;
-        return $self->{genericModels};
+        return 1;
+        return $self->{genericAdded} || $self->{genericModels};
     }
     
     sub wantsImagesSelection
@@ -319,7 +347,15 @@ use GCExport::GCExportBase;
         else
         {
             $template =~ s/ /_/;
-            $file = $self->{modelsDir}.'/'.$self->{options}->{template};
+            if ($self->{isGeneric}->{$template})
+            {
+                $file = $self->{genericModelsDir}.'/'.$self->{options}->{template};
+            }
+            else
+            {
+                $file = $self->{modelsDir}.'/'.$self->{options}->{template};
+            }
+
             $file =~ s/"//g;
             #"
         }
@@ -498,8 +534,8 @@ use GCExport::GCExportBase;
         #Variables to be used in POST section
         my $header = $$headerRef;
         my $body = $$bodyRef;
-        my @items = @{$self->{options}->{items}};
-        
+        my @items = @{$self->{sortedArray}};
+
         eval $self->{post};
         print "Errors with HTML template in POST:\n  $@\n" if $@;
 
