@@ -91,7 +91,10 @@ use GCExport::GCExportBase;
             $self->{currentDir} = getcwd;
 
             my $backend = new GCBackend::GCBeXmlParser($self);
-            $backend->setParameters($baseDir.'/'.$listFile, 1);
+            $backend->setParameters(file => $baseDir.'/'.$listFile,
+                                    version => $self->{options}->{parent}->{version},
+                                    wantRestore => 1,
+                                    standAlone => 1);
     
             my $result = $backend->save($options->{items},
                                         $options->{originalList}->getInformation,
