@@ -37,16 +37,15 @@ use strict;
     sub getLang
     {
         my ($self) = @_;
-    
-        if (! $self->{lang})
+        if (! $self->{langContainer})
         {
             my $langFile = $self->{moduleName};
             my %tmpLang;
             eval "use GCLang::".$self->{langName}."::$langFile\n";
             eval "%tmpLang = %GCLang::".$self->{langName}."::".$langFile."::lang";
-            $self->{lang} = \%tmpLang;
+            $self->{langContainer} = \%tmpLang;
         }
-        return $self->{lang};
+        return $self->{langContainer};
     }
 
     sub getName
@@ -106,6 +105,8 @@ use GCDialogs;
         {
             $self->{sorter}->hide;
             $self->{sortLabel}->hide;
+            $self->{order}->hide;
+            $self->{orderLabel}->hide;
         }
         # TODO : Hide File selection when not wanted
         #$self->{fileVbox}->hide if ! $self->{module}->wantsFileSelection;
@@ -186,10 +187,14 @@ use GCDialogs;
         $self->set_title($self->{title}." [".$module->getName."]");
         if ($module->wantsDirectorySelection)
         {
+            $self->{labelFile}->set_label($self->{parent}->{lang}->{FileChooserDirectory});
+            $self->{file}->setTitle($self->{parent}->{lang}->{FileChooserOpenDirectory});
             $self->{file}->setType('select-folder', 0);
         }
         else
         {
+            $self->{labelFile}->set_label($self->{parent}->{lang}->{ImportExportFile});
+            $self->{file}->setTitle($self->{parent}->{lang}->{FileChooserOpenFile});
             $self->{file}->setType($self->{fileType}, $self->{withFilter});
         }
         $self->{file}->setPatternFilter($module->getFilePatterns)
@@ -205,6 +210,12 @@ use GCDialogs;
             $self->{sorter}->setValue($module->{options}->{sorter})
                 if exists $module->{options};
         }
+        if ($self->{order})
+        {
+            $self->{order}->setValue(0);
+            $self->{order}->setValue($module->{options}->{order})
+                if exists $module->{options};
+        }
         foreach ($self->{optionsTable}->get_children)
         {
             $self->{optionsTable}->remove($_);
@@ -328,6 +339,9 @@ use GCDialogs;
 #            }
             $widget->set_sensitive(0) if $option->{insensitive};
             $widget->setValue($value);
+            $self->{parent}->{tooltips}->set_tip($widget,
+                                                 $module->getLang->{$option->{tooltip}})
+                if $option->{tooltip};
             $options{$option->{name}} = $widget;
             $row++;
         }
@@ -350,11 +364,12 @@ use GCDialogs;
         if ($module->wantsFieldsSelection)
         {
             $self->{optionsTable}->resize($row, 3);
-            my $button = new Gtk2::Button($self->{fieldsButtonLabel});
-            $self->{parent}->{tooltips}->set_tip($button,
-                                     $self->{fieldsTip});
-            $self->{optionsTable}->attach($button, 0, 3, $row, $row + 1, 'fill', 'fill', 0, 0);
-            $button->signal_connect('clicked' => sub {
+            $self->{fieldsSelection} = new Gtk2::Button($self->{fieldsButtonLabel});
+            $self->{parent}->{tooltips}->set_tip($self->{fieldsSelection},
+                                                 $self->{fieldsTip});
+            $self->{optionsTable}->attach($self->{fieldsSelection},
+                                          0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+            $self->{fieldsSelection}->signal_connect('clicked' => sub {
                 $self->{fieldsDialog}->show;
             });
             $row++;
@@ -425,13 +440,13 @@ use GCDialogs;
         $self->{dataTable}->set_row_spacings($GCUtils::halfMargin);
         $self->{dataFrame}->addWidget($self->{dataTable});
         
-        $self->{labelFile} = new Gtk2::Label($parent->{lang}->{ImportExportFile});
+        $self->{labelFile} = new GCLabel($parent->{lang}->{ImportExportFile});
         #$hbox->pack_start($labelFile,0,0,5);
         
         $self->{fileType} = ($type eq 'import') ? 'open' : 'save';
         $self->{withFilter} = ($self->{type} eq 'import') ? 1 : 0;
         $self->{file} = new GCFile($self,
-                                   $parent->{lang}->{ImportExportSave},
+                                   $parent->{lang}->{FileChooserOpenFile},
                                    $self->{fileType},
                                    $self->{withFilter});
 
