@@ -150,7 +150,7 @@ use GCImport::GCImportBase;
 
         while (! eof ITEMS)
         {
-            my $id = $self->readInt;  #Id
+            $result[$i]->{identifier} = $self->readInt;  #Id
             $self->readInt;  #Add date
             $result[$i]->{rating} = $self->readInt;
             
@@ -168,7 +168,7 @@ use GCImport::GCImportBase;
             
             $self->readBool;  #Checked
             
-            $self->readString;  #Media label
+            $result[$i]->{place} = $self->readString;  #Media label
             $result[$i]->{format} = $self->readString;
             $self->readString;  #Source
             $result[$i]->{borrower} = $self->readString;
