@@ -64,7 +64,7 @@ use GCImport::GCImportBase;
         
         my $pluginsList = '';
         foreach (@{$self->{model}->getPluginsNames})
-	    {
+        {
             my $plugin = $GCPlugins::pluginsMap{$self->{model}->getName}->{$_};
             $pluginsList .= $plugin->getName . ',';
         }
@@ -101,17 +101,23 @@ use GCImport::GCImportBase;
         my @result;
 
         #First we try to get the correct plugin
-        my $plugin = $GCPlugins::pluginsMap{$self->{options}->{model}->getName}->{$self->{options}->{plugin}};
+        my $plugin = $GCPlugins::pluginsMap{$self->{model}->getName}->{$self->{options}->{plugin}};
+        $plugin->{bigPics} = $self->{options}->{parent}->{options}->bigPics;
+
+        my $titleField = $self->{model}->{commonFields}->{title};
 
-        my $titleField = $self->{options}->{model}->{commonFields}->{title};
         open ITEMS, $file;
         binmode(ITEMS, ':utf8');
 
         my $i = 0;
 
-        my $resultsDialog = $self->{options}->{parent}->getDialog('Results');
-        $resultsDialog->setModel($self->{options}->{model}, $self->{model}->{fieldsInfo});
-        $resultsDialog->setMultipleSelection(0);
+        my $resultsDialog;
+        if (!$self->{options}->{first})
+        {
+            $resultsDialog = $self->{options}->{parent}->getDialog('Results');
+            $resultsDialog->setModel($self->{model}, $self->{model}->{fieldsInfo});
+            $resultsDialog->setMultipleSelection(0);
+        }
         while (<ITEMS>)
         {
             chomp;
@@ -120,7 +126,7 @@ use GCImport::GCImportBase;
             # $_ contains the title to search
             $plugin->{title} = $_;
             $plugin->{type} = 'load';
-            $plugin->{urlField} = $self->{options}->{model}->{commonFields}->{url};
+            $plugin->{urlField} = $self->{model}->{commonFields}->{url};
 
             #Initialize what will be pushed in the array
             my $info = {$titleField => $_};
@@ -153,9 +159,9 @@ use GCImport::GCImportBase;
                 $info = $plugin->getItemInfo;
                 my $title = $info->{$titleField};
                 $self->{options}->{parent}->{defaultPictureSuffix} = $plugin->getDefaultPictureSuffix;
-                foreach my $field(@{$self->{options}->{model}->{managedImages}})
+                foreach my $field(@{$self->{model}->{managedImages}})
                 {
-                    $info->{$field} = '' if $info->{image} eq 'empty';
+                    $info->{$field} = '' if $info->{$field} eq 'empty';
                     next if !$info->{$field};
                     ($info->{$field}) = $self->{options}->{parent}->downloadPicture($info->{$field}, $title);
                 }
@@ -169,7 +175,7 @@ use GCImport::GCImportBase;
                                  . "\n";
 
                 # Add the default value
-                my $defaultInfo = $self->{options}->{model}->getInitInfo;
+                my $defaultInfo = $self->{model}->getInitInfo;
                 foreach my $field(keys %$defaultInfo)
                 {
                     next if exists $info->{$field};
