@@ -89,6 +89,15 @@ use GCImport::GCImportBase;
         return ($self->{parsingError}, 'error');
     }
     
+    sub addFieldsToDefaultModel
+    {
+        my ($self, $inlineModel) = @_;
+        my $model = GCModelLoader->newFromInline($self, {inlineModel => $inlineModel, defaultModifier => 1});
+        $self->{model}->addFields($model);
+        $self->{options}->{parent}->setCurrentModel($self->{model});
+        $self->{modelAlreadySet} = 1;
+    }
+
     sub getItemsArray
     {
         my ($self, $file) = @_;
@@ -112,7 +121,7 @@ use GCImport::GCImportBase;
         $self->{modelAlreadySet} = 0;
 
         my $backend = new GCBackend::GCBeXmlParser($self);            
-        $backend->setParameters($listFile);
+        $backend->setParameters(file => $listFile);
         my $loaded = $backend->load(0);
         my $itemsArray = [];
         if ($loaded->{error})
