@@ -204,12 +204,12 @@ use GCImport::GCImportBase;
         {
             $result{age} = 17;
         }
-        $result{genre} = {'line' => []};
+        $result{genre} = [];
         if ($entry->{genres}->[0])
         {
             for my $genre(@{$entry->{genres}->[0]->{genre}})
             {
-                push @{$result{genre}->{line}}, {'col' => [$genre]};
+                push @{$result{genre}}, [$genre];
             }
         }
         if ($entry->{nationalitys}->[0])
@@ -242,20 +242,20 @@ use GCImport::GCImportBase;
         }
         $result{director} =~ s/, $//;
         
-        $result{audio} = {'line' => []};
+        $result{audio} = [];
         if ($entry->{languages}->[0])
         {
             for my $language(@{$entry->{languages}->[0]->{language}})
             {
-                push @{$result{audio}->{line}}, {'col' => [$language]};
+                push @{$result{audio}}, [$language];
             }
         }
-        $result{subt} = {'line' => []};
+        $result{subt} = [];
         if ($entry->{subtitles}->[0])
         {
             for my $subtitle(@{$entry->{subtitles}->[0]->{subtitle}})
             {
-                push @{$result{subt}->{line}}, {'col' => [$subtitle]};
+                push @{$result{subt}}, [$subtitle];
             }
         }    
         $result{time} = $entry->{'running-time'}->[0];
@@ -282,12 +282,12 @@ use GCImport::GCImportBase;
         $result{name} = $entry->{title}->[0];
         $result{platform} = $entry->{platform}->[0];
         $result{released} = $entry->{year}->[0];
-        $result{genre} = {'line' => []};
+        $result{genre} = [];
         if ($entry->{genres}->[0])
         {
             for my $genre(@{$entry->{genres}->[0]->{genre}})
             {
-                push @{$result{genre}->{line}}, {'col' => [$genre]};
+                push @{$result{genre}}, [$genre];
             }
         }
         if ($entry->{publishers}->[0])
@@ -313,12 +313,12 @@ use GCImport::GCImportBase;
         my %result;
     
         $result{title} = $entry->{title}->[0];
-        $result{authors} = {'line' => []};
+        $result{authors} = [];
         if ($entry->{authors}->[0])
         {
             for my $author(@{$entry->{authors}->[0]->{author}})
             {
-                push @{$result{authors}->{line}}, {'col' => [$author]};
+                push @{$result{authors}}, [$author];
             }
         }
         $result{publisher} = $entry->{publisher}->[0];
@@ -338,12 +338,12 @@ use GCImport::GCImportBase;
         $result{pages} = $entry->{pages}->[0];
         $result{read} = 1 if ($entry->{read}->[0] eq 'true');
         $result{acquisition} = $entry->{pur_date}->[0];
-        $result{genre} = {'line' => []};
+        $result{genre} = [];
         if ($entry->{genres}->[0])
         {
             for my $genre(@{$entry->{genres}->[0]->{genre}})
             {
-                push @{$result{genre}->{line}}, {'col' => [$genre]};
+                push @{$result{genre}}, [$genre];
             }
         }
         $result{rating} = $self->convertRating($entry->{rating}->[0]);
@@ -377,12 +377,12 @@ use GCImport::GCImportBase;
             $result{label} =~ s/, $//;
         }
         $result{release} = $entry->{year}->[0];
-        $result{genre} = {'line' => []};
+        $result{genre} = [];
         if ($entry->{genres}->[0])
         {
             for my $genre(@{$entry->{genres}->[0]->{genre}})
             {
-                push @{$result{genre}->{line}}, {'col' => [$genre]};
+                push @{$result{genre}}, [$genre];
             }
         }
         if ($entry->{tracks}->[0])
@@ -390,9 +390,9 @@ use GCImport::GCImportBase;
             my $trackNum = 1;
             for my $track(@{$entry->{tracks}->[0]->{track}})
             {
-                push @{$result{tracks}->{line}}, {'col' => [$trackNum,
-                                                            $track->{column}->[0],
-                                                            $track->{column}->[2]]};
+                push @{$result{tracks}}, [$trackNum,
+                                          $track->{column}->[0],
+                                          $track->{column}->[2]];
                 $trackNum++;
             }
         }
