@@ -121,6 +121,22 @@ sub loadPluginsLangs
     
 }
 
+sub languageDirection
+{
+    my $lang = shift;
+
+    $lang =~ m/([a-z]*)/;
+    if ($1 eq 'ar')
+    {
+        # Langauge is RTL
+        return 'RTL';
+    }
+    else
+    {
+        return 'LTR';
+    }
+}
+
 # Used to check languages (which translation are missing)
 # Usage: perl -e "use GCLang; GCLang::checkLangs"
 sub checkLangs
@@ -128,7 +144,7 @@ sub checkLangs
     my @langsToCheck = @_;
 
     my $ref = 'EN';
-    my $otherRef = 'FR';
+    #my $otherRef = 'FR';
     
     loadLangs;
     loadPluginsLangs;
@@ -147,10 +163,10 @@ sub checkLangs
             }
             else
             {
-                next if $langName eq $otherRef;
+                #next if $langName eq $otherRef;
                 push @{$results{$langName}{warning}}, $_
                     if ($langs{$langName}->{$_} eq $langs{$ref}->{$_})
-                    || ($langs{$langName}->{$_} eq $langs{$otherRef}->{$_});
+                #    || ($langs{$langName}->{$_} eq $langs{$otherRef}->{$_});
             }
         }
     }
