@@ -42,9 +42,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'ModelNotFound' => 'Invalid template file',
-        'UseFile' => 'Use file specified below',
-        'TemplateExternalFile' => 'Template file',
+        'ModelNotFound' => 'قالب غير صالح',
+        'UseFile' => 'قم بإستعمال الملف أدناه',
+        'TemplateExternalFile' => 'القالب',
         'WithJS' => 'إستعمل Javascript',
        	'FileTemplate' => 'قالب:',
         'Preview' => 'معاينة',
@@ -69,7 +69,7 @@
         'Borrowed' => 'تمت إستعارته من قبل: ',
         'NotBorrowed' => 'متاح',
         'Top' => 'للأعلى',
-        'Bottom' => 'Bottom',
+        'Bottom' => 'للأسفل',
      );
 }
 
