@@ -60,7 +60,7 @@
 		Case => 'الحالة',
         Manual => 'دليل الإستخدام',
         Completion => 'الإكمال (%)',
-        Executable => 'Executable',
+        Executable => 'ملف تنفيذي',
         Description => 'الوصف',
         Codes => 'شيفرات',
         Code => 'شيفرة',
