@@ -7,11 +7,11 @@
 #	This file translated by :
 #		Muhammad Bashir Al-Noimi
 #	Contact me:
-#		webmaster@hali-sy.com
+#		mhdbnoimi@gmail.com
 #		bashir.storm@gmail.com
-#		hali83@cec.sy
+#		mbnoimi@gmail.com
 #	MY Blog:
-#		http://www.hali-sy.com/blog
+#		http://mbnoimi.net/
 #	
 ###################################################
 #
@@ -58,33 +58,32 @@
 		'AllItemsFiltered' => 'لم يتم العثور على أي عنصر من خلال معيار البحث الذي قمت بتخصيصه',
      
 #Installation
-        'InstallDirInfo' => 'Installing in ',
-        'InstallMandatory' => 'Mandatory components',
-        'InstallOptional' => 'Optional Components',
-        'InstallErrorMissing' => 'Error : Following Perl components have to be installed: ',
-        'InstallPrompt' => 'Base directory for installation [/usr/local]: ',
-        'InstallEnd' => 'End of the installation',
-        'InstallNoError' => 'No error',
-        'InstallLaunch' => 'To use this application, one can launch ',
-        'InstallDirectory' => 'Base directory',
-        'InstallTitle' => 'GCstar installation',
-        'InstallDependencies' => 'Dependencies',
-        'InstallPath' => 'Path',
-        'InstallOptions' => 'Options',
-        'InstallSelectDirectory' => 'Select base directory for the installation',
-        'InstallWithClean' => 'Remove files found in installation directory',
-        'InstallWithMenu' => 'Add GCstar to Applications menu',
-        'InstallNoPermission' => 'Error: You don\'t have permission to write in the selected directory',
-        'InstallMissingMandatory' => 'Mandatory dependencies are missing. You won\'t be able to install GCstar until they have been added to your system.',
-        'InstallMissingOptional' => 'Some optional dependencies are missing. There are listed under. GCstar may be installed but some features won\'t be available.',
-        'InstallMissingNone' => 'There are no missing dependency. You may continue and install GCstar.',
-        'InstallOK' => 'OK',
-        'InstallMissing' => 'Missing',
-        'InstallMissingFor' => 'Missing for',
-        'InstallCleanDirectory' => 'Removing GCstar\'s files in directory: ',
-        'InstallCopyDirectory' => 'Copying files in directory: ',
-        'InstallCopyDesktop' => 'Copying desktop file in: ',
-
+        'InstallDirInfo' => 'تم تنصيبه ضمن ',
+        'InstallMandatory' => 'مكونات أساسية',
+        'InstallOptional' => 'مكونات إختيارية',
+        'InstallErrorMissing' => 'خطأ : مكونات بيرل التالية يجب أن يتم تنصيبها: ',
+        'InstallPrompt' => 'مجلد التنصيب [/usr/local]: ',
+        'InstallEnd' => 'نهاية التنصيب',
+        'InstallNoError' => 'لا توجد أخطاء',
+        'InstallLaunch' => 'لتشغيل البرنامج يجب إستدعاء نسخة واحدة ',
+        'InstallDirectory' => 'المجلد الرئيسي',
+        'InstallTitle' => 'تنصيب جي سي ستار',
+        'InstallDependencies' => 'الإعتمادية',
+        'InstallPath' => 'مسار',
+        'InstallOptions' => 'خيارات',
+        'InstallSelectDirectory' => 'قم بتحديد مجلد التنصيب',
+        'InstallWithClean' => 'إزالة الملفات الموجودة ضمن مجلد التنصيب',
+        'InstallWithMenu' => 'إضافة جي سي ستار لقائمة البرامج',
+        'InstallNoPermission' => 'خطأ : ليس لديك سماحية الكتابة ضمن المجلد المحدد',
+        'InstallMissingMandatory' => 'إعتماديات أساسية مفقودة. ليس بإمكانك تنصيب جي سي ستار إلا بعد إضافة الإعتماديات الرئيسية لنظامك.',
+        'InstallMissingOptional' => 'بعض الإعتماديات الإختيارية مفقودة كما هو موضح أدناه. يمكن تنصيب جي سي ستار لكن بعض الميزات لن تكون متوفرة للعمل.',
+        'InstallMissingNone' => 'لا توجد إعتماديات مفقودة. بإمكانك الإستمرار و تنصيب جي سي ستار.',
+        'InstallOK' => 'موافق',
+        'InstallMissing' => 'مفقود',
+        'InstallMissingFor' => 'مفقود',
+        'InstallCleanDirectory' => 'إزالة ملفات جي سي ستار من المجلد: ',
+        'InstallCopyDirectory' => 'نسخ الملفات للمجلد: ',
+        'InstallCopyDesktop' => 'نسخ ملف سطح المكتب إلى: ',
 
 #Update
 		'UpdateUseProxy' => 'البروكسي الذي سيتم إستعماله (قم بالنقر على Enter في حال عدم وجود بروكسي): ',
@@ -96,13 +95,13 @@
         'SplashInit' => 'تهيئة',
         'SplashLoad' => 'تحميل المجموعات',
         'SplashDisplay' => 'عرض المجموعات',
-        'SplashSort' => 'Sorting Collection',
+        'SplashSort' => 'ترتيب المجموعات',
         'SplashDone' => 'جاهز',
 
 #Import from GCfilms
-        'GCfilmsImportQuestion' => 'It seems you were using GCfilms before. What do you want to import from GCfilms to GCstar (it won\'t impact GCfilms if you still want to use it)?',
-        'GCfilmsImportOptions' => 'Settings',
-        'GCfilmsImportData' => 'Movies list',
+        'GCfilmsImportQuestion' => 'يبدو أنك كنت تستعمل جي سي فيلم من قبل. هل ترغب بإستيراد البيانات من جي سي فيلم إلى جي سي ستار؟',
+        'GCfilmsImportOptions' => 'إعدادات',
+        'GCfilmsImportData' => 'قائمة الأفلام',
 
 #Menus
         'MenuFile' => '_ملف',
@@ -119,6 +118,9 @@
             'MenuEditLockItems' => '_إقفال المجموعة',
     
         'MenuDisplay' => 'ت_صفية',
+            'MenuSavedSearches' => 'حفظ البحث',
+                'MenuSavedSearchesSave' => 'حفظ البحث الحالي',
+                'MenuSavedSearchesEdit' => 'تعديل بحث محفوظ',
             'MenuAdvancedSearch' => 'ب_حث متقدّم',
             'MenuViewAllItems' => 'عرض _كل العناصر',
             'MenuNoFilter' => '_أي شيء',
@@ -126,22 +128,28 @@
         'MenuConfiguration' => '_إعدادات',
             'MenuDisplayOptions' => '_المعلومات المعروضة',
             'MenuBorrowers' => '_إستعارة',
+            'MenuToolbarConfiguration' => '_عناصر شريط الأدوات',
             'MenuGenresConversion' => 'نم_ط التحويل',
         
-        'MenuBookmarks' => '_مجموعاتي',
+        'MenuBookmarks' => '_محفوظات',
             'MenuBookmarksAdd' => '_أضف الجموعة الحالية',
-            'MenuBookmarksEdit' => '_تحرير مجموعاتي',
+            'MenuBookmarksEdit' => '_تحرير المحفوظات',
 
         'MenuHelp' => '_مساعدة',
             'MenuHelpContent' => '_المحتوى',
             'MenuAllPlugins' => 'عرض الملحقات',
             'MenuBugReport' => 'الإبلاغ عن خطأ',
-            'MenuAbout' => '_حول GCstar',
+            'MenuAbout' => '_حول جي سي ستار',
     
         'MenuNewWindow' => 'عرض العنصر بنافذة _جديدة',
         
         'ContextExpandAll' => 'توسيع الكل',
         'ContextCollapseAll' => 'طي الكل',
+        'ContextChooseImage' => 'قم بإختيار صورة',
+        'ContextOpenWith' => 'فتح بواسطة',
+        'ContextImageEditor' => 'محرر الصور',
+        'ContextImgFront' => 'الواجهة',
+        'ContextImgBack' => 'الخلفية',
         
         'DialogEnterNumber' => 'قم بإدخال قيمة',
 
@@ -152,12 +160,14 @@
         'OpenList' => 'قم بتحديد مجموعة',
 		'SaveList' => 'قم بتحديد مسار حفظ المجموعة',
         'SaveListTooltip' => 'حفظ المجموعة الحالية',
-		'SaveCurrentList' => 'أتريد حفظ المجموعة الحالية؟',
-        'SaveUnsavedChanges' => 'توجد بعض التعديلات على مجموعتك لم تُحفظ. هل تريد حفظ التعديلات؟',
+		'SaveCurrentList' => 'هل تريد حفظ المجموعة الحالية؟',
+        'SaveUnsavedChanges' => 'لم يتم حفظ التعديلات على مجموعتك لم تُحفظ. هل تريد حفظ التعديلات؟',
         'SaveDontSave' => 'لا تحفظ',
         'PreferencesTooltip' => 'تفضيلات البرنامج',
         'ViewTooltip' => 'تغيير عرض المجموعة',
 		'PlayTooltip' => 'قراءة ملف الفيديو المرتبط بالعنصر',
+        'PlayFileNotFound' => 'الملف الذي سيتم إستدعاؤه غير موجود في هذا المسار:',
+        'PlayRetry' => 'إعادة القراءة',
 
         'StatusSave' => 'الحفظ جاري...',
         'StatusLoad' => 'التحميل جاري...',
@@ -168,10 +178,14 @@
 		'SaveError' => 'غير قادر على حفظ قائمة العناصر. من فضلك قم بفحص سماحيات الكتابة على القرص',
         'OpenError' => 'غير قادر على فتح قائمة العناصر. من فضلك قم بفحص سماحيات القرص',
 		'OpenFormatError' => 'غير قادر على فتح قائمة العناصر. تأكد من صحة التنسيق',
+        'OpenVersionWarning' => 'المجموعة تم حفظها بواسطة عدة إصدارات من جي سي ستار. إذا قمت بحفظها هنالك إحتمال أن تفقد بعض البيانات.',
+        'OpenVersionQuestion' => 'هل لا تزال ترغب بالإستمرار؟',
 		'ImageError' => 'المسار المحدّد من أجل حفظ الصوّر غير صالح. من فضلك قم بتحديد مسار آخر',
         'OptionsCreationError'=> 'غير قادر على إنشاء ملف الخيارات: ',
         'OptionsOpenError'=> 'غير قادر على فتح ملف الخيارات: ',
         'OptionsSaveError'=> 'غير قادر على حفظ ملف الخيارات: ',
+        'ErrorModelNotFound' => 'النموذج غير موجود: ',
+        'ErrorModelUserDir' => 'النماذج المعرفة من قبل المستخدم موجودة ضمن: ',
         
         'RandomTooltip' => 'ما الذي ترغب برؤيته هذا المساء؟',
         'RandomError'=> 'لم يتم تحديد أي عنصر',
@@ -179,35 +193,38 @@
         'RandomNextTip'=> 'الإقتراح التالي',
         'RandomOkTip'=> 'قبول هذا العنصر',
         
-        'AboutTitle' => 'حول GCstar',
+        'AboutTitle' => 'حول جي سي ستار',
         'AboutDesc' => 'لإدارة المجموعات',
         'AboutVersion' => 'إصدار',
         'AboutTeam' => 'فريق',
         'AboutWho' => 'مدير المشروع، مبرمج: Christian Jodar (Tian)
+مبرمج: Nyall Dawson (Zombiepig)
+مبرمج: TPF
 مبرمج: Adolfo González
-مبرمج: Nyall Dawson (Zombiepig)',
+',
         'AboutLicense' => 'المشروع تم تطويره و توزيعه وفق رخصة البرامج مفتوحة المصدر GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'دعم اللغة العربية: محمد بشير النعيمي 
-http://www.hali-sy.com/blog
-webmaster@hali-sy.com
+http://mbnoimi.net/
+mhdbnoimi@gmail.com
 bashir.storm@gmail.com
-hali83@cec.sy',
+mbnoimi@gmail.com',
         'AboutDesign' => 'تم أنجاز الشعار و تصميم الويب من قبل le Spektre',
 
         'ToolbarRandom' => 'هذه اللّيلة',
 
+        'UnsavedCollection' => 'مجموعة لم يتم حفظها',
         'ModelsSelect' => 'حدّد نوع المجموعة',
         'ModelsPersonal' => 'نماذج شخصية',
         'ModelsDefault' => 'نماذج إفتراضية',
         'ModelsList' => 'تعريف المجموعة',
         'ModelSettings' => 'إعدادات المجموعة',
-        'ModelNewType' => 'نوع مجموعة جديد',
-        'ModelName' => 'إسم نوع المجموعة: ',
-		'ModelFields' => 'Fields',
-		'ModelOptions'	=> 'Options',
-		'ModelFilters'	=> 'Filters',
+        'ModelNewType' => 'مجموعة جديدة',
+        'ModelName' => 'إسم المجموعة: ',
+		'ModelFields' => 'حقول',
+		'ModelOptions'	=> 'خيارات',
+		'ModelFilters'	=> 'مرشحات تصفية',
         'ModelNewField' => 'حقل جديد',
         'ModelFieldInformation' => 'معلومات',
         'ModelFieldName' => 'تسمية:',
@@ -219,6 +236,9 @@ hali83@cec.sy',
         'ModelFieldMax' => 'الحد الأعلى:',
         'ModelFieldList' => 'قائمة القيم:',
         'ModelFieldListLegend' => '<i>كل قيمة تفصل عن الأخرى بفاصلة</i>',
+        'ModelFieldDisplayAs' => 'عرض بهيئة: ',
+        'ModelFieldDisplayAsText' => 'نص',
+        'ModelFieldDisplayAsGraphical' => 'عنصر تقييم',
         'ModelFieldTypeShortText' => 'نص قصير',
         'ModelFieldTypeLongText' => 'نص طويل',
         'ModelFieldTypeYesNo' => 'نعم/لا',
@@ -230,7 +250,7 @@ hali83@cec.sy',
         'ModelFieldTypeFile' => 'ملف',
         'ModelFieldTypeFormatted' => 'يعتمد على الحقول الأخرى',
         'ModelFieldParameters' => 'وسائط',
-        'ModelFieldHasHistory' => 'إستعمل المحفوظات',
+        'ModelFieldHasHistory' => 'إستعمال المحفوظات',
         'ModelFieldFlat' => 'عرض ضمن صفّ واحد',
         'ModelFieldStep' => 'خطوة الزيادة:',
         'ModelFieldFileFormat' => 'تنسيق الملف:',
@@ -248,11 +268,13 @@ hali83@cec.sy',
         'ModelOptionsFieldsCover' => 'حسب الغلاف',
         'ModelOptionsFieldsPlay' => 'من أجل زر القراءة',
         'ModelCollectionSettings' => 'إعدادات المجموعة',
-        'ModelCollectionSettingsLending' => 'لا يمكن إعارة العناصر',
-        'ModelCollectionSettingsTagging' => 'Items can be tagged',
-        'ModelFilterActivated' => 'ضمن أن يكون ضمن صندوق البحث',
+        'ModelCollectionSettingsLending' => 'إمكانية إعارة العناصر',
+        'ModelCollectionSettingsTagging' => 'عناصر يسمح بوسمها',
+        'ModelFilterActivated' => 'عرض ضمن صندوق البحث',
         'ModelFilterComparison' => 'مقارنة',
         'ModelFilterContain' => 'يحتوي',
+        'ModelFilterDoesNotContain' => 'لا يحتوي على',
+        'ModelFilterRegexp' => 'تعبير منتظم',
         'ModelFilterRange' => 'مجال',
         'ModelFilterNumeric' => 'المقارنة عددية',
         'ModelFilterQuick' => 'إنشاء تصفية سريعة',
@@ -263,39 +285,44 @@ hali83@cec.sy',
         'ModelTooltipHistory' => 'القيم المدخلة سابقاً سيتم تخزينها ضمن قائمة مرتبطة بالحقل',
         'ModelTooltipFormat' => 'تستعمل هذه الصيغة لتخصيص طريقة فتح الملف بإستعمال زر القراءة',
         'ModelTooltipLending' => 'سيتم إضافة بعض الحقول من أجل إدارة الإستعارة',
-        'ModelTooltipTagging' => 'This will add some fields to manage tags',
+        'ModelTooltipTagging' => 'إضافة بعض الحقول من أجل إدارة الوسوم',
         'ModelTooltipNumeric' => 'سيتم معاملة جميع المقارنات على أنها أعداد',
         'ModelTooltipQuick' => 'سيتم إضافة قائمة فرعية ضمن قائمة التصفية',
         
         'ResultsTitle' => 'حدد عنصر',
         'ResultsNextTip' => 'البحث ضمن الموقع',
         'ResultsPreview' => 'معاينة',
-        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
+        'ResultsInfo' => 'بإمكانك إضافة عدة عناصر للمجموعة عن طريق النقر المستمر على زر Ctrl أو Shift ثم إختيار العنصر',
         
         'OptionsTitle' => 'التفضيلات',
+		'OptionsExpertMode' => 'متقدّم',
+        'OptionsPrograms' => 'تخصيص التطبيقات الإفتراضية ضمن البرنامج، سيتم إستعمال إفتراضيات النظام في حال ترك الحقل فارغاً',
         'OptionsBrowser' => 'متصفّح الإنترنت',
         'OptionsPlayer' => 'قارئ الفيديو',
         'OptionsAudio' => 'قارئ الصوت',
+        'OptionsImageEditor' => 'محرر الصور',
+        'OptionsCdDevice' => 'جهاز القرص المدمج',
         'OptionsImages' => 'مجلد الصوّر',
-        'OptionsUseRelativePaths' => 'إستعمل المسارات المحليّة من أجل الصوّر',
+        'OptionsUseRelativePaths' => 'إستعمال المسارات النسبية من أجل الصوّر',
         'OptionsLayout' => 'تخطيط العرض',
         'OptionsStatus' => 'عرض شريط الحالة',
+        'OptionsUseStars' => 'إستعمال النجوم من أجل عرض التقييم',
         'OptionsWarning' => 'تحذير: جميع التعديلات ستظهر عند إعادة تشغيل البرنامج، و لن تظهر مباشرة الآن',
-        'OptionsRemoveConfirm' => 'أظهر رسالة تأكيد حذف العنصر',
+        'OptionsRemoveConfirm' => 'إظهار رسالة تأكيد حذف العنصر',
         'OptionsAutoSave' => 'حفظ المجموعة بشكل تلقائي',
         'OptionsAutoLoad' => 'فتح المجموعة السابقة عند بدء تشغيل البرنامج',
         'OptionsSplash' => 'عرض الشاشة الترحيبية',
-        'OptionsSpellCheck' => 'Use spelling checker for long text fields',
-        'OptionsImagesTitle' => 'حدد مجلد',
+        'OptionsTearoffMenus' => 'تمكين تثبيت القوائم',
+        'OptionsSpellCheck' => 'إستعمال المدقق الإملائي ضمن حقول النص الطويلة',
         'OptionsProgramTitle' => 'حدد البرنامج الذي سيتم إستعماله',
 		'OptionsPlugins' => 'الموقع الذي سيتم جلب البيانات منه',
-		'OptionsAskPlugins' => 'Ask (جميع المواقع)',
+		'OptionsAskPlugins' => 'سؤال جميع المواقع',
 		'OptionsPluginsMulti' => 'عدد معيّن من المواقع',
-		'OptionsPluginsMultiAsk' => 'Ask (عدد معين من المواقع)',
+		'OptionsPluginsMultiAsk' => 'سؤال عدد معين من المواقع',
 		'OptionsPluginsList' => 'تخصيص قائمة المواقع',
         'OptionsAskImport' => 'حدد الحقول التي سيتم إستيرادها',
 		'OptionsProxy' => 'إستعمل البروكسي',
-		'OptionsCookieJar' => 'Use this cookie jar file',
+		'OptionsCookieJar' => 'إستعمال ملف الكوكي',
         'OptionsLang' => 'لغة',
         'OptionsMain' => 'عام',
         'OptionsPaths' => 'مسارات',
@@ -306,10 +333,10 @@ hali83@cec.sy',
         'OptionsToolbars' => {0 => 'بلا', 1 => 'صغير', 2 => 'كبير'},
         'OptionsToolbarPosition' => 'توضّع',
         'OptionsToolbarPositions' => {0 => 'في الأعلى', 1 => 'في الأسفل', 2 => 'في اليسار', 3 => 'في اليمين'},
-        'OptionsExpandersMode' => 'Expanders too long',
-        'OptionsExpandersModes' => {'asis' => 'Do nothing', 'cut' => 'Cut', 'wrap' => 'Line wrap'},
-        'OptionsDateFormat' => 'Date Format',
-        'OptionsDateFormatTooltip' => 'Format is the one used by strftime(3). Default is %d/%m/%Y',
+        'OptionsExpandersMode' => 'طريقة إحتواء العناصر الكبيرة',
+        'OptionsExpandersModes' => {'asis' => 'لا تفعل شيء', 'cut' => 'إقتطاع', 'wrap' => 'إلتفاف السطر'},
+        'OptionsDateFormat' => 'صيغة التاريخ',
+        'OptionsDateFormatTooltip' => 'صيغة التاريخ. القيمة الإفتراضية هي: %d/%m/%Y',
         'OptionsView' => 'قائمة العناصر',
         'OptionsViews' => {0 => 'نص', 1 => 'صورة', 2 => 'تفاصيل'},
         'OptionsColumns' => 'أعمدة',
@@ -317,26 +344,27 @@ hali83@cec.sy',
         'OptionsSMTP' => 'الملقم',
         'OptionsFrom' => 'عنوان بريدك الإلكتروني',
 
-        'OptionsTransform' => 'وضع الشرح التوصيفي بنهاية العناوين',
-        'OptionsArticles' => 'الشرح التوصيفي (كل توصيف مفصول عن الآخر بفاصلة)',
+        'OptionsTransform' => 'وضع مقطع التعريف بنهاية العناوين',
+        'OptionsArticles' => 'مقطع التعريف (كل مقطع مفصول عن الآخر بفاصلة)',
         'OptionsSearchStop' => 'السماح بإحباط عملية البحث',
+        'OptionsBigPics' => 'إستعمال الصور بقياس كبير في حال توفرهم',
 
         'OptionsAlwaysOriginal' => 'استعمل العنوان الرئيسي كعنوان أصلي إن لم يتم تخصيصه',
-        'OptionsRestoreAccelerators' => 'Restore accelerators',
+        'OptionsRestoreAccelerators' => 'إستعادة الإختصارات الإفتراضية',
         'OptionsHistory' => 'حجم المحفوظات',
         'OptionsClearHistory' => 'مسح المحفوظات',
 		'OptionsStyle' => 'مظهرية العرض',
         'OptionsDontAsk' => 'لا تسألني مرة أخرى',
         'OptionsPathProgramsGroup' => 'تطبيقات',
-        'OptionsProgramsSystem' => 'Use programs defined by system',
-        'OptionsProgramsUser' => 'Use specified programs',
-        'OptionsProgramsSet' => 'Set programs',
+        'OptionsProgramsSystem' => 'إستعمال البرامج المعرفة من قبل النظام',
+        'OptionsProgramsUser' => 'إستعمال البرامج المعرفة من قبل المستخدم',
+        'OptionsProgramsSet' => 'تخصيص البرامج',
         'OptionsPathImagesGroup' => 'صور',
         'OptionsInternetDataGroup' => 'استيراد البيانات',
         'OptionsInternetSettingsGroup' => 'إعدادات',
         'OptionsDisplayInformationGroup' => 'عرض المعلومات',
 
-        'OptionsDisplayArticlesGroup' => 'شرح توصيفي',
+        'OptionsDisplayArticlesGroup' => 'مقاطع التعريف',
         'OptionsImagesDisplayGroup' => 'عرض',
         'OptionsImagesStyleGroup' => 'نمط',
         'OptionsDetailedPreferencesGroup' => 'تفضيلات',
@@ -345,32 +373,32 @@ hali83@cec.sy',
         'OptionsPicturesFormat' => 'البادئة التي ستستعمل للصوّر',
         'OptionsPicturesFormatInternal' => 'gcstar__',
         'OptionsPicturesFormatTitle' => 'عنوان أو اسم العنصر المرتبط',
-        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
-        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
-        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
+        'OptionsPicturesWorkingDir' => 'الصيغة %WORKING_DIR% . سيتم إستبدالها بمجلد المجموعة (تستعمل فقط في بداية المسار)',
+        'OptionsPicturesFileBase' => 'الصيغة %FILE_BASE% سيتم إستبدالها بواسطة إسم ملف المجموعة دون اللاحقة (.gcs)',
+        'OptionsPicturesWorkingDirError' => 'الصيغة %WORKING_DIR% يمكن إستعمالها فقط في بداية المسار للصور',
         'OptionsConfigureMailers' => 'تهيئة برامج البريد الإلكتروني',
 
         'ImagesOptionsButton' => 'إعدادات',
         'ImagesOptionsTitle' => 'إعدادات قائمة الصوّر',
         'ImagesOptionsSelectColor' => 'حدد لون',
-        'ImagesOptionsUseOverlays' => 'Use image overlays',
+        'ImagesOptionsUseOverlays' => 'عرض ضمن إطار زجاجي',
         'ImagesOptionsBg' => 'خلفية',
         'ImagesOptionsBgPicture' => 'إستعمل صورة الخلفية',
         'ImagesOptionsFg'=> 'تحديد',
         'ImagesOptionsBgTooltip' => 'تغيير لون الخلفية',
         'ImagesOptionsFgTooltip'=> 'تغيير لون التحديد',
+        'ImagesOptionsResizeImgList' => 'تغيير عدد الأعمدة بشكل تلقائي',
         'ImagesOptionsSizeLabel' => 'حجم',
         'ImagesOptionsSizeList' => {0 => 'صغير جداً', 1 => 'صغير', 2 => 'متوسط', 3 => 'كبير', 4 => 'كبير جداً'},
         'ImagesOptionsSizeTooltip' => 'حدد حجم الصورة',
 		        
         'DetailedOptionsTitle' => 'إعدادات قائمة تفاصيل',
         'DetailedOptionsImageSize' => 'قياس الصوّر',
-        'DetailedOptionsGroupItems' => 'تجميع العناصر عن طريق',
-        'DetailedOptionsSecondarySort' => 'Sort field for children',
+        'DetailedOptionsGroupItems' => 'تجميع العناصر بواسطة',
+        'DetailedOptionsSecondarySort' => 'ترتيب الحقول الفرعية',
 		'DetailedOptionsFields' => 'حدد التي الحقول التي سيتم عرضها',
-        'DetailedOptionsGroupedFirst' => 'Keep together orphaned items',
-        'DetailedOptionsAddCount' => 'Add number of elements on categories',
-
+        'DetailedOptionsGroupedFirst' => 'فرز العناصر الغير مجمّعة',
+        'DetailedOptionsAddCount' => 'إضافة عدد العناصر ضمن التصنيفات',
         'ExtractButton' => 'معلومات',
         'ExtractTitle' => 'معلومات الملف',
         'ExtractImport' => 'إستعمل القيم',
@@ -378,19 +406,19 @@ hali83@cec.sy',
         'FieldsListOpen' => 'فتح قائمة الحقول من ملف',
         'FieldsListSave' => 'حفظ قائمة الحقول لملف',
         'FieldsListError' => 'لا يمكن إستعمال قائمة الحقول مع هذا النوع من المجموعات',
-        'FieldsListIgnore' => '--- Ignore',
+        'FieldsListIgnore' => '--- تجاهل',
 
         'ExportTitle' => 'تصدير قائمة العناصر',
         'ExportFilter' => 'تصدير العناصر المعروضة فقط',
         'ExportFieldsTitle' => 'حقول سيتم تصديرها',
         'ExportFieldsTip' => 'حدد الحقول التي تود تصديرها',
         'ExportWithPictures' => 'نسخ الصّور لمجلّد فرعي',
-        'ExportSortBy' => 'Sort by',
+        'ExportSortBy' => 'ترتيب حسب',
+        'ExportOrder' => 'ترتيب',
 
         'ImportListTitle' => 'إستيراد قائمة عناصر أخرى',
         'ImportExportData' => 'بيانات',
         'ImportExportFile' => 'ملف',
-        'ImportExportSave' => 'قم بتحديد ملف ليتم إستعاله',
         'ImportExportFieldsUnused' => 'حقول عير مستعملة',
         'ImportExportFieldsUsed' => 'حقول مستعملة',
         'ImportExportFieldsFill' => 'إضافة الكل',
@@ -404,7 +432,10 @@ hali83@cec.sy',
         'ImportDropError' => 'حدث خطأ أثناء فتح الملف. القائمة السابقة سيعاد تحميلها من جديد',
 		'ImportGenerateId' => 'إنشاء رقم معرّف من أجل كل عنصر',
 
-        'FileOverwrite' => 'الملف موجود مسبقاً. هل تود إستبداله؟',
+        'FileChooserOpenFile' => 'قم بتحديد ملف ليتم إستعاله',
+        'FileChooserDirectory' => 'مجلد',
+        'FileChooserOpenDirectory' => 'حدد مجلد',
+        'FileChooserOverwrite' => 'الملف موجود مسبقاً. هل تود إستبداله؟',
 
         #Some default panels
         'PanelCompact' => 'مدمج',
@@ -419,7 +450,7 @@ hali83@cec.sy',
         'PanelImageTitle' => 'حدد صورة',
         'PanelImageNoImage' => 'لا توجد صورة',
         'PanelSelectFileTitle' => 'حدد ملف',
-        'PanelRestoreDefault' => 'Restore default',
+        'PanelRestoreDefault' => 'إستعادة الإفتراضيات',
 
         'PanelFrom' =>'من',
         'PanelTo' =>'إلى',
@@ -445,9 +476,11 @@ hali83@cec.sy',
         'PanelLendedYes' => 'مُعار',
         'PanelLendedNo' => 'متاح',
 
-        'PanelTags' => 'Tags',
-        'PanelFavourite' => 'Favourite',
-        'TagsAssigned' => 'Assigned Tags', 
+        'PanelTags' => 'وسوم',
+        'PanelFavourite' => 'محفوظات',
+        'TagsAssigned' => 'وسوم مستعملة', 
+
+        'PanelUser' => 'حقول المستخدم',
 
         'CheckUndef' => 'اما',
         'CheckYes' => 'نعم',
@@ -457,6 +490,10 @@ hali83@cec.sy',
         'ToolbarAllTooltip' => 'عرض كل العناصر',
         'ToolbarGroupBy' => 'تجميع حسب',
         'ToolbarGroupByTooltip' => 'حدد الحقل الذي سيستعمل من أجل تجميع عناصر القائمة',
+        'ToolbarQuickSearch' => 'بحث سريع',
+        'ToolbarQuickSearchLabel' => 'بحث',
+        'ToolbarQuickSearchTooltip' => 'قم بتحديد الحقل الذي سيتم البحث ضمنه.',
+        'ToolbarSeparator' => ' فاصل',
 
         'PluginsTitle' => 'البحث عن عنصر',
         'PluginsQuery' => 'إستعلام',
@@ -487,6 +524,7 @@ hali83@cec.sy',
 
         'BorrowedTitle' => 'عناصر مُعارة',
         'BorrowedDate' => 'منذ',
+        'BorrowedDisplayInPanel' => 'عرض العنصر في النافذة الرئيسية',
 
         'MailTitle' => 'إرسال رسالة إلكترونية',
         'MailFrom' => 'من: ',
@@ -527,6 +565,7 @@ hali83@cec.sy',
         'GenresModify' => 'تحرير التحويل',
 
         'PropertiesName' => 'إسم المجموعة',
+        'PropertiesLang' => 'رمز اللغة',
         'PropertiesOwner' => 'المالك',
         'PropertiesEmail' => 'بريد إلكتروني',
         'PropertiesDescription' => 'الوصف',
@@ -536,6 +575,7 @@ hali83@cec.sy',
         'PropertiesFileSize' => 'حجم',
         'PropertiesFileSizeSymbols' => ['بايت', 'كيلوبايت', 'ميغابايت', 'جيجابايت', 'تيرابايت', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'خصائص المجموعة',
+        'PropertiesDefaultPicture' => 'الصورة الإفتراضية',
 
         'MailProgramsTitle' => 'برامج من أجل إرسال البريد الإلكتروني',
         'MailProgramsName' => 'الإسم',
@@ -558,13 +598,18 @@ hali83@cec.sy',
         'AdvancedSearchTypeAnd' => 'مطابقة كل المعايير',
         'AdvancedSearchTypeOr' => 'مطايقة معيار واحد على الأقل',
         'AdvancedSearchCriteria' => 'المعيار',
-        'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchAnyField' => 'أي حقل',
+        'AdvancedSearchSaveTitle' => 'حفظ البحث',
+        'AdvancedSearchSaveName' => 'الإسم',
+        'AdvancedSearchSaveOverwrite' => 'عملية بحث تم حفظها سابقا تحمل نفس التسمية. قم بإختيار تسمية أخرى.',
+        'AdvancedSearchUseCase' => 'تحسس حالة الأحرف',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
  
-        'BugReportSubject' => 'Bug report generated from GCstar',
-        'BugReportVersion' => 'Version',
-        'BugReportPlatform' => 'Operating system',
-        'BugReportMessage' => 'Error message',
-        'BugReportInformation' => 'Additional information',
+        'BugReportSubject' => 'تقرير الإبلاغ عن خطأ قام بتوليده جي سي ستار',
+        'BugReportVersion' => 'الإصدار',
+        'BugReportPlatform' => 'نظام التشغيل',
+        'BugReportMessage' => 'رسالة الخطأ',
+        'BugReportInformation' => 'معلومات إضافية',
     );
 }
 1;
