@@ -30,6 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Invalid template file',
+        'UseFile' => 'Use file specified below',
+        'TemplateExternalFile' => 'Template file',
         'WithJS' => 'Използване Javascript',
        	'FileTemplate' => 'Шаблон :',
         'Preview' => 'Предварителен изглед',
@@ -54,6 +57,7 @@
         'Borrowed' => 'Взет от: ',
         'NotBorrowed' => 'Наличен',
         'Top' => 'Горна част',
+        'Bottom' => 'Bottom',
      );
 }
 
