@@ -109,6 +109,9 @@
             'MenuEditLockItems' => '_Заключване на колекция',
 
         'MenuDisplay' => 'Ф_илтър',
+            'MenuSavedSearches' => 'Saved searches',
+                'MenuSavedSearchesSave' => 'Save current search',
+                'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'A_dvanced Search',
             'MenuViewAllItems' => 'Показване на _всички филми',
             'MenuNoFilter' => '_Всякакъв',
@@ -116,6 +119,7 @@
         'MenuConfiguration' => '_Настройки',
             'MenuDisplayOptions' => '_Показана информация',
             'MenuBorrowers' => '_Наематели',
+            'MenuToolbarConfiguration' => '_Toolbar controls',
             'MenuGenresConversion' => 'Конвертиране на жанр',
 
         'MenuBookmarks' => 'My _Collections',
@@ -132,6 +136,11 @@
         
         'ContextExpandAll' => 'Expand all',
         'ContextCollapseAll' => 'Collapse all',
+        'ContextChooseImage' => 'Choose _Image',
+        'ContextOpenWith' => 'Open Wit_h',
+        'ContextImageEditor' => 'Image Editor',
+        'ContextImgFront' => 'Front',
+        'ContextImgBack' => 'Back',
 
         'DialogEnterNumber' => 'Please enter value',
 
@@ -148,6 +157,8 @@
         'PreferencesTooltip' => 'Установете предпочитанията си',
         'ViewTooltip' => 'Промяна на изгледа на колекция',
         'PlayTooltip' => 'Възпроизвеждане на видео, асоцииран с филм',
+        'PlayFileNotFound' => 'File to launch was not found in this location:',
+        'PlayRetry' => 'Retry',
 
         'StatusSave' => 'Saving...',
         'StatusLoad' => 'Loading...',
@@ -158,10 +169,14 @@
         'SaveError' => 'Списъкът с филми не може да бъде съхранен . Моля проверете правата за достъп и наличното дисково пространство.',
         'OpenError' => 'Списъкът с филми не може да бъде отворен. Моля проверенте правата за достъп.',
 		'OpenFormatError' => 'Списъкът с филми не може да бъде отворен.',
+        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
+        'OpenVersionQuestion' => 'Do you still want to continue?',
         'ImageError' => 'Избраната директория за съхраняване на изображения не е коректна. Моля изберете друга.',
         'OptionsCreationError'=> 'Файлът с настройки не може да бъде създаден: ',
         'OptionsOpenError'=> 'Файлът с настройки не може да бъде отворен: ',
         'OptionsSaveError'=> 'Файлът с настройки не може да бъде съхранен:',
+        'ErrorModelNotFound' => 'Model not found: ',
+        'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Какво да се гледа тази вечер?',
         'RandomError'=> 'Няме филми, които да не сте гледали',
@@ -174,8 +189,11 @@
         'AboutVersion' => 'Версия',
         'AboutTeam' => 'Екип',
         'AboutWho' => 'Christian Jodar (Tian): Мениджър на проекта, Програмист
+Nyall Dawson (Zombiepig): Програмист
+TPF: Програмист
 Adolfo González: Програмист
-Nyall Dawson (Zombiepig): Програмист',
+',
+
         'AboutLicense' => 'Разпространява се под условията на GNU GPL
 Автор на логото le Spektre
 http://le-spektre.org',
@@ -184,6 +202,7 @@ http://le-spektre.org',
 
         'ToolbarRandom' => 'Довечера',
         
+        'UnsavedCollection' => 'Unsaved Collection',
         'ModelsSelect' => 'Select a collection type',
         'ModelsPersonal' => 'Personal models',
         'ModelsDefault' => 'Default models',
@@ -205,6 +224,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maximum:',
         'ModelFieldList' => 'Values list:',
         'ModelFieldListLegend' => '<i>Comma separated</i>',
+        'ModelFieldDisplayAs' => 'Display as:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Short text',
         'ModelFieldTypeLongText' => 'Long text',
         'ModelFieldTypeYesNo' => 'Yes/No',
@@ -239,6 +261,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Should be in search box',
         'ModelFilterComparison' => 'Comparison',
         'ModelFilterContain' => 'Contains',
+        'ModelFilterDoesNotContain' => 'Does not contain',
+        'ModelFilterRegexp' => 'Regular expression',
         'ModelFilterRange' => 'Range',
         'ModelFilterNumeric' => 'Comparison is numeric',
         'ModelFilterQuick' => 'Create a quick filter',
@@ -258,20 +282,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Предпочитания',
+		'OptionsExpertMode' => 'Expert Mode',
+        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
         'OptionsBrowser' => 'Уеб-четец',
         'OptionsPlayer' => 'Видео плеър',
         'OptionsAudio' => 'Audio player',
+        'OptionsImageEditor' => 'Image Editor',
+        'OptionsCdDevice' => 'CD device',
         'OptionsImages' => 'Директория с изображения',
         'OptionsUseRelativePaths' => 'Използване на относителни пътеки към изображения',
         'OptionsLayout' => 'Оформление',
         'OptionsStatus' => 'Показване на статус-лента',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Внимание: Промените няма да имат ефект докато приложението не бъде рестартирано.',
         'OptionsRemoveConfirm' => 'Изисване на потвърждение преди изтриване',
         'OptionsAutoSave' => 'Автоматично съхраняване на колекция',
         'OptionsAutoLoad' => 'Load previous collection on startup',
         'OptionsSplash' => 'Показване на splash екран',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Use spelling checker for long text fields',
-        'OptionsImagesTitle' => 'Избор на директория',
         'OptionsProgramTitle' => 'Избор на програма, която да бъде използвана',
 		'OptionsPlugins' => 'Сайтове, от които да се получава информация',
 		'OptionsAskPlugins' => 'Питане (Всички сайтове)',
@@ -304,6 +333,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Поставяне на статиите в края на заглавията',
         'OptionsArticles' => 'Статии (Разделени със запетая)',
         'OptionsSearchStop' => 'Позволяване прекъсване на търсенето',
+        'OptionsBigPics' => 'Use big pictures when available',
         'OptionsAlwaysOriginal' => 'Използване на основното заглавие ако оригиналното не е представено',
         'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Размер на историята',
@@ -340,6 +370,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Избор',
         'ImagesOptionsBgTooltip' => 'Промяна на фонов цвят',
         'ImagesOptionsFgTooltip'=> 'Промяна на избран цвят',
+        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
         'ImagesOptionsSizeLabel' => 'Размер',
         'ImagesOptionsSizeList' => {0 => 'Много малък', 1 => 'Малък', 2 => 'Среден', 3 => 'Голям', 4 => 'Много голям'},
         'ImagesOptionsSizeTooltip' => 'Избор на размер на изображение',
@@ -367,11 +398,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Избор на полета, които да бъдат експортирани',
         'ExportWithPictures' => 'Копиране на изображенията в под-директория',
         'ExportSortBy' => 'Sort by',
+        'ExportOrder' => 'Order',
 
         'ImportListTitle' => 'Импортиране на друг списък с филми',
         'ImportExportData' => 'Data',
         'ImportExportFile' => 'Файл',
-        'ImportExportSave' => 'Моля изберете друг файл',
         'ImportExportFieldsUnused' => 'Неизползвани полета',
         'ImportExportFieldsUsed' => 'Използвани полета',
         'ImportExportFieldsFill' => 'Добавяне на всички',
@@ -385,7 +416,10 @@ http://le-spektre.org',
         'ImportDropError' => 'There was an error opening at least one file. Previous list will be reloaded.',
         'ImportGenerateId' => 'Generate identifier for each item',
 
-        'FileOverwrite' => 'Този файл вече съществува. Желаете ли презапис?',
+        'FileChooserOpenFile' => 'Моля изберете друг файл',
+        'FileChooserDirectory' => 'Directory',
+        'FileChooserOpenDirectory' => 'Избор на директория',
+        'FileChooserOverwrite' => 'Този файл вече съществува. Желаете ли презапис?',
 
         'PanelCompact' => 'Компактен',
         'PanelReadOnly' => 'Само за четене',
@@ -428,6 +462,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favourite',
         'TagsAssigned' => 'Assigned Tags', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Без значение',
         'CheckYes' => 'Да',
         'CheckNo' => 'Не',
@@ -436,6 +472,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Показване на всички филми',
         'ToolbarGroupBy' => 'Group by',
         'ToolbarGroupByTooltip' => 'Select the field to use to group items in list',
+        'ToolbarQuickSearch' => 'Quick search',
+        'ToolbarQuickSearchLabel' => 'Search',
+        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
+        'ToolbarSeparator' => ' Separator',
         
         'PluginsTitle' => 'Търсене на филм',
         'PluginsQuery' => 'Query',
@@ -466,6 +506,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Дадени филми',
         'BorrowedDate' => 'От',
+        'BorrowedDisplayInPanel' => 'Show item in main window',
 
         'MailTitle' => 'Изпращане на е-поща',
         'MailFrom' => 'От: ',
@@ -506,6 +547,7 @@ http://le-spektre.org',
         'GenresModify' => 'Редактиране на конвертирането',
 
         'PropertiesName' => 'Collection name',
+        'PropertiesLang' => 'Language code',
         'PropertiesOwner' => 'Owner',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Description',
@@ -515,6 +557,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Size',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Collection properties',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
@@ -538,6 +581,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
         'AdvancedSearchCriteria' => 'Criteria',
         'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Save search',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
 
         'BugReportSubject' => 'Bug report generated from GCstar',
         'BugReportVersion' => 'Version',
