@@ -57,7 +57,7 @@
         'Borrowed' => 'Prestatari: ',
         'NotBorrowed' => 'Disponible',
         'Top' => 'Amunt',
-        'Bottom' => 'Bottom',
+        'Bottom' => 'Devall',
      );
 }
 
