@@ -30,7 +30,8 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'Header' => 'Ignorar primera línia',
+        'Charset' => 'Joc de caràcters',
+        'Header' => 'Ignora la primera línia',
         'Separator' => 'Delimitador',
      );
 }
