@@ -30,7 +30,7 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'CopyPictures' => 'Copiar imatges',
+        'CopyPictures' => 'Copia les imatges',
      );
 }
 
