@@ -109,6 +109,9 @@ podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
             'MenuEditLockItems' => '_Bloqueja la informació',
         
         'MenuDisplay' => '_Visualitza',
+            'MenuSavedSearches' => 'Cerques desades',
+                 'MenuSavedSearchesSave' => 'Desa la cerca actual',
+                 'MenuSavedSearchesEdit' => 'Modica cerques desades',
             'MenuAdvancedSearch' => '_Cerca avançada',
             'MenuViewAllItems' => '_Mostra tots les elements',
             'MenuNoFilter' => '_Tot',
@@ -116,6 +119,7 @@ podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
         'MenuConfiguration' => '_Configura',	
             'MenuDisplayOptions' => '_Informació a mostrar',
             'MenuBorrowers' => '_Prestataris',	
+            'MenuToolbarConfiguration' => '_Controls de la barra d\'eines',
             'MenuGenresConversion' => '_Conversió de gèneres',
 
         'MenuBookmarks' => 'Les _meves Col·leccions',
@@ -132,6 +136,11 @@ podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
         
         'ContextExpandAll' => 'Expandeix tots',
         'ContextCollapseAll' => 'Colapsa tots',
+        'ContextChooseImage' => 'Tria _Imatge',
+        'ContextImageEditor' => 'Obri amb l\'editor d\'imatges',
+        'ContextOpenWith' => 'Obri _amb',
+        'ContextImgFront' => 'A sobre',
+        'ContextImgBack' => 'A sota',
 
         'DialogEnterNumber' => 'Entreu un valor',
 
@@ -148,6 +157,8 @@ podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
         'PreferencesTooltip' => 'Canvia les preferències',
         'ViewTooltip' => 'Canvia el tipus de col·lecció',
         'PlayTooltip' => 'Reprodueix el vídeo associat a l\'element',
+        'PlayFileNotFound' => 'El fitxer a reproduir no s\'ha trobat en aquest lloc:',
+        'PlayRetry' => 'Torna-ho a intentar',
         
         'StatusSave' => 'Desant...',
         'StatusLoad' => 'Carregant...',
@@ -158,10 +169,14 @@ podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
         'SaveError' => 'Impossible desar la llista d\'elements. Comproveu els permisos i l\'espai disponible en el disc.',
         'OpenError' => 'Impossible obrir la llista d\'elements. Comproveu els permisos.',
         'OpenFormatError' => 'Impossible obrir la llista d\'elements. El format pot ser incorrecte',
+        'OpenVersionWarning' => 'La col·lecció s\'ha creat amb una versió més recent de GCstar. Si la deseu, podeu perdre dades.',
+        'OpenVersionQuestion' => 'Encara voleu continuar?',
         'ImageError' => 'El directori triat per a desar les imatges no és correcte. Voleu triar-ne un altre?',
         'OptionsCreationError'=> 'Impossible crear el fitxer d\'opcions: ',
         'OptionsOpenError'=> 'Impossible obrir el fitxer d\'opcions: ',
         'OptionsSaveError'=> 'Impossible desar el fitxer d\'opcions: ',
+        'ErrorModelNotFound' => 'Model no trobat: ',
+        'ErrorModelUserDir' => 'Els models definits per l\'usuari són a: ',
 
         'RandomTooltip' => 'Qué voleu veure aquesta nit?',
         'RandomError'=> 'No queden elements per a seleccionar',
@@ -174,8 +189,10 @@ podeu usar <b>el botó situat devall dels detalls de la pel·lícula</b>.',
         'AboutVersion' => 'Versió',
         'AboutTeam' => 'Equip',
         'AboutWho' => 'Christian Jodar (Tian): Gestió del projecte, Programació
+Nyall Dawson (Zombiepig): Programació
+TPF: Programació
 Adolfo González: Programació
-Nyall Dawson (Zombiepig): Programació',
+',
         'AboutLicense' => 'Distribuït segons els termes de la GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
@@ -184,6 +201,7 @@ http://le-spektre.org',
         
         'ToolbarRandom' => 'Aquesta nit',
 
+        'UnsavedCollection' => 'Col·lecció no desada',
         'ModelsSelect' => 'Seleccioneu un tipus de Col·lecció',
         'ModelsPersonal' => 'Models personals',
         'ModelsDefault' => 'Models predeterminats',
@@ -205,6 +223,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Màxim:',
         'ModelFieldList' => 'Llista de valors:',
         'ModelFieldListLegend' => '<i>Separat per a coma</i>',
+        'ModelFieldDisplayAs' => 'Mostra com:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Control de rati',
         'ModelFieldTypeShortText' => 'Text curt',
         'ModelFieldTypeLongText' => 'Text llarg',
         'ModelFieldTypeYesNo' => 'Sí/No',
@@ -239,6 +260,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Hauria d\'estar al formulari de cerca',
         'ModelFilterComparison' => 'Comparació',
         'ModelFilterContain' => 'Conté',
+        'ModelFilterDoesNotContain' => 'No conté',
+        'ModelFilterRegexp' => 'Expressió regular',
         'ModelFilterRange' => 'Rang',
         'ModelFilterNumeric' => 'La comparació és numèrica',
         'ModelFilterQuick' => 'Crea un filtre ràpid',
@@ -258,20 +281,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'Podeu afegir múltiples elements a la col·lecció pitjant la tecla Ctrl o Majús i seleccionant-los',
 
         'OptionsTitle' => 'Preferències',
+		'OptionsExpertMode' => 'Mode Expert',
+        'OptionsPrograms' => 'Especifiqueu els programes a utilitzar pels diferents continguts, deixau-ho en blanc per utilitzar els predeterminats del sistema',
         'OptionsBrowser' => 'Navegador d\'Internet',
         'OptionsPlayer' => 'Reproductor de vídeo',
         'OptionsAudio' => 'Reproductor d\'audio',
+        'OptionsImageEditor' => 'Editor d\'imatges',
+        'OptionsCdDevice' => 'Dispositiu de CD',
         'OptionsImages' => 'Directori d\'imatges',
         'OptionsUseRelativePaths' => 'Utilitza camins relatius per a les imatges',
         'OptionsLayout' => 'Disposició',
         'OptionsStatus' => 'Mostra la barra d\'estat',	
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Alerteu: Els canvis fets a n\'aquest formulari no es tindran en compte fins reiniciar l\'aplicació', 
         'OptionsRemoveConfirm' => 'Demana confirmació abans d\'eliminar',
         'OptionsAutoSave' => 'Desa automàticament la col·lecció',
         'OptionsAutoLoad' => 'Carrega la col·lecció prèvia a l\'inici',
         'OptionsSplash' => 'Mostra la pantalla d\'inici', 
+        'OptionsTearoffMenus' => 'Activa els menús desplegables',
         'OptionsSpellCheck' => 'Utilitza la correcció ortogràfica pels camps de text llargs',
-        'OptionsImagesTitle' => 'Tria un directori',	
         'OptionsProgramTitle' => 'Tria el programa que ha d\'utilitzar-se',
         'OptionsPlugins' => 'Lloc per descarregar les fitxes',
         'OptionsAskPlugins' => 'Pregunta',
@@ -304,6 +332,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Posar els articles al final dels títols',	
         'OptionsArticles' => 'Articles (separats per una coma)',	
         'OptionsSearchStop' => 'L\'usuari pot aturar las cerques',
+        'OptionsBigPics' => 'Utilitza les imatges grans quan estiguin disponibles',
         'OptionsAlwaysOriginal' => 'Empra el títol principal com l\'original si no se\'n troba cap',
         'OptionsRestoreAccelerators' => 'Restaura acceleradors',
         'OptionsHistory' => 'Mida de l\'historial',
@@ -340,6 +369,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Selecció',
         'ImagesOptionsBgTooltip' => 'Canvia el color de fons',
         'ImagesOptionsFgTooltip'=> 'Canvia el color de la selecció',
+        'ImagesOptionsResizeImgList' => 'Canvia automàticament el nombre de columnes',
         'ImagesOptionsSizeLabel' => 'Mida',
         'ImagesOptionsSizeList' => {0 => 'Molt Petit', 1 => 'Petit', 2 => 'Mitjà', 3 => 'Gran', 4 => 'Molt Gran'},
         'ImagesOptionsSizeTooltip' => 'Trieu la mida de la imatge',
@@ -367,11 +397,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Trieu els camps a exportar',
         'ExportWithPictures' => 'Copia les imatges a un subdirectori',
         'ExportSortBy' => 'Ordena per',
+        'ExportOrder' => 'Ordre',
 
         'ImportListTitle' => 'Importa un altre llistat d\'elements',
         'ImportExportData' => 'Dades',
         'ImportExportFile' => 'fitxer',
-        'ImportExportSave' => 'Tria el fitxer a utilitzar', 	
         'ImportExportFieldsUnused' => 'Camps sense utilitzar',
         'ImportExportFieldsUsed' => 'Camps utilitzats',
         'ImportExportFieldsFill' => 'Tots els camps',
@@ -385,7 +415,10 @@ http://le-spektre.org',
         'ImportDropError' => 'Hi ha hagut un error obrint al menys un fitxer. Es recarregarà el llistat anterior.',
         'ImportGenerateId' => 'Genera un identificador per a cada element',
 
-        'FileOverwrite' => 'Aquest fitxer ja existeix. Voleu substituir-lo?',
+        'FileChooserOpenFile' => 'Tria el fitxer a utilitzar', 	
+        'FileChooserDirectory' => 'Directori',
+        'FileChooserOpenDirectory' => 'Tria un directori',	
+        'FileChooserOverwrite' => 'Aquest fitxer ja existeix. Voleu substituir-lo?',
 
         #Some default panels
         'PanelCompact' => 'Compacte',
@@ -429,6 +462,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favorit',
         'TagsAssigned' => 'Etiquetes assignades', 
 
+        'PanelUser' => 'Camps d\'usuari',
+
         'CheckUndef' => 'Qualsevol',
         'CheckYes' => 'Sí',
         'CheckNo' => 'No',
@@ -437,6 +472,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Mostra tots els elements',	
         'ToolbarGroupBy' => 'Agrupa per',
         'ToolbarGroupByTooltip' => 'Tria el camp per agrupar elements a la llista',
+        'ToolbarQuickSearch' => 'Cerca ràpida',
+        'ToolbarQuickSearchLabel' => 'Cerca',
+        'ToolbarQuickSearchTooltip' => 'Seleccioneu el camp per a cercar. Entreu els termes de cerca i premeu Intro',
+        'ToolbarSeparator' => ' Separador',
 
         'PluginsTitle' => 'Cerca un element',
         'PluginsQuery' => 'Petició',
@@ -467,6 +506,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Elements prestats',	
         'BorrowedDate' => 'Des del',
+        'BorrowedDisplayInPanel' => 'Mostra l\'element a la finestra principal',
         
         'MailTitle' => 'Envia un correu electrònic',	
         'MailFrom' => 'De: ',	
@@ -507,6 +547,7 @@ http://le-spektre.org',
         'GenresModify' => 'Edita la conversió',
 
         'PropertiesName' => 'Nom de la col·lecció',
+        'PropertiesLang' => 'Codi d\'idioma',
         'PropertiesOwner' => 'Propietari',
         'PropertiesEmail' => 'Correu electrònic',
         'PropertiesDescription' => 'Descripció',
@@ -516,6 +557,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Mida',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Propietats de la col·lecció',
+        'PropertiesDefaultPicture' => 'Imatge per omissió',
 
         'MailProgramsTitle' => 'Programes per enviar correu',
         'MailProgramsName' => 'Nom',
@@ -539,6 +581,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Elements que compleixen al menys amb un criteri',
         'AdvancedSearchCriteria' => 'Criteri',
         'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Desa la cerca',
+        'AdvancedSearchSaveName' => 'Nom',
+        'AdvancedSearchSaveOverwrite' => 'Ja existeix una cerca desada amb aquest nom. Trieu-ne un altre.',
+        'AdvancedSearchUseCase' => 'Sensible a les majúscules',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignora els accents',
 
         'BugReportSubject' => 'Informe d\'error generat per GCstar',
         'BugReportVersion' => 'Versió',
