@@ -108,6 +108,9 @@ K rozlišení, který server vlastní dané informace, můžete použít
             'MenuEditLockItems' => '_Uzamkni sbírku',
     
         'MenuDisplay' => '_Filtr',
+            'MenuSavedSearches' => 'Saved searches',
+                'MenuSavedSearchesSave' => 'Save current search',
+                'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => '_Pokročilé vyhledávání',
             'MenuViewAllItems' => 'Zobrazit _všechny položky',
             'MenuNoFilter' => '_Vše',
@@ -115,6 +118,7 @@ K rozlišení, který server vlastní dané informace, můžete použít
         'MenuConfiguration' => '_Nastavení',
             'MenuDisplayOptions' => '_Zobrazené informace',
             'MenuBorrowers' => '_Dlužníci',
+            'MenuToolbarConfiguration' => '_Toolbar controls',
             'MenuGenresConversion' => '_Konverze žánru',
         
         'MenuBookmarks' => 'Mé _Sbíky',
@@ -131,7 +135,12 @@ K rozlišení, který server vlastní dané informace, můžete použít
         
         'ContextExpandAll' => 'Zobraz vše',
         'ContextCollapseAll' => 'Skryj vše',
-    
+        'ContextChooseImage' => 'Choose _Image',
+        'ContextOpenWith' => 'Open Wit_h',
+        'ContextImageEditor' => 'Image Editor',
+        'ContextImgFront' => 'Front',
+        'ContextImgBack' => 'Back',
+
         'DialogEnterNumber' => 'Prosím zadej hodnotu',
 
         'RemoveConfirm' => 'Opravdu chcete vymazat tuto položku?',
@@ -147,6 +156,8 @@ K rozlišení, který server vlastní dané informace, můžete použít
         'PreferencesTooltip' => 'Umožňuje změnu nastavení',
         'ViewTooltip' => 'Změní zobrazení sbírky',
         'PlayTooltip' => 'Přehraje video asociované filmem',
+        'PlayFileNotFound' => 'File to launch was not found in this location:',
+        'PlayRetry' => 'Retry',
 
         'StatusSave' => 'Ukládám...',
         'StatusLoad' => 'Nahrávám...',
@@ -157,10 +168,14 @@ K rozlišení, který server vlastní dané informace, můžete použít
         'SaveError' => 'Nemohu uložit seznam. Prosím zkontrolujte přístupová práva a volné místo na disku.',
         'OpenError' => 'Nemohu otevřít seznam. Prosím zkontrolujte přístupová práva.',
         'OpenFormatError' => 'Nemohu otevřít seznam.',
+        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
+        'OpenVersionQuestion' => 'Do you still want to continue?',
         'ImageError' => 'Adresář vybraný k ukládání obrázků není správný. Prosím vyberte jiný.',
         'OptionsCreationError'=> 'Nemohu vytvořit soubor s nastavením: ',
         'OptionsOpenError'=> 'Nemohu otevřít soubor s nastavením: ',
         'OptionsSaveError'=> 'Nemohu uložit soubor s nastavením: ',
+        'ErrorModelNotFound' => 'Model not found: ',
+        'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Co budu dělat dnes večer?',
         'RandomError'=> 'Nic nemáte',
@@ -173,8 +188,10 @@ K rozlišení, který server vlastní dané informace, můžete použít
         'AboutVersion' => 'Verze',
         'AboutTeam' => 'Tým',
         'AboutWho' => 'Christian Jodar (Tian): Project manager, Programmer
+Nyall Dawson (Zombiepig): Programmer
+TPF: Programmer
 Adolfo González: Programmer
-Nyall Dawson (Zombiepig): Programmer',
+',
         'AboutLicense' => 'Distribuováno za podmínek GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
@@ -183,6 +200,7 @@ http://le-spektre.org',
 
         'ToolbarRandom' => 'Dnes večer',
         
+        'UnsavedCollection' => 'Unsaved Collection',
         'ModelsSelect' => 'Vyber typ sbírky',
         'ModelsPersonal' => 'Vlastní šablony',
         'ModelsDefault' => 'Standardní šablony',
@@ -204,6 +222,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maximální:',
         'ModelFieldList' => 'Seznam hodnot:',
         'ModelFieldListLegend' => '<i>Oddělovač je čárka</i>',
+        'ModelFieldDisplayAs' => 'Display as:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Krátký text',
         'ModelFieldTypeLongText' => 'Dlouhý text',
         'ModelFieldTypeYesNo' => 'Ano/Ne',
@@ -238,6 +259,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Pole bude ve vyhledávání',
         'ModelFilterComparison' => 'Porovnání',
         'ModelFilterContain' => 'Obsahuje',
+        'ModelFilterDoesNotContain' => 'Does not contain',
+        'ModelFilterRegexp' => 'Regular expression',
         'ModelFilterRange' => 'Rozsah',
         'ModelFilterNumeric' => 'Porovnávání je číselné',
         'ModelFilterQuick' => 'Vytvořit rychlý filtr',
@@ -257,20 +280,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Možnosti',
+		'OptionsExpertMode' => 'Expert Mode',
+        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
         'OptionsBrowser' => 'Webový prohlížeč',
         'OptionsPlayer' => 'Přehrávač videa',
         'OptionsAudio' => 'Přehrávač hudby',
+        'OptionsImageEditor' => 'Image Editor',
+        'OptionsCdDevice' => 'CD device',
         'OptionsImages' => 'Adresář s obrázky',
         'OptionsUseRelativePaths' => 'Pro obrázky používat relativní cesty',
         'OptionsLayout' => 'Rozložení',
         'OptionsStatus' => 'Zobrazit stavový řádek',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Varování: Změny v této záložce budou bez efektu až do restartu aplikace',
         'OptionsRemoveConfirm' => 'Před smazáním položky požadovat potvrzení',
         'OptionsAutoSave' => 'Automaticky ukládat sbírku',
         'OptionsAutoLoad' => 'Při startu nahrát předchozí sbírku',
         'OptionsSplash' => 'Zobrazit úvodní obrázek',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Use spelling checker for long text fields',
-        'OptionsImagesTitle' => 'Vyberte adresář pro ukládání obrázků',
         'OptionsProgramTitle' => 'Vyberte webový prohlížeč',
 		'OptionsPlugins' => 'Server, odkud stahovat data',
 		'OptionsAskPlugins' => 'Zeptat se (všechny servery)',
@@ -303,6 +331,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Členy umístit na konce názvů',
         'OptionsArticles' => 'Členy (odděleny čárkou)',
         'OptionsSearchStop' => 'Umožnit zrušení hledání',
+        'OptionsBigPics' => 'Use big pictures when available',
         'OptionsAlwaysOriginal' => 'Použít hlavní titul jako originální titul, pokud není vyplněn',
         'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Velikost historie',
@@ -339,6 +368,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Výběr',
         'ImagesOptionsBgTooltip' => 'Změna barvy pozadí',
         'ImagesOptionsFgTooltip'=> 'Změna barvy výběru',
+        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
         'ImagesOptionsSizeLabel' => 'Velikost obrázků',
         'ImagesOptionsSizeList' => {0 => 'Velmi malé', 1 => 'Malé', 2 => 'Středně velké', 3 => 'Velké', 4 => 'Velmi velké'},
         'ImagesOptionsSizeTooltip' => 'Výběr velikosti obrázků',
@@ -366,11 +396,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Vyber pole k exportu',
         'ExportWithPictures' => 'Zkopírovat obrázky do podadresáře',
         'ExportSortBy' => 'Řadit podle',
+        'ExportOrder' => 'Order',
 
         'ImportListTitle' => 'Import dalšího seznamu',
         'ImportExportData' => 'Data',
         'ImportExportFile' => 'Soubor',
-        'ImportExportSave' => 'Prosím vyberte soubor',
         'ImportExportFieldsUnused' => 'Nepoužité pole',
         'ImportExportFieldsUsed' => 'Použité pole',
         'ImportExportFieldsFill' => 'Přidat vše',
@@ -384,7 +414,10 @@ http://le-spektre.org',
         'ImportDropError' => 'Při otevírání souboru se vyskytl problém. Znovu se načte předchozí seznam.',
         'ImportGenerateId' => 'Vytvořit identifikátor pro každou položku',
 
-        'FileOverwrite' => 'Tento soubor již existuje. Chcete jej přepsat?',
+        'FileChooserOpenFile' => 'Prosím vyberte soubor',
+        'FileChooserDirectory' => 'Directory',
+        'FileChooserOpenDirectory' => 'Vyberte adresář pro ukládání obrázků',
+        'FileChooserOverwrite' => 'Tento soubor již existuje. Chcete jej přepsat?',
 
         'PanelCompact' => 'Kompaktní',
         'PanelReadOnly' => 'Pouze pro čtení',
@@ -427,6 +460,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favourite',
         'TagsAssigned' => 'Assigned Tags', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Nezáleží',
         'CheckYes' => 'Ano',
         'CheckNo' => 'Ne',
@@ -435,6 +470,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Zobrazí celý seznam',
         'ToolbarGroupBy' => 'Řadit podle',
         'ToolbarGroupByTooltip' => 'Vyberte pole, podle kterého se mají řadit položky seznamu',
+        'ToolbarQuickSearch' => 'Quick search',
+        'ToolbarQuickSearchLabel' => 'Search',
+        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
+        'ToolbarSeparator' => ' Separator',
         
         'PluginsTitle' => 'Hledat',
         'PluginsQuery' => 'Dotaz',
@@ -465,6 +504,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Půjčené položky',
         'BorrowedDate' => 'Od',
+        'BorrowedDisplayInPanel' => 'Show item in main window',
 
         'MailTitle' => 'Poslat e-mail',
         'MailFrom' => 'Od: ',
@@ -505,6 +545,7 @@ http://le-spektre.org',
         'GenresModify' => 'Upravit konverzi',
 
         'PropertiesName' => 'Název sbírky',
+        'PropertiesLang' => 'Language code',
         'PropertiesOwner' => 'Vlastník',
         'PropertiesEmail' => 'E-mail',
         'PropertiesDescription' => 'Popis',
@@ -514,6 +555,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Velikost',
         'PropertiesFileSizeSymbols' => ['Bytů', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Vlastnosti sbírky',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Programy pro odesílání mailů',
         'MailProgramsName' => 'Název',
@@ -537,6 +579,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Položky odpovídají alespoň jedné podmínce',
         'AdvancedSearchCriteria' => 'Podmínky',
         'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Save search',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
 
         'BugReportSubject' => 'Zpráva o chybě generovaná z GCstar',
         'BugReportVersion' => 'Verze',
