@@ -108,6 +108,9 @@ Webseite, von der die Informationen stammen.',
 		'MenuEditLockItems' => 'Liste _sperren',
 
 	'MenuDisplay' => '_Filter',
+        'MenuSavedSearches' => 'Gespeicherte Suchanfragen',
+        'MenuSavedSearchesSave' => 'Aktuelle Suchanfrage speichern',
+        'MenuSavedSearchesEdit' => 'Gespeicherte Suchanfragen bearbeiten',
         'MenuAdvancedSearch' => 'Erweiterte Suche',
 		'MenuViewAllItems' => '_Alle Elemente anzeigen',
 		'MenuNoFilter' => '_Alle',
@@ -115,6 +118,7 @@ Webseite, von der die Informationen stammen.',
 	'MenuConfiguration' => '_Einstellungen',
 		'MenuDisplayOptions' => 'Sichtbare _Felder',
 		'MenuBorrowers' => 'Ent_leiher',
+		'MenuToolbarConfiguration' => '_Werkzeugleiste konfigurieren',
         'MenuGenresConversion' => 'Genres _konvertieren',
 
     'MenuBookmarks' => 'Meine _Sammlung',
@@ -131,6 +135,11 @@ Webseite, von der die Informationen stammen.',
         
         'ContextExpandAll' => 'alle ausklappen',
         'ContextCollapseAll' => 'alle zusammenklappen',
+        'ContextChooseImage' => '_Bild wählen',
+        'ContextOpenWith' => 'Öffnen mit',
+        'ContextImageEditor' => 'Bildbearbeitungsprogramm',
+        'ContextImgFront' => 'Vorderseite',
+        'ContextImgBack' => 'Rückseite',
 
         'DialogEnterNumber' => 'Bitte geben Sie einen Wert ein',
 
@@ -147,6 +156,8 @@ Webseite, von der die Informationen stammen.',
         'PreferencesTooltip' => 'Ändern der Programmeinstellungen',
         'ViewTooltip' => 'Anzeige der Liste ändern',
         'PlayTooltip' => 'Mit dem Film verknüpftes Video abspielen',
+        'PlayFileNotFound' => 'Abzuspielende Datei nicht gefunden in:',
+        'PlayRetry' => 'Retry',
 
         'StatusSave' => 'Speichere...',
         'StatusLoad' => 'Lade...',
@@ -157,24 +168,29 @@ Webseite, von der die Informationen stammen.',
         'SaveError' => 'Die Liste kann nicht gespeichert werden. Bitte überprüfen Sie die Dateirechte, und ob genügend freier Speicherplatz zur Verfügung steht.',
         'OpenError' => 'Kann die Liste nicht öffnen. Bitte überprüfen Sie die Dateirechte.',
         'OpenFormatError' => 'Kann die Liste nicht öffnen.',
+        'OpenVersionWarning' => 'Die Sammlung wurde mit einer neueren Version von GCStar erzeugt. Beim speichern können Daten verloren gehen.',
+        'OpenVersionQuestion' => 'Möchten Sie trotzdem fortfahren?',
         'ImageError' => 'Das Verzeichnis zum Speichern der Bilder ist nicht korrekt. Bitte wählen Sie ein anderes.',
         'OptionsCreationError'=> 'Kann die Einstellungsdatei nicht erstellen: ',
         'OptionsOpenError'=> 'Kann die Einstellungen nicht laden: ',
         'OptionsSaveError'=> 'Kann die Einstellungen nicht speichern: ',
-        
-        'RandomTooltip' => 'Film für heute Abend vorschlagen',
-        'RandomError'=> 'Sie haben keine ungesehenen Filme',
-        'RandomEnd'=> 'Keine weiteren Filme verfügbar',
+        'ErrorModelNotFound' => 'Folgendes Modell wurde nicht gefunden: ',
+        'ErrorModelUserDir' => 'Die Nutzerdefinierten Modelle sind in: ',        
+        'RandomTooltip' => 'Element für heute Abend vorschlagen',
+        'RandomError'=> 'Sie haben keine ungesehenen Elemente',
+        'RandomEnd'=> 'Keine weiteren Vorschläge verfügbar',
         'RandomNextTip'=> 'Nächster Vorschlag',
-        'RandomOkTip'=> 'Diesen Film akzeptieren',
+        'RandomOkTip'=> 'Diesen Vorschlag akzeptieren',
         
         'AboutTitle' => 'Über GCstar',
         'AboutDesc' => 'Gtk2 Sammlungs Manager',
         'AboutVersion' => 'Version',
         'AboutTeam' => 'Team',
         'AboutWho' => 'Christian Jodar (Tian) : Projektmanager, Programmierer
+Nyall Dawson (Zombiepig) : Programmierer
+TPF : Programmierer
 Adolfo González : Programmierer
-Nyall Dawson (Zombiepig) : Programmierer',
+',
         'AboutLicense' => 'Veröffentlicht unter den Bedingungen der GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
@@ -183,6 +199,7 @@ http://le-spektre.org',
         
         'ToolbarRandom' => 'Heute Abend',
         
+        'UnsavedCollection' => 'Ungespeicherte Sammlung',
         'ModelsSelect' => 'Wählen Sie den Typ der Sammlung',
         'ModelsPersonal' => 'Eigene Modelle',
         'ModelsDefault' => 'Vorgegebene Modelle',
@@ -204,6 +221,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maximum:',
         'ModelFieldList' => 'Wertliste:',
         'ModelFieldListLegend' => '<i>Kommasepariert</i>',
+        'ModelFieldDisplayAs' => 'Anzeige als:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Bewertungselement',
         'ModelFieldTypeShortText' => 'Kurzer Text',
         'ModelFieldTypeLongText' => 'Langer Text',
         'ModelFieldTypeYesNo' => 'Ja/Nein',
@@ -215,7 +235,7 @@ http://le-spektre.org',
         'ModelFieldTypeFile' => 'Datei',
         'ModelFieldTypeFormatted' => 'von anderen Feldern abhängig',
         'ModelFieldParameters' => 'Parameter',
-        'ModelFieldHasHistory' => 'Benutze History',
+        'ModelFieldHasHistory' => 'Benutze Verlauf',
         'ModelFieldFlat' => 'Auf einer Zeile anzeigen',
         'ModelFieldStep' => 'Schrittweite:',
         'ModelFieldFileFormat' => 'Dateiformat:',
@@ -238,6 +258,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Soll in Suchfeld sein',
         'ModelFilterComparison' => 'Vergleich',
         'ModelFilterContain' => 'Beinhaltet',
+        'ModelFilterDoesNotContain' => 'ist nicht enthalten',
+        'ModelFilterRegexp' => 'Regulärer Ausdruck',
         'ModelFilterRange' => 'Bereich',
         'ModelFilterNumeric' => 'numerischer Vergleich',
 		'ModelFilterQuick' => 'Schnellen Filter erstellen',
@@ -257,20 +279,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'Es können mehrere Elemente durch Auswahl bei gedrückter STRG oder UMSCHALT Taste zu der Sammlung hinzugefügt werden.',
         
         'OptionsTitle' => 'Einstellungen',
-        'OptionsBrowser' => 'Web-Browser',
+		'OptionsExpertMode' => 'Expertenmodus',
+        'OptionsPrograms' => 'Wählen Sie eine Anwendung für verschiedene Medientypen. Wird nichts eingetragen, werden die Voreinstellungen des Systems verwendet.',
+        'OptionsBrowser' => 'Internetbrowser',
         'OptionsPlayer' => 'Videoabspielprogramm',
         'OptionsAudio' => 'Musikabspielprogramm',
+        'OptionsImageEditor' => 'Bildbearbeitungsprogramm',
+        'OptionsCdDevice' => 'CD Gerät',
         'OptionsImages' => 'Verzeichnis für Bilder',
         'OptionsUseRelativePaths' => 'Relative Pfade für Bilder verwenden',
         'OptionsLayout' => 'Layout',
         'OptionsStatus' => 'Statusleiste am unteren Fensterrand anzeigen',
+        'OptionsUseStars' => 'Sterne für die Bewertung nutzen',
         'OptionsWarning' => 'Warnung: Die Einstellungen in diesem Panel werden erst nach dem Neustart der Anwendung wirksam!',
         'OptionsRemoveConfirm' => 'Löschen von Elementen bestätigen lassen',
         'OptionsAutoSave' => 'Sammlung automatisch speichern',
         'OptionsAutoLoad' => 'Vorhergehende Sammlung beim Programmstart laden',
         'OptionsSplash' => 'Splash-Screen anzeigen',
+        'OptionsTearoffMenus' => 'Ablösbare Menüs aktivieren',
         'OptionsSpellCheck' => 'Rechtschreibprüfung für lange Textfelder verwenden',
-        'OptionsImagesTitle' => 'Wählen Sie ein Verzeichnis',
         'OptionsProgramTitle' => 'Wählen Sie die gewünschte Anwendung',
 		'OptionsPlugins' => 'Seite zum Bezug von Informationen',
 		'OptionsAskPlugins' => 'Fragen (Alle Seiten)',
@@ -287,15 +314,29 @@ http://le-spektre.org',
         'OptionsConveniences' => 'Eigenschaften',
         'OptionsDisplay' => 'Anzeige',
         'OptionsToolbar' => 'Werkzeugleiste',
-        'OptionsToolbars' => {0 => 'Keine', 1 => 'Klein', 2 => 'Groß', 3 => 'Systemeinstellung'},
+		'OptionsToolbars' => {
+			0 => 'Keine', 
+			1 => 'Klein', 
+			2 => 'Groß', 
+			3 => 'Systemeinstellung'},
         'OptionsToolbarPosition' => 'Position',
-        'OptionsToolbarPositions' => {0 => 'Oben', 1 => 'Unten', 2 => 'Links', 3 => 'Rechts'},
+        'OptionsToolbarPositions' => {
+			0 => 'Oben', 
+			1 => 'Unten', 
+			2 => 'Links', 
+			3 => 'Rechts'},
         'OptionsExpandersMode' => 'ausklappbare Zeile zu lang',
-        'OptionsExpandersModes' => {'asis' => 'Tue nichts', 'cut' => 'Abschneiden', 'wrap' => 'Zeilenumbruch'},
+		'OptionsExpandersModes' => {
+			'asis' => 'Unverändert', 
+			'cut' => 'Abschneiden', 
+			'wrap' => 'Zeilenumbruch'},
         'OptionsDateFormat' => 'Datumsformat',
         'OptionsDateFormatTooltip' => 'Das Format entspricht dem bei der Funktion strftime(3) genutzten. Voreinstellung ist %d/%m/%Y',
         'OptionsView' => 'Listenansicht',
-        'OptionsViews' => {0 => 'Text', 1 => 'Bilder', 2 => 'Detailliert'},
+        'OptionsViews' => {
+			0 => 'Text', 
+			1 => 'Bilder', 
+			2 => 'Detailliert'},
         'OptionsColumns' => 'Spalten',
         'OptionsMailer' => 'E-Mail-Versand per',
         'OptionsSMTP' => 'Server',
@@ -303,8 +344,9 @@ http://le-spektre.org',
         'OptionsTransform' => 'Artikel ans Ende des Titels stellen',
         'OptionsArticles' => 'Artikel (getrennt durch Kommata)',
         'OptionsSearchStop' => 'Suche kann abgebrochen werden',
+        'OptionsBigPics' => 'Große Bilder anzeigen sofern verfügbar',
         'OptionsAlwaysOriginal' => 'Titel statt Originaltitel verwenden, wenn dieser nicht vorhanden ist',
-        'OptionsRestoreAccelerators' => 'Restore accelerators',
+        'OptionsRestoreAccelerators' => 'Schnellzugriffe wiederherstellen',
         'OptionsHistory' => 'Größe des Verlaufs',
         'OptionsClearHistory' => 'Verlauf löschen',
 		'OptionsStyle' => 'Skin',
@@ -312,7 +354,7 @@ http://le-spektre.org',
         'OptionsPathProgramsGroup' => 'Anwendungsprogramme',
         'OptionsProgramsSystem' => 'Nutze systemweite Einstellungen',
         'OptionsProgramsUser' => 'Nutze hier angegebene Programme',
-        'OptionsProgramsSet' => 'Setze Programme',
+        'OptionsProgramsSet' => 'Programmeinstellungen',
         'OptionsPathImagesGroup' => 'Bilder',
         'OptionsInternetDataGroup' => 'Datenimport',
         'OptionsInternetSettingsGroup' => 'Einstellungen',
@@ -339,10 +381,11 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Auswahl',
         'ImagesOptionsBgTooltip' => 'Hintergrundfarbe ändern',
         'ImagesOptionsFgTooltip'=> 'Farbe für die Auswahl einstellen',
+        'ImagesOptionsResizeImgList' => 'Anzahl der Spalten automatisch anpassen',
         'ImagesOptionsSizeLabel' => 'Größe',
         'ImagesOptionsSizeList' => {0 => 'Sehr klein', 1 => 'Klein', 2 => 'Mittel', 3 => 'Groß', 4 => 'Sehr Groß'},
         'ImagesOptionsSizeTooltip' => 'Bildgröße auswählen',
-		        
+
         'DetailedOptionsTitle' => 'Einstellungen für die detaillierte Sammlung',
         'DetailedOptionsImageSize' => 'Bildgröße',
         'DetailedOptionsGroupItems' => 'Gruppiere Elemente nach',
@@ -366,11 +409,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Wählen Sie die zu exportierenden Felder',
         'ExportWithPictures' => 'Bilder in ein Unterverzeichnis kopieren',
         'ExportSortBy' => 'Sortierung nach',
+        'ExportOrder' => 'Reihenfolge',
 
         'ImportListTitle' => 'Eine weitere Sammlung importieren',
         'ImportExportData' => 'Data',
         'ImportExportFile' => 'Datei',
-        'ImportExportSave' => 'Bitte wählen Sie die zu verwendende Datei',
         'ImportExportFieldsUnused' => 'Freie Felder',
         'ImportExportFieldsUsed' => 'Verwendete Felder',
         'ImportExportFieldsFill' => 'Alle hinzufügen',
@@ -384,7 +427,10 @@ http://le-spektre.org',
         'ImportDropError' => 'Es gab mindestens einen Fehler beim Öffnen der Dateien. Vorherige Liste wird wiederhergestellt.',
         'ImportGenerateId' => 'ID für jedes Element erzeugen',
 
-        'FileOverwrite' => 'Diese Datei existiert bereits. Möchten Sie sie überschreiben?',
+        'FileChooserOpenFile' => 'Bitte wählen Sie die zu verwendende Datei',
+        'FileChooserDirectory' => 'Verzeichnis',
+        'FileChooserOpenDirectory' => 'Wählen Sie ein Verzeichnis',
+        'FileChooserOverwrite' => 'Diese Datei existiert bereits. Möchten Sie sie überschreiben?',
 
         'PanelCompact' => 'Komprimieren',
         'PanelReadOnly' => 'Nur Lesen',
@@ -427,6 +473,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favoriten',
         'TagsAssigned' => 'Zugeordnete Tags', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Egal',
         'CheckYes' => 'Ja',
         'CheckNo' => 'Nein',
@@ -435,6 +483,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Alle Elemente anzeigen',
         'ToolbarGroupBy' => 'Gruppiere nach',
         'ToolbarGroupByTooltip' => 'Wählen Sie das Feld, nach dem die Einträge gruppiert werden sollen',
+        'ToolbarQuickSearch' => 'Schnelle Suche',
+        'ToolbarQuickSearchLabel' => 'Suche',
+        'ToolbarQuickSearchTooltip' => 'Bitte wählen Sie das Feld, in dem gesucht werden soll. Geben Sie den Suchbegriff ein und drücken Sie anschließend Enter.',
+        'ToolbarSeparator' => ' Trenner',
         
         'PluginsTitle' => 'Nach einem Element suchen',
         'PluginsQuery' => 'Query',
@@ -465,6 +517,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Verliehene Elemente',
         'BorrowedDate' => 'Seit',
+        'BorrowedDisplayInPanel' => 'Elemente im Hauptfenster anzeigen',
 
         'MailTitle' => 'E-Mail senden',
         'MailFrom' => 'Von: ',
@@ -505,6 +558,7 @@ http://le-spektre.org',
         'GenresModify' => 'Genre bearbeiten',
 
         'PropertiesName' => 'Name der Sammlung',
+        'PropertiesLang' => 'Sprachcode',
         'PropertiesOwner' => 'Besitzer',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Beschreibung',
@@ -514,6 +568,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Dateigröße',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Eigenschaften der Sammlung',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Programm zum senden von Emails',
         'MailProgramsName' => 'Name',
@@ -537,6 +592,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Elemente, die mindestens ein Kriterium erfüllen',
         'AdvancedSearchCriteria' => 'Suchkriterium',
         'AdvancedSearchAnyField' => 'In allen Elementen',
+        'AdvancedSearchSaveTitle' => 'Suchanfrage speichern',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'Es existiert bereits eine Suchanfrage mit diesem Namen. Bitte nutzen Sie einen anderen.',
+        'AdvancedSearchUseCase' => 'Groß/Kleinschreibung beachten',
+        'AdvancedSearchIgnoreDiacritics' => 'Sonderzeichen ignorieren',
 
         'BugReportSubject' => 'Fehlermeldung erstellt von GCstar',
         'BugReportVersion' => 'Version',
