@@ -67,8 +67,8 @@ may use the <b>button below item details</b>.',
         'InstallWithMenu' => 'Add GCstar to Applications menu',
         'InstallNoPermission' => 'Error: You don\'t have permission to write in the selected directory',
         'InstallMissingMandatory' => 'Mandatory dependencies are missing. You won\'t be able to install GCstar until they have been added to your system.',
-        'InstallMissingOptional' => 'Some optional dependencies are missing. There are listed under. GCstar may be installed but some features won\'t be available.',
-        'InstallMissingNone' => 'There are no missing dependency. You may continue and install GCstar.',
+        'InstallMissingOptional' => 'Some optional dependencies are missing. These are listed below. GCstar may be installed but some features won\'t be available.',
+        'InstallMissingNone' => 'There are no missing dependencies. You may continue and install GCstar.',
         'InstallOK' => 'OK',
         'InstallMissing' => 'Missing',
         'InstallMissingFor' => 'Missing for',
@@ -103,36 +103,45 @@ may use the <b>button below item details</b>.',
             'MenuExport' => '_Export',
     
         'MenuEdit'  => '_Edit',
-            'MenuDuplicate' => 'Du_plicate item',
-            'MenuEditDeleteCurrent' => '_Remove item',
-            'MenuEditFields' => '_Change collection fields',
+            'MenuDuplicate' => 'Du_plicate Item',
+            'MenuEditDeleteCurrent' => '_Remove Item',
+            'MenuEditFields' => '_Change Collection Fields',
             'MenuEditLockItems' => '_Lock Collection',
     
         'MenuDisplay' => 'F_ilter',
+            'MenuSavedSearches' => 'Saved searches',
+                'MenuSavedSearchesSave' => 'Save current search',
+                'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'A_dvanced Search',
-            'MenuViewAllItems' => 'Show _All items',
+            'MenuViewAllItems' => 'Show _All Items',
             'MenuNoFilter' => '_Any',
     
         'MenuConfiguration' => '_Settings',
             'MenuDisplayOptions' => '_Displayed Information',
             'MenuBorrowers' => '_Borrowers',
+            'MenuToolbarConfiguration' => '_Toolbar Controls',
             'MenuGenresConversion' => 'Genre _Conversion',
         
         'MenuBookmarks' => 'My _Collections',
-            'MenuBookmarksAdd' => '_Add current collection',
-            'MenuBookmarksEdit' => '_Edit bookmarked collections',
+            'MenuBookmarksAdd' => '_Add Current Collection',
+            'MenuBookmarksEdit' => '_Edit Bookmarked Collections',
 
         'MenuHelp' => '_Help',
             'MenuHelpContent' => '_Content',
-            'MenuAllPlugins' => 'View _plugins',
-            'MenuBugReport' => 'Report a _bug',
+            'MenuAllPlugins' => 'View _Plugins',
+            'MenuBugReport' => 'Report a Problem',
             'MenuAbout' => '_About GCstar',
     
-        'MenuNewWindow' => 'Show item in _New Window',
-        
-        'ContextExpandAll' => 'Expand all',
-        'ContextCollapseAll' => 'Collapse all',
+        'MenuNewWindow' => 'Show Item in _New Window',
         
+        'ContextExpandAll' => 'Expand All',
+        'ContextCollapseAll' => 'Collapse All',
+        'ContextChooseImage' => 'Choose _Image',
+        'ContextOpenWith' => 'Open Wit_h',
+        'ContextImageEditor' => 'Image Editor',
+        'ContextImgFront' => 'Front',
+        'ContextImgBack' => 'Back',
+
         'DialogEnterNumber' => 'Please enter value',
 
         'RemoveConfirm' => 'Do you really want to remove this item?',
@@ -147,7 +156,9 @@ may use the <b>button below item details</b>.',
         'SaveDontSave' => 'Don\'t save',
         'PreferencesTooltip' => 'Set your preferences',
         'ViewTooltip' => 'Change collection display',
-        'PlayTooltip' => 'Play video associated to the item',
+        'PlayTooltip' => 'Launch file associated to the item',
+        'PlayFileNotFound' => 'File to launch was not found in this location:',
+        'PlayRetry' => 'Retry',
 
         'StatusSave' => 'Saving...',
         'StatusLoad' => 'Loading...',
@@ -157,11 +168,15 @@ may use the <b>button below item details</b>.',
                 
         'SaveError' => 'Cannot save items list. Please check access rights and disk free space.',
         'OpenError' => 'Cannot open items list. Please check access rights.',
-		'OpenFormatError' => 'Cannot open items list. Format may be incorrect.',
+        'OpenFormatError' => 'Cannot open items list. Format may be incorrect.',
+        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
+        'OpenVersionQuestion' => 'Do you still want to continue?',
         'ImageError' => 'Selected directory to save images is not correct. Please select another one.',
         'OptionsCreationError'=> 'Cannot create options file: ',
         'OptionsOpenError'=> 'Cannot open options file: ',
         'OptionsSaveError'=> 'Cannot save options file: ',
+        'ErrorModelNotFound' => 'Model not found: ',
+        'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'What to see this evening ?',
         'RandomError'=> 'You have no item that could be selected',
@@ -174,16 +189,17 @@ may use the <b>button below item details</b>.',
         'AboutVersion' => 'Version',
         'AboutTeam' => 'Team',
         'AboutWho' => 'Christian Jodar (Tian): Project manager, Programmer
+Nyall Dawson (Zombiepig): Programmer
+TPF: Programmer
 Adolfo González: Programmer
-Nyall Dawson (Zombiepig): Programmer',
+',
         'AboutLicense' => 'Distributed under the terms of the GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'English translation by Christian Jodar and Jason Day',
         'AboutDesign' => 'Logo and webdesign by le Spektre',
 
-        'ToolbarRandom' => 'Tonight',
-
+        'UnsavedCollection' => 'Unsaved Collection',
         'ModelsSelect' => 'Select a collection type',
         'ModelsPersonal' => 'Personal models',
         'ModelsDefault' => 'Default models',
@@ -205,6 +221,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maximum:',
         'ModelFieldList' => 'Values list:',
         'ModelFieldListLegend' => '<i>Comma separated</i>',
+        'ModelFieldDisplayAs' => 'Display as:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Short text',
         'ModelFieldTypeLongText' => 'Long text',
         'ModelFieldTypeYesNo' => 'Yes/No',
@@ -239,6 +258,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Should be in search box',
         'ModelFilterComparison' => 'Comparison',
         'ModelFilterContain' => 'Contains',
+        'ModelFilterDoesNotContain' => 'Does not contain',
+        'ModelFilterRegexp' => 'Regular expression',
         'ModelFilterRange' => 'Range',
         'ModelFilterNumeric' => 'Comparison is numeric',
         'ModelFilterQuick' => 'Create a quick filter',
@@ -258,20 +279,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Preferences',
+		'OptionsExpertMode' => 'Expert Mode',
+        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
         'OptionsBrowser' => 'Web browser',
         'OptionsPlayer' => 'Video player',
         'OptionsAudio' => 'Audio player',
+        'OptionsImageEditor' => 'Image editor',
+        'OptionsCdDevice' => 'CD device',
         'OptionsImages' => 'Images directory',
         'OptionsUseRelativePaths' => 'Use relative paths for images',
         'OptionsLayout' => 'Layout',
         'OptionsStatus' => 'Display status bar',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Warning: Changes in this tab won\'t take effect until the application is restarted.',
         'OptionsRemoveConfirm' => 'Ask confirmation before item deletion',
         'OptionsAutoSave' => 'Automatically save collection',
         'OptionsAutoLoad' => 'Load previous collection on startup',
         'OptionsSplash' => 'Show splash screen',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Use spelling checker for long text fields',
-        'OptionsImagesTitle' => 'Select a directory',
         'OptionsProgramTitle' => 'Select the program to be used',
 		'OptionsPlugins' => 'Site to retrieve data from',
 		'OptionsAskPlugins' => 'Ask (All sites)',
@@ -304,6 +330,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Place articles at the end of titles',
         'OptionsArticles' => 'Articles (Comma separated)',
         'OptionsSearchStop' => 'Allow search to be aborted',
+        'OptionsBigPics' => 'Use big pictures when available',
         'OptionsAlwaysOriginal' => 'Use main title as the original title if none present',
         'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Size of history',
@@ -312,7 +339,7 @@ http://le-spektre.org',
         'OptionsDontAsk' => 'Don\'t ask anymore',
         'OptionsPathProgramsGroup' => 'Applications',
         'OptionsProgramsSystem' => 'Use programs defined by system',
-        'OptionsProgramsUser' => 'Use specified programs',
+        'OptionsProgramsUser' => 'Override default programs',
         'OptionsProgramsSet' => 'Set programs',
         'OptionsPathImagesGroup' => 'Images',
         'OptionsInternetDataGroup' => 'Data import',
@@ -340,6 +367,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Selection',
         'ImagesOptionsBgTooltip' => 'Change background color',
         'ImagesOptionsFgTooltip'=> 'Change selection color',
+        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
         'ImagesOptionsSizeLabel' => 'Size',
         'ImagesOptionsSizeList' => {0 => 'Very Small', 1 => 'Small', 2 => 'Medium', 3 => 'Large', 4 => 'Extra Large'},
         'ImagesOptionsSizeTooltip' => 'Select image size',
@@ -367,11 +395,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Select fields you want to export',
         'ExportWithPictures' => 'Copy pictures in a sub-directory',
         'ExportSortBy' => 'Sort by',
+        'ExportOrder' => 'Order',
 
         'ImportListTitle' => 'Import another items list',
         'ImportExportData' => 'Data',
         'ImportExportFile' => 'File',
-        'ImportExportSave' => 'Please select file to use',
         'ImportExportFieldsUnused' => 'Unused fields',
         'ImportExportFieldsUsed' => 'Used fields',
         'ImportExportFieldsFill' => 'Add All',
@@ -385,7 +413,10 @@ http://le-spektre.org',
         'ImportDropError' => 'There was an error opening at least one file. Previous list will be reloaded.',
         'ImportGenerateId' => 'Generate identifier for each item',
 
-        'FileOverwrite' => 'This file already exists. Do you want to overwrite it?',
+        'FileChooserOpenFile' => 'Please select file to use',
+        'FileChooserDirectory' => 'Directory',
+        'FileChooserOpenDirectory' => 'Select a directory',
+        'FileChooserOverwrite' => 'This file already exists. Do you want to overwrite it?',
 
         #Some default panels
         'PanelCompact' => 'Compact',
@@ -429,14 +460,21 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favourite',
         'TagsAssigned' => 'Assigned Tags', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Either',
         'CheckYes' => 'Yes',
         'CheckNo' => 'No',
 
+        'ToolbarRandom' => 'Tonight',
         'ToolbarAll' => 'View All',
         'ToolbarAllTooltip' => 'View all items',
         'ToolbarGroupBy' => 'Group by',
         'ToolbarGroupByTooltip' => 'Select the field to use to group items in list',
+        'ToolbarQuickSearch' => 'Quick search',
+        'ToolbarQuickSearchLabel' => 'Search',
+        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
+        'ToolbarSeparator' => ' Separator',
         
         'PluginsTitle' => 'Search an item',
         'PluginsQuery' => 'Query',
@@ -467,6 +505,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Borrowed items',
         'BorrowedDate' => 'Since',
+        'BorrowedDisplayInPanel' => 'Show item in main window',
 
         'MailTitle' => 'Send an e-mail',
         'MailFrom' => 'From: ',
@@ -507,6 +546,7 @@ http://le-spektre.org',
         'GenresModify' => 'Edit conversion',
 
         'PropertiesName' => 'Collection name',
+        'PropertiesLang' => 'Language code',
         'PropertiesOwner' => 'Owner',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Description',
@@ -516,6 +556,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Size',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Collection properties',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
@@ -539,7 +580,12 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
         'AdvancedSearchCriteria' => 'Criteria',
         'AdvancedSearchAnyField' => 'Any field',
- 
+        'AdvancedSearchSaveTitle' => 'Save search',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
+
         'BugReportSubject' => 'Bug report generated from GCstar',
         'BugReportVersion' => 'Version',
         'BugReportPlatform' => 'Operating system',
