@@ -109,6 +109,9 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
             'MenuEditLockItems' => '_Bloquear la información',
         
         'MenuDisplay' => '_Visualización',        
+            'MenuSavedSearches' => 'Búsquedas guardadas',
+                'MenuSavedSearchesSave' => 'Guardar búsqueda actual',
+                'MenuSavedSearchesEdit' => 'Modificar búsquedas guardadas',
             'MenuAdvancedSearch' => 'Búsqueda _avanzada',
             'MenuViewAllItems' => '_Ver todas las películas',	
             'MenuNoFilter' => '_Todas las películas',	
@@ -116,6 +119,7 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         'MenuConfiguration' => '_Configuración',	
             'MenuDisplayOptions' => '_Información a mostrar',
             'MenuBorrowers' => 'Pres_tatarios',	
+            'MenuToolbarConfiguration' => 'Controles de la barra de _herramientas',
             'MenuGenresConversion' => 'Conversión de _géneros',
 
         'MenuBookmarks' => 'Mis _Colecciones',
@@ -132,6 +136,11 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         
         'ContextExpandAll' => 'Expandir todo',
         'ContextCollapseAll' => 'Contraer todo',
+        'ContextChooseImage' => 'Elegir _Imagen',
+        'ContextOpenWith' => 'Abrir _Con',
+        'ContextImageEditor' => 'Editor de Imágenes',  
+        'ContextImgFront' => 'Frontal',
+        'ContextImgBack' => 'Trasera',
 
         'DialogEnterNumber' => 'Introduzca un valor por favor',
 
@@ -148,6 +157,8 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         'PreferencesTooltip' => 'Cambiar sus preferencias',
         'ViewTooltip' => 'Cambiar el tipo de lista',
         'PlayTooltip' => 'Reproducir archivo de video asociado a la película',
+        'PlayFileNotFound' => 'No se encontró el fichero a reproducir:',
+        'PlayRetry' => 'Reintentar',
         
         'StatusSave' => 'Guardando...',
         'StatusLoad' => 'Cargando...',
@@ -158,10 +169,14 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         'SaveError' => 'Imposible guardar la lista de películas. Compruebe los permisos y el espacio disponible en el disco.',
         'OpenError' => 'Imposible abrir la lista de películas. Compruebe los permisos.',
         'OpenFormatError' => 'Imposible abrir la lista de películas.',
+        'OpenVersionWarning' => 'La colección se creó con una versión mñas erciente de GCstar. Si la guarda, podría perder datos.',
+        'OpenVersionQuestion' => '¿Todavía quiere continuar?',
         'ImageError' => 'El repertorio elegido para salvar las imágenes no es correcto.¿Quiere elegir otro?',
         'OptionsCreationError'=> 'Imposible crear el fichero de opciones : ',
         'OptionsOpenError'=> 'Imposible abrir el fichero de opciones : ',
         'OptionsSaveError'=> 'Imposible guardar el fichero de opciones',
+        'ErrorModelNotFound' => 'Modelo no encontrado: ',
+        'ErrorModelUserDir' => 'Los modelos definidos por el usuario están en: ',
 
         'RandomTooltip' => '¿Qué quieres ver esta noche?',
         'RandomError'=> 'No quedan películas sin ver',
@@ -174,8 +189,10 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         'AboutVersion' => 'Versión',
         'AboutTeam' => 'Equipo',
         'AboutWho' => 'Christian Jodar (Tian) : Gestión del proyecto, Programación
+Nyall Dawson (Zombiepig) : Programación
+TPF : Programación
 Adolfo González Blázquez : Programación
-Nyall Dawson (Zombiepig) : Programación',
+',
         'AboutLicense' => 'Distribuido según los términos de la GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
@@ -184,6 +201,7 @@ http://le-spektre.org',
         
         'ToolbarRandom' => 'Esta noche',
 
+        'UnsavedCollection' => 'Colección no guardada',
         'ModelsSelect' => 'Seleccionar un tipo de colección',
         'ModelsPersonal' => 'Modelos personales',
         'ModelsDefault' => 'Modelos predefinidos',
@@ -205,6 +223,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Máximo:',
         'ModelFieldList' => 'Lista de valores:',
         'ModelFieldListLegend' => '<i>Separados por comas</i>',
+        'ModelFieldDisplayAs' => 'Mostrar como:',
+        'ModelFieldDisplayAsText' => 'Texto',
+        'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Texto corto',
         'ModelFieldTypeLongText' => 'Texto largo',
         'ModelFieldTypeYesNo' => 'Si/No',
@@ -239,6 +260,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Debe aparecer en la caja de búsqueda',
         'ModelFilterComparison' => 'Comparación',
         'ModelFilterContain' => 'Contiene',
+        'ModelFilterDoesNotContain' => 'No contiene',
+        'ModelFilterRegexp' => 'Expresión regular',
         'ModelFilterRange' => 'Rango',
         'ModelFilterNumeric' => 'Comparación numérica',
         'ModelFilterQuick' => 'Crear un filtro rápido',
@@ -258,20 +281,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'Puedes añadir varios elementos a la colección presionando Control ó Mayúsculas y seleccionándolos',
 
         'OptionsTitle' => 'Preferencias',
+		'OptionsExpertMode' => 'Modo experto',
+        'OptionsPrograms' => 'Especifíque que aplicaciones usar para cada tipo de medio, o déjelos en blanco para usar los predeterminados del sistema',
         'OptionsBrowser' => 'Navegador de Internet',
         'OptionsPlayer' => 'Reproductor de video',
         'OptionsAudio' => 'Reproductor de audio',
+        'OptionsImageEditor' => 'Editor de imágenes',
+        'OptionsCdDevice' => 'Dispositivo de CD',
         'OptionsImages' => 'Directorio de imágenes', 	
         'OptionsUseRelativePaths' => 'Usar rutas relativas para las imágenes',
         'OptionsLayout' => 'Disposición',	
         'OptionsStatus' => 'Barra de estado',	
+        'OptionsUseStars' => 'Usar estrellas para mostrar las puntuaciones',
         'OptionsWarning' => 'Cuidado : Los cambios efectuados en este pestaña no se tendrán en cuenta hasta reiniciar la aplicación', 
         'OptionsRemoveConfirm' => 'Pedir confirmación antes de eliminar',
         'OptionsAutoSave' => 'Protección automática de la lista de películas',
         'OptionsAutoLoad' => 'Cargar la colección anterior en el inicio',
         'OptionsSplash' => 'Mostrar la pantalla de arranque',
+        'OptionsTearoffMenus' => 'Activar menus desprendibles',
         'OptionsSpellCheck' => 'Usar corrector de ortografía en los campos de texto largos',
-        'OptionsImagesTitle' => 'Elija un directorio',
         'OptionsProgramTitle' => 'Elija el programa que debe utilizarse',
         'OptionsPlugins' => 'Sitio para descargar las fichas',
         'OptionsAskPlugins' => 'Preguntar',
@@ -304,6 +332,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Poner al final de los títulos los artículos',	
         'OptionsArticles' => 'Artículos (separados por una coma)',	
         'OptionsSearchStop' => 'El usuario puede parar las búsquedas',
+        'OptionsBigPics' => 'Usar imágenes grandes cuando estén disponibles',
         'OptionsAlwaysOriginal' => 'Usar título principal como el original si no se encuentra ninguno',
         'OptionsRestoreAccelerators' => 'Restaurar aceleradores',
         'OptionsHistory' => 'Tamaño del historial',
@@ -340,6 +369,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Selección',
         'ImagesOptionsBgTooltip' => 'Cambiar el color de fondo',
         'ImagesOptionsFgTooltip'=> 'Cambiar el color de la selección',
+        'ImagesOptionsResizeImgList' => 'Cambiar automáticamente el número de columnas',
         'ImagesOptionsSizeLabel' => 'Tamaño',
         'ImagesOptionsSizeList' => {0 => 'Muy Pequeño', 1 => 'Pequeño', 2 => 'Mediano', 3 => 'Grande', 4 => 'Extra Grande'},
         'ImagesOptionsSizeTooltip' => 'Seleccione el tamaño de imagen',
@@ -367,11 +397,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Elija los campos a exportar',
         'ExportWithPictures' => 'Copiar las imágenes a un subdirectorio',
         'ExportSortBy' => 'Ordenar por',
+        'ExportOrder' => 'Orden',
 
         'ImportListTitle' => 'Importar otro listado de películas',
         'ImportExportData' => 'Datos',
         'ImportExportFile' => 'Fichero',	 
-        'ImportExportSave' => '¿En qué fichero guardar?', 	
         'ImportExportFieldsUnused' => 'Campos sin utilizar',
         'ImportExportFieldsUsed' => 'Campos utilizados',
         'ImportExportFieldsFill' => 'Todos los campos',
@@ -385,7 +415,10 @@ http://le-spektre.org',
         'ImportDropError' => 'Hubo un error abriendo al menos un fichero. Se recargará el listado anterior.',
         'ImportGenerateId' => 'Generate identifier for each item',
 
-        'FileOverwrite' => 'Este fichero existe. ¿Quiere sustituirlo?',
+        'FileChooserOpenFile' => '¿En qué fichero guardar?', 	
+        'FileChooserDirectory' => 'Directorio',
+        'FileChooserOpenDirectory' => 'Elija un directorio',
+        'FileChooserOverwrite' => 'Este fichero ya existe. ¿Quiere sustituirlo?',
 
         'PanelCompact' => 'Compacto',
         'PanelReadOnly' => 'Sólo Lectura',
@@ -428,6 +461,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favorita',
         'TagsAssigned' => 'Etiquetas asignadas', 
 
+        'PanelUser' => 'Campos del usuario',
+
         'CheckUndef' => 'Cualquiera',
         'CheckYes' => 'Si',
         'CheckNo' => 'No',
@@ -436,6 +471,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Ver todas las películas',	
         'ToolbarGroupBy' => 'Agrupar por',
         'ToolbarGroupByTooltip' => 'Seleccionar el campo a usar para agrupos los elementos en la lista',
+        'ToolbarQuickSearch' => 'Búsqueda rápida',
+        'ToolbarQuickSearchLabel' => 'Buscar',
+        'ToolbarQuickSearchTooltip' => 'Seleccione el campo en el que buscar. Introduzca los términos de búsqueda y pulse Enter',
+        'ToolbarSeparator' => ' Separador',
 
         'PluginsTitle' => 'Buscar una película',	
         'PluginsQuery' => 'Búsqueda',
@@ -466,6 +505,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Películas prestadas',	
         'BorrowedDate' => 'Desde el',	
+        'BorrowedDisplayInPanel' => 'Mostrar elemento en la ventana principal',
 
         'MailTitle' => 'Enviar un correo electrónico',	
         'MailFrom' => 'De: ',	
@@ -506,6 +546,7 @@ http://le-spektre.org',
         'GenresModify' => 'Editar conversión',
 
         'PropertiesName' => 'Nombre de la colección',
+        'PropertiesLang' => 'Código de idioma',
         'PropertiesOwner' => 'Dueño',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Descripción',
@@ -515,6 +556,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Tamaño',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Propiedades de la colección',
+        'PropertiesDefaultPicture' => 'Imagen predeterminada',
 
         'MailProgramsTitle' => 'Programas para enviar correos',
         'MailProgramsName' => 'Nombre',
@@ -538,6 +580,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Elementos que cunplan al menos un criterio',
         'AdvancedSearchCriteria' => 'Critero',
         'AdvancedSearchAnyField' => 'Cualquier campo',
+        'AdvancedSearchSaveTitle' => 'Guardar búsqueda',
+        'AdvancedSearchSaveName' => 'Nombre',
+        'AdvancedSearchSaveOverwrite' => 'Ya esixte una búsqueda guardada con el mismo nombre. Por favor, use uno diferente.',
+        'AdvancedSearchUseCase' => 'Sensible a mayúsculas',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignorar acentos y otros diacríticos',
 
         'BugReportSubject' => 'Informe de error generado por GCstar',
         'BugReportVersion' => 'Versión',
