@@ -48,10 +48,11 @@
         Developer => 'Développeur',
         Genre => 'Genre',
         Box => 'Boîtier',
+        BoxBack => 'Arrière',
         Case => 'Boîte',
         Manual => 'Notice',
         Completion => 'Avancement (%)',
-        Executable => 'Executable',
+        Executable => 'Exécutable',
         Description => 'Description',
         Codes => 'Codes',
         Code => 'Code',
