@@ -78,10 +78,10 @@ le <b>bouton situé en dessous de sa fiche</b>.',
         'InstallCopyDesktop' => 'Copie du fichier de lancement (.desktop) dans le répertoire : ',
 
 #Update
-        'UpdateUseProxy' => 'Proxy to use (just press enter if none): ',
-        'UpdateNoPermission' => 'Write permission denied in this directory: ',
-        'UpdateNone' => 'No update have been found',
-        'UpdateFileNotFound' => 'File not found',
+        'UpdateUseProxy' => 'Proxy à utiliser (appuyer simplement sur Entrée s\'il n\'y en a pas): ',
+        'UpdateNoPermission' => 'Pas de permissions d\'écriture dans ce répertoire : ',
+        'UpdateNone' => 'Aucune mise à jour trouvée',
+        'UpdateFileNotFound' => 'Fichier non trouvé',
 
 #Splash
         'SplashInit' => 'Initialisation',
@@ -110,6 +110,9 @@ le <b>bouton situé en dessous de sa fiche</b>.',
             'MenuEditLockItems' => 'Verroui_ller les informations',
     
         'MenuDisplay' => 'Fil_tres',
+            'MenuSavedSearches' => 'Recherches sauvegardées',
+                'MenuSavedSearchesSave' => 'Sauvegarder la recherche courante',
+                'MenuSavedSearchesEdit' => 'Modifier les recherches sauvegardées',
             'MenuAdvancedSearch' => 'Recherche _Avancée',
             'MenuViewAllItems' => 'Voir _tous les éléments',
             'MenuNoFilter' => '_Tous',
@@ -117,6 +120,7 @@ le <b>bouton situé en dessous de sa fiche</b>.',
         'MenuConfiguration' => '_Configuration',
             'MenuDisplayOptions' => '_Informations à afficher',
             'MenuBorrowers' => '_Emprunteurs',
+            'MenuToolbarConfiguration' => '_Boutons de la barre d\'outils',
             'MenuGenresConversion' => 'Conversions de _genres',
     
         'MenuBookmarks' => 'Mes _collections',
@@ -133,12 +137,16 @@ le <b>bouton situé en dessous de sa fiche</b>.',
                 
         'ContextExpandAll' => 'Tout développer',
         'ContextCollapseAll' => 'Tout réduire',
+        'ContextChooseImage' => 'Changer l\'_image',
+        'ContextOpenWith' => '_Envoyer à',
+        'ContextImageEditor' => 'Editeur d\'images',
+        'ContextImgFront' => 'Recto',
+        'ContextImgBack' => 'Verso',
 
         'DialogEnterNumber' => 'Veuillez entrer une valeur',
  
-
         'RemoveConfirm' => 'Voulez-vous vraiment supprimer cet élément ?',
-        'DefaultNewItem' => 'New item',
+        'DefaultNewItem' => 'Nouvel élément',
         'NewItemTooltip' => 'Ajouter un nouvel élément',
         'NoItemFound' => 'Aucun élément ne correspond. Voulez-vous tenter une recherche sur un autre site ?',
         'OpenList' => 'Quelle collection ouvrir ?',
@@ -149,10 +157,12 @@ le <b>bouton situé en dessous de sa fiche</b>.',
         'SaveDontSave' => 'Ne pas enregistrer',
         'PreferencesTooltip' => 'Changer vos préférences',
         'ViewTooltip' => 'Changer le type de liste',
-        'PlayTooltip' => 'Lancer la lecture de la vidéo associée',
+        'PlayTooltip' => 'Lancer le fichier associé',
+        'PlayFileNotFound' => 'Le fichier à lancer n\'a pas été trouvé dans cet emplacement :',
+        'PlayRetry' => 'Réessayer',
         
         'StatusSave' => 'Sauvegarde...',
-        'StatusLoad' => 'Loading...',
+        'StatusLoad' => 'Chargement...',
         'StatusSearch' => 'Recherche en cours...',
         'StatusGetInfo' => 'Récupération des informations...',
         'StatusGetImage' => 'Téléchargement de l\'image...',
@@ -160,13 +170,17 @@ le <b>bouton situé en dessous de sa fiche</b>.',
 		'SaveError' => 'Impossible de sauver la collection. Vérifiez les permissions et la place disponible sur le disque.',
 		'OpenError' => 'Impossible d\'ouvrir la collection. Vérifiez les permissions.',
 		'OpenFormatError' => 'Impossible d\'ouvrir la collection. Le format semble ne pas être bon.',
+        'OpenVersionWarning' => 'La collection a été créée avec une version plus récente de GCstar. Si vous la sauvegardez, vous pourriez perdre des données.',
+        'OpenVersionQuestion' => 'Voulez-vous tout de même continuer ?',
 		'ImageError' => 'Le répertoire choisi pour stocker les images n\'est pas correct. Veuillez en choisir un autre.',
         'OptionsCreationError'=> 'Impossible de créer le fichier d\'options : ',
         'OptionsOpenError'=> 'Impossible d\'ouvrir le fichier d\'options : ',
         'OptionsSaveError'=> 'Impossible d\'enregistrer le fichier d\'options : ',
+        'ErrorModelNotFound' => 'Modèle non trouvé : ',
+        'ErrorModelUserDir' => 'Les modèles créés par l\'utilisateur sont dans : ',
 
         'RandomTooltip' => 'Que vais-je regarder ce soir ?',
-        'RandomError'=> 'Vous n\'avez pas d\'élément pouvant être selectionné',
+        'RandomError'=> 'Vous n\'avez pas d\'élément pouvant être sélectionné',
         'RandomEnd'=> 'Il n\'y a plus d\'autre élément',
         'RandomNextTip'=> 'Proposition suivante',
         'RandomOkTip'=> 'Accepter cet élément',
@@ -176,16 +190,17 @@ le <b>bouton situé en dessous de sa fiche</b>.',
         'AboutVersion' => 'Version',
         'AboutTeam' => 'Equipe',
         'AboutWho' => 'Christian Jodar (Tian) : Gestionnaire du projet, Programmeur
+Nyall Dawson (Zombiepig) : Programmeur
+TPF : Programmeur
 Adolfo González : Programmeur
-Nyall Dawson (Zombiepig) : Programmeur',
+',
         'AboutLicense' => 'Distribué selon les termes de la GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Traduction française par Christian Jodar',
         'AboutDesign' => 'Logo et webdesign par le Spektre',
 
-        'ToolbarRandom' => 'Ce soir',
-
+        'UnsavedCollection' => 'Collection non sauvegardée',
         'ModelsSelect' => 'Choisissez un type de collection',
         'ModelsPersonal' => 'Types personnels',
         'ModelsDefault' => 'Types par défaut',
@@ -193,9 +208,9 @@ http://le-spektre.org',
         'ModelSettings' => 'Réglages de la collection',
         'ModelNewType' => 'Nouveau type de collection',
         'ModelName' => 'Description du type de collection:',
-		'ModelFields' => 'Fields',
+		'ModelFields' => 'Champs',
 		'ModelOptions'	=> 'Options',
-		'ModelFilters'	=> 'Filters',
+		'ModelFilters'	=> 'Filtres',
         'ModelNewField' => 'Nouveau champ',
         'ModelFieldInformation' => 'Informations',
         'ModelFieldName' => 'Nom :',
@@ -207,6 +222,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maximum :',
         'ModelFieldList' => 'Liste des valeurs :',
         'ModelFieldListLegend' => '<i>Séparées par des virgules</i>',
+        'ModelFieldDisplayAs' => 'Afficher comme :',
+        'ModelFieldDisplayAsText' => 'Texte',
+        'ModelFieldDisplayAsGraphical' => 'Notation',
         'ModelFieldTypeShortText' => 'Texte court',
         'ModelFieldTypeLongText' => 'Texte long',
         'ModelFieldTypeYesNo' => 'Oui/Non',
@@ -241,6 +259,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Présent dans la fenêtre de recherche',
         'ModelFilterComparison' => 'Comparaison',
         'ModelFilterContain' => 'Contient',
+        'ModelFilterDoesNotContain' => 'Ne contient pas',
+        'ModelFilterRegexp' => 'Expression régulière',
         'ModelFilterRange' => 'Intervalle',
         'ModelFilterNumeric' => 'La comparaison est numérique',
         'ModelFilterQuick' => 'Créer un filtre rapide',
@@ -260,20 +280,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'Vous pouvez ajouter plusieurs éléments à la collection en maintenant la touche Shift ou Ctrl et en les sélectionnant',
 
         'OptionsTitle' => 'Préférences',
+		'OptionsExpertMode' => 'Mode expert',
+        'OptionsPrograms' => 'Indiquez les applications à utiliser, ou laissez vide pour utiliser celles par défaut',
         'OptionsBrowser' => 'Navigateur web',
         'OptionsPlayer' => 'Lecteur de vidéos',
         'OptionsAudio' => 'Lecteur audio',
+        'OptionsImageEditor' => 'Éditeur d\'images',
+        'OptionsCdDevice' => 'Périphérique CD',
         'OptionsImages' => 'Répertoire images',
         'OptionsUseRelativePaths' => 'Utiliser des chemins relatifs pour les images',
         'OptionsLayout' => 'Disposition',
         'OptionsStatus' => 'Afficher la barre d\'état en bas de la fenêtre',
+        'OptionsUseStars' => 'Afficher les notes avec des étoiles',
         'OptionsWarning' => 'Attention : Les changements effectués dans cet onglet ne seront pris en compte qu\'après un redémarrage de l\'application',
         'OptionsRemoveConfirm' => 'Demander confirmation avant la suppression',
         'OptionsAutoSave' => 'Sauvegarde automatique de la collection',
         'OptionsAutoLoad' => 'Ouvrir la collection précédente au démarrage',
         'OptionsSplash' => 'Afficher l\'écran de démarrage',
+        'OptionsTearoffMenus' => 'Activer les menus détachables',
         'OptionsSpellCheck' => 'Utiliser le vérificateur orthographique pour les champs texte longs',
-        'OptionsImagesTitle' => 'Choisissez un répertoire',
         'OptionsProgramTitle' => 'Choisissez le programme à utiliser',
 		'OptionsPlugins' => 'Site où récupérer les fiches',
 		'OptionsAskPlugins' => 'Demander (Tous les sites)',
@@ -306,6 +331,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Mettre à la fin des titres les articles',
         'OptionsArticles' => 'Articles (Séparés par des virgules)',
         'OptionsSearchStop' => 'Une recherche peut être arrêtée',
+        'OptionsBigPics' => 'Utiliser les grandes images quand disponibles',
         'OptionsAlwaysOriginal' => 'Utiliser le titre principal comme titre original si non présent',
         'OptionsRestoreAccelerators' => 'Rétablir raccourcis',
 		'OptionsHistory' => 'Taille de l\'historique',
@@ -339,12 +365,13 @@ http://le-spektre.org',
         'ImagesOptionsUseOverlays' => 'Effet brillant',
         'ImagesOptionsBg' => 'Fond',
         'ImagesOptionsBgPicture' => 'Utiliser une image de fond',
-        'ImagesOptionsFg'=> 'Selection',
+        'ImagesOptionsFg'=> 'Sélection',
         'ImagesOptionsBgTooltip' => 'Changer la couleur de fond',
         'ImagesOptionsFgTooltip'=> 'Changer la couleur de la sélection',
+        'ImagesOptionsResizeImgList' => 'Changer dynamiquement le nombre de colonnes',
         'ImagesOptionsSizeLabel' => 'Taille',
         'ImagesOptionsSizeList' => {0 => 'Minuscule', 1 => 'Petit', 2 => 'Moyen', 3 => 'Grand', 4 => 'Enorme'},
-        'ImagesOptionsSizeTooltip' => 'Selectionnez la taille pour les images',
+        'ImagesOptionsSizeTooltip' => 'Sélectionnez la taille pour les images',
 
         'DetailedOptionsTitle' => 'Réglages pour la liste détaillée',
         'DetailedOptionsImageSize' => 'Taille des images',
@@ -369,11 +396,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Choisir les champs devant être exportés',
         'ExportWithPictures' => 'Copier les images dans un sous-répertoire',
         'ExportSortBy' => 'Trier selon',
+        'ExportOrder' => 'Ordre',
 
         'ImportListTitle' => 'Importer une autre collection',
         'ImportExportData' => 'Données',
         'ImportExportFile' => 'Fichier',
-        'ImportExportSave' => 'Choisissez le fichier à utiliser',
         'ImportExportFieldsUnused' => 'Champs inutilisés',
         'ImportExportFieldsUsed' => 'Champs utilisés',
         'ImportExportFieldsFill' => 'Tous les champs',
@@ -387,7 +414,10 @@ http://le-spektre.org',
         'ImportDropError' => 'Il y a eu une erreur dans l\'ouverture d\'au moins un fichier. La liste précédente va être rechargée.',
         'ImportGenerateId' => 'Générer l\'identifiant de chaque élément',
         
-        'FileOverwrite' => 'Ce fichier existe. Voulez vous le remplacer ?',
+        'FileChooserOpenFile' => 'Choisissez le fichier à utiliser',
+        'FileChooserDirectory' => 'Répertoire',
+        'FileChooserOpenDirectory' => 'Choisissez un répertoire',
+        'FileChooserOverwrite' => 'Ce fichier existe. Voulez vous le remplacer ?',
 
         'PanelCompact' => 'Compact',
         'PanelReadOnly' => 'Lecture seule',
@@ -430,14 +460,21 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favori',
         'TagsAssigned' => 'Mots-clés associés',
 
+        'PanelUser' => 'Champs utilisateur',
+
         'CheckUndef' => 'Sans importance',
         'CheckYes' => 'Oui',
         'CheckNo' => 'Non',
 
+        'ToolbarRandom' => 'Ce soir',
         'ToolbarAll' => 'Voir tous',
         'ToolbarAllTooltip' => 'Afficher toute la collection',
         'ToolbarGroupBy' => 'Grouper par',
         'ToolbarGroupByTooltip' => 'Choisir le champ à utiliser pour regrouper les éléments dans la liste',
+        'ToolbarQuickSearch' => 'Recherche rapide',
+        'ToolbarQuickSearchLabel' => 'Rechercher',
+        'ToolbarQuickSearchTooltip' => 'Choisissez le champ dans lequel rechercher, entrez le texte de la recherche et pressez Entréé',
+        'ToolbarSeparator' => ' Séparateur',
 
         'PluginsTitle' => 'Chercher un élément',
         'PluginsQuery' => 'Recherche',
@@ -468,6 +505,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Eléments empruntés',
         'BorrowedDate' => 'Depuis le',
+        'BorrowedDisplayInPanel' => 'Voir dans la fenêtre principale',
 
         'MailTitle' => '_Envoyer un e-mail',
         'MailFrom' => 'De : ',
@@ -508,6 +546,7 @@ http://le-spektre.org',
         'GenresModify' => 'Changer la conversion',
 
         'PropertiesName' => 'Nom de la collection',
+        'PropertiesLang' => 'Code langue',
         'PropertiesOwner' => 'Propriétaire',
         'PropertiesEmail' => 'Adresse e-mail',
         'PropertiesDescription' => 'Description',
@@ -517,6 +556,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Taille',
         'PropertiesFileSizeSymbols' => ['octets', 'Ko', 'Mo', 'Go', 'To', 'Po', 'Eo', 'Zo', 'Yo'],
         'PropertiesCollection' => 'Propriétés de la collection',
+        'PropertiesDefaultPicture' => 'Image par défaut',
 
         'MailProgramsTitle' => 'Programmes pour envoyer des emails',
         'MailProgramsName' => 'Nom',
@@ -529,7 +569,7 @@ http://le-spektre.org',
  %s sera remplacé par le sujet du message.
  %b sera remplacé par le contenu du message.',
 
-        'BookmarksBookmarks' => 'Bookmarks',
+        'BookmarksBookmarks' => 'Collections',
         'BookmarksFolder' => 'Répertoire',
         'BookmarksLabel' => 'Nom',
         'BookmarksPath' => 'Chemin',
@@ -538,8 +578,13 @@ http://le-spektre.org',
         'AdvancedSearchType' => 'Type de recherche',
         'AdvancedSearchTypeAnd' => 'Eléments correspondants à tous les critères',
         'AdvancedSearchTypeOr' => 'Eléments correspondants à au moins un critère',
-        'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchCriteria' => 'Critères',
         'AdvancedSearchAnyField' => 'N\'importe quel champ',
+        'AdvancedSearchSaveTitle' => 'Sauvegarder la recherche',
+        'AdvancedSearchSaveName' => 'Nom',
+        'AdvancedSearchSaveOverwrite' => 'Il y a déjà une recherche sauvegardée avec ce nom. Veuillez en choisir un autre.',
+        'AdvancedSearchUseCase' => 'Différencier majuscules et minuscules',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignorer les accents et autres diacritiques',
 
         'BugReportSubject' => 'Rapport d\'erreur généré depuis GCstar',
         'BugReportVersion' => 'Version',
