@@ -109,6 +109,9 @@ utilizar <b>o botón situado debaixo dos detalles do elemento</b>.',
             'MenuEditLockItems' => '_Bloquear Colección',
     
         'MenuDisplay' => 'F_iltros',
+            'MenuSavedSearches' => 'Saved searches',
+                'MenuSavedSearchesSave' => 'Save current search',
+                'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'Procura A_vanzada ',
             'MenuViewAllItems' => '_Amosar todos os elementos',
             'MenuNoFilter' => '_Calquera',
@@ -116,6 +119,7 @@ utilizar <b>o botón situado debaixo dos detalles do elemento</b>.',
         'MenuConfiguration' => '_Configuración',
             'MenuDisplayOptions' => '_Información amosada',
             'MenuBorrowers' => '_Prestatarios',
+            'MenuToolbarConfiguration' => '_Toolbar controls',
             'MenuGenresConversion' => '_Conversión de Xéneros',
         
         'MenuBookmarks' => 'As miñas _Coleccións',
@@ -132,7 +136,12 @@ utilizar <b>o botón situado debaixo dos detalles do elemento</b>.',
         
         'ContextExpandAll' => 'Expandir todo',
         'ContextCollapseAll' => 'Contraer todo',
-        
+         'ContextChooseImage' => 'Choose _Image',
+        'ContextOpenWith' => 'Open Wit_h',
+        'ContextImageEditor' => 'Image Editor',
+        'ContextImgFront' => 'Front',
+        'ContextImgBack' => 'Back',
+       
         'DialogEnterNumber' => 'Introduza un valor',
 
         'RemoveConfirm' => 'Está seguro de que quere eliminar este elemento?',
@@ -148,6 +157,8 @@ utilizar <b>o botón situado debaixo dos detalles do elemento</b>.',
         'PreferencesTooltip' => 'Aplicar as súas configuracións',
         'ViewTooltip' => 'Cambiar o tipo de visualización',
         'PlayTooltip' => 'Reproducir un video asociado ao elemento',
+        'PlayFileNotFound' => 'File to launch was not found in this location:',
+        'PlayRetry' => 'Retry',
 
         'StatusSave' => 'Gardando...',
         'StatusLoad' => 'Cargando...',
@@ -158,10 +169,14 @@ utilizar <b>o botón situado debaixo dos detalles do elemento</b>.',
         'SaveError' => 'Non se pode gardar a listaxe. Comprobe os permisos de acceso e se hai suficiente espazo libre en disco..',
         'OpenError' => 'Non se pode abrir a listaxe. Comprobe os permisos de acceso.',
 		'OpenFormatError' => 'Non se pode abrir a listaxe. Pode que o formato sexa incorrecto.',
+        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
+        'OpenVersionQuestion' => 'Do you still want to continue?',
         'ImageError' => 'O directorio seleccionado para gardar as imaxes non é correcto. Seleccione outro..',
         'OptionsCreationError'=> 'Non se pode crear o ficheiro de opcións: ',
         'OptionsOpenError'=> 'Non se pode abrir o ficheiro de opcións: ',
         'OptionsSaveError'=> 'Non se pode gardar o ficheiro de opcións: ',
+        'ErrorModelNotFound' => 'Model not found: ',
+        'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Que pode ver esta noite ?',
         'RandomError'=> 'Non pode seleccionar ningún elemento',
@@ -174,8 +189,10 @@ utilizar <b>o botón situado debaixo dos detalles do elemento</b>.',
         'AboutVersion' => 'Versión',
         'AboutTeam' => 'Equipo',
         'AboutWho' => 'Christian Jodar (Tian): Gestión do proxecto, Programador
+Nyall Dawson (Zombiepig): Programador
+TPF: Programador
 Adolfo González: Programador
-Nyall Dawson (Zombiepig): Programador',
+',
         'AboutLicense' => 'Distribuido baixo os termos de GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
@@ -184,6 +201,7 @@ http://le-spektre.org',
 
         'ToolbarRandom' => 'Esta noite',
 
+        'UnsavedCollection' => 'Unsaved Collection',
         'ModelsSelect' => 'Seleccionar un tipo de colección',
         'ModelsPersonal' => 'Modelos persoais',
         'ModelsDefault' => 'Modelos predeterminados',
@@ -205,6 +223,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Máximo:',
         'ModelFieldList' => 'Listaxe de valores:',
         'ModelFieldListLegend' => '<i>Separado por comas</i>',
+        'ModelFieldDisplayAs' => 'Display as:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Texto curto',
         'ModelFieldTypeLongText' => 'Texto longo',
         'ModelFieldTypeYesNo' => 'Si/Non',
@@ -239,6 +260,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Debería ser nunha caixa de procura',
         'ModelFilterComparison' => 'Comparación',
         'ModelFilterContain' => 'Contén',
+        'ModelFilterDoesNotContain' => 'Does not contain',
+        'ModelFilterRegexp' => 'Regular expression',
         'ModelFilterRange' => 'Rango',
         'ModelFilterNumeric' => 'Comparación numérica',
         'ModelFilterQuick' => 'Crear un filtro rápido',
@@ -258,20 +281,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'Pode engadir varios elementos á colección seleccionandoos mentres preme Ctrl ou Shift',
         
         'OptionsTitle' => 'Preferencias',
+		'OptionsExpertMode' => 'Expert Mode',
+        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
         'OptionsBrowser' => 'Navegador Web',
         'OptionsPlayer' => 'Reprodutor de Video',
         'OptionsAudio' => 'Reprodutor de Audio',
+        'OptionsImageEditor' => 'Image editor',
+        'OptionsCdDevice' => 'CD device',
         'OptionsImages' => 'Directorio de Imaxes',
         'OptionsUseRelativePaths' => 'Utilizar rutas relativas para as imaxes',
         'OptionsLayout' => 'Disposición',
         'OptionsStatus' => 'Amosar barra de estado',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Atención: Os cambios nesta pestana non terán efecto até que reinicie a aplicación.',
         'OptionsRemoveConfirm' => 'Pedir confirmación antes de eliminar un elemento',
         'OptionsAutoSave' => 'Gardar automáticamente a colección',
         'OptionsAutoLoad' => 'Cargar a colección anterior ao inicio',
         'OptionsSplash' => 'Amosar pantalla de inicio',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Utilizar corrector ortográfico para os campos de texto longos',
-        'OptionsImagesTitle' => 'Seleccione un directorio',
         'OptionsProgramTitle' => 'Seleccione que programa se utilizará',
 		'OptionsPlugins' => 'Sitio web do que recuperar os datos',
 		'OptionsAskPlugins' => 'Preguntar (Todos os sitios web)',
@@ -304,6 +332,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Poñer os artigos ao final dos títulos',
         'OptionsArticles' => 'Artigos (Separados por comas)',
         'OptionsSearchStop' => 'Permitir cancelar a procura',
+        'OptionsBigPics' => 'Use big pictures when available',
         'OptionsAlwaysOriginal' => 'Utilizar título principal se non está o título orixinal',
         'OptionsRestoreAccelerators' => 'Restaurar aceleradores',
         'OptionsHistory' => 'Tamaño do historial',
@@ -340,6 +369,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Selección',
         'ImagesOptionsBgTooltip' => 'Cambiar a cor de fondo',
         'ImagesOptionsFgTooltip'=> 'Cambiar a selección de cor',
+        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
         'ImagesOptionsSizeLabel' => 'Tamaño',
         'ImagesOptionsSizeList' => {0 => 'Moi pequeno', 1 => 'Pequeno', 2 => 'Medio', 3 => 'Grande', 4 => 'Moi grande'},
         'ImagesOptionsSizeTooltip' => 'Seleccionar o tamaño da imaxe',
@@ -367,11 +397,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Seleccione os ficheiros que quere exportar',
         'ExportWithPictures' => 'Copiar imaxes nun sub-directorio',
         'ExportSortBy' => 'Ordear por',
+        'ExportOrder' => 'Order',
 
         'ImportListTitle' => 'Importar outra listaxe de elementos',
         'ImportExportData' => 'Datos',
         'ImportExportFile' => 'Ficheiro',
-        'ImportExportSave' => 'Selecione o ficheiro',
         'ImportExportFieldsUnused' => 'Campos sen utilizar',
         'ImportExportFieldsUsed' => 'Campos utilizados',
         'ImportExportFieldsFill' => 'Engadir todo',
@@ -385,7 +415,10 @@ http://le-spektre.org',
         'ImportDropError' => 'Houbo un erro abrindo algúns dos ficheiros. Cargarase a listaxe anterior.',
         'ImportGenerateId' => 'Xerar identificador para cada elemento',
 
-        'FileOverwrite' => 'Este ficheiro xa existe. Quere sobreescribilo?',
+        'FileChooserOpenFile' => 'Selecione o ficheiro',
+        'FileChooserDirectory' => 'Directory',
+        'FileChooserOpenDirectory' => 'Seleccione un directorio',
+        'FileChooserOverwrite' => 'Este ficheiro xa existe. Quere sobreescribilo?',
 
         #Some default panels
         'PanelCompact' => 'Compacto',
@@ -429,6 +462,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favorito',
         'TagsAssigned' => 'Etiquetas asignadas', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Calquera',
         'CheckYes' => 'Si',
         'CheckNo' => 'Non',
@@ -437,6 +472,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Ver todos os elementos',
         'ToolbarGroupBy' => 'Agrupar por',
         'ToolbarGroupByTooltip' => 'Seleccionar o campo para agrupar os elementos da lista',
+        'ToolbarQuickSearch' => 'Quick search',
+        'ToolbarQuickSearchLabel' => 'Search',
+        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
+        'ToolbarSeparator' => ' Separator',
         
         'PluginsTitle' => 'Procurar un elemento',
         'PluginsQuery' => 'Procura',
@@ -467,6 +506,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Elementos prestados',
         'BorrowedDate' => 'Desde',
+        'BorrowedDisplayInPanel' => 'Show item in main window',
 
         'MailTitle' => 'Enviar un correo electrónico',
         'MailFrom' => 'Desde: ',
@@ -507,6 +547,7 @@ http://le-spektre.org',
         'GenresModify' => 'Editar conversión',
 
         'PropertiesName' => 'Nome da colección',
+        'PropertiesLang' => 'Language code',
         'PropertiesOwner' => 'Propietario/a',
         'PropertiesEmail' => 'Correo electrónico',
         'PropertiesDescription' => 'Descripción',
@@ -516,6 +557,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Tamaño',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Propiedades da colección',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Programas de envío de correo',
         'MailProgramsName' => 'Nome',
@@ -539,6 +581,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Elementos que cumpren polo menos un criterio',
         'AdvancedSearchCriteria' => 'Criterios',
         'AdvancedSearchAnyField' => 'Calquer campo',
+        'AdvancedSearchSaveTitle' => 'Save search',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
  
         'BugReportSubject' => 'Reporte de erro xerado por GCstar',
         'BugReportVersion' => 'Versión',
