@@ -109,6 +109,9 @@ may use the <b>button below item details</b>.',
             'MenuEditLockItems' => '_Lock Collection',
     
         'MenuDisplay' => 'F_ilter',
+            'MenuSavedSearches' => 'Simpan pencarian',
+                'MenuSavedSearchesSave' => 'Simpan pencarian yang sekarang',
+                'MenuSavedSearchesEdit' => 'Ubah simpanan pencarian',
             'MenuAdvancedSearch' => 'A_dvanced Search',
             'MenuViewAllItems' => 'Show _All items',
             'MenuNoFilter' => '_Any',
@@ -116,6 +119,7 @@ may use the <b>button below item details</b>.',
         'MenuConfiguration' => '_Settings',
             'MenuDisplayOptions' => '_Displayed Information',
             'MenuBorrowers' => '_Borrowers',
+            'MenuToolbarConfiguration' => '_Toolbar controls',
             'MenuGenresConversion' => 'Genre _Conversion',
         
         'MenuBookmarks' => 'My _Collections',
@@ -132,6 +136,11 @@ may use the <b>button below item details</b>.',
         
         'ContextExpandAll' => 'Expand all',
         'ContextCollapseAll' => 'Collapse all',
+        'ContextChooseImage' => 'Choose _Image',
+        'ContextOpenWith' => 'Open Wit_h',
+        'ContextImageEditor' => 'Buka dengan pengedit gambar',
+        'ContextImgFront' => 'Front',
+        'ContextImgBack' => 'Back',
         
         'DialogEnterNumber' => 'Please enter value',
 
@@ -148,6 +157,8 @@ may use the <b>button below item details</b>.',
         'PreferencesTooltip' => 'Set your preferences',
         'ViewTooltip' => 'Change collection display',
         'PlayTooltip' => 'Play video associated to the item',
+        'PlayFileNotFound' => 'File to launch was not found in this location:',
+        'PlayRetry' => 'Retry',
 
         'StatusSave' => 'Menyimpan...',
         'StatusLoad' => 'Membuka...',
@@ -158,10 +169,14 @@ may use the <b>button below item details</b>.',
         'SaveError' => 'Cannot save items list. Please check access rights and disk free space.',
         'OpenError' => 'Cannot open items list. Please check access rights.',
 		'OpenFormatError' => 'Cannot open items list. Format may be incorrect.',
+        'OpenVersionWarning' => 'Koleksi dibuat menggunakan versi terbaru GCstar. Mungkin akan terjadi kerusakan data jika disimpan.',
+        'OpenVersionQuestion' => 'Masih ingin melanjutkan ??',
         'ImageError' => 'Selected directory to save images is not correct. Please select another one.',
         'OptionsCreationError'=> 'Cannot create options file: ',
         'OptionsOpenError'=> 'Cannot open options file: ',
         'OptionsSaveError'=> 'Cannot save options file: ',
+        'ErrorModelNotFound' => 'Model tidak ditemukan: ',
+        'ErrorModelUserDir' => 'Model buatan pengguna ada di: ',
         
         'RandomTooltip' => 'What to see this evening ?',
         'RandomError'=> 'You have no item that could be selected',
@@ -174,8 +189,10 @@ may use the <b>button below item details</b>.',
         'AboutVersion' => 'Versi',
         'AboutTeam' => 'Tim',
         'AboutWho' => 'Christian Jodar (Tian): Manajer Proyek, Programmer
+Nyall Dawson (Zombiepig): Programmer
+TPF: Programmer
 Adolfo González: Programmer
-Nyall Dawson (Zombiepig): Programmer',
+',
         'AboutLicense' => 'Distributed under the terms of the GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
@@ -184,6 +201,7 @@ http://le-spektre.org',
 
         'ToolbarRandom' => 'Malam ini',
 
+        'UnsavedCollection' => 'Koleksi yang belum disimpan',
         'ModelsSelect' => 'Pilih tipe koleksi',
         'ModelsPersonal' => 'Personal models',
         'ModelsDefault' => 'Default models',
@@ -205,6 +223,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maksimum:',
         'ModelFieldList' => 'Values list:',
         'ModelFieldListLegend' => '<i>Comma separated</i>',
+        'ModelFieldDisplayAs' => 'Ditampilkan sebagai:',
+        'ModelFieldDisplayAsText' => 'Teks',
+        'ModelFieldDisplayAsGraphical' => 'Pengendali Rating',
         'ModelFieldTypeShortText' => 'Text pendek',
         'ModelFieldTypeLongText' => 'Text panjang',
         'ModelFieldTypeYesNo' => 'Ya/Tidak',
@@ -239,6 +260,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Should be in search box',
         'ModelFilterComparison' => 'Perbandingan',
         'ModelFilterContain' => 'Berisi',
+        'ModelFilterDoesNotContain' => 'Tidak mengandung kata',
+        'ModelFilterRegexp' => 'Regular expression',
         'ModelFilterRange' => 'Range',
         'ModelFilterNumeric' => 'Comparison is numeric',
         'ModelFilterQuick' => 'Create a quick filter',
@@ -258,20 +281,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'Anda dapat menambah barang lebih dari satu ke koleksi dengan menekan+tahan tombol Ctrl atau Shift dan pilih barang yang akan dimasukkan',
         
         'OptionsTitle' => 'Preferences',
+		'OptionsExpertMode' => 'Expert Mode',
+        'OptionsPrograms' => 'Tetapkan jenis aplikasi untuk digunakan oleh media yang berbeda, tinggalkan kosong untuk menggunakan konfigurasi dasar sistem',
         'OptionsBrowser' => 'Penjelajah web',
         'OptionsPlayer' => 'Video player',
         'OptionsAudio' => 'Audio player',
+        'OptionsImageEditor' => 'Pengedit gambar',
+        'OptionsCdDevice' => 'CD device',
         'OptionsImages' => 'Direktori gambar',
         'OptionsUseRelativePaths' => 'Use relative paths for images',
         'OptionsLayout' => 'Layout',
         'OptionsStatus' => 'Tampilkan status bar',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Peringatan: Perubahan pada tab ini tidak akan berpengaruh sampai aplikasi ini ditutup kemudian dibuka kembali.',
         'OptionsRemoveConfirm' => 'Ask confirmation before item deletion',
         'OptionsAutoSave' => 'Otomatis menyimpan koleksi',
         'OptionsAutoLoad' => 'Load previous collection on startup',
         'OptionsSplash' => 'Perlihatkan splash screen',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Gunakan pemeriksa bahasa untuk teks yang panjang',
-        'OptionsImagesTitle' => 'Pilih direktori',
         'OptionsProgramTitle' => 'Pilih program yang akan digunakan',
 		'OptionsPlugins' => 'Situs untuk pengambilan data',
 		'OptionsAskPlugins' => 'Tanya (Semua situs)',
@@ -304,6 +332,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Place articles at the end of titles',
         'OptionsArticles' => 'Artikel (Dipisahkan koma)',
         'OptionsSearchStop' => 'Allow search to be aborted',
+        'OptionsBigPics' => 'Use big pictures when available',
         'OptionsAlwaysOriginal' => 'Use main title as the original title if none present',
         'OptionsRestoreAccelerators' => 'Mengembalikan accelerators',
         'OptionsHistory' => 'Size of history',
@@ -340,6 +369,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Selection',
         'ImagesOptionsBgTooltip' => 'Change background color',
         'ImagesOptionsFgTooltip'=> 'Change selection color',
+        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
         'ImagesOptionsSizeLabel' => 'Ukuran',
         'ImagesOptionsSizeList' => {0 => 'Sangat Kecil', 1 => 'Kecil', 2 => 'Medium', 3 => 'Besar', 4 => 'Sangat besar'},
         'ImagesOptionsSizeTooltip' => 'Pilih ukuran gambar',
@@ -367,11 +397,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Select fields you want to export',
         'ExportWithPictures' => 'Copy pictures in a sub-directory',
         'ExportSortBy' => 'Sort by',
+        'ExportOrder' => 'Urutan',
 
         'ImportListTitle' => 'Import another items list',
         'ImportExportData' => 'Data',
         'ImportExportFile' => 'File',
-        'ImportExportSave' => 'Please select file to use',
         'ImportExportFieldsUnused' => 'Unused fields',
         'ImportExportFieldsUsed' => 'Used fields',
         'ImportExportFieldsFill' => 'Tambahkan Semua',
@@ -385,7 +415,10 @@ http://le-spektre.org',
         'ImportDropError' => 'There was an error opening at least one file. Previous list will be reloaded.',
         'ImportGenerateId' => 'Generate identifier for each item',
 
-        'FileOverwrite' => 'This file already exists. Do you want to overwrite it?',
+        'FileChooserOpenFile' => 'Please select file to use',
+        'FileChooserDirectory' => 'Direktori',
+        'FileChooserOpenDirectory' => 'Pilih direktori',
+        'FileChooserOverwrite' => 'This file already exists. Do you want to overwrite it?',
 
         #Some default panels
         'PanelCompact' => 'Compact',
@@ -429,6 +462,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favorit',
         'TagsAssigned' => 'Assigned Tags', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Either',
         'CheckYes' => 'Ya',
         'CheckNo' => 'Tidak',
@@ -437,6 +472,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'View all items',
         'ToolbarGroupBy' => 'Group by',
         'ToolbarGroupByTooltip' => 'Select the field to use to group items in list',
+        'ToolbarQuickSearch' => 'Pencarian cepat',
+        'ToolbarQuickSearchLabel' => 'Pencarian',
+        'ToolbarQuickSearchTooltip' => 'Pilih bagian yang akan dicari. masukkan kata yang dicari kemudian tekan enter',
+        'ToolbarSeparator' => ' Separator',
         
         'PluginsTitle' => 'Search an item',
         'PluginsQuery' => 'Query',
@@ -467,6 +506,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Barang yang dipinjam',
         'BorrowedDate' => 'Sejak',
+        'BorrowedDisplayInPanel' => 'Show item in main window',
 
         'MailTitle' => 'Send an e-mail',
         'MailFrom' => 'Dari: ',
@@ -507,6 +547,7 @@ http://le-spektre.org',
         'GenresModify' => 'Edit conversion',
 
         'PropertiesName' => 'Collection name',
+        'PropertiesLang' => 'Kode bahasa',
         'PropertiesOwner' => 'Owner',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Description',
@@ -516,6 +557,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Size',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Collection properties',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
@@ -539,6 +581,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
         'AdvancedSearchCriteria' => 'Criteria',
         'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Simpan pencarian',
+        'AdvancedSearchSaveName' => 'Nama',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
  
         'BugReportSubject' => 'Laporan kerusakan dibuat dari GCstar',
         'BugReportVersion' => 'Versi',
