@@ -22,7 +22,14 @@
 #  along with GCstar; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-###################################################
+#######################################################
+#
+#  v1.0.2 - Italian localization by Andreas Troschka
+#
+#  for GCstar v1.1.1
+#
+#######################################################
+
     
     use strict;
     use base 'Exporter';
@@ -30,30 +37,34 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
+        'ModelNotFound' => 'Invalid template file',
+        'UseFile' => 'Use file specified below',
+        'TemplateExternalFile' => 'Template file',
         'WithJS' => 'Usa Javascript',
-       	'FileTemplate' => 'Mascherina :',
-        'Preview' => 'Preview',
-        'NoPreview' => 'No preview available',
+       	'FileTemplate' => 'Modello:',
+        'Preview' => 'Anteprima',
+        'NoPreview' => 'Anteprima non disponibilee',
         'Title' => 'Titolo pagina',
-        'InfoFile' => 'La lista dei films è nel file : ',
+        'InfoFile' => 'La lista dei film è nel file : ',
         'InfoDir' => 'Immagini sono in : ',
         'HeightImg' => 'Altezza in pixel dell\'immagine da esportare :',
-        'OpenFileInBrowser' => 'Open generated file in web browser',
+        'OpenFileInBrowser' => 'Apri il file generato nel web browser',
         'Note' => 'Lista generata con <a href="http://www.gcstar.org/">GCstar</a>',
         'InputTitle' => 'Immetti testo da cercare',
         'SearchType1' => 'Solo il titolo',
         'SearchType2' => 'Informazioni complete',
         'SearchButton' => 'Cerca',    
-        'SearchTitle' => 'Visualizza solo i films trovati con il criterio precedente',
+        'SearchTitle' => 'Visualizza solo i film trovati con il criterio precedente',
         'AllButton' => 'Tutto',
-        'AllTitle' => 'Visualizza tutti i films',
-        'Expand' => 'Estendi tuttol',
-        'ExpandTitle' => 'Visulizza tutte le informazioni dei films',
-        'Collapse' => 'Contrai tutto',
-        'CollapseTitle' => 'Contrai tutte le informazioni dei films',
+        'AllTitle' => 'Visualizza tutti i film',
+        'Expand' => 'Espandi tutto',
+        'ExpandTitle' => 'Visualizza tutte le informazioni dei film',
+        'Collapse' => 'Comprimi tutto',
+        'CollapseTitle' => 'Comprimi tutte le informazioni dei film',
         'Borrowed' => 'Preso in prestito da: ',
         'NotBorrowed' => 'Disponibile',
-        'Top' => 'Vertice',
+        'Top' => 'In alto',
+        'Bottom' => 'Bottom',
      );
 }
 
