@@ -61,6 +61,7 @@
         Seen => 'Gia\' visto',
         Number => 'Numero',
         Format => 'Tipo',
+        Region => 'Region',
         Identifier => 'Identifier',
         Url => 'URL',
         Audio => 'Audio',
@@ -90,7 +91,7 @@
         FilterSeenYes => '_Gia\' visto',
         FilterRatingSelect => 'Valutazione maggiore di...',
 
-        ExtractSize => 'Durata',
+        ExtractSize => 'Dimensione',
      );
 }
 
