@@ -114,6 +114,9 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
     		'MenuEditLockItems' => 'B_locca la collezione',
 
         'MenuDisplay' => 'F_iltri',
+            'MenuSavedSearches' => 'Saved searches',
+                'MenuSavedSearchesSave' => 'Save current search',
+                'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'Ricerca Avanzata',
             'MenuViewAllItems' => 'Mostr_a tutti gli articoli',
             'MenuNoFilter' => 'Tutti',
@@ -121,6 +124,7 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         'MenuConfiguration' => 'Configurazione',
             'MenuDisplayOptions' => 'Visualizzazione articoli',
             'MenuBorrowers' => 'Gestione prestiti',
+            'MenuToolbarConfiguration' => '_Toolbar controls',
             'MenuGenresConversion' => '_Conversione di Genere',
 
         'MenuBookmarks' => '_Collezioni',
@@ -137,6 +141,11 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         
         'ContextExpandAll' => 'Espandi tutti',
         'ContextCollapseAll' => 'Collassa tutti',
+        'ContextChooseImage' => 'Choose _Image',
+        'ContextOpenWith' => 'Open Wit_h',
+        'ContextImageEditor' => 'Image Editor', 
+        'ContextImgFront' => 'Front',
+        'ContextImgBack' => 'Back',
 
         'DialogEnterNumber' => 'Immetere valore',
 
@@ -153,6 +162,8 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         'PreferencesTooltip' => 'Impostazione preferenze',
         'ViewTooltip' => 'Cambia visualizzazione',
         'PlayTooltip' => 'Mostra il video associato all\'articolo',
+        'PlayFileNotFound' => 'File to launch was not found in this location:',
+        'PlayRetry' => 'Retry',
 
         'StatusSave' => 'Salvataggio...',
         'StatusLoad' => 'Caricamento...',
@@ -163,10 +174,14 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         'SaveError' => 'Impossibile salvare la collezione! Controllare i diritti di accesso e lo spazio libero sul disco.',
         'OpenError' => 'Impossibile caricare la collezione! Controllare i diritti di accesso.',
         'OpenFormatError' => 'Impossibile interpretare la collezione! Formato probabilmente scorretto.',
+        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
+        'OpenVersionQuestion' => 'Do you still want to continue?',
         'ImageError' => 'Directory non corretta! Selezionarne un\'altra.',
         'OptionsCreationError'=> 'Generazione file opzioni impossibile: ',
         'OptionsOpenError'=> 'Caricamento file opzioni impossibile: ',
         'OptionsSaveError'=> 'Salvataggio file opzioni impossibile: ',
+        'ErrorModelNotFound' => 'Model not found: ',
+        'ErrorModelUserDir' => 'User defined models are in: ',
 
         'RandomTooltip' => 'Articoli non visti',
         'RandomError'=> 'Non ci sono articoli non visti',
@@ -179,8 +194,10 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         'AboutVersion' => 'Versione',
         'AboutTeam' => 'Team',
         'AboutWho' => 'Christian Jodar (Tian) : Project Manager, Programmatore
+Nyall Dawson (Zombiepig) : Programmatore
+TPF : Programmatore
 Adolfo González : Programmatore
-Nyall Dawson (Zombiepig) : Programmatore',
+',
         'AboutLicense' => 'Distribuito nei i termini della GNU GPL
 Logo Copyright le Spektre
 http://le-spektre.org',
@@ -190,6 +207,7 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
 
         'ToolbarRandom' => 'Non visti',
 
+        'UnsavedCollection' => 'Unsaved Collection',
         'ModelsSelect' => 'Selezionare un modello/collezione',
         'ModelsPersonal' => 'Personali',
         'ModelsDefault' => 'Predefiniti',
@@ -211,6 +229,9 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'ModelFieldMax' => 'Massimo:',
         'ModelFieldList' => 'Lista valori:',
         'ModelFieldListLegend' => '<i>separati da virgole</i>',
+        'ModelFieldDisplayAs' => 'Display as:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Testo corto',
         'ModelFieldTypeLongText' => 'Testo lungo',
         'ModelFieldTypeYesNo' => 'Si/No',
@@ -245,6 +266,8 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'ModelFilterActivated' => 'Nel box di ricerca',
         'ModelFilterComparison' => 'Comparazione',
         'ModelFilterContain' => 'Contiene',
+        'ModelFilterDoesNotContain' => 'Does not contain',
+        'ModelFilterRegexp' => 'Regular expression',
         'ModelFilterRange' => 'Campo',
         'ModelFilterNumeric' => 'Comparazione numerica',
         'ModelFilterQuick' => 'Creazione filtro veloce',
@@ -264,20 +287,25 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Preferenze',
+		'OptionsExpertMode' => 'Expert Mode',
+        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
         'OptionsBrowser' => 'Web browser',
         'OptionsPlayer' => 'Video player',
         'OptionsAudio' => 'Audio player',
+        'OptionsImageEditor' => 'Image editor',
+        'OptionsCdDevice' => 'CD device',
         'OptionsImages' => 'Indice di immagini',
         'OptionsUseRelativePaths' => 'Utilizza percorsi relativi per le immagini',
         'OptionsLayout' => 'Maschera',
         'OptionsStatus' => 'Visualizza la barra di stato in fondo alla finestra',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Attenzione:  Le modifiche eventualmente appportate in questo pannello avranno effetto solo dopo il riavvio dell\' applicazione GCstar!!!',
         'OptionsRemoveConfirm' => 'Chiedi conferma prima di rimuovere un articolo dalla collezione',
         'OptionsAutoSave' => 'Salva automaticamente la collezione',
         'OptionsAutoLoad' => 'All\'avvio carica l\'ultima collezione trattata',
         'OptionsSplash' => 'Mostra splashscreen',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Use spelling checker for long text fields',
-        'OptionsImagesTitle' => 'Seleziona un indice',
         'OptionsProgramTitle' => 'Seleziona il programma per essere usato',
 		'OptionsPlugins' => 'Siti da utilizzare per le informazioni degli articoli',
 		'OptionsAskPlugins' => 'Chiedi (Tutti i siti)',
@@ -310,6 +338,7 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'OptionsTransform' => 'Mettere gli articoli alla fine dei titoli',
         'OptionsArticles' => 'Articoli (separare mediante virgola)',
         'OptionsSearchStop' => 'L\'utente può arrestare una ricerca',
+        'OptionsBigPics' => 'Use big pictures when available',
         'OptionsAlwaysOriginal' => 'Utilizza il titolo principale come originale in mancanza di uno specificato',
         'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Dimensione della cronologia',
@@ -346,6 +375,7 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'ImagesOptionsFg'=> 'Selezione',
         'ImagesOptionsBgTooltip' => 'Cambia colore di sfondo',
         'ImagesOptionsFgTooltip'=> 'Cambia il colore di selezione',
+        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
         'ImagesOptionsSizeLabel' => 'Dimensione',
         'ImagesOptionsSizeList' => {0 => 'Ultra piccola', 1 => 'Piccola', 2 => 'Media', 3 => 'Grande', 4 => 'Extra Grande'},
         'ImagesOptionsSizeTooltip' => 'Seleziona dimensioni immagine',
@@ -373,11 +403,11 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'ExportFieldsTip' => 'Campi prescelti per l\'esportazione',
         'ExportWithPictures' => 'Copiare le immagini in una sottodirectory',
         'ExportSortBy' => 'Sort by',
+        'ExportOrder' => 'Order',
 
         'ImportListTitle' => 'Importazione della collezione:',
         'ImportExportData' => 'Dati',
         'ImportExportFile' => 'Elenco',
-        'ImportExportSave' => 'Selezionare l\'elenco',
         'ImportExportFieldsUnused' => 'Campi non selezionati',
         'ImportExportFieldsUsed' => 'Campi selezionati',
         'ImportExportFieldsFill' => 'Tutti i campi',
@@ -391,7 +421,10 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'ImportDropError' => 'Si e\' verificato un errore durante l\'apertura di almeno un file. Viene ricaricata la precedente collezione!',
         'ImportGenerateId' => 'Generare identificatore per ogni articolo',
 
-        'FileOverwrite' => 'Questa collezione esiste gia\', sovrascriverla?',
+        'FileChooserOpenFile' => 'Selezionare l\'elenco',
+        'FileChooserDirectory' => 'Directory',
+        'FileChooserOpenDirectory' => 'Seleziona un indice',
+        'FileChooserOverwrite' => 'Questa collezione esiste gia\', sovrascriverla?',
 
         'PanelCompact' => 'Compattare',
         'PanelReadOnly' => 'Sola lettura',
@@ -434,6 +467,8 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'PanelFavourite' => 'Favourite',
         'TagsAssigned' => 'Assigned Tags', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Nessun problema',
         'CheckYes' => 'Sì',
         'CheckNo' => 'No',
@@ -442,6 +477,10 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'ToolbarAllTooltip' => 'Visualizza tutti gli articoli',
         'ToolbarGroupBy' => 'Raggruppa per',
         'ToolbarGroupByTooltip' => 'Selezionare il campo da utilizzare per raggruppare gli articoli della collezione',
+        'ToolbarQuickSearch' => 'Quick search',
+        'ToolbarQuickSearchLabel' => 'Search',
+        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
+        'ToolbarSeparator' => ' Separator',
                
         'PluginsTitle' => 'Cerca un articolo',
         'PluginsQuery' => 'Query',
@@ -472,6 +511,7 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
 
         'BorrowedTitle' => 'Articoli prestati',
         'BorrowedDate' => 'Il',
+        'BorrowedDisplayInPanel' => 'Show item in main window',
 
         'MailTitle' => 'Manda una e-mail',
         'MailFrom' => 'Da: ',
@@ -512,6 +552,7 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'GenresModify' => 'Modifica conversione',
 
         'PropertiesName' => 'Nome collezione',
+        'PropertiesLang' => 'Language code',
         'PropertiesOwner' => 'Proprietario',
         'PropertiesEmail' => 'e-mail',
         'PropertiesDescription' => 'Descrizione',
@@ -521,6 +562,7 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'PropertiesFileSize' => 'Dimensione',
         'PropertiesFileSizeSymbols' => ['Byte', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Proprieta\' collezione',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Programmi per spedizione e-mail',
         'MailProgramsName' => 'Nome',
@@ -544,6 +586,11 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'AdvancedSearchTypeOr' => 'Articoli soddisfacenti almeno un criterio (OR)',
         'AdvancedSearchCriteria' => 'Criteri',
         'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Save search',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
 
         'BugReportSubject' => 'Bug report generated from GCstar',
         'BugReportVersion' => 'Version',
