@@ -109,6 +109,9 @@ można użyć <b>przycisku pod szczegółami</b>.',
             'MenuEditLockItems' => 'Zablokuj Zbiory',
     
         'MenuDisplay' => 'Filtr',
+            'MenuSavedSearches' => 'Zapisane wyszukiwania',
+                 'MenuSavedSearchesSave' => 'Zapisz bieżące wyszukiwanie',
+                 'MenuSavedSearchesEdit' => 'Edytuj zapisane wyszukiwania',
             'MenuAdvancedSearch' => 'Wyszukiwanie zaawansowane',
             'MenuViewAllItems' => 'Pokaż wszystkie pozycje',
             'MenuNoFilter' => 'Wszystkie',
@@ -116,6 +119,7 @@ można użyć <b>przycisku pod szczegółami</b>.',
         'MenuConfiguration' => 'Ustawienia',
             'MenuDisplayOptions' => 'Wyświetlane informacje',
             'MenuBorrowers' => 'Dłużnicy',
+            'MenuToolbarConfiguration' => 'Dos_tosuj pasek narzędzi',
             'MenuGenresConversion' => 'Konwersja gatunków',
             
         'MenuBookmarks' => 'Ulubione',
@@ -132,6 +136,11 @@ można użyć <b>przycisku pod szczegółami</b>.',
         
         'ContextExpandAll' => 'Rozwiń wszystkie',
         'ContextCollapseAll' => 'Zwiń wszystkie',
+        'ContextChooseImage' => 'Wyb_ierz obraz',
+        'ContextOpenWith' => 'O_twórz w',
+        'ContextImageEditor' => 'Otwórz w edytorze graficznym',
+        'ContextImgFront' => 'Przód',
+        'ContextImgBack' => 'Tył',
     
         'DialogEnterNumber' => 'Wprowadź wartość',
 
@@ -148,6 +157,8 @@ można użyć <b>przycisku pod szczegółami</b>.',
         'PreferencesTooltip' => 'Ustaw swoje preferencje',
         'ViewTooltip' => 'Zmień sposób wyświetlania Zbioru',
         'PlayTooltip' => 'Odtwórz wideo połączone z filmem',
+        'PlayFileNotFound' => 'W podanym miejscu nie ma pliku do odtworzenia:',
+        'PlayRetry' => 'Ponów',
 
         'StatusSave' => 'Zapisuję...',
         'StatusLoad' => 'Wczytuję...',
@@ -158,10 +169,14 @@ można użyć <b>przycisku pod szczegółami</b>.',
         'SaveError' => 'Nie mogę zapisać listy pozycji. Sprawdź uprawnienia lub wolne miejsce na dysku.',
         'OpenError' => 'Nie mogę odczytać listy pozycji. Sprawdź uprawnienia.',
         'OpenFormatError' => 'Nie mogę odczytać listy pozycji.',
+        'OpenVersionWarning' => 'Zbiór został utworzony za pomocą nowszej wersji programu GCstar. Jeśli go zapiszesz możesz utracić część danych.',
+        'OpenVersionQuestion' => 'Czy mimo to chcesz kontynuować?',
         'ImageError' => 'Wybrany katalog dla obrazów jest niewłaściwy. Wybierz inny.',
         'OptionsCreationError'=> 'Nie mogę stworzyć pliku konfiguracji: ',
         'OptionsOpenError'=> 'Nie mogę otworzyć pliku konfiguracji: ',
         'OptionsSaveError'=> 'Nie mogę zapisać pliku konfiguracji: ',
+        'ErrorModelNotFound' => 'Nie znaleziono szablonu: ',
+        'ErrorModelUserDir' => 'Szablony zdefiniowane przez użytkownika znajdują się w: ',
 
         'RandomTooltip' => 'Co by tu dziś ...?',
         'RandomError'=> 'Wszystko już było',
@@ -174,8 +189,10 @@ można użyć <b>przycisku pod szczegółami</b>.',
         'AboutVersion' => 'Wersja',
         'AboutTeam' => 'Organizacja',
         'AboutWho' => 'Christian Jodar (Tian): Project manager, Programmer
+Nyall Dawson (Zombiepig): Programmer
+TPF: Programmer
 Adolfo González: Programmer
-Nyall Dawson (Zombiepig): Programmer',
+',
         'AboutLicense' => 'Rozpowszechniany na warunkach licencji GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
@@ -184,6 +201,7 @@ http://le-spektre.org',
 
         'ToolbarRandom' => 'Dziś wieczorem',
 
+        'UnsavedCollection' => 'Zbiór nie zapisany',
         'ModelsSelect' => 'Wybierz typ zbioru',
         'ModelsPersonal' => 'Szablony osobiste',
         'ModelsDefault' => 'Szablony domyślne',
@@ -205,6 +223,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maksimum:',
         'ModelFieldList' => 'Lista wartości:',
         'ModelFieldListLegend' => '<i>oddzielone przecinkami</i>',
+        'ModelFieldDisplayAs' => 'Wyświetl jako:',
+        'ModelFieldDisplayAsText' => 'Tekst',
+        'ModelFieldDisplayAsGraphical' => 'Grafika',
         'ModelFieldTypeShortText' => 'Krótki tekst',
         'ModelFieldTypeLongText' => 'Długi tekst',
         'ModelFieldTypeYesNo' => 'Tak/Nie',
@@ -239,6 +260,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Pole będzie szukane',
         'ModelFilterComparison' => 'Porównanie',
         'ModelFilterContain' => 'Zawiera',
+        'ModelFilterDoesNotContain' => 'Nie zawiera',
+        'ModelFilterRegexp' => 'Wyrażenie regularne',
         'ModelFilterRange' => 'W zakresie',
         'ModelFilterNumeric' => 'Porównanie jest numeryczne',
         'ModelFilterQuick' => 'Utwórz szybki filtr',
@@ -258,20 +281,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'Do Zbioru możesz dodać wiele pozycji jednocześnie, wybierając je trzymaj wciśnięty klawisz Ctrl lub Shift',
         
         'OptionsTitle' => 'Preferencje',
+		'OptionsExpertMode' => 'Ustawienia zaawansowane',
+        'OptionsPrograms' => 'Wybierz program do obsługi plików danego typu, puste pole spowoduje użycie aplikacji domyślnej',
         'OptionsBrowser' => 'Przeglądarka',
         'OptionsPlayer' => 'Odtwarzacz multimedialny',
         'OptionsAudio' => 'Odtwarzacz muzyczny',
+        'OptionsImageEditor' => 'Edytor graficzny',
+        'OptionsCdDevice' => 'Urządzenie CD',
         'OptionsImages' => 'Katalog obrazów',
         'OptionsUseRelativePaths' => 'Używaj względnych ścieżek dla obrazów',
         'OptionsLayout' => 'Układ',
         'OptionsStatus' => 'Wyświetlaj pasek stanu',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Ostrzeżenie: Zmiany zostaną wprowadzone dopiero po ponownym uruchomieniu programu.',
         'OptionsRemoveConfirm' => 'Potwierdzaj przed usunięciem pozycji',
         'OptionsAutoSave' => 'Autozapis Zbioru',
         'OptionsAutoLoad' => 'Po uruchomieniu załaduj poprzedni Zbiór',
         'OptionsSplash' => 'Pokazuj logo przy uruchamianiu',
+        'OptionsTearoffMenus' => 'Włącz odrywane menu',
         'OptionsSpellCheck' => 'Zastosuj korektor pisowni w długich polach tekstowych',
-        'OptionsImagesTitle' => 'Wybierz katalog',
         'OptionsProgramTitle' => 'Wybierz program którego chcesz używać',
 		'OptionsPlugins' => 'Witryna do pobierania danych',
 		'OptionsAskPlugins' => 'Pytaj (Wszystkie witryny)',
@@ -304,6 +332,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Umieszczaj rodzajniki na końcu',
         'OptionsArticles' => 'Rodzajniki',
         'OptionsSearchStop' => 'Zezwalaj na zatrzymanie szukania',
+        'OptionsBigPics' => 'Użyj dużego zdjęcia jeśli to możliwe',
         'OptionsAlwaysOriginal' => 'Używaj głównego tytułu jako tytułu oryginalnego',
         'OptionsRestoreAccelerators' => 'Przywróć domyślne skróty',
         'OptionsHistory' => 'Rozmiar historii',
@@ -340,6 +369,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Zaznaczenie',
         'ImagesOptionsBgTooltip' => 'Zmień kolor tła',
         'ImagesOptionsFgTooltip'=> 'Zmień kolor zaznaczenia',
+        'ImagesOptionsResizeImgList' => 'Automatycznie ustal liczbę kolumn',
         'ImagesOptionsSizeLabel' => 'Rozmiar',
         'ImagesOptionsSizeList' => {0 => 'Bardzo mały', 1 => 'Mały', 2 => 'Średni', 3 => 'Duży', 4 => 'Ogromny'},
         'ImagesOptionsSizeTooltip' => 'Wybierz rozmiar obrazka',
@@ -367,11 +397,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Wybierz pola, które chcesz wyeksportować',
         'ExportWithPictures' => 'Kopiuj obrazy do podkatalogu',
         'ExportSortBy' => 'Sortuj według',
+        'ExportOrder' => 'Kolejność',
 
         'ImportListTitle' => 'Importuj listę pozycji',
         'ImportExportData' => 'Dane',
         'ImportExportFile' => 'Plik',
-        'ImportExportSave' => 'Wybierz plik, który chcesz użyć',
         'ImportExportFieldsUnused' => 'Nieużywane pola',
         'ImportExportFieldsUsed' => 'Używane pola',
         'ImportExportFieldsFill' => 'Dodaj wszystkie',
@@ -385,7 +415,10 @@ http://le-spektre.org',
         'ImportDropError' => 'Jeden lub więcej z ładowanych plików spowodował błąd. Poprzednia lista zostanie przywrócona.',
         'ImportGenerateId' => 'Utwórz identyfikator dla każdej z pozycji',
 
-        'FileOverwrite' => 'Plik już istnieje. Czy chcesz go zastąpić?',
+        'FileChooserOpenFile' => 'Wybierz plik, który chcesz użyć',
+        'FileChooserDirectory' => 'Katalog',
+        'FileChooserOpenDirectory' => 'Wybierz katalog',
+        'FileChooserOverwrite' => 'Plik już istnieje. Czy chcesz go zastąpić?',
 
         'PanelCompact' => 'Kompaktowy',
         'PanelReadOnly' => 'Tylko do odczytu',
@@ -428,6 +461,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Ulubione',
         'TagsAssigned' => 'Znaczniki przydzielone', 
 
+        'PanelUser' => 'Pola użytkownika',
+
         'CheckUndef' => 'Oba',
         'CheckYes' => 'Tak',
         'CheckNo' => 'Nie',
@@ -436,6 +471,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Zobacz wszystkie pozycje',
         'ToolbarGroupBy' => 'Grupuj według',
         'ToolbarGroupByTooltip' => 'Wybierz pole, według którego będą grupowane pozycje z listy',
+        'ToolbarQuickSearch' => 'Szybkie wyszukiwanie',
+        'ToolbarQuickSearchLabel' => 'Znajdź',
+        'ToolbarQuickSearchTooltip' => 'Wybierz pole do przeszukania. Wprowadź wyrażenie i naciśnij Enter',
+        'ToolbarSeparator' => ' Separator',
 
         'PluginsTitle' => 'Wyszukiwanie',
         'PluginsQuery' => 'Szukaj',
@@ -466,6 +505,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Pożyczone pozycje',
         'BorrowedDate' => 'Od',
+        'BorrowedDisplayInPanel' => 'Pokaż tą pozycję w głównym oknie',
 
         'MailTitle' => 'Wyślij e-mail',
         'MailFrom' => 'Od: ',
@@ -506,6 +546,7 @@ http://le-spektre.org',
         'GenresModify' => 'Edytuj konwersje',
 
         'PropertiesName' => 'Nazwa Zbioru',
+        'PropertiesLang' => 'Kod języka',
         'PropertiesOwner' => 'Właściciel',
         'PropertiesEmail' => 'E-mail',
         'PropertiesDescription' => 'Opis',
@@ -515,6 +556,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Rozmiar',
         'PropertiesFileSizeSymbols' => ['Bajtów', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Właściwości Zbioru',
+        'PropertiesDefaultPicture' => 'Zdjęcie domyślne',
 
         'MailProgramsTitle' => 'Programy pocztowe',
         'MailProgramsName' => 'Nazwa',
@@ -538,6 +580,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Pozycje spełniające co najmniej jeden z warunków',
         'AdvancedSearchCriteria' => 'Warunki',
         'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Zapisz wyszukiwanie',
+        'AdvancedSearchSaveName' => 'Nazwa',
+        'AdvancedSearchSaveOverwrite' => 'Wyszukiwanie o tej nazwie już istnieje. Proszę użyć innej nazwy.',
+        'AdvancedSearchUseCase' => 'Uwzględniaj wielkość liter',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignoruj znaki diakrytyczne',
 
         'BugReportSubject' => 'Zgłoszenie błędu wygenerowane z programu GCstar',
         'BugReportVersion' => 'Wersja',
