@@ -109,6 +109,9 @@ pode usar o <b>botão abaixo dos detalhes do item</b>.',
             'MenuEditLockItems' => '_Bloquear coleção',
         
         'MenuDisplay' => '_Filtros',        
+            'MenuSavedSearches' => 'Saved searches',
+                'MenuSavedSearchesSave' => 'Save current search',
+                'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'Busca _avançada',
             'MenuViewAllItems' => '_Ver todos os itens',	
             'MenuNoFilter' => '_Todos',	
@@ -116,6 +119,7 @@ pode usar o <b>botão abaixo dos detalhes do item</b>.',
         'MenuConfiguration' => '_Configurações',	
             'MenuDisplayOptions' => '_Informações exibidas',
             'MenuBorrowers' => '_Devedores',	
+            'MenuToolbarConfiguration' => '_Toolbar controls',
             'MenuGenresConversion' => 'Conversão de _gêneros',
 
         'MenuBookmarks' => 'Minhas _Coleções',
@@ -132,6 +136,11 @@ pode usar o <b>botão abaixo dos detalhes do item</b>.',
         
         'ContextExpandAll' => 'Expandir tudo',
         'ContextCollapseAll' => 'Contrair todo',
+        'ContextChooseImage' => 'Choose _Image',
+        'ContextOpenWith' => 'Open Wit_h',
+        'ContextImageEditor' => 'Image Editor',
+        'ContextImgFront' => 'Front',
+        'ContextImgBack' => 'Back',
 
         'DialogEnterNumber' => 'Por favor, introduza um valor',
 
@@ -148,6 +157,8 @@ pode usar o <b>botão abaixo dos detalhes do item</b>.',
         'PreferencesTooltip' => 'Selecionar preferências',
         'ViewTooltip' => 'Trocar o tipo de coleção',
         'PlayTooltip' => 'Reproduzir arquivo de vídeo associado ao item',
+        'PlayFileNotFound' => 'File to launch was not found in this location:',
+        'PlayRetry' => 'Retry',
         
         'StatusSave' => 'Salvando...',
         'StatusLoad' => 'Carregando...',
@@ -158,10 +169,14 @@ pode usar o <b>botão abaixo dos detalhes do item</b>.',
         'SaveError' => 'Impossível salvar a coleção. Por favor, verifique as permissões de acesso e o espaço livre.',
         'OpenError' => 'Impossível abrir a coleção. Por favor, verifique as permissões de acesso.',
         'OpenFormatError' => 'Impossível abrir a coleção. O formato pode estar incorreto',
+        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
+        'OpenVersionQuestion' => 'Do you still want to continue?',
         'ImageError' => 'O diretório de imagens está incorreto. Por favor, selecione outro.',
         'OptionsCreationError'=> 'Impossível criar um arquivo de opções: ',
         'OptionsOpenError'=> 'Impossível abrir um arquivo de opções: ',
         'OptionsSaveError'=> 'Impossível salvar um arquivo de opções: ',
+        'ErrorModelNotFound' => 'Model not found: ',
+        'ErrorModelUserDir' => 'User defined models are in: ',
 
         'RandomTooltip' => 'O que quer ver esta noite?',
         'RandomError'=> 'Você não possui itens selecionáveis',
@@ -174,8 +189,10 @@ pode usar o <b>botão abaixo dos detalhes do item</b>.',
         'AboutVersion' => 'Versão',
         'AboutTeam' => 'Equipe',
         'AboutWho' => 'Christian Jodar (Tian) : Gerente de projeto, Programador
+Nyall Dawson (Zombiepig) : Programador
+TPF : Programador
 Adolfo González : Programador
-Nyall Dawson (Zombiepig) : Programador',
+',
         'AboutLicense' => 'Distribuído segundo os termos da GNU GPL
 Logos Copyright le Spektre
 http://le-spektre.org',
@@ -184,6 +201,7 @@ http://le-spektre.org',
         
         'ToolbarRandom' => 'Esta noite',
 
+        'UnsavedCollection' => 'Unsaved Collection',
         'ModelsSelect' => 'Selecionar um tipo de coleção',
         'ModelsPersonal' => 'Modelos pessoais',
         'ModelsDefault' => 'Modelos padrões',
@@ -205,6 +223,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Máximo:',
         'ModelFieldList' => 'Lista de valores:',
         'ModelFieldListLegend' => '<i>Separados por vírgulas</i>',
+        'ModelFieldDisplayAs' => 'Display as:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Texto curto',
         'ModelFieldTypeLongText' => 'Texto longo',
         'ModelFieldTypeYesNo' => 'Sim/Não',
@@ -239,6 +260,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Deve aparecer na caixa de busca',
         'ModelFilterComparison' => 'Comparação',
         'ModelFilterContain' => 'Contém',
+        'ModelFilterDoesNotContain' => 'Does not contain',
+        'ModelFilterRegexp' => 'Regular expression',
         'ModelFilterRange' => 'Escopo',
         'ModelFilterNumeric' => 'Comparação numérica',
         'ModelFilterQuick' => 'Criar um filtro rápido',
@@ -258,20 +281,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
 
         'OptionsTitle' => 'Preferências',
+		'OptionsExpertMode' => 'Expert Mode',
+        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
         'OptionsBrowser' => 'Navegador de Internet',
         'OptionsPlayer' => 'Reprodutor de vídeo',
         'OptionsAudio' => 'Reprodutor de áudio',
+        'OptionsImageEditor' => 'Image editor',
+        'OptionsCdDevice' => 'CD device',
         'OptionsImages' => 'Pasta de imagens', 	
         'OptionsUseRelativePaths' => 'Usar rotas relativas para as imagens',
         'OptionsLayout' => 'Disposição',	
         'OptionsStatus' => 'Barra de status',	
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Atenção: As mudanças efetuadas nesta aba não terão efeito até que o aplicativo seja reiniciado.', 
         'OptionsRemoveConfirm' => 'Pedir confirmação antes de apagar',
         'OptionsAutoSave' => 'Salvar coleção automaticamente',
         'OptionsAutoLoad' => 'Carregar a coleção anterior ao início',
         'OptionsSplash' => 'Exibir tela de início',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Use spelling checker for long text fields',
-        'OptionsImagesTitle' => 'Escolha uma pasta',
         'OptionsProgramTitle' => 'Escolha que programa a utilizar',
         'OptionsPlugins' => 'Site para baixar informações',
         'OptionsAskPlugins' => 'Perguntar (Todos os sites)',
@@ -304,6 +332,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Colocar artigos ao final dos títulos',	
         'OptionsArticles' => 'Artigos (separados por vírgula)',	
         'OptionsSearchStop' => 'O usuário pode cancelar a busca',
+        'OptionsBigPics' => 'Use big pictures when available',
         'OptionsAlwaysOriginal' => 'Usar título principal como o original se não encontrar nenhum',
         'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Tamanho do histórico',
@@ -340,6 +369,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Seleção',
         'ImagesOptionsBgTooltip' => 'Trocar cor de fundo',
         'ImagesOptionsFgTooltip'=> 'Trocar cor de seleção',
+        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
         'ImagesOptionsSizeLabel' => 'Tamanho',
         'ImagesOptionsSizeList' => {0 => 'Muito Pequeno', 1 => 'Pequeno', 2 => 'Médio', 3 => 'Grande', 4 => 'Muito Grande'},
         'ImagesOptionsSizeTooltip' => 'Selecione um tamanho de imagem',
@@ -367,11 +397,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Escolha os campos para exportar',
         'ExportWithPictures' => 'Copiar as imagens de uma sub-pasta',
         'ExportSortBy' => 'Sort by',
+        'ExportOrder' => 'Order',
 
         'ImportListTitle' => 'Importar outra lista de itens',
         'ImportExportData' => 'Informação',
         'ImportExportFile' => 'Arquivo',	 
-        'ImportExportSave' => 'Por favor, selecione um arquivo', 	
         'ImportExportFieldsUnused' => 'Campos inutilizados',
         'ImportExportFieldsUsed' => 'Campos utilizados',
         'ImportExportFieldsFill' => 'Todos os campos',
@@ -385,7 +415,10 @@ http://le-spektre.org',
         'ImportDropError' => 'Ocorreu um erro ao abrir em pelo menos um arquivo. A lista anterior será recarregada.',
         'ImportGenerateId' => 'Gerar identificador para cada item',
 
-        'FileOverwrite' => 'Este arquivo já existe. Deseja sobrescrevê-lo?',
+        'FileChooserOpenFile' => 'Por favor, selecione um arquivo', 	
+        'FileChooserDirectory' => 'Directory',
+        'FileChooserOpenDirectory' => 'Escolha uma pasta',
+        'FileChooserOverwrite' => 'Este arquivo já existe. Deseja sobrescrevê-lo?',
 
         #Some default panels
         'PanelCompact' => 'Compacto',
@@ -429,6 +462,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favourite',
         'TagsAssigned' => 'Assigned Tags', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Qualquer',
         'CheckYes' => 'Sim',
         'CheckNo' => 'Não',
@@ -437,6 +472,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Ver todos os itens',	
         'ToolbarGroupBy' => 'Agrupar por',
         'ToolbarGroupByTooltip' => 'Selecionar o campo para usar nos itens agrupados na lista',
+        'ToolbarQuickSearch' => 'Quick search',
+        'ToolbarQuickSearchLabel' => 'Search',
+        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
+        'ToolbarSeparator' => ' Separator',
 
         'PluginsTitle' => 'Buscar um item',	
         'PluginsQuery' => 'Pergunta',
@@ -467,6 +506,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Itens emprestados',	
         'BorrowedDate' => 'Desde',	
+        'BorrowedDisplayInPanel' => 'Show item in main window',
 
         'MailTitle' => 'Enviar um e-mail',	
         'MailFrom' => 'De: ',	
@@ -507,6 +547,7 @@ http://le-spektre.org',
         'GenresModify' => 'Editar conversão',
 
         'PropertiesName' => 'Nome da coleção',
+        'PropertiesLang' => 'Language code',
         'PropertiesOwner' => 'Dono',
         'PropertiesEmail' => 'E-mail',
         'PropertiesDescription' => 'Descrição',
@@ -516,6 +557,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Tamanho',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Propriedades da coleção',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Programas para enviar e-mails',
         'MailProgramsName' => 'Nome',
@@ -539,6 +581,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Itens que cumpram pelo menos um critério',
         'AdvancedSearchCriteria' => 'Critério',
         'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Save search',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
 
         'BugReportSubject' => 'Bug report generated from GCstar',
         'BugReportVersion' => 'Version',
