@@ -109,6 +109,9 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
             'MenuEditLockItems' => 'B_lochează colecţia',
     
         'MenuDisplay' => 'F_iltrare',
+            'MenuSavedSearches' => 'Saved searches',
+                'MenuSavedSearchesSave' => 'Save current search',
+                'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'Căutare a_vansată',
             'MenuViewAllItems' => 'Afişează to_ate elementele',
             'MenuNoFilter' => '_Oricare',
@@ -116,6 +119,7 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
         'MenuConfiguration' => '_Setări',
             'MenuDisplayOptions' => '_Informaţii afişate',
             'MenuBorrowers' => '_Persoane care au împrumutat',
+            'MenuToolbarConfiguration' => '_Toolbar controls',
             'MenuGenresConversion' => '_Conversie gen',
 
         'MenuBookmarks' => '_Colecţiile mele',
@@ -132,6 +136,11 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
         
         'ContextExpandAll' => 'Desfă tot',
         'ContextCollapseAll' => 'Strânge tot',
+        'ContextChooseImage' => 'Choose _Image',
+        'ContextOpenWith' => 'Open Wit_h',
+        'ContextImageEditor' => 'Image Editor',
+        'ContextImgFront' => 'Front',
+        'ContextImgBack' => 'Back',
 
         'DialogEnterNumber' => 'Vă rugăm introduceţi o valoare',
 
@@ -148,6 +157,8 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
         'PreferencesTooltip' => 'Setaţi preferinţele dumneavoastră',
         'ViewTooltip' => 'Schimbă afişarea colecţiei',
         'PlayTooltip' => 'Redă fişierul video asociat acestui element',
+        'PlayFileNotFound' => 'File to launch was not found in this location:',
+        'PlayRetry' => 'Retry',
 
         'StatusSave' => 'Salvez...',
         'StatusLoad' => 'Încarc...',
@@ -158,10 +169,14 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
         'SaveError' => 'Nu am putut salva lista de elemente. Vă rugăm verificaţi drepturile de acces şi spaţiul liber pe disc.',
         'OpenError' => 'Nu am putut deschide lista de elemente. Vă rugăm verificaţi drepturile de acces.',
         'OpenFormatError' => 'Nu am putut deschide lista de elemente.',
+        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
+        'OpenVersionQuestion' => 'Do you still want to continue?',
         'ImageError' => 'Directorul selectat pentru a salva imaginile nu este corect. Vă rugăm selectaţi alt director.',
         'OptionsCreationError'=> 'Nu pot crea fişierul de opţiuni: ',
         'OptionsOpenError'=> 'Nu pot deschide fişierul de opţiuni: ',
         'OptionsSaveError'=> 'Nu pot salva fişierul de opţiuni: ',
+        'ErrorModelNotFound' => 'Model not found: ',
+        'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Ce să vedem în acestă seară?',
         'RandomError'=> 'Nu aveţi nici un element care să poate fi selectat',
@@ -174,8 +189,10 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
         'AboutVersion' => 'Versiune',
         'AboutTeam' => 'Echipa',
         'AboutWho' => 'Christian Jodar (Tian): Manager de proiect, programator
+Nyall Dawson (Zombiepig) : Programator
+TPF : Programator
 Adolfo González : Programator
-Nyall Dawson (Zombiepig) : Programator',
+',
         'AboutLicense' => 'Distribuit în termenii licenţei GNU GPL
 Copyright logo le Spektre
 http://le-spektre.org',
@@ -184,6 +201,7 @@ http://le-spektre.org',
 
         'ToolbarRandom' => 'În seara asta',
         
+        'UnsavedCollection' => 'Unsaved Collection',
         'ModelsSelect' => 'Selectaţi un tip de colecţie',
         'ModelsPersonal' => 'Modele personale',
         'ModelsDefault' => 'Modele implicite',
@@ -205,6 +223,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maxim:',
         'ModelFieldList' => 'Listă valori:',
         'ModelFieldListLegend' => '<i>Separare prin virgulă</i>',
+        'ModelFieldDisplayAs' => 'Display as:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Text scurt',
         'ModelFieldTypeLongText' => 'Text lung',
         'ModelFieldTypeYesNo' => 'Da/Nu',
@@ -239,6 +260,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Ar trebui să apară în fereastra de căutare',
         'ModelFilterComparison' => 'Comparaţie',
         'ModelFilterContain' => 'Conţine',
+        'ModelFilterDoesNotContain' => 'Does not contain',
+        'ModelFilterRegexp' => 'Regular expression',
         'ModelFilterRange' => 'Domeniu',
         'ModelFilterNumeric' => 'Comparaţia e numerică',
         'ModelFilterQuick' => 'Creaţi un filtru rapid',
@@ -258,20 +281,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Preferinţe',
+		'OptionsExpertMode' => 'Expert Mode',
+        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
         'OptionsBrowser' => 'Navigator web',
         'OptionsPlayer' => 'Player video',
         'OptionsAudio' => 'Player audio',
+        'OptionsImageEditor' => 'Image editor',
+        'OptionsCdDevice' => 'CD device',
         'OptionsImages' => 'Director de imagini',
         'OptionsUseRelativePaths' => 'Foloseşte căi relative pentru imagini',
         'OptionsLayout' => 'Layout',
         'OptionsStatus' => 'Afişează bara de status',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Atenţie: Modificările din acest tab nu vor avea efect decât după repornirea aplicaţiei.',
         'OptionsRemoveConfirm' => 'Cere o confirmare înainte de ştergerea elementului',
         'OptionsAutoSave' => 'Salvează colecţia automat',
         'OptionsAutoLoad' => 'Încarcă colecţia anterioară la pornire',
         'OptionsSplash' => 'Afişează ecranul de pornire',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Use spelling checker for long text fields',
-        'OptionsImagesTitle' => 'Selectaţi un director',
         'OptionsProgramTitle' => 'Selectaţi programul ce va fi folosit',
 		'OptionsPlugins' => 'Situl de la care se vor obţine informaţiile',
 		'OptionsAskPlugins' => 'Întreabă (toate siturile)',
@@ -304,6 +332,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Plasează articolele la sfârşitul titlurilor',
         'OptionsArticles' => 'Articole (separate prin virgulă)',
         'OptionsSearchStop' => 'Permite întreruperea căutărilor',
+        'OptionsBigPics' => 'Use big pictures when available',
         'OptionsAlwaysOriginal' => 'Foloseşte titlul principal ca titlu original în cazul în care acesta nu este prezent',
         'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Mărime istoric',
@@ -340,6 +369,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Selecţie',
         'ImagesOptionsBgTooltip' => 'Schimbă culoarea pentru fundal',
         'ImagesOptionsFgTooltip'=> 'Schimbă culoarea pentru selecţie',
+        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
         'ImagesOptionsSizeLabel' => 'Mărime',
         'ImagesOptionsSizeList' => {0 => 'Foarte mică', 1 => 'Mică', 2 => 'Medie', 3 => 'Mare', 4 => 'Foarte mare'},
         'ImagesOptionsSizeTooltip' => 'Selectaţi mărimea imaginii',
@@ -367,11 +397,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Selectaţi câmpurile pe care doriţi să le exportaţi',
         'ExportWithPictures' => 'Copiază imaginile într-un subdirector',
         'ExportSortBy' => 'Sortare după',
+        'ExportOrder' => 'Order',
 
         'ImportListTitle' => 'Importă altă listă de elemente',
         'ImportExportData' => 'Data',
         'ImportExportFile' => 'Fişier',
-        'ImportExportSave' => 'Vă rugăm selectaţi fişierul pentru folosire',
         'ImportExportFieldsUnused' => 'Câmpuri nefolosite',
         'ImportExportFieldsUsed' => 'Câmpuri folosite',
         'ImportExportFieldsFill' => 'Adaugă toate',
@@ -385,7 +415,10 @@ http://le-spektre.org',
         'ImportDropError' => 'A intervenit o eroare la deschiderea a cel puţin unui fişier. Listă precedentă va fi reîncărcată.',
         'ImportGenerateId' => 'Generează identificator pentru fiecare element',
 
-        'FileOverwrite' => 'Acest fişier deja există. Doriţi să îl suprascrieţi?',
+        'FileChooserOpenFile' => 'Vă rugăm selectaţi fişierul pentru folosire',
+        'FileChooserDirectory' => 'Directory',
+        'FileChooserOpenDirectory' => 'Selectaţi un director',
+        'FileChooserOverwrite' => 'Acest fişier deja există. Doriţi să îl suprascrieţi?',
 
         'PanelCompact' => 'Compact',
         'PanelReadOnly' => 'Doar pentru citire',
@@ -428,6 +461,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favourite',
         'TagsAssigned' => 'Assigned Tags', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Nu contează',
         'CheckYes' => 'Da',
         'CheckNo' => 'Nu',
@@ -436,6 +471,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Afişează toate elementele',
         'ToolbarGroupBy' => 'Grupează după',
         'ToolbarGroupByTooltip' => 'Selectaţi câmpul folosit pentru a grupa elementele din listă',
+        'ToolbarQuickSearch' => 'Quick search',
+        'ToolbarQuickSearchLabel' => 'Search',
+        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
+        'ToolbarSeparator' => ' Separator',
         
         'PluginsTitle' => 'Cautare elemente',
         'PluginsQuery' => 'Interogare',
@@ -466,6 +505,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Elemente împrumutate',
         'BorrowedDate' => 'Din data de',
+        'BorrowedDisplayInPanel' => 'Show item in main window',
 
         'MailTitle' => 'Trimite un email',
         'MailFrom' => 'De la: ',
@@ -506,6 +546,7 @@ http://le-spektre.org',
         'GenresModify' => 'Editează conversia',
 
         'PropertiesName' => 'Nume colecţie',
+        'PropertiesLang' => 'Language code',
         'PropertiesOwner' => 'Proprietar',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Descriere',
@@ -515,6 +556,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Mărime',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Proprietăţi colecţie',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Programe pentru trimis mailuri',
         'MailProgramsName' => 'Nume',
@@ -538,6 +580,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Elementele se potrivesc la cel puţin un criteriu',
         'AdvancedSearchCriteria' => 'Criteriu',
         'AdvancedSearchAnyField' => 'Orice câmp',
+        'AdvancedSearchSaveTitle' => 'Save search',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
 
         'BugReportSubject' => 'Raportare bug generată de GCstar',
         'BugReportVersion' => 'Versiune',
