@@ -109,6 +109,9 @@
             'MenuEditLockItems' => '_Зафиксировать коллекцию',
     
         'MenuDisplay' => '_Фильтр',
+            'MenuSavedSearches' => 'Saved searches',
+                'MenuSavedSearchesSave' => 'Save current search',
+                'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'Расширенный _Поиск',
             'MenuViewAllItems' => 'Показать _ВСЕ фильмы',
             'MenuNoFilter' => '_Любой',
@@ -116,6 +119,7 @@
         'MenuConfiguration' => '_Настройки',
             'MenuDisplayOptions' => '_Отображаемая информация',
             'MenuBorrowers' => '_Должники',
+            'MenuToolbarConfiguration' => '_Toolbar controls',
             'MenuGenresConversion' => '_Преобразование жанров',
         
         'MenuBookmarks' => 'Моя _Коллекция',
@@ -132,6 +136,11 @@
         
         'ContextExpandAll' => 'Развернуть всё',
         'ContextCollapseAll' => 'Свернуть всё',
+        'ContextChooseImage' => 'Choose _Image',
+        'ContextOpenWith' => 'Open Wit_h',
+        'ContextImageEditor' => 'Image Editor',
+        'ContextImgFront' => 'Front',
+        'ContextImgBack' => 'Back',
     
         'DialogEnterNumber' => 'Пожалуйста введите занчение',
 
@@ -148,6 +157,8 @@
         'PreferencesTooltip' => 'Установите свои предпочтения',
         'ViewTooltip' => 'Изменить отоюражение коллекции',
         'PlayTooltip' => 'Воспроизвести видео ассоциируемое с фильмом',
+        'PlayFileNotFound' => 'File to launch was not found in this location:',
+        'PlayRetry' => 'Retry',
 
         'StatusSave' => 'Сохраняется...',
         'StatusLoad' => 'Загружается...',
@@ -158,10 +169,14 @@
         'SaveError' => 'Не могу сохранить список фильмов. Пожалуйста проверьте права доступа и свободное мето на диске.',
         'OpenError' => 'Не могу открыть список фильмо. Пожалуйста проверьте права доступа.',
         'OpenFormatError' => 'Не могу открыть список фильмо.',
+        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
+        'OpenVersionQuestion' => 'Do you still want to continue?',
         'ImageError' => 'Выбранная для сохранения изображение директория не верна. Пожалуйста выберите другую.',
         'OptionsCreationError'=> 'Не могу создать файл опций: ',
         'OptionsOpenError'=> 'Не могу открыть файл опций: ',
         'OptionsSaveError'=> 'Не могу сохранить файл опций: ',
+        'ErrorModelNotFound' => 'Model not found: ',
+        'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Чего бы посмотреть сегодня вечером ?',
         'RandomError'=> 'У вас нет непросмотренных фильмов',
@@ -174,8 +189,10 @@
         'AboutVersion' => 'Версия',
         'AboutTeam' => 'Команда',
         'AboutWho' => 'Christian Jodar (Tian): Руководитель проекта, Программист
+Nyall Dawson (Zombiepig): Программист
+TPF: Программист
 Adolfo González: Программист
-Nyall Dawson (Zombiepig): Программист',
+',
         'AboutLicense' => 'Распространяется под лицензией GNU GPL
 Логотипы Copyright le Spektre
 http://le-spektre.org',
@@ -184,6 +201,7 @@ http://le-spektre.org',
 
         'ToolbarRandom' => 'Сегодня вечером',
         
+        'UnsavedCollection' => 'Unsaved Collection',
         'ModelsSelect' => 'Выберите тип коллекции',
         'ModelsPersonal' => 'Персональные модели',
         'ModelsDefault' => 'По-умолчанию',
@@ -205,6 +223,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Максимум:',
         'ModelFieldList' => 'Список значений:',
         'ModelFieldListLegend' => '<i>Разделённые запятой</i>',
+        'ModelFieldDisplayAs' => 'Display as:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Короткое описание текст',
         'ModelFieldTypeLongText' => 'Длинное описание',
         'ModelFieldTypeYesNo' => 'Да/Нет',
@@ -239,6 +260,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Должно быть в строке поиска',
         'ModelFilterComparison' => 'Сравнение',
         'ModelFilterContain' => 'Содержит',
+        'ModelFilterDoesNotContain' => 'Does not contain',
+        'ModelFilterRegexp' => 'Regular expression',
         'ModelFilterRange' => 'Диапазон',
         'ModelFilterNumeric' => 'ИСпользовать цифровое сравнение',
         'ModelFilterQuick' => 'Создать бытрый фильтр',
@@ -258,20 +281,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Предпочтения',
+		'OptionsExpertMode' => 'Expert Mode',
+        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
         'OptionsBrowser' => 'Вэб браузер',
         'OptionsPlayer' => 'Видео проигрыватель',
         'OptionsAudio' => 'Аудио проигрыватель',
+        'OptionsImageEditor' => 'Image editor',
+        'OptionsCdDevice' => 'CD device',
         'OptionsImages' => 'Директория с изображения',
         'OptionsUseRelativePaths' => 'Использовать относительные пути для изображений',
         'OptionsLayout' => 'Расположение',
         'OptionsStatus' => 'Отображать строку статуса',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Внимание : изменения на этой вкладке не будут применыны до перезагрузки приложения.',
         'OptionsRemoveConfirm' => 'Спрашивать подтверждение перед удалением фильма',
         'OptionsAutoSave' => 'Автоматически сохранять коллекцию',
         'OptionsAutoLoad' => 'Загружать предыдущую коллекцию при старте',
         'OptionsSplash' => 'Показывать стартовый экран',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Use spelling checker for long text fields',
-        'OptionsImagesTitle' => 'Выберите директорию',
         'OptionsProgramTitle' => 'Выберите программу',
 		'OptionsPlugins' => 'Сайт с которого нужно получать данные',
 		'OptionsAskPlugins' => 'Спрашивать (Все сайты)',
@@ -304,6 +332,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Помещать артикли в конце названия',
         'OptionsArticles' => 'Артикли (разделённые запятой)',
         'OptionsSearchStop' => 'Разрешить прерывать поиск',
+        'OptionsBigPics' => 'Use big pictures when available',
         'OptionsAlwaysOriginal' => 'Использовать основной заголовок вместо оригинального, если он отсутствует',
         'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Размер истории',
@@ -340,6 +369,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Выделение',
         'ImagesOptionsBgTooltip' => 'Изменить цвет фона',
         'ImagesOptionsFgTooltip'=> 'Изменить цвет выделения',
+        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
         'ImagesOptionsSizeLabel' => 'Размер',
         'ImagesOptionsSizeList' => {0 => 'Очень маленькое', 1 => 'Маленькое', 2 => 'Среднее', 3 => 'Большое', 4 => 'Очень большое'},
         'ImagesOptionsSizeTooltip' => 'Выберите размер изображеня',
@@ -367,11 +397,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Выберите поля которые вы хотите экспортировать',
         'ExportWithPictures' => 'Скопировать изображения в под-директорию',
         'ExportSortBy' => 'Sort by',
+        'ExportOrder' => 'Order',
 
         'ImportListTitle' => 'Импортировать другой список фильмоа',
         'ImportExportData' => 'Данные',
         'ImportExportFile' => 'Файл',
-        'ImportExportSave' => 'Пожалуйста, выберите файл',
         'ImportExportFieldsUnused' => 'Неиспользуемые поля',
         'ImportExportFieldsUsed' => 'Используемые поля',
         'ImportExportFieldsFill' => 'Добавить все',
@@ -385,7 +415,10 @@ http://le-spektre.org',
         'ImportDropError' => 'Произошла ошибка в процессе открытия, по крайней мере в одном файле. Будет загружен предыдущий список.',
         'ImportGenerateId' => 'Generate identifier for each item',
 
-        'FileOverwrite' => 'Такой файл уже существует. Вы хотите перезаписать его?',
+        'FileChooserOpenFile' => 'Пожалуйста, выберите файл',
+        'FileChooserDirectory' => 'Directory',
+        'FileChooserOpenDirectory' => 'Выберите директорию',
+        'FileChooserOverwrite' => 'Такой файл уже существует. Вы хотите перезаписать его?',
 
         'PanelCompact' => 'Компактно',
         'PanelReadOnly' => 'Только для чтения',
@@ -428,6 +461,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favourite',
         'TagsAssigned' => 'Assigned Tags', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Или',
         'CheckYes' => 'Да',
         'CheckNo' => 'Нет',
@@ -436,6 +471,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Показать все фильмы',
         'ToolbarGroupBy' => 'Группировать по',
         'ToolbarGroupByTooltip' => 'Выберите поля для группировки элементов в списке',
+        'ToolbarQuickSearch' => 'Quick search',
+        'ToolbarQuickSearchLabel' => 'Search',
+        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
+        'ToolbarSeparator' => ' Separator',
         
         'PluginsTitle' => 'Искать фильм',
         'PluginsQuery' => 'Запрос',
@@ -466,6 +505,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'На руках',
         'BorrowedDate' => 'С ',
+        'BorrowedDisplayInPanel' => 'Show item in main window',
 
         'MailTitle' => 'Послать e-mail',
         'MailFrom' => 'От: ',
@@ -506,6 +546,7 @@ http://le-spektre.org',
         'GenresModify' => 'Редактировать конвертацию',
 
         'PropertiesName' => 'Имя коллекции',
+        'PropertiesLang' => 'Language code',
         'PropertiesOwner' => 'Владелец',
         'PropertiesEmail' => 'E-mail',
         'PropertiesDescription' => 'Описание',
@@ -515,6 +556,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Размер',
         'PropertiesFileSizeSymbols' => ['Байт', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Свойства коллекции',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Программы для отправки почты',
         'MailProgramsName' => 'Имя',
@@ -538,6 +580,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Элементы удовлетворяющие по крайней мере одному критерию',
         'AdvancedSearchCriteria' => 'Критерий',
         'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Save search',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
 
         'BugReportSubject' => 'Bug report generated from GCstar',
         'BugReportVersion' => 'Version',
