@@ -106,6 +106,9 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
     		'MenuEditLockItems' => '_Zaključaj Kolekciju',
     
     	'MenuDisplay' => 'F_ilter',
+            'MenuSavedSearches' => 'Saved searches',
+                'MenuSavedSearchesSave' => 'Save current search',
+                'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'A_dvanced Search',
     		'MenuViewAllItems' => 'Prikaži _Sve Filmove',
             'MenuNoFilter' => '_Bilo Koji',
@@ -113,6 +116,7 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
     	'MenuConfiguration' => '_Podešavanja',
     		'MenuDisplayOptions' => '_Prikazane Informacije',
     		'MenuBorrowers' => '_Pozajmljivači',
+            'MenuToolbarConfiguration' => '_Toolbar controls',
             'MenuGenresConversion' => 'Prebacivanje _Žanra',
     
         'MenuBookmarks' => 'My _Collections',
@@ -129,6 +133,11 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
         
         'ContextExpandAll' => 'Expand all',
         'ContextCollapseAll' => 'Collapse all',
+        'ContextChooseImage' => 'Choose _Image',
+        'ContextOpenWith' => 'Open Wit_h',
+        'ContextImageEditor' => 'Image Editor', 
+        'ContextImgFront' => 'Front',
+        'ContextImgBack' => 'Back',
 
         'DialogEnterNumber' => 'Please enter value',
 
@@ -145,6 +154,8 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
         'PreferencesTooltip' => 'Podesite svoje parametre',
         'ViewTooltip' => 'Promenite prikaz kolekcije',
         'PlayTooltip' => 'Pustite film',
+        'PlayFileNotFound' => 'File to launch was not found in this location:',
+        'PlayRetry' => 'Retry',
 
         'StatusSave' => 'Saving...',
         'StatusLoad' => 'Loading...',
@@ -155,10 +166,14 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
         'SaveError' => 'Ne mogu da sačuvam listu filmova. Proverite prava pristupa i slobodan prostor na disku.',
         'OpenError' => 'Ne mogu da otvorim listu filmova. Proverite prava pristupa.',
 		'OpenFormatError' => 'Cannot open items list. Format may be incorrect.',
+        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
+        'OpenVersionQuestion' => 'Do you still want to continue?',
         'ImageError' => 'Odabrani direktorijum za čuvanje slika nije ispravan. Odaberite drugi.',
         'OptionsCreationError'=> 'Ne mogu da napravim fajl sa opcijama: ',
         'OptionsOpenError'=> 'Ne mogu da otvorim fajl sa opcijama: ',
         'OptionsSaveError'=> 'Ne mogu da sačuvam fajl sa opcijama:  ',
+        'ErrorModelNotFound' => 'Model not found: ',
+        'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Šta gledati večeras ?',
         'RandomError'=> 'Nemate neodgledanih filmova',
@@ -171,8 +186,10 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
         'AboutVersion' => 'Verzija',
         'AboutTeam' => 'Tim',
         'AboutWho' => 'Christian Jodar (Tian): Vođa projekta, Programer
+Nyall Dawson (Zombiepig): Programer
+TPF: Programer
 Adolfo González: Programer
-Nyall Dawson (Zombiepig): Programer',
+',
         'AboutLicense' => 'Distribuirano pod GNU GPL uslovima
 Logo Copyright le Spektre
 http://le-spektre.org',
@@ -181,6 +198,7 @@ http://le-spektre.org',
 
         'ToolbarRandom' => 'Večeras',
         
+        'UnsavedCollection' => 'Unsaved Collection',
         'ModelsSelect' => 'Select a collection type',
         'ModelsPersonal' => 'Personal models',
         'ModelsDefault' => 'Default models',
@@ -202,6 +220,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maximum:',
         'ModelFieldList' => 'Values list:',
         'ModelFieldListLegend' => '<i>Comma separated</i>',
+        'ModelFieldDisplayAs' => 'Display as:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Short text',
         'ModelFieldTypeLongText' => 'Long text',
         'ModelFieldTypeYesNo' => 'Yes/No',
@@ -236,6 +257,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Should be in search box',
         'ModelFilterComparison' => 'Comparison',
         'ModelFilterContain' => 'Contains',
+        'ModelFilterDoesNotContain' => 'Does not contain',
+        'ModelFilterRegexp' => 'Regular expression',
         'ModelFilterRange' => 'Range',
         'ModelFilterNumeric' => 'Comparison is numeric',
         'ModelFilterQuick' => 'Create a quick filter',
@@ -255,20 +278,25 @@ http://le-spektre.org',
         'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Podešavanja',
+		'OptionsExpertMode' => 'Expert Mode',
+        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
         'OptionsBrowser' => 'Web brauzer',
         'OptionsPlayer' => 'Video plejer',
         'OptionsAudio' => 'Audio player',
+        'OptionsImageEditor' => 'Image editor',
+        'OptionsCdDevice' => 'CD device',
         'OptionsImages' => 'Direktorijum sa slikama',
         'OptionsUseRelativePaths' => 'Koristi relativnu putanju do slika',
         'OptionsLayout' => 'Izgled',
         'OptionsStatus' => 'Pokaži statusnu liniju',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Upozorenje: Izmene sa ove kartice se neće videti dok se program ponovo ne pokrene.',
         'OptionsRemoveConfirm' => 'Traži potvrdu pre nego što obrišeš film',
         'OptionsAutoSave' => 'Automatski sačuvaj kolekciju',
         'OptionsAutoLoad' => 'Load previous collection on startup',
         'OptionsSplash' => 'Prikaži uvodni ekran (splash screen)',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Use spelling checker for long text fields',
-        'OptionsImagesTitle' => 'Odaberite direktorijum',
         'OptionsProgramTitle' => 'Odaberite koji program želite da koristite',
 		'OptionsPlugins' => 'Sajt sa kog želite da preuzmete podatke',
 		'OptionsAskPlugins' => 'Pitaj me (Svi sajtovi)',
@@ -301,6 +329,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Stavi članove posle naslova filma',
         'OptionsArticles' => 'Članovi (Odvojeni zarezom)',
         'OptionsSearchStop' => 'Dozvoli da pretraga bude prekinuta',
+        'OptionsBigPics' => 'Use big pictures when available',
         'OptionsAlwaysOriginal' => 'Koristi glavni naslov kao originalni ukoliko originalnog nema',
         'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Veličina istorije',
@@ -337,6 +366,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Selekcija',
         'ImagesOptionsBgTooltip' => 'Promeni boju pozadine',
         'ImagesOptionsFgTooltip'=> 'Promeni boju selekcije',
+        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
         'ImagesOptionsSizeLabel' => 'Veličina',
         'ImagesOptionsSizeList' => {0 => 'Vrlo mali', 1 => 'Mali', 2 => 'Srednji', 3 => 'Veliki', 4 => 'Vrlo veliki'},
         'ImagesOptionsSizeTooltip' => 'Odaberi veličinu slike',
@@ -364,11 +394,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Odaberi polja koja želiš da izvezeš',
         'ExportWithPictures' => 'Kopiraj slike u pod-direktorijum',
         'ExportSortBy' => 'Sort by',
+        'ExportOrder' => 'Order',
 
         'ImportListTitle' => 'Uvezi drugu listu filmova',
         'ImportExportData' => 'Data',
         'ImportExportFile' => 'Fajl',
-        'ImportExportSave' => 'Odaberi fajl koji ?eš da koristiš',
         'ImportExportFieldsUnused' => 'Neiskorišćena polja',
         'ImportExportFieldsUsed' => 'Iskorišćena polja',
         'ImportExportFieldsFill' => 'Dodaj sva',
@@ -382,7 +412,10 @@ http://le-spektre.org',
         'ImportDropError' => 'Došlo je do greške pri otvaranju najmanje jednog fajla. Učitaće se prethodna lista.',
         'ImportGenerateId' => 'Generate identifier for each item',
 
-        'FileOverwrite' => 'Ovaj fajl već postoji. Da li želite da ga zamenite novim fajlom?',
+        'FileChooserOpenFile' => 'Odaberi fajl koji ?eš da koristiš',
+        'FileChooserDirectory' => 'Directory',
+        'FileChooserOpenDirectory' => 'Odaberite direktorijum',
+        'FileChooserOverwrite' => 'Ovaj fajl već postoji. Da li želite da ga zamenite novim fajlom?',
 
         'PanelCompact' => 'Sažeti',
         'PanelReadOnly' => 'Samo Za čitanje',
@@ -425,6 +458,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favourite',
         'TagsAssigned' => 'Assigned Tags', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Ili',
         'CheckYes' => 'Da',
         'CheckNo' => 'Ne',
@@ -433,6 +468,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Vidi sve filmove',
         'ToolbarGroupBy' => 'Group by',
         'ToolbarGroupByTooltip' => 'Select the field to use to group items in list',
+        'ToolbarQuickSearch' => 'Quick search',
+        'ToolbarQuickSearchLabel' => 'Search',
+        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
+        'ToolbarSeparator' => ' Separator',
         
         'PluginsTitle' => 'Traži po filmovima',
         'PluginsQuery' => 'Query',
@@ -463,6 +502,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Pozajmljeni filmovi',
         'BorrowedDate' => 'Od',
+        'BorrowedDisplayInPanel' => 'Show item in main window',
 
         'MailTitle' => 'Pošalji mu e-mail',
         'MailFrom' => 'Od: ',
@@ -503,6 +543,7 @@ http://le-spektre.org',
         'GenresModify' => 'Izmeni menjanje žanrova',
 
         'PropertiesName' => 'Collection name',
+        'PropertiesLang' => 'Language code',
         'PropertiesOwner' => 'Owner',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Description',
@@ -512,6 +553,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Size',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Collection properties',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
@@ -535,6 +577,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
         'AdvancedSearchCriteria' => 'Criteria',
         'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Save search',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
 
         'BugReportSubject' => 'Bug report generated from GCstar',
         'BugReportVersion' => 'Version',
