@@ -106,6 +106,9 @@ För att avgöra vilken hemsida som äger informationen, så kan du använda <b>
             'MenuEditLockItems' => '_Lås Samling',
     
         'MenuDisplay' => 'F_ilter',
+            'MenuSavedSearches' => 'Sparade sökningar',
+                'MenuSavedSearchesSave' => 'Spara aktuell sökning',
+                'MenuSavedSearchesEdit' => 'Modifiera sparade sökningar',
             'MenuAdvancedSearch' => 'A_vancerad Sök',
             'MenuViewAllItems' => 'Visa _Alla artiklar',
             'MenuNoFilter' => '_Någon',
@@ -113,6 +116,7 @@ För att avgöra vilken hemsida som äger informationen, så kan du använda <b>
         'MenuConfiguration' => '_Inställningar',
             'MenuDisplayOptions' => '_Visad Information',
             'MenuBorrowers' => '_Låntagare',
+            'MenuToolbarConfiguration' => '_Verktygsfältets kontroller',
             'MenuGenresConversion' => 'Genre _Konvertering',
         
         'MenuBookmarks' => 'Mina _Samlingar',
@@ -129,6 +133,11 @@ För att avgöra vilken hemsida som äger informationen, så kan du använda <b>
         
         'ContextExpandAll' => 'Expandera alla',
         'ContextCollapseAll' => 'Komprimera alla',
+        'ContextChooseImage' => 'Välj _Bild',
+        'ContextImageEditor' => 'Öppna med Bildredigerare',
+        'ContextOpenWith' => 'Öppna me_d',
+        'ContextImgFront' => 'Framsida',
+        'ContextImgBack' => 'Baksida',
         
         'DialogEnterNumber' => 'Var god ange ett värde',
 
@@ -145,6 +154,8 @@ För att avgöra vilken hemsida som äger informationen, så kan du använda <b>
         'PreferencesTooltip' => 'Ställ in dina inställningar',
         'ViewTooltip' => 'Ändra samlingsvisning',
         'PlayTooltip' => 'Spela video associerad med artikel',
+        'PlayFileNotFound' => 'Filen att spela hittades ej på denna platsen:',
+        'PlayRetry' => 'Försök igen',
 
         'StatusSave' => 'Sparar...',
         'StatusLoad' => 'Laddar...',
@@ -155,10 +166,14 @@ För att avgöra vilken hemsida som äger informationen, så kan du använda <b>
         'SaveError' => 'Artikellistan kunde inte sparas. Var god kontrollera rättigheter och ledigt diskutrymme.',
         'OpenError' => 'Artikellistan kunde inte öppnas. Var god kontrollera rättigheter.',
 		'OpenFormatError' => 'Artikellistan kunde inte öppnas. Formatet kan vara felaktigt.',
+        'OpenVersionWarning' => 'Samlingen är skapad med en nyare version av GCstar. Om du sparar den, kan dataförlust ske.',
+        'OpenVersionQuestion' => 'Vill du fortfarande fortsätta?',
         'ImageError' => 'Vald katalog att spara bilder till är felaktig. Var god välj en annan.',
         'OptionsCreationError'=> 'Kan inte skapa inställningsfil: ',
         'OptionsOpenError'=> 'Kan inte öppna inställningsfil: ',
         'OptionsSaveError'=> 'Kan inte spara inställningsfil: ',
+        'ErrorModelNotFound' => 'Modell ej funnen: ',
+        'ErrorModelUserDir' => 'Användardefinierade modeller finns i: ',
         
         'RandomTooltip' => 'Vad ska vi se ikväll ?',
         'RandomError'=> 'Du har inga artiklar som kan bli valda',
@@ -171,8 +186,10 @@ För att avgöra vilken hemsida som äger informationen, så kan du använda <b>
         'AboutVersion' => 'Version',
         'AboutTeam' => 'Team',
         'AboutWho' => 'Christian Jodar (Tian): Projektföreståndare, Programmerare
+Nyall Dawson (Zombiepig): Programmerare
+TPF: Programmerare
 Adolfo González: Programmerare
-Nyall Dawson (Zombiepig): Programmerare',
+',
         'AboutLicense' => 'Distribuerad under GNU GPL Licensen, Logotyper Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Svensk översättning av anonym medarbetare',
@@ -180,6 +197,7 @@ http://le-spektre.org',
 
         'ToolbarRandom' => 'Ikväll',
 
+        'UnsavedCollection' => 'Osparad samling',
         'ModelsSelect' => 'Välj en samlingstyp',
         'ModelsPersonal' => 'Personliga samlingar',
         'ModelsDefault' => 'Förvalda samlingar',
@@ -187,9 +205,9 @@ http://le-spektre.org',
         'ModelSettings' => 'Samlingsinställningar',
         'ModelNewType' => 'Ny samlingstyp',
         'ModelName' => 'Namn på samlingstyp:',
-		'ModelFields' => 'Fält',
-		'ModelOptions'	=> 'Inställningar',
-		'ModelFilters'	=> 'Filter',
+        'ModelFields' => 'Fält',
+        'ModelOptions'	=> 'Inställningar',
+        'ModelFilters'	=> 'Filter',
         'ModelNewField' => 'Nytt fält',
         'ModelFieldInformation' => 'Information',
         'ModelFieldName' => 'Beteckning:',
@@ -201,6 +219,9 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maximum:',
         'ModelFieldList' => 'Värdelista:',
         'ModelFieldListLegend' => '<i>Separerat med komma</i>',
+        'ModelFieldDisplayAs' => 'Visa som: ',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Värdering',
         'ModelFieldTypeShortText' => 'Kort text',
         'ModelFieldTypeLongText' => 'Lång text',
         'ModelFieldTypeYesNo' => 'Ja/Nej',
@@ -235,6 +256,8 @@ http://le-spektre.org',
         'ModelFilterActivated' => 'Bör vara i sökrutan',
         'ModelFilterComparison' => 'Jämförelser',
         'ModelFilterContain' => 'Innehåller',
+        'ModelFilterDoesNotContain' => 'Innehåller ej',
+        'ModelFilterRegexp' => 'Reguljära uttryck',
         'ModelFilterRange' => 'Räckvidd',
         'ModelFilterNumeric' => 'Jämförelsen är numerisk',
         'ModelFilterQuick' => 'Skapa ett snabbt filter',
@@ -254,29 +277,34 @@ http://le-spektre.org',
         'ResultsInfo' => 'Du kan lägga till flera produkter till en samling genom att hålla ner Ctrl- eller Skift-tangenten för att markera dem',
         
         'OptionsTitle' => 'Inställningar',
+		'OptionsExpertMode' => 'Expert Läge',
+        'OptionsPrograms' => 'Specifiera program att använda med övrig media, lämna tomt för att använda systemets inställningar.',
         'OptionsBrowser' => 'Webbläsare',
         'OptionsPlayer' => 'Videospelare',
         'OptionsAudio' => 'Ljudspelare',
+        'OptionsImageEditor' => 'Bildredigerare',
+        'OptionsCdDevice' => 'CD enhet',
         'OptionsImages' => 'Bildkatalog',
         'OptionsUseRelativePaths' => 'Använd relativa sökvägar för bilder',
         'OptionsLayout' => 'Layout',
         'OptionsStatus' => 'Visa statusfält',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Varning: Ändringar i denna flik kommer ej ta effekt förrän applikationen startas om.',
         'OptionsRemoveConfirm' => 'Fråga efter godkännande innan artikel tas bort',
         'OptionsAutoSave' => 'Spara samling automatiskt',
         'OptionsAutoLoad' => 'Ladda senast valda samling vid uppstart',
         'OptionsSplash' => 'Visa splash screen',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Använd stavningskontroll för långa textfält',
-        'OptionsImagesTitle' => 'Välj en katalog',
         'OptionsProgramTitle' => 'Välj program att använda',
-		'OptionsPlugins' => 'Hemsida att hämta data från',
-		'OptionsAskPlugins' => 'Fråga (Alla hemsidor)',
-		'OptionsPluginsMulti' => 'Många hemsidor',
-		'OptionsPluginsMultiAsk' => 'Fråga (Många hemsidor)',
-		'OptionsPluginsList' => 'Ställ in lista',
+        'OptionsPlugins' => 'Hemsida att hämta data från',
+        'OptionsAskPlugins' => 'Fråga (Alla hemsidor)',
+        'OptionsPluginsMulti' => 'Många hemsidor',
+        'OptionsPluginsMultiAsk' => 'Fråga (Många hemsidor)',
+        'OptionsPluginsList' => 'Ställ in lista',
         'OptionsAskImport' => 'Välj fält som ska importeras',
-		'OptionsProxy' => 'Använd en proxy',
-		'OptionsCookieJar' => 'Använd denna kak-jarfil',
+        'OptionsProxy' => 'Använd en proxy',
+        'OptionsCookieJar' => 'Använd denna kak-jarfil',
         'OptionsLang' => 'Språk',
         'OptionsMain' => 'Huvud',
         'OptionsPaths' => 'Sökväg',
@@ -300,6 +328,7 @@ http://le-spektre.org',
         'OptionsTransform' => 'Placera artiklar i slutet av titlarna',
         'OptionsArticles' => 'Artiklar (Separerat med komma)',
         'OptionsSearchStop' => 'Tillåt att pågående sökning avbryts',
+        'OptionsBigPics' => 'Använd stora bilder om möjligt',
         'OptionsAlwaysOriginal' => 'Använd huvudtitels som förvald titel om ingen finns',
         'OptionsRestoreAccelerators' => 'Återställ acceleratorer',
         'OptionsHistory' => 'Storlek av histori',
@@ -337,6 +366,7 @@ http://le-spektre.org',
         'ImagesOptionsFg'=> 'Markering',
         'ImagesOptionsBgTooltip' => 'Ändra bakgrundsfärg',
         'ImagesOptionsFgTooltip'=> 'Ändra markeringsfärg',
+        'ImagesOptionsResizeImgList' => 'Ändra automatiskt antalet kolumner',
         'ImagesOptionsSizeLabel' => 'Storlek',
         'ImagesOptionsSizeList' => {0 => 'Väldigt liten', 1 => 'Liten', 2 => 'Mellan', 3 => 'Stor', 4 => 'Extra Stor'},
         'ImagesOptionsSizeTooltip' => 'Välj en bildstorlek',
@@ -364,11 +394,11 @@ http://le-spektre.org',
         'ExportFieldsTip' => 'Välj fält som du vill exportera',
         'ExportWithPictures' => 'Kopiera bilder i en underkatalog',
         'ExportSortBy' => 'Sortera på',
+        'ExportOrder' => 'Ordning',
 
         'ImportListTitle' => 'Importa en annan artikellista',
         'ImportExportData' => 'Data',
         'ImportExportFile' => 'Fil',
-        'ImportExportSave' => 'Var god välj en fil att använda',
         'ImportExportFieldsUnused' => 'Osparade fält',
         'ImportExportFieldsUsed' => 'Använda fält',
         'ImportExportFieldsFill' => 'Lägg till Alla',
@@ -382,7 +412,10 @@ http://le-spektre.org',
         'ImportDropError' => 'Det uppstod ett fel med att öppna åtminstone en fil. Föregående lista kommer laddas om.',
         'ImportGenerateId' => 'Generera identifierare för varje artikel',
 
-        'FileOverwrite' => 'Den här filen existerar redan. Vill du skriva över den?',
+        'FileChooserOpenFile' => 'Var god välj en fil att använda',
+        'FileChooserDirectory' => 'Mapp',
+        'FileChooserOpenDirectory' => 'Välj en katalog',
+        'FileChooserOverwrite' => 'Den här filen existerar redan. Vill du skriva över den?',
 
         #Some default panels
         'PanelCompact' => 'Kompakt',
@@ -426,6 +459,8 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favorit',
         'TagsAssigned' => 'Tilldelad etikett', 
 
+        'PanelUser' => 'Användarfält',
+
         'CheckUndef' => 'Både',
         'CheckYes' => 'Ja',
         'CheckNo' => 'Nej',
@@ -434,6 +469,10 @@ http://le-spektre.org',
         'ToolbarAllTooltip' => 'Visa alla artiklar',
         'ToolbarGroupBy' => 'Gruppera på',
         'ToolbarGroupByTooltip' => 'Välj det fält att använda för att gruppera artiklar i listan',
+        'ToolbarQuickSearch' => 'Snabbsök',
+        'ToolbarQuickSearchLabel' => 'Sök',
+        'ToolbarQuickSearchTooltip' => 'Markera fältet att söka i. Ange sökord och tryck Enter',
+        'ToolbarSeparator' => ' Avskiljare',
         
         'PluginsTitle' => 'Sök en artikel',
         'PluginsQuery' => 'Förfrågan',
@@ -464,6 +503,7 @@ http://le-spektre.org',
 
         'BorrowedTitle' => 'Lånade artiklar',
         'BorrowedDate' => 'Sedan',
+        'BorrowedDisplayInPanel' => 'Visa artikel i huvudfönstret',
 
         'MailTitle' => 'Skicka e-post',
         'MailFrom' => 'Från: ',
@@ -504,6 +544,7 @@ http://le-spektre.org',
         'GenresModify' => 'Redigera konvertering',
 
         'PropertiesName' => 'Namn på samling',
+        'PropertiesLang' => 'Språkkod',
         'PropertiesOwner' => 'Ägare',
         'PropertiesEmail' => 'E-post',
         'PropertiesDescription' => 'Beskrivning',
@@ -513,6 +554,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Storlek',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Egenskap för samling',
+        'PropertiesDefaultPicture' => 'Förinställd bild',
 
         'MailProgramsTitle' => 'Program för att skicka e-post',
         'MailProgramsName' => 'Namn',
@@ -536,6 +578,11 @@ http://le-spektre.org',
         'AdvancedSearchTypeOr' => 'Artiklarna matchade åtminstone ett kriterium',
         'AdvancedSearchCriteria' => 'Kriterium',
         'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Spara sökning',
+        'AdvancedSearchSaveName' => 'Namn',
+        'AdvancedSearchSaveOverwrite' => 'En sparad sökning existerar redan med detta namn. Var god använd ett annat.',
+        'AdvancedSearchUseCase' => 'Skiftlägeskänslighet',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignorera brytning och diakritiska tecken',
  
         'BugReportSubject' => 'Felrapport genererad från GCstar',
         'BugReportVersion' => 'Version',
