@@ -113,6 +113,9 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
             'MenuEditLockItems' => '_Veritabanını kilitle',
     
         'MenuDisplay' => '_Filtrele',
+            'MenuSavedSearches' => 'Saved searches',
+                'MenuSavedSearchesSave' => 'Save current search',
+                'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'A_dvanced Search',
             'MenuViewAllItems' => 'Tümünü Göste',
             'MenuNoFilter' => '_Hepsi',
@@ -120,6 +123,7 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
         'MenuConfiguration' => '_Ayarlar',
             'MenuDisplayOptions' => '_Bilgi Alanları',
             'MenuBorrowers' => '_Ödünç Alanlar',
+            'MenuToolbarConfiguration' => '_Toolbar controls',
             'MenuGenresConversion' => '_Tür Çevrimi',
         
         'MenuBookmarks' => 'My _Collections',
@@ -136,6 +140,11 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
         
         'ContextExpandAll' => 'Hepsini Aç',
         'ContextCollapseAll' => 'Hepsini Kapa',
+        'ContextChooseImage' => 'Choose _Image',
+        'ContextOpenWith' => 'Open Wit_h',
+        'ContextImageEditor' => 'Image Editor',
+        'ContextImgFront' => 'Front',
+        'ContextImgBack' => 'Back',
         
         'DialogEnterNumber' => 'Lütfen bir değer giriniz',
 
@@ -152,6 +161,8 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
         'PreferencesTooltip' => 'Ayarları yapmak için tıklayınız',
         'ViewTooltip' => 'Koleksiyonun görsel ayarlarını değiştirir',
         'PlayTooltip' => 'Dosyayı lişkilendirilmiş oynatıcı ile başlatır',
+        'PlayFileNotFound' => 'File to launch was not found in this location:',
+        'PlayRetry' => 'Retry',
 
         'StatusSave' => 'Saving...',
         'StatusLoad' => 'Loading...',
@@ -162,10 +173,14 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
         'SaveError' => 'GCStar Koleksiyonu kaydedilemiyor. Erişim engelleri ve boş alan kontrolü yapınız.',
         'OpenError' => 'GCStar Koleksiyonu açamıyor. Dosyanın erişim izinlerini kontrol ediniz.',
 		'OpenFormatError' => 'Koleksiyonu açamıyor.',
+        'OpenVersionWarning' => 'Collection was created with a more recent version of GCstar. If you save it, you may loose some data.',
+        'OpenVersionQuestion' => 'Do you still want to continue?',
         'ImageError' => 'Kapak dosyaları için seçtiğiniz klasör yanlış. Lütfen başka bir klasör seçiniz.',
         'OptionsCreationError'=> 'Ayar dosyası oluşturulamıyor: ',
         'OptionsOpenError'=> 'Ayar dosyası açılamıyor: ',
         'OptionsSaveError'=> 'Ayar dosyası kaydedilemiyor: ',
+        'ErrorModelNotFound' => 'Model not found: ',
+        'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Bana öneride bulun. Rastgele dosya seçer.',
         'RandomError'=> 'Tüm başlıkları izlemişsiniz ya da veritanında başlık yok.',
@@ -178,8 +193,10 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
         'AboutVersion' => 'Sürüm',
         'AboutTeam' => 'Takım',
         'AboutWho' => 'Christian Jodar (Tian): Proje Yöneticisi, Programcı
+Nyall Dawson (Zombiepig): Programcı
+TPF: Programcı
 Adolfo González: Programcı
-Nyall Dawson (Zombiepig): Programcı',
+',
         'AboutLicense' => 'GNU GPL lisansı altında dağıtılmaktadır
 Logoların telif hakları le Spektre
 http://le-spektre.org\'a aittir.',
@@ -188,6 +205,7 @@ http://le-spektre.org\'a aittir.',
 
         'ToolbarRandom' => 'Gece',
 
+        'UnsavedCollection' => 'Unsaved Collection',
         'ModelsSelect' => 'Bir koleksiyon türü seçiniz',
         'ModelsPersonal' => 'Personal models',
         'ModelsDefault' => 'Default models',
@@ -209,6 +227,9 @@ http://le-spektre.org\'a aittir.',
         'ModelFieldMax' => 'Maximum:',
         'ModelFieldList' => 'Values list:',
         'ModelFieldListLegend' => '<i>Comma separated</i>',
+        'ModelFieldDisplayAs' => 'Display as:',
+        'ModelFieldDisplayAsText' => 'Text',
+        'ModelFieldDisplayAsGraphical' => 'Rating Control',
         'ModelFieldTypeShortText' => 'Short text',
         'ModelFieldTypeLongText' => 'Long text',
         'ModelFieldTypeYesNo' => 'Yes/No',
@@ -243,6 +264,8 @@ http://le-spektre.org\'a aittir.',
         'ModelFilterActivated' => 'Should be in search box',
         'ModelFilterComparison' => 'Comparison',
         'ModelFilterContain' => 'Contains',
+        'ModelFilterDoesNotContain' => 'Does not contain',
+        'ModelFilterRegexp' => 'Regular expression',
         'ModelFilterRange' => 'Range',
         'ModelFilterNumeric' => 'Comparison is numeric',
         'ModelFilterQuick' => 'Create a quick filter',
@@ -262,20 +285,25 @@ http://le-spektre.org\'a aittir.',
         'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
         
         'OptionsTitle' => 'Ayarlar',
+		'OptionsExpertMode' => 'Expert Mode',
+        'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
         'OptionsBrowser' => 'Web tarayıcı',
         'OptionsPlayer' => 'Video oynatıcı',
         'OptionsAudio' => 'Audio oynatıcı',
+        'OptionsImageEditor' => 'Image editor',
+        'OptionsCdDevice' => 'CD device',
         'OptionsImages' => 'Kapak klasörü',
         'OptionsUseRelativePaths' => 'Kapak resimleri için değişken dizin yapısı kullan',
         'OptionsLayout' => 'Başlık Bilgileri Paneli',
         'OptionsStatus' => 'Durum barını göster',
+        'OptionsUseStars' => 'Use stars to display ratings',
         'OptionsWarning' => 'Dikkat: Bu alandaki değişikleri uygulamak için yazılımı tekrar başlatmalısınız.',
         'OptionsRemoveConfirm' => 'Başlık silmeden önce onay iste',
         'OptionsAutoSave' => 'Veritabanını otomatik olarak kaydet',
         'OptionsAutoLoad' => 'Load previous collection on startup',
         'OptionsSplash' => 'Başlangıç ekranını göster',
+        'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Use spelling checker for long text fields',
-        'OptionsImagesTitle' => 'Bir Klasör Seçiniz',
         'OptionsProgramTitle' => 'Bir Program Seçiniz',
 		'OptionsPlugins' => 'Bilginin alınacağı siteyi seçiniz',
 		'OptionsAskPlugins' => 'Sor (Tüm Siteler)',
@@ -308,6 +336,7 @@ http://le-spektre.org\'a aittir.',
         'OptionsTransform' => 'Aşağıdaki öbekleri film adının sonuna koy',
         'OptionsArticles' => 'Öbekler (virgülle ayrılmış)',
         'OptionsSearchStop' => 'Aramanın durdurulmasını sağlar',
+        'OptionsBigPics' => 'Use big pictures when available',
         'OptionsAlwaysOriginal' => 'Başlık için özgün ad yoksa kendi adını kullan',
         'OptionsRestoreAccelerators' => 'Restore accelerators',
         'OptionsHistory' => 'Geçmiş dosya kısıtlaması',
@@ -344,6 +373,7 @@ http://le-spektre.org\'a aittir.',
         'ImagesOptionsFg'=> 'Seçim',
         'ImagesOptionsBgTooltip' => 'Arkaplanı değiştir',
         'ImagesOptionsFgTooltip'=> 'Seçili alan rengini değiştir',
+        'ImagesOptionsResizeImgList' => 'Automatically change number of columns',
         'ImagesOptionsSizeLabel' => 'Boyut',
         'ImagesOptionsSizeList' => {0 => 'Minik', 1 => 'Küçük', 2 => 'Orta', 3 => 'Büyük', 4 => 'Devasa'},
         'ImagesOptionsSizeTooltip' => 'Resim boyutu seçiniz',
@@ -371,11 +401,11 @@ http://le-spektre.org\'a aittir.',
         'ExportFieldsTip' => 'Aktarılacak alanları seçiniz',
         'ExportWithPictures' => 'Kapak resimlerini bir alt klasöre kopyala',
         'ExportSortBy' => 'Sort by',
+        'ExportOrder' => 'Order',
 
         'ImportListTitle' => 'Diğer bir film listesinden aktar',
         'ImportExportData' => 'Data',
         'ImportExportFile' => 'Dosya',
-        'ImportExportSave' => 'Lütfen bir dosya seçiniz',
         'ImportExportFieldsUnused' => 'Kullanılmayacak alanlar',
         'ImportExportFieldsUsed' => 'Kullanılacak alanlar',
         'ImportExportFieldsFill' => 'Tümüün Ekle',
@@ -389,7 +419,10 @@ http://le-spektre.org\'a aittir.',
         'ImportDropError' => 'Dosyanın açılmasında sorun çıktı. Bir önceki veritabanı yüklenecek.',
         'ImportGenerateId' => 'Generate identifier for each item',
 
-        'FileOverwrite' => 'Bu dosya zaten var. Üzerine yazmak istediğinizden emin misiniz?',
+        'FileChooserOpenFile' => 'Lütfen bir dosya seçiniz',
+        'FileChooserDirectory' => 'Directory',
+        'FileChooserOpenDirectory' => 'Bir Klasör Seçiniz',
+        'FileChooserOverwrite' => 'Bu dosya zaten var. Üzerine yazmak istediğinizden emin misiniz?',
 
         #Some default panels
         'PanelCompact' => 'İşlevsel',
@@ -433,6 +466,8 @@ http://le-spektre.org\'a aittir.',
         'PanelFavourite' => 'Favourite',
         'TagsAssigned' => 'Assigned Tags', 
 
+        'PanelUser' => 'User fields',
+
         'CheckUndef' => 'Farketmez',
         'CheckYes' => 'Evet',
         'CheckNo' => 'Hayır',
@@ -441,6 +476,10 @@ http://le-spektre.org\'a aittir.',
         'ToolbarAllTooltip' => 'Tüm filmleri görmek için tıklayınız',
         'ToolbarGroupBy' => 'Grupla',
         'ToolbarGroupByTooltip' => 'Select the field to use to group items in list',
+        'ToolbarQuickSearch' => 'Quick search',
+        'ToolbarQuickSearchLabel' => 'Search',
+        'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
+        'ToolbarSeparator' => ' Separator',
         
         'PluginsTitle' => 'Film arayınız',
         'PluginsQuery' => 'Query',
@@ -471,6 +510,7 @@ http://le-spektre.org\'a aittir.',
 
         'BorrowedTitle' => 'Ödünç verilmiş filmler',
         'BorrowedDate' => 'Alma Tarihi',
+        'BorrowedDisplayInPanel' => 'Show item in main window',
 
         'MailTitle' => 'E-posta gönder',
         'MailFrom' => 'Kimden: ',
@@ -511,6 +551,7 @@ http://le-spektre.org\'a aittir.',
         'GenresModify' => 'Tür Düzenle',
 
         'PropertiesName' => 'Collection name',
+        'PropertiesLang' => 'Language code',
         'PropertiesOwner' => 'Owner',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Description',
@@ -520,6 +561,7 @@ http://le-spektre.org\'a aittir.',
         'PropertiesFileSize' => 'Size',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Collection properties',
+        'PropertiesDefaultPicture' => 'Default picture',
 
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
@@ -543,6 +585,11 @@ http://le-spektre.org\'a aittir.',
         'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
         'AdvancedSearchCriteria' => 'Criteria',
         'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Save search',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
 
         'BugReportSubject' => 'Bug report generated from GCstar',
         'BugReportVersion' => 'Version',
