@@ -71,7 +71,7 @@ use strict;
         foreach ($self->{menuBookmarks}->get_children)
         {
             $i++;
-            next if $i < 5;
+            next if ($i < 4 + ($self->{parent}->{options}->tearoffMenus ? 1 : 0));
             $self->{menuBookmarks}->remove($_);
             $_->destroy;
         }
@@ -123,14 +123,13 @@ use strict;
         $self->createFilters($model,
                              $model->{fieldsInfo});
         $self->initExportList($model);
-        $self->{editFieldsItem}->set_sensitive($model->isPersonal);
     }
 
     sub initFilters
     {
         my ($self, $info) = @_;
 
-        $self->selectAll;
+        $self->selectAll(1);
         $self->block;
         my $fieldsInfo = $self->{fieldsInfo};
         foreach (keys %$info)
@@ -227,14 +226,16 @@ use strict;
         foreach (@{$self->{existingFilters}})
         {
             $self->{menuDisplay}->remove($_);
+            $_->destroy;
         }
-        
+
         $self->{existingFilters} = [];
         $self->{existingFiltersMenu} = [];
         $self->{dynamicFilters} = {};
         $self->{fieldsInfo} = $fieldsInfo;
         $self->{filtersInfo} = {};
-        my $position = 1;
+        my $position = ($self->{parent}->{options}->tearoffMenus ? 1 : 0);
+        $self->createUserFilters($model, $position + 1);
         foreach my $filter(@{$model->{filters}})
         {
             next if (!defined $filter->{quick}) || ($filter->{quick} ne 'true');
@@ -367,7 +368,75 @@ use strict;
             $position++;
         }
     }
-    
+
+    sub createUserFilters
+    {
+        my ($self, $model, $position) = @_;
+        if (!defined $position)
+        {
+            # Here we need to find the correct position
+            $position = 0;
+            foreach ($self->{menuDisplay}->get_children)
+            {
+                $position++;
+                last if $_->isa('Gtk2::SeparatorMenuItem');
+            }
+        }
+        if ($self->{userFiltersMenu})
+        {
+            foreach ($self->{userFiltersMenu}->get_children)
+            {
+                $self->{userFiltersMenu}->remove($_);
+                $_->destroy;
+            }
+            $self->{menuDisplay}->remove($self->{userFiltersItem});
+            $self->{userFiltersMenu}->destroy;
+            $self->{userFiltersItem}->destroy;
+            $self->{userFiltersMenu} = 0;
+        }
+        return if !$model->getName;
+        my @userFilters = @{$model->getUserFilters};
+        $self->{userFiltersMenu} = new Gtk2::Menu;
+        # Setting the accel group to be able to use also shortcuts on user filters
+        $self->{userFiltersMenu}->set_accel_group($self->{accel});
+        $self->{userFiltersItem} = Gtk2::MenuItem->new_with_mnemonic($self->{parent}->{lang}->{MenuSavedSearches});
+        $self->{userFiltersItem}->set_accel_path('<main>/Display/SavedSearches');
+        $self->{userFiltersItem}->set_submenu($self->{userFiltersMenu});
+        $self->{menuDisplay}->insert($self->{userFiltersItem}, $position);
+        if (@userFilters)
+        {
+            foreach my $userFilter(@userFilters)
+            {
+                my $filter = Gtk2::MenuItem->new($userFilter->{name});
+                $filter->set_accel_path('<main>/Display/SavedSearches/'.$userFilter->{name});
+                $filter->signal_connect('activate' => sub {
+                    my ($widget, $filter) = @_;
+                    $self->selectAll(1);
+                    $self->{parent}->setSearchWithTypes(info => $filter->{info},
+                                                        mode => $filter->{mode},
+                                                        regexp => $filter->{regexp},
+                                                        case => $filter->{case},
+                                                        ignoreDiacritics => $filter->{ignoreDiacritics});
+                }, $userFilter);
+                $self->{userFiltersMenu}->append($filter);
+            }
+        }
+        $self->{userFiltersMenu}->append(Gtk2::SeparatorMenuItem->new);
+        my $newUserFilter = Gtk2::MenuItem->new($self->{parent}->{lang}->{MenuSavedSearchesSave});
+        $newUserFilter->signal_connect('activate' => sub {
+            $self->{parent}->saveCurrentSearch;
+        });
+        $self->{userFiltersMenu}->append($newUserFilter);
+        my $editUserFilter = Gtk2::MenuItem->new($self->{parent}->{lang}->{MenuSavedSearchesEdit});
+        $editUserFilter->signal_connect('activate' => sub {
+            $self->{parent}->editSavedSearches;
+        });
+        $self->{userFiltersMenu}->append($editUserFilter);
+
+            $self->{userFiltersItem}->show_all;
+        $self->{menuDisplay}->show_all;
+    }
+
     sub refreshFilters
     {
         my $self = shift;
@@ -471,8 +540,11 @@ use strict;
         $self->{menuFile}->set_accel_path('<main>/File');
         $self->{menuFile}->set_accel_group($self->{accel});
 
-        my $fto = Gtk2::TearoffMenuItem->new();
-        $self->{menuFile}->append($fto);
+        if ($parent->{options}->tearoffMenus)
+        {
+            my $fto = Gtk2::TearoffMenuItem->new();
+            $self->{menuFile}->append($fto);
+        }
 
         my $newdb = Gtk2::ImageMenuItem->new_from_stock('gtk-new');
         $newdb->set_accel_path('<main>/File/gtk-new');
@@ -546,15 +618,22 @@ use strict;
         $importItem->set_accel_path('<main>/File/gtk-convert');
         $self->{menuImport} = Gtk2::Menu->new;
         $self->{menuImport}->set_accel_path('<main>/Import');
-        $self->{menuImport}->set_accel_group($self->{accel});       
+        $self->{menuImport}->set_accel_group($self->{accel});
+        my %importItems;
+        my $langName = $parent->{options}->lang;
         foreach my $importer(@GCImport::importersArray)
         {
-            $importer->setLangName($parent->{options}->lang);
-            my $item = Gtk2::MenuItem->new_with_mnemonic($importer->getName);
+            $importer->setLangName($langName);
+            my $name = $importer->getName;
+            my $item = Gtk2::MenuItem->new_with_mnemonic($name);
             $item->signal_connect ('activate' => sub {
-                    $self->{parent}->import($importer);
-                });
-            $self->{menuImport}->append($item);
+                $self->{parent}->import($importer);
+            });
+            $importItems{$name} = $item;
+        }
+        foreach my $importerName(sort keys %importItems)
+        {
+            $self->{menuImport}->append($importItems{$importerName});
         }        
         $importItem->set_submenu($self->{menuImport});
         $self->{menuFile}->append($importItem);        
@@ -566,14 +645,17 @@ use strict;
         $self->{exporters} = {};
         foreach my $exporter(@GCExport::exportersArray)
         {
-            $exporter->setLangName($parent->{options}->lang);
+            $exporter->setLangName($langName);
             my $item = Gtk2::MenuItem->new_with_mnemonic($exporter->getName);
             $item->signal_connect ('activate' => sub {
                     $self->{parent}->export($exporter);
                 });
-            $self->{menuExport}->append($item);
             $self->{exporters}->{$exporter->getName} = $item;
-        }        
+        }
+        foreach my $exportName(sort keys %{$self->{exporters}})
+        {
+            $self->{menuExport}->append($self->{exporters}->{$exportName});
+        }
         $exportItem->set_submenu($self->{menuExport});
         $self->{menuFile}->append($exportItem);        
 
@@ -598,8 +680,12 @@ use strict;
         $self->{menuEdit} = Gtk2::Menu->new;
         $self->{menuEdit}->set_accel_path('<main>/Edit');
         $self->{menuEdit}->set_accel_group($self->{accel});
-        my $eto = Gtk2::TearoffMenuItem->new();
-        $self->{menuEdit}->append($eto);
+
+        if ($parent->{options}->tearoffMenus)
+        {
+            my $eto = Gtk2::TearoffMenuItem->new();
+            $self->{menuEdit}->append($eto);
+        }
 
         my $duplicateItem = Gtk2::ImageMenuItem->new_from_stock('gtk-dnd');
         $duplicateItem->set_accel_path('<main>/Edit/gtk-dnd');
@@ -669,11 +755,15 @@ use strict;
         $self->{menuDisplay} = Gtk2::Menu->new;
         $self->{menuDisplay}->set_accel_path('<main>/Display');
         $self->{menuDisplay}->set_accel_group($self->{accel});
-        my $dto = Gtk2::TearoffMenuItem->new;
-        $self->{menuDisplay}->append($dto);
 
-        $self->{menuDisplay}->append(new Gtk2::SeparatorMenuItem);
+        if ($parent->{options}->tearoffMenus)
+        {
+            my $dto = Gtk2::TearoffMenuItem->new;
+            $self->{menuDisplay}->append($dto);
+        }
         ############################
+        
+        $self->{menuDisplay}->append(Gtk2::SeparatorMenuItem->new);
 
         my $search = Gtk2::ImageMenuItem->new_from_stock('gtk-find');
         $search->set_accel_path('<main>/Display/gtk-find');
@@ -721,8 +811,13 @@ use strict;
         $self->{menuConfig} = Gtk2::Menu->new;
         $self->{menuConfig}->set_accel_path('<main>/Config');
         $self->{menuConfig}->set_accel_group($self->{accel});
-        my $cto = Gtk2::TearoffMenuItem->new;
-        $self->{menuConfig}->append($cto);
+
+        if ($parent->{options}->tearoffMenus)
+        {
+            my $cto = Gtk2::TearoffMenuItem->new;
+            $self->{menuConfig}->append($cto);
+        }
+
         my $options = Gtk2::ImageMenuItem->new_from_stock('gtk-preferences');
         $options->set_accel_path('<main>/Config/gtk-preferences');
         $options->signal_connect('activate' , sub {
@@ -745,6 +840,13 @@ use strict;
         });
         $self->{menuConfig}->append($borrowers);
 
+        my $toolbarConfig = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuToolbarConfiguration});
+        $toolbarConfig->set_accel_path('<main>/Config/Toolbar');
+        $toolbarConfig->signal_connect ('activate' => sub {
+            $self->{parent}->toolbarOptions;
+        });
+        $self->{menuConfig}->append($toolbarConfig);
+
         my $configitem = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuConfiguration});
         $configitem->set_submenu($self->{menuConfig});
         $self->append($configitem);
@@ -755,9 +857,16 @@ use strict;
         $self->{menuBookmarks} = Gtk2::Menu->new;
         $self->{menuBookmarks}->set_accel_path('<main>/Bookmarks');
         $self->{menuBookmarks}->set_accel_group($self->{accel});
-        my $bto = Gtk2::TearoffMenuItem->new;
-        $self->{menuBookmarks}->append($bto);
-        $self->{addBookmark} = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuBookmarksAdd});
+
+        if ($parent->{options}->tearoffMenus)
+        {
+            my $bto = Gtk2::TearoffMenuItem->new;
+            $self->{menuBookmarks}->append($bto);
+        }
+
+        $self->{addBookmark} = Gtk2::ImageMenuItem->new_with_mnemonic($parent->{lang}->{MenuBookmarksAdd});
+        my $addBookmarkImage = Gtk2::Image->new_from_stock('gtk-add', 'menu');
+        $self->{addBookmark}->set_image($addBookmarkImage);
         $self->{addBookmark}->set_accel_path('<main>/Bookmarks/Add');
         $self->{addBookmark}->signal_connect('activate' , sub {
             $self->{parent}->addBookmark;
@@ -783,8 +892,13 @@ use strict;
         $self->{menuHelp} = Gtk2::Menu->new;
         $self->{menuHelp}->set_accel_path('<main>/Help');
         $self->{menuHelp}->set_accel_group($self->{accel});
-        my $hto = Gtk2::TearoffMenuItem->new;
-        $self->{menuHelp}->append($hto);
+
+        if ($parent->{options}->tearoffMenus)
+        {
+            my $hto = Gtk2::TearoffMenuItem->new;
+            $self->{menuHelp}->append($hto);
+        }
+
         my $help = Gtk2::ImageMenuItem->new_from_stock('gtk-help');
         $help->set_accel_path('<main>/Help/Content');
         $help->signal_connect('activate' , sub {
@@ -893,11 +1007,11 @@ use strict;
 
     sub selectAll
     {
-        my $self = shift;
+        my ($self, $noRefresh) = @_;
         
         $self->block;
-        $self->{parent}->removeSearch;
-        
+        $self->{parent}->removeSearch($noRefresh);
+
         foreach (@{$self->{existingFiltersMenu}})
         {
             $_->set_active(0);
@@ -927,6 +1041,15 @@ use strict;
     package GCToolBar;
     use base 'Gtk2::Toolbar';
 
+    our $CONFIGURATION_FILE = 'Toolbar';
+    our @DEFAULT_CONTROLS = (
+            'gtk-add', 'gtk-save', 'gtk-preferences',
+            'ToolbarSeparator',
+            'gtk-find', 'gtk-refresh', 'gtk-execute', 'gtk-media-play',
+            'ToolbarSeparator',
+            'ToolbarGroupBy'        
+    );
+
     sub new
     {
         my ($proto, $parent) = @_;
@@ -939,51 +1062,265 @@ use strict;
         $self->{lang} = $parent->{lang};
         
         $self->set_name('GCToolbar');
+        $self->set_show_arrow (1);
 
-        $self->{add} = $self->insert_stock("gtk-add" ,$self->{lang}->{NewItemTooltip}, undef, sub {$parent->newItem}, undef, -1);
-        $self->{save} = $self->insert_stock("gtk-save" ,$self->{lang}->{SaveListTooltip}, undef, sub {$parent->saveList}, undef, -1);
-        $self->insert_stock("gtk-preferences" ,$self->{lang}->{PreferencesTooltip}, undef, sub {$parent->options}, undef, -1);
-        $self->append_space;
-        $self->insert_stock("gtk-find" ,$self->{lang}->{SearchTooltip}, undef, sub {$parent->search('all')}, undef, -1);
-        $self->insert_stock("gtk-refresh" ,$self->{lang}->{ToolbarAllTooltip}, undef, sub {$parent->allItems}, undef, -1);
-        $self->{tonight} = $self->insert_stock("gtk-execute" ,$self->{lang}->{RandomTooltip}, undef, sub {$parent->randomItem}, undef, -1);
-        $self->{play} = $self->insert_stock("gtk-media-play" ,$self->{lang}->{PlayTooltip}, undef, sub {$parent->playItem}, undef, -1);
-        $self->append_space;
-
-        $self->{groupLabel} = new Gtk2::Label($self->{lang}->{ToolbarGroupBy});
-        $self->append_widget($self->{groupLabel}, undef, undef);
-        $self->{groupOption} = new GCFieldSelector(0, undef, 1);
-        $self->{groupOption}->set_focus_on_click(0);
-        $self->{groupOption}->signal_connect('changed' => sub {
-            return if $self->{blocked};
-            my $field = $self->{groupOption}->getValue;
-            return if $self->{currentGroupField} eq $field;
-            $self->{parent}->setGrouping($field);
-        });
-        $self->{groupBox} = new Gtk2::VBox(0,0);
-        $self->{groupBox}->set_border_width($GCUtils::halfMargin);
-        $self->{groupBox}->pack_start($self->{groupOption}, 1, 0, 0);
-        $parent->{tooltips}->set_tip($self->{groupOption}, $self->{lang}->{ToolbarGroupByTooltip}, '');
+        $self->{configFile} = $ENV{GCS_CONFIG_HOME}.'/'.$GCToolBar::CONFIGURATION_FILE;
         
-        $self->append_widget($self->{groupBox}, undef, undef);
+        $self->{stockIdToWidget} = {
+            'gtk-add' => {
+                           tooltip => $self->{lang}->{NewItemTooltip},
+                           callback => sub {$parent->newItem}
+            },
+            'gtk-save' => {
+                           tooltip => $self->{lang}->{SaveListTooltip},
+                           callback => sub {$parent->saveList}
+            },
+            'gtk-preferences' => {
+                           tooltip => $self->{lang}->{PreferencesTooltip},
+                           callback => sub {$parent->options}
+            },
+            'gtk-find' => {
+                           tooltip => $self->{lang}->{SearchTooltip},
+                           callback => sub {$parent->search('all')}
+            },
+            'gtk-refresh' => {
+                           tooltip => $self->{lang}->{ToolbarAllTooltip},
+                           callback => sub {$parent->allItems}
+            },
+            'gtk-execute' => {
+                           tooltip => $self->{lang}->{RandomTooltip},
+                           callback => sub {$parent->randomItem}
+            },
+            'gtk-media-play' => {
+                           tooltip => $self->{lang}->{PlayTooltip},
+                           callback => sub {$parent->playItem}
+            },
+            'gtk-new' => {
+                           tooltip => undef,
+                           callback => sub {$parent->newList}
+            },
+            'gtk-open' => {
+                           tooltip => undef,
+                           callback => sub {$parent->openList}
+            },
+            'gtk-properties' => {
+                           tooltip => undef,
+                           callback => sub {$parent->properties}
+            },
+            'gtk-quit' => {
+                           tooltip => undef,
+                           callback => sub {$parent->leave}
+            },
+            'gtk-dnd' => {
+                           tooltip => undef,
+                           callback => sub {$parent->duplicateItem}
+            },
+            'gtk-delete' => {
+                           tooltip => undef,
+                           callback => sub {$parent->deleteCurrentItem}
+            },
+            'gtk-find-and-replace' => {
+                           tooltip => undef,
+                           callback => sub {$parent->queryReplace}
+            },
+            'gtk-help' => {
+                           tooltip => undef,
+                           callback => sub {$parent->help}
+            },
+        };
+        
+        $self->loadControls;
+
         $self->{blocked} = 1;
         $self->setSaveActive(0);
         $self->{showFieldsSelection} = 1;
 
         return $self;
     }
-    
+
+    sub loadControls
+    {
+        my $self = shift;
+        my @controls;
+        if (! -f $self->{configFile})
+        {
+            @controls = @GCToolBar::DEFAULT_CONTROLS;
+        }
+        else
+        {
+            open CONFIG, $self->{configFile};
+            my @array;
+            foreach (<CONFIG>)
+            {
+                s/\s+$//;
+                push @controls, $_;
+            }
+            close CONFIG;
+        }
+        foreach (@controls)
+        {
+            if (/^gtk-/)
+            {
+                $self->{controls}->{$_} = Gtk2::ToolButton->new_from_stock($_);
+                $self->{controls}->{$_}->signal_connect('clicked' => $self->{stockIdToWidget}->{$_}->{callback});
+                $self->{parent}->{tooltips}->set_tip($self->{controls}->{$_}, $self->{stockIdToWidget}->{$_}->{tooltip}, '')
+                    if $self->{stockIdToWidget}->{$_}->{tooltip};
+                $self->insert($self->{controls}->{$_}, -1);
+
+            }
+            elsif ($_ eq 'ToolbarSeparator')
+            {
+                $self->insert(Gtk2::SeparatorToolItem->new, -1);
+            }
+            else
+            {
+                if ($_ eq 'ToolbarGroupBy')
+                {
+                    $self->{controls}->{groupLabel} = new Gtk2::Label($self->{lang}->{ToolbarGroupBy});
+                    $self->{controls}->{groupOption} = new GCFieldSelector(0, undef, 1);
+                    $self->{controls}->{groupOption}->set_focus_on_click(0);
+                    $self->{controls}->{groupOption}->signal_connect('changed' => sub {
+                        return if $self->{blocked};
+                        my $field = $self->{controls}->{groupOption}->getValue;
+                        return if $self->{currentGroupField} eq $field;
+                        $self->{parent}->setGrouping($field);
+                    });
+                    my $groupVBox = new Gtk2::VBox(0,0);
+                    $groupVBox->set_border_width($GCUtils::halfMargin);
+                    $groupVBox->pack_start($self->{controls}->{groupOption}, 1, 0, 0);
+                    $self->{parent}->{tooltips}->set_tip($self->{controls}->{groupOption}, $self->{lang}->{ToolbarGroupByTooltip}, '');
+                    my $groupBox = new Gtk2::HBox(0,0);
+                    $groupBox->pack_start($self->{controls}->{groupLabel}, 0, 0, 0);
+                    $groupBox->pack_start($groupVBox, 1, 1, $GCUtils::halfMargin);
+                    my $groupItem = new Gtk2::ToolItem;
+                    $groupItem->add($groupBox);
+                    $self->insert($groupItem, -1);
+                }
+                elsif ($_ eq 'OptionsView')
+                {                    
+                    my %views = %{$self->{lang}->{OptionsViews}};
+                    $self->{controls}->{viewOption} = new GCMenuList;
+                    my @viewsOptions = map {{value => $_, displayed => $views{$_}}}
+                                           (sort keys %views);
+                    $self->{controls}->{viewOption}->setValues(\@viewsOptions);
+                    $self->{controls}->{viewOption}->signal_connect('changed' => sub {
+                        return if $self->{blocked};
+                        $self->{parent}->{options}->view($self->{controls}->{viewOption}->getValue);
+                        $self->{parent}->setItemsList(0, 1);
+                    });
+                    my $listViewBox = new Gtk2::VBox(0,0);
+                    $listViewBox->set_border_width(0);
+                    $listViewBox->pack_start($self->{controls}->{viewOption}, 1, 0, 0);
+                    my $viewItem = new Gtk2::ToolItem;
+                    $viewItem->add($listViewBox);
+                    $self->insert($viewItem, -1);
+                }
+                elsif ($_ eq 'OptionsLayout')
+                {                    
+                    $self->{controls}->{layoutOption} = new GCMenuList;
+                    $self->{controls}->{layoutOption}->signal_connect('changed' => sub {
+                        return if $self->{blocked};
+                        $self->{model}->{preferences}->layout($self->{controls}->{layoutOption}->getValue);
+                        $self->{parent}->changePanel;
+                    });
+                    my $layoutBox = new Gtk2::VBox(0,0);
+                    $layoutBox->set_border_width(0);
+                    $layoutBox->pack_start($self->{controls}->{layoutOption}, 1, 0, 0);
+                    my $layoutItem = new Gtk2::ToolItem;
+                    $layoutItem->add($layoutBox);
+                    $self->insert($layoutItem, -1);
+                }
+                elsif ($_ eq 'ToolbarQuickSearch')
+                {
+                    my $quickBox = new Gtk2::HBox(0,0);
+                    $self->{controls}->{quickLabel} = new Gtk2::Label($self->{lang}->{ToolbarQuickSearchLabel});
+                    $quickBox->pack_start($self->{controls}->{quickLabel}, 0, 0, 0);
+
+                    $self->{controls}->{quickEntry} = new GCShortText;
+                    $self->{controls}->{quickEntry}->signal_connect('activate' => sub {
+                        $self->{parent}->setQuickSearch($self->{controls}->{quickFields}->getValue,
+                                                        $self->{controls}->{quickEntry}->getValue);
+                        $self->{controls}->{quickEntry}->grab_focus;
+                    });
+
+                    $self->{controls}->{quickFields} = new GCFieldSelector(0, undef, 0, 1, 1);
+                    $self->{controls}->{quickFields}->set_focus_on_click(0);
+
+                    # Without 2 handlers below, the focus goes out of the toolbar when
+                    # pressing Tab or Shift-Tab
+                    $self->{controls}->{quickEntry}->signal_connect('key-press-event' => sub {
+                        my ($widget, $event) = @_;
+                        my $key = Gtk2::Gdk->keyval_name($event->keyval);
+                        if ($key eq 'Tab')
+                        {
+                            $self->{controls}->{quickFields}->grab_focus;
+                            return 1;
+                        }
+                        # Let key be managed by Gtk2
+                        return 0;
+                    });
+                    $self->{controls}->{quickFields}->signal_connect('key-press-event' => sub {
+                        my ($widget, $event) = @_;
+                        my $key = Gtk2::Gdk->keyval_name($event->keyval);
+                        my $state = $event->get_state;
+                        if (($key =~ /Tab$/) && ($state =~ /shift-mask/))
+                        {
+                            $self->{controls}->{quickEntry}->grab_focus;
+                            return 1;
+                        }
+                        # Let key be managed by Gtk2
+                        return 0;
+                    });
+                    $quickBox->pack_start($self->{controls}->{quickEntry}, 0, 0, $GCUtils::halfMargin);
+                    my $quickFieldsBox = new Gtk2::VBox(0,0);
+                    $quickFieldsBox->set_border_width(0);
+                    $quickFieldsBox->pack_start($self->{controls}->{quickFields}, 1, 0, 0);
+                    $quickBox->pack_start($quickFieldsBox, 0, 0, 0);
+                    $self->{parent}->{tooltips}->set_tip($self->{controls}->{quickEntry}, $self->{lang}->{ToolbarQuickSearchTooltip}, '');
+                    $self->{parent}->{tooltips}->set_tip($self->{controls}->{quickFields}, $self->{lang}->{ToolbarQuickSearchTooltip}, '');
+                    my $quickItem = new Gtk2::ToolItem;
+                    $quickItem->add($quickBox);
+                    $self->insert($quickItem, -1);
+                }
+            }
+        }
+        my $separator = Gtk2::SeparatorToolItem->new;
+        $separator->set_expand(1);
+        $separator->set_draw(0);
+
+        my $logoPixbuf = Gtk2::Gdk::Pixbuf->new_from_file($self->{parent}->{logosDir}.'/button.png');
+        my ($width, $height) = Gtk2::IconSize->lookup($self->get_icon_size);
+        $logoPixbuf = GCUtils::scaleMaxPixbuf($logoPixbuf, $width * 1.7, $height * 1.7);
+        
+        my $logo = Gtk2::Image->new_from_pixbuf($logoPixbuf);
+        my $logoButton = new Gtk2::Button;
+        $logoButton->add($logo);
+        my $logoItem = new Gtk2::ToolItem;
+        $logoItem->add($logoButton);
+        $logoButton->set_relief('none');
+        $self->{parent}->{tooltips}->set_tip($logoButton,
+                                             $self->{lang}->{AboutTitle});
+        $logoButton->signal_connect('clicked' , sub {
+            $self->{parent}->about;
+        });
+
+        $self->insert($separator, -1);
+        $self->insert($logoItem, -1);
+    }
+
     sub setShowFieldsSelection
     {
         my ($self, $value) = @_;
+        return;
+        return if ! $self->{controls}->{groupOption};
         if ($value)
         {
-            $self->{groupLabel}->show;
+            $self->{controls}->{groupLabel}->show;
             $self->{groupBox}->show;
         }
         else
         {
-            $self->{groupLabel}->hide;
+            $self->{controls}->{groupLabel}->hide;
             $self->{groupBox}->hide;
         }
     }
@@ -991,29 +1328,62 @@ use strict;
     sub setSaveActive
     {
         my ($self, $value) = @_;
-        $self->{save}->set_sensitive($value);
+        $self->{controls}->{'gtk-save'}->set_sensitive($value)
+            if $self->{controls}->{'gtk-save'};
     }
     
     sub setAddActive
     {
         my ($self, $value) = @_;
-        $self->{add}->set_sensitive($value);
+        $self->{controls}->{'gtk-add'}->set_sensitive($value)
+            if $self->{controls}->{'gtk-add'};
     }
     
     sub setModel
     {
         my ($self, $model) = @_;
         $self->{blocked} = 1;
-        $self->{groupOption}->setModel($model);
+        $self->{model} = $model;
+        $self->{controls}->{groupOption}->setModel($model)
+            if $self->{controls}->{groupOption};
         $self->setGroupField($model->{preferences}->groupBy, 1);
         
+        if ($self->{controls}->{quickFields})
+        {
+            $self->{controls}->{quickFields}->signal_handler_disconnect(
+                $self->{quickFieldsHandler}
+            ) if $self->{quickFieldsHandler};
+            $self->{controls}->{quickFields}->setModel($model);
+            $self->{controls}->{quickFields}->setValue($model->{preferences}->quickSearchField);
+            $self->{quickFieldsHandler} = $self->{controls}->{quickFields}->signal_connect(
+            'changed' => sub {
+               my $value = $self->{controls}->{quickFields}->getValue;
+               $self->{model}->{preferences}->quickSearchField($value)
+                    if $value;
+            });
+        }
+
+        if ($self->{controls}->{layoutOption})
+        {
+            my @panels = map {{value => $_,
+                               displayed => $model->getDisplayedText($model->{panels}->{$_}->{label})}}
+                             @{$model->{panelsNames}};
+            $self->{controls}->{layoutOption}->setValues(\@panels);
+        }
+
         # Hide tonight button if needed
-        $self->{tonight}->show;
-        $self->{tonight}->hide if !$model->hasRandom;
+        if ($self->{controls}->{'gtk-execute'})
+        {
+            $self->{controls}->{'gtk-execute'}->show;
+            $self->{controls}->{'gtk-execute'}->hide if !$model->hasRandom;
+        }
         
         # Hide play button if needed
-        $self->{play}->show;
-        $self->{play}->hide if !$model->hasPlay;
+        if ($self->{controls}->{'gtk-media-play'})
+        {
+            $self->{controls}->{'gtk-media-play'}->show;
+            $self->{controls}->{'gtk-media-play'}->hide if !$model->hasPlay;
+        }
 
         $self->{blocked} = 0;
     }
@@ -1024,7 +1394,22 @@ use strict;
         my $i = 0;
         return if (defined $self->{currentGroupField}) && ($self->{currentGroupField} eq $field) && !$force;
         $self->{currentGroupField} = $field;
-        $self->{groupOption}->setValue($field);
+        $self->{controls}->{groupOption}->setValue($field)
+            if $self->{controls}->{groupOption};
+    }
+    
+    sub setItemsList
+    {
+        my ($self, $view) = @_;
+        return if ! $self->{controls}->{viewOption};
+        $self->{controls}->{viewOption}->setValue($view);
+    }
+    
+    sub setLayout
+    {
+        my ($self, $layout) = @_;
+        return if ! $self->{controls}->{layoutOption};
+        $self->{controls}->{layoutOption}->setValue($layout);
     }
     
     sub setSize
@@ -1040,6 +1425,161 @@ use strict;
             $self->set_icon_size($size == 1 ? 'small-toolbar' : 'large-toolbar');
         }
     }
+
+    sub removeSearch
+    {
+        my $self = shift;
+        $self->{controls}->{quickEntry}->setValue('')
+            if $self->{controls}->{quickEntry};
+    }
+
+}
+
+
+{
+    package GCToolbarOptionsDialog;
+    use base 'GCDoubleListDialog';
+
+    sub new
+    {
+        my ($proto, $parent) = @_;
+        my $class = ref($proto) || $proto;
+        my $self  = $class->SUPER::new($parent, 'Toolbar configuration', 1);
+
+        bless($self, $class);
+
+        $self->{separatorString} = $self->{parent}->{lang}->{ToolbarSeparator};
+        $self->addToPermanent($self->{separatorString});
+
+        my $defaultButton = new GCButton->newFromStock('gtk-undo', 0, $parent->{lang}->{PanelRestoreDefault});
+        $defaultButton->set_border_width($GCUtils::margin);
+        $defaultButton->signal_connect('clicked' => sub {
+            $self->preFill;
+        });
+        my $clearButton = new GCButton->newFromStock('gtk-clear');
+        $clearButton->set_border_width($GCUtils::margin);
+        $clearButton->signal_connect('clicked' => sub {
+            $self->clearList;
+        });            
+        
+        $self->{vboxUnused}->pack_start($defaultButton, 0, 0, 0);
+        $self->{vboxUsed}->pack_start($clearButton, 0, 0, 0);
+
+        $self->{configFile} = $ENV{GCS_CONFIG_HOME}.'/'.$GCToolBar::CONFIGURATION_FILE;
+        $self->{conversionMap} = {};
+
+        my @separatorXpm = (
+            '16 16 3 1',
+            ' 	c None', '-	c grey', '+	c black',
+            '       +-       ', '       +-       ', '       +-       ', '       +-       ',
+            '       +-       ', '       +-       ', '       +-       ', '       +-       ',
+            '       +-       ', '       +-       ', '       +-       ', '       +-       ',
+            '       +-       ', '       +-       ', '       +-       ', '       +-       ');
+        $self->{separatorPixbuf} = Gtk2::Gdk::Pixbuf->new_from_xpm_data(@separatorXpm);
+
+        return $self;
+    }
+
+    sub getInitData
+    {
+        my $self = shift;
+        
+        return $self->getDataFromList([
+            'ToolbarSeparator',
+            'gtk-add', 'gtk-save', 'gtk-preferences',
+            'gtk-find', 'gtk-refresh', 'gtk-execute', 'gtk-media-play',
+            'gtk-new', 'gtk-open', 'gtk-properties', 'gtk-quit',
+            'gtk-dnd', 'gtk-delete', 'gtk-find-and-replace',
+            'gtk-help',
+            'ToolbarGroupBy', 'ToolbarQuickSearch', 'OptionsView', 'OptionsLayout',
+        ], 1);
+    }
+    
+    sub getData
+    {
+        my $self = shift;
+        if (! -f $self->{configFile})
+        {
+            return $self->getDefaultData;
+        }
+        open CONFIG, $self->{configFile};
+        my @array;
+        foreach (<CONFIG>)
+        {
+            s/\s+$//;
+            push @array, $_;
+        }
+        close CONFIG;
+        return $self->getDataFromList(\@array);
+    }
+    
+    sub getDefaultData
+    {
+        my $self = shift;
+        return $self->getDataFromList(\@GCToolBar::DEFAULT_CONTROLS);
+    }
+
+    sub saveList
+    {
+        my ($self, $list) = @_;
+
+        open CONFIG, '>',$self->{configFile};
+        foreach (@$list)
+        {
+            print CONFIG $self->{conversionMap}->{$_->[1]}, "\n";
+        }
+        close CONFIG;
+    }
+        
+    sub getUnusedLabel
+    {
+        my $self = shift;
+        
+        return $self->{parent}->{lang}->{ImportExportFieldsUnused};
+    }
+    sub getUsedLabel
+    {
+        my $self = shift;
+        
+        return $self->{parent}->{lang}->{ImportExportFieldsUsed};
+    }
+
+    sub preFill
+    {
+        my $self = shift;
+        
+        my @data;
+        $self->setListData($self->getDefaultData);
+    }
+    
+    sub getDataFromList
+    {
+        my ($self, $list, $init) = @_;
+        my @data;
+        foreach my $id (@$list)
+        {
+            if ($id =~ /^gtk-/)
+            {
+                my $stockItem = Gtk2::Stock->lookup($id);
+                (my $label = $stockItem->{label}) =~ s/_//g;
+                my $pixbuf = $self->{parent}->render_icon($id, 'menu');                            
+                push @data, [$pixbuf, $label];
+                $self->{conversionMap}->{$label} = $id if $init;
+            }
+            else
+            {
+                my $pixbuf = undef;
+                if ($id eq 'ToolbarSeparator')
+                {
+                    $pixbuf = $self->{separatorPixbuf};
+                }
+                my $label = $self->{parent}->{lang}->{$id};
+                push @data, [$pixbuf, $label];
+                $self->{conversionMap}->{$label} = $id if $init;
+            }
+        }
+        return \@data;
+    }
 }
 
 1;
