@@ -32,10 +32,12 @@ our $autoId = 'gcsautoid';
 our $autoField = 'GCSAuto';
 our $noneField = 'GCSNone';
 our $initDefault = 'DefaultNewItem';
+our $linkNameSeparator = '##';
 
 {
     package GCModelLoader;
 
+    use GCUtils 'glob';
     use XML::Simple;
     $XML::Simple::PREFERRED_PARSER='XML::Parser';
     #$XML::Simple::PREFERRED_PARSER='XML::SAX::Expat';
@@ -75,14 +77,16 @@ our $initDefault = 'DefaultNewItem';
         $self->{commonFields} = $self->{collection}->{options}->{fields};
         $self->{resultsFields} = $self->{collection}->{options}->{fields}->{results}->{field};
         $self->{defaultImage} = $ENV{GCS_SHARE_DIR}.'/logos/'.$self->{options}->{defaults}->{image};
+        $self->{userFiltersDir} = $ENV{GCS_DATA_HOME}.'/Filters/'.$self->getName;
         $self->{random} = $self->{collection}->{random}->{filter};
-
+        my $langName = $self->{parent}->{options}->lang;
         if (exists $self->{collection}->{lang})
         {
             my $lang = $self->{collection}->{lang};
             my %tmpLang;
-            eval "use GCLang::".$self->{parent}->{options}->lang."::GCModels::$lang\n";
-            eval "%tmpLang = %GCLang::".$self->{parent}->{options}->lang."::GCModels::".$lang."::lang";
+            # The string should be splitted to avoid considering some scopped variables
+            eval "use GCLang::$langName"."::GCModels::$lang\n";
+            eval "%tmpLang = %GCLang::$langName"."::GCModels::".$lang."::lang";
             $self->{lang} = \%tmpLang;
         }
         
@@ -218,9 +222,30 @@ our $initDefault = 'DefaultNewItem';
             }
             delete $collection->{groups}->{group}->[(scalar @{$collection->{groups}->{group}}) - 1];
         }
+        if ($self->{defaultModifier})
+        {
+            delete $collection->{fields}->{lending};
+            delete $collection->{fields}->{tags};
+            delete $collection->{options};
+            delete $collection->{random};
+        }
         return $collection;
     }
+
+    sub getAddedFields
+    {
+        my $self = shift;
+        return [] if ! $self->{addedModel};
+        return $self->{addedModel}->{collection}->{fields}->{field};
+    }
     
+    sub getAddedGroups
+    {
+        my $self = shift;
+        return {} if ! $self->{addedModel};
+        return $self->{addedModel}->getGroups;
+    }
+
     sub toString
     {
         my ($self, $root, $withPanel) = @_;
@@ -231,9 +256,28 @@ our $initDefault = 'DefaultNewItem';
                                   KeyAttr => {'group' => '',
                                               'values' => 'id'
                                              });
+        if ($self->{defaultModifier})
+        {
+            $xmlData =~ s|(</?)item|$1userItem|g;
+        }
         return $xmlData;
     }
-    
+
+    sub toStringAddedFields
+    {
+        my ($self, $root) = @_;
+        if (($self->{addedModel})
+         && exists $self->{addedModel}->{fieldsNames}
+         && scalar @{$self->{addedModel}->{fieldsNames}})
+        {
+            return $self->{addedModel}->toString($root, 1);
+        }
+        else
+        {
+            return '';
+        }
+    }
+
     sub loadPreferences
     {
         my $self = shift;
@@ -253,6 +297,9 @@ our $initDefault = 'DefaultNewItem';
         
         $self->{preferences}->groupBy($self->{options}->{defaults}->{groupby})
             if ! $self->{preferences}->exists('groupBy');
+
+        $self->{preferences}->quickSearchField($self->{commonFields}->{title})
+            if ! $self->{preferences}->exists('quickSearchField');
     }
 
     sub isEmpty
@@ -308,7 +355,7 @@ our $initDefault = 'DefaultNewItem';
             push @fieldsNotNull, $name
                 if (exists $_->{notnull}) && ($_->{notnull} eq 'true');
             push @fieldsNotFormatted, $name
-                if (!exists $_->{type}) || ($_->{type} ne 'formatted');
+                if ((!exists $_->{type}) || ($_->{type} ne 'formatted'));
         }
         $self->{fieldsNames} = \@fieldsNames;
         $self->{fieldsInfo} = \%fieldsInfo;
@@ -365,10 +412,91 @@ our $initDefault = 'DefaultNewItem';
         $self->{filtersGroup} = $self->{collection}->{filters}->{group};
     }
 
+    sub getUserFilters
+    {
+        my $self = shift;
+        # Deactive user filters for personal collections without a name
+        return [] if ! $self->getName;
+        if (!$self->{userFilters})
+        {
+            my @filters;
+            mkdir $self->{userFiltersDir};
+            foreach my $filterFile(sort {uc($a) cmp uc($b)} glob($self->{userFiltersDir}.'/*'))
+            {
+                my $xs = XML::Simple->new;
+                my $filter = $xs->XMLin($filterFile,
+                                        ForceArray => ['info', 'filter']);
+                push @filters, $filter;
+                $self->{isUserFilterSaved}->{$filter->{name}} = 1;
+            }
+            $self->{userFilters} = \@filters;
+        }
+        return $self->{userFilters};
+    }
+
+    sub filterNameToFile
+    {
+        my ($self, $name) = @_;
+        my $fileName = GCUtils::getSafeFileName($name);
+        return $self->{userFiltersDir}."/$fileName";
+    }
+
+    sub saveUserFilters
+    {
+        my $self = shift;
+        my $xs = XML::Simple->new;
+        foreach my $filter(@{$self->{userFilters}})
+        {
+            next if $self->{isUserFilterSaved}->{$filter->{name}};
+            $xs->XMLout($filter,
+                        RootName => 'search',
+                        OutputFile => $self->filterNameToFile($filter->{name}));
+            $self->{isUserFilterSaved}->{$filter->{name}} = 1;
+        }
+    }
+    
+    sub setUserFilters
+    {
+        my ($self, $filters) = @_;
+        $self->{userFilters} = $filters;
+        # Make sure they will be saved if needed
+        foreach my $filter(@$filters)
+        {
+            $self->{isUserFilterSaved}->{$filter->{name}} = $filter->{saved};
+            # This should not be saved
+            delete $filter->{saved};
+        }
+    }
+
+    sub addUserFilter
+    {
+        my ($self, $filter) = @_;
+        push (@{$self->{userFilters}}, $filter);
+        my @sorted = sort {uc($a->{name}) cmp uc($b->{name})} @{$self->{userFilters}};
+        $self->{userFilters} = \@sorted;
+        $self->{isUserFilterSaved}->{$filter->{name}} = 0;
+    }
+
+    sub deleteUserFilters
+    {
+        my ($self, $names) = @_;
+        foreach my $name(@$names)
+        {
+            unlink $self->filterNameToFile($name);
+        }
+    }
+
+    sub existsUserFilter
+    {
+        my ($self, $name) = @_;
+        return 1 if exists $self->{isUserFilterSaved}->{$name};
+        return 1 if -e $self->filterNameToFile($name);
+    }
+
     sub addDefaultFields
     {
         my $self = shift;
-        return if $self->isEmpty;
+        return if $self->isEmpty || $self->{defaultModifier};
         if (! $self->{commonFields}->{id})
         {
             $self->{commonFields}->{id} = $GCModel::autoId;
@@ -384,6 +512,113 @@ our $initDefault = 'DefaultNewItem';
         }
     }
 
+    sub removeAddedFields
+    {
+        my $self = shift;
+        return if ! $self->{addedModel};
+        delete $self->{addedModel}->{collection}->{panels}->{panel};
+        foreach my $container('fieldsNames', 'fieldsHistory', 'fieldsNotNull',
+                              'fieldsNotFormatted', 'managedImages', 'fieldsImage')
+        {
+            my @filtered = grep(!/gcsfield/, @{$self->{$container}});
+            $self->{$container} = \@filtered;
+        }
+        foreach (keys %{$self->{panels}})
+        {
+            if ($_ eq 'form')
+            {
+                if ($self->{formNotebook})
+                {
+                    my @filtered = grep(!$_->{userDefined}, @{$self->{formNotebook}->{item}});
+                    $self->{formNotebook}->{item} = \@filtered;
+                }
+            }
+            else
+            {
+                my @filtered = grep(!$_->{userDefined}, @{$self->{panels}->{$_}->{item}});
+                $self->{panels}->{$_}->{item} = \@filtered;
+            }
+        }
+        my $addedModel = $self->{addedModel};
+        delete $self->{addedModel};
+        return $addedModel;
+    }
+
+    sub updateAddedFields
+    {
+        my ($self, $fields, $groups) = @_;
+        
+        # First clean what we previously added
+        my $addedModel = $self->removeAddedFields;
+
+        if (!$addedModel)
+        {
+            # We didn't have one previously. We need to create it.
+            $addedModel = GCModelLoader->newEmpty($self->{parent}, {defaultModifier => 1});
+        }
+        $addedModel->setGroups($groups);
+        $addedModel->setFields($fields);
+
+        $self->addFields($addedModel);
+    }
+
+    sub addFields
+    {
+        my ($self, $model) = @_;
+        # Fields are stored in another model
+
+        $self->{addedModel} = $model;
+
+        return if ! scalar @{$model->{fieldsNames}};
+
+        # Groups part
+        push @{$self->{groups}}, @{$model->{groups}};
+
+        # initFields part
+        foreach(@{$model->{fieldsNames}})
+        {
+            push @{$self->{fieldsNames}}, $_;
+            $self->{fieldsInfo}->{$_} = $model->{fieldsInfo}->{$_};
+        }
+        push @{$self->{fieldsHistory}}, @{$model->{fieldsHistory}};
+        push @{$self->{fieldsNotNull}}, @{$model->{fieldsNotNull}};
+        push @{$self->{fieldsNotFormatted}}, @{$model->{fieldsNotFormatted}};
+        push @{$self->{managedImages}}, @{$model->{managedImages}};
+        push @{$self->{fieldsImage}}, @{$model->{fieldsImage}};
+        
+        # initPanels part
+        foreach (keys %{$model->{panels}})
+        {
+            # We mark them to be able to remove them later
+            foreach my $container(@{$model->{panels}->{$_}->{item}})
+            {
+                $container->{userDefined} = 1;
+            }
+            
+            if ($_ eq 'form')
+            {
+                # Search the main notebook
+                sub getNotebook
+                {
+                    my $item = shift;
+                    return $item if $item->{type} eq 'notebook';
+                    foreach my $child(@{$item->{item}})
+                    {
+                        my $notebook = getNotebook($child);
+                        return $notebook if $notebook;
+                    }
+                    return undef;
+                }
+                $self->{formNotebook} = getNotebook($self->{panels}->{$_});
+                push @{$self->{formNotebook}->{item}}, @{$model->{panels}->{$_}->{item}};
+            }
+            else
+            {
+                push @{$self->{panels}->{$_}->{item}}, @{$model->{panels}->{$_}->{item}};
+            }
+        }
+    }
+
     sub checkLending
     {
         my $self = shift;
@@ -486,7 +721,6 @@ our $initDefault = 'DefaultNewItem';
 
     }
 
-
     sub initPanels
     {
         my $self = shift;
@@ -505,33 +739,45 @@ our $initDefault = 'DefaultNewItem';
     sub createDefaultPanel
     {
         my $self = shift;
-        return if ! $self->{commonFields}->{title};
+        return if (! $self->{commonFields}->{title}) && (!$self->{defaultModifier});
         my $panel;
         $panel->{name} = 'form';
         $panel->{label} = 'PanelForm';
         $panel->{editable} = 'true';
         my @items;
         
-        my $header = {type => 'line'};
-        push @{$header->{item}}, {
-                                    type => 'value',
-                                    for => $self->{commonFields}->{id},
-                                    width => '5'
-                                 }
-            if $self->{commonFields}->{id} && ($self->{commonFields}->{id} ne $GCModel::autoId);
-        push @{$header->{item}}, {
-                                    type => 'value',
-                                    for => $self->{commonFields}->{title},
-                                    expand => 'true'
-                                 };
-        push @items, $header;
+        if (!$self->{defaultModifier})
+        {
+            my $header = {type => 'line'};
+            push @{$header->{item}}, {
+                                        type => 'value',
+                                        for => $self->{commonFields}->{id},
+                                        width => '5'
+                                     }
+                if $self->{commonFields}->{id} && ($self->{commonFields}->{id} ne $GCModel::autoId);
+            push @{$header->{item}}, {
+                                        type => 'value',
+                                        for => $self->{commonFields}->{title},
+                                        expand => 'true'
+                                     };
+            push @items, $header;
+        }
         
         my $fields = $self->getDisplayedInfo;
         my $notebook;
-        my $hasTabs = (scalar @$fields > 1);
-        if ($hasTabs)
+        my $hasTabs;
+        if ($self->{defaultModifier})
         {
-            $notebook = {type => 'notebook', expand => 'true'};
+            $hasTabs = 1;
+            $notebook = undef;
+        }
+        else
+        {
+            $hasTabs = (scalar @$fields > 1);
+            if ($hasTabs)
+            {
+                $notebook = {type => 'notebook', expand => 'true'};
+            }
         }
         
         my $i = 0;
@@ -651,8 +897,17 @@ our $initDefault = 'DefaultNewItem';
                 }
             }
             $tab->{item}->[$tabRank]->{rows} = $row;
-            push @{$notebook->{item}}, $tab
-                if $hasTabs;
+            if ($hasTabs)
+            {
+                if ($self->{defaultModifier})
+                {
+                     push @items, $tab;
+                }
+                else
+                {
+                    push @{$notebook->{item}}, $tab;
+                }
+            }
             $i++;
         }
         if ($self->{hasLending})
@@ -699,26 +954,28 @@ our $initDefault = 'DefaultNewItem';
             push @{$notebook->{item}}, $tab
         }
         
-        push @items, $notebook;
-        
-        my $footer = {type => 'line',
-                      item => [
-                                {
-                                    type => 'special',
-                                    for => 'deleteButton',
-                                    expand => 'true'
-                                }
-                            ]
-                   };
-                   
-        unshift @{$footer->{item}}, {
-                                    type => 'value',
-                                    for => $self->{commonFields}->{url},
-                                    expand => 'true'
-        } if $self->{commonFields}->{url};
-                   
-                   
-        push @items, $footer;
+        if (!$self->{defaultModifier})   
+        {
+            push @items, $notebook;
+            my $footer = {type => 'line',
+                          item => [
+                                    {
+                                        type => 'special',
+                                        for => 'deleteButton',
+                                        expand => 'true'
+                                    }
+                                  ]
+                          };
+                       
+            unshift @{$footer->{item}}, {
+                                        type => 'value',
+                                        for => $self->{commonFields}->{url},
+                                        expand => 'true'
+            } if $self->{commonFields}->{url};
+                       
+                       
+            push @items, $footer;
+        }
 
         $panel->{item} = \@items;
         $self->{collection}->{panels}->{panel}->[0] = $panel;
@@ -728,21 +985,24 @@ our $initDefault = 'DefaultNewItem';
     sub createDefaultReadOnlyPanel
     {
         my $self = shift;
-        return if ! $self->{commonFields}->{title};
+        return if (! $self->{commonFields}->{title}) && (!$self->{defaultModifier});
         my $panel;
         $panel->{name} = 'readonly';
         $panel->{label} = 'PanelReadOnly';
         $panel->{editable} = 'false';
         my @items;
         
-        my $header = {
-                        type => 'line', item => [
-                            {type => 'value', for => $self->{commonFields}->{title},
-                            style => 'header', row => 0, col => 0, colspan => 3,
-                            expand => 'true'}
-                        ]
-                     };
-        push @items, $header;
+        if (!$self->{defaultModifier})
+        {
+            my $header = {
+                            type => 'line', item => [
+                                {type => 'value', for => $self->{commonFields}->{title},
+                                style => 'header', row => 0, col => 0, colspan => 3,
+                                expand => 'true'}
+                            ]
+                         };
+            push @items, $header;
+        }
         
         my $fields = $self->getDisplayedInfo;
         my $i = 0;
@@ -754,7 +1014,7 @@ our $initDefault = 'DefaultNewItem';
             next if (($_->{id} eq 'lending') || ($_->{id} eq 'tagpanel'));
             my $container;
             my $inExpander = 0;
-            if ($i == 0)
+            if (($i == 0) && (!$self->{defaultModifier}))
             {
                 if ($self->{commonFields}->{cover})
                 {
@@ -1005,8 +1265,10 @@ our $initDefault = 'DefaultNewItem';
         my @result;
         foreach (@{$self->{fieldsNames}})
         {
-            push @result, $_ if $self->{fieldsInfo}->{$_}->{group}
-                             && $self->{fieldsInfo}->{$_}->{label};
+            my $info = $self->{fieldsInfo}->{$_};
+            #next if exists $info->{linkedto};
+            push @result, $_ if $info->{group}
+                             && $info->{label};
         }
         return \@result;
     }
@@ -1026,7 +1288,7 @@ our $initDefault = 'DefaultNewItem';
         foreach (@{$self->{fieldsNames}})
         {
             my $info = $self->{fieldsInfo}->{$_};
-            next if ! $info->{label};
+            next if (! $info->{label}); # || (exists $info->{linkedto});
             my $group = $info->{group};
             push @{$groups{$group}}, {
                 id => $_,
@@ -1056,6 +1318,7 @@ our $initDefault = 'DefaultNewItem';
             $info->{$field} = $self->getDisplayedText($self->{fieldsInfo}->{$field}->{init});
             if ($self->{fieldsInfo}->{$field}->{type} eq 'formatted')
             {
+                $info->{$field} =~ s/\[(.*?)\]//g;
                 $info->{$field} =~ s/%(.*?)%//g;
             }
             #foreach (@{$self->{fieldsNames}});
@@ -1138,6 +1401,7 @@ our $initDefault = 'DefaultNewItem';
         bless $self, $class;
         $self->{isInline} = 1;
         $self->{xmlString} = $container->{inlineModel};
+        $self->{defaultModifier} = $container->{defaultModifier};
         $self->{preferences} = GCOptionLoader->newFromXmlString($container->{inlinePreferences});
         $self->loadFromString;
         return $self;
@@ -1147,11 +1411,14 @@ our $initDefault = 'DefaultNewItem';
     {
         my ($proto, $parent, $container) = @_;
         my $class = ref($proto) || $proto;
-        my $self  = {parent => $parent};
+        my $self  = {parent => $parent, isInline => 1, isPersonal => 1};
         bless $self, $class;
-        $self->{isInline} = 1;
         $self->{xmlString} = '<collection><options/><groups/><fields lending="false" tags="false"/></collection>';
         $self->{preferences} = GCOptionLoader->newFromXmlString('');
+        if ($container)
+        {
+            $self->{defaultModifier} = $container->{defaultModifier};
+        }
         $self->loadFromString;
         return $self;
     }
@@ -1161,6 +1428,7 @@ our $initDefault = 'DefaultNewItem';
         my $self = shift;
         $self->{preferences}->save
             if ! $self->{isInline};
+        $self->saveUserFilters;
     }
 }
 
@@ -1175,6 +1443,7 @@ our $initDefault = 'DefaultNewItem';
         my ($proto, $parent) = @_;
         my $class = ref($proto) || $proto;
         mkdir $ENV{GCS_DATA_HOME}.'/GCModels/';
+        mkdir $ENV{GCS_DATA_HOME}.'/Filters/';
         my $self  = {
             parent => $parent,
             cache => {},
@@ -1208,9 +1477,11 @@ our $initDefault = 'DefaultNewItem';
                 $self->{cache}->{$cacheId} = GCModelLoader->new($self->{parent},
                                                                 $file,
                                                                 ($dir eq $self->{persoDirectory}));
-                #$self->{cache}->{$cacheId}->{isPersonal} = 1 if $dir eq $self->{persoDirectory};
             }
         }
+        # Clean it if user added some fields
+        $self->{cache}->{$cacheId}->removeAddedFields
+            if $self->{cache}->{$cacheId};
         return $self->{cache}->{$cacheId};
     }
 
@@ -1279,7 +1550,7 @@ our $initDefault = 'DefaultNewItem';
         # name could be used with getModel
         
         my @results;
-
+        $self->{langName} = $self->{parent}->{options}->lang;
         foreach (glob $self->{defaultDirectory}.'*'.$self->{modelsSuffix})
         {
             #my $model = $self->getModel(basename($_));
@@ -1310,13 +1581,13 @@ our $initDefault = 'DefaultNewItem';
         }
         close FILE;
 
-        open LANG, $ENV{GCS_LIB_DIR}.'/GCLang/'.$self->{parent}->{options}->lang."/GCModels/$lang.pm";
+        open LANG, $ENV{GCS_LIB_DIR}.'/GCLang/'.$self->{langName}."/GCModels/$lang.pm";
         binmode(LANG, ':utf8');
         while (<LANG>)
         {
-            if (/CollectionDescription\s*=>\s*'(.*?)'/)
+            if (/CollectionDescription\s*=>\s*'(.*?)',/)
             {
-                $result->{description} = $1;
+                ($result->{description} = $1) =~ s/\\'/'/g;
                 last;
             }
             
@@ -1515,6 +1786,23 @@ use Gtk2;
 
     use GCGraphicComponents;
 
+    sub setPersonalMode
+    {
+        my ($self, $personal) = @_;
+        $self->{personal} = $personal;
+        if ($personal)
+        {
+            $self->set_title($self->{parent}->{lang}->{ModelSettings});
+        }
+        else
+        {
+            $self->set_title($self->{parent}->{lang}->{PanelUser});
+            $self->{notebook}->set_current_page(0);
+        }
+        $self->{notebook}->set_show_tabs($personal);
+        $self->{collectionName}->set_sensitive($personal);
+    }
+
     sub setDescription
     {
         my ($self, $desc) = @_;
@@ -1528,7 +1816,8 @@ use Gtk2;
         $self->{removeButton}->set_sensitive($value);
         $self->{toUp}->set_sensitive($value);
         $self->{toDown}->set_sensitive($value);
-        $self->activateOkButton($value);
+        $self->activateOkButton($value)
+            if $self->{personal};
     }
 
     sub initFields
@@ -1670,8 +1959,16 @@ use Gtk2;
         }
         if (! scalar(@$groups))
         {
-            push @$groups, {id => 'Main', label => 'OptionsMain',
-                            displayed => $self->{parent}->{lang}->{OptionsMain}};
+            if ($self->{personal})
+            {
+                push @$groups, {id => 'Main', label => 'OptionsMain',
+                                displayed => $self->{parent}->{lang}->{OptionsMain}};
+            }
+            else
+            {
+                push @$groups, {id => 'User', label => 'PanelUser',
+                                displayed => $self->{parent}->{lang}->{PanelUser}};
+            }
         }
         my $defaultGroup = $groups->[0]->{id};
         foreach (@{$self->{fields}})
@@ -2008,6 +2305,8 @@ use Gtk2;
         $self->{params}->{max}->set_sensitive($sensitive);
         $self->{stepLabel}->set_sensitive($sensitive);
         $self->{params}->{step}->set_sensitive($sensitive);
+        $self->{displayasLabel}->set_sensitive($sensitive);
+        $self->{params}->{displayas}->set_sensitive($sensitive);
         $sensitive = 0;
         $sensitive = 1 if $type eq 'options';
         $self->{valuesListLabel}->set_sensitive($sensitive);
@@ -2090,13 +2389,13 @@ use Gtk2;
         my $collectionNameLabel = new GCLabel($parent->{lang}->{ModelName});
         $self->{collectionName} = new GCShortText;
         $self->{tooltips}->set_tip($self->{collectionName},
-                                   $parent->{lang}->{ModelTooltipName});
+                                   $self->{parent}->{lang}->{ModelTooltipName});
         $hboxCollectionName->pack_start($collectionNameLabel, 0, 0, $GCUtils::margin);
         $hboxCollectionName->pack_start($self->{collectionName}, 1, 1, 0);
         
-        my $notebook = new Gtk2::Notebook;
-        $notebook->set_tab_pos('left');
-        $notebook->set_show_border(0);
+        $self->{notebook} = new Gtk2::Notebook;
+        $self->{notebook}->set_tab_pos('left');
+        $self->{notebook}->set_show_border(0);
         
         my $vboxFields = new Gtk2::VBox(0,0);
         my $vboxOptions = new Gtk2::VBox(0,0);
@@ -2145,7 +2444,7 @@ use Gtk2;
         $vboxMove->pack_start($self->{toUp}, 0, 0, $GCUtils::margin);
         $vboxMove->pack_start($self->{toDown}, 0, 0, $GCUtils::margin);
         
-        $self->{fieldsOptionsTable} = new Gtk2::Table(17, 4);
+        $self->{fieldsOptionsTable} = new Gtk2::Table(18, 4);
         $self->{fieldsOptionsTable}->set_row_spacings($GCUtils::halfMargin);
         $self->{fieldsOptionsTable}->set_col_spacings($GCUtils::margin);
         $self->{fieldsOptionsTable}->set_border_width($GCUtils::margin);
@@ -2228,6 +2527,12 @@ use Gtk2;
         $self->{valuesListLabel} = GCLabel->new($parent->{lang}->{ModelFieldList});
         $self->{params}->{values} = new GCShortText;
         $self->{valuesListLegend} = GCLabel->new($parent->{lang}->{ModelFieldListLegend});
+        $self->{displayasLabel} = GCLabel->new($parent->{lang}->{ModelFieldDisplayAs});
+        $self->{params}->{displayas} = new GCMenuList;
+        $self->{params}->{displayas}->setValues([
+                                    {value => 'text', displayed => $parent->{lang}->{ModelFieldDisplayAsText}},
+                                    {value => 'graphical', displayed => $parent->{lang}->{ModelFieldDisplayAsGraphical}}
+                                 ]);
         my $valuesLabel = new GCHeaderLabel($parent->{lang}->{ModelFieldValues});
         $self->{fieldsOptionsTable}->attach($valuesLabel, 0, 4, 10, 11, 'fill', 'fill', 0, 0);  
         $self->{fieldsOptionsTable}->attach($initLabel, 2, 3, 11, 12, 'fill', 'fill', 0, 0);  
@@ -2238,10 +2543,13 @@ use Gtk2;
         $self->{fieldsOptionsTable}->attach($self->{params}->{max}, 3, 4, 13, 14, ['expand', 'fill'], 'fill', 0, 0);  
         $self->{fieldsOptionsTable}->attach($self->{stepLabel}, 2, 3, 14, 15, 'fill', 'fill', 0, 0);  
         $self->{fieldsOptionsTable}->attach($self->{params}->{step}, 3, 4, 14, 15, ['expand', 'fill'], 'fill', 0, 0);  
-        $self->{fieldsOptionsTable}->attach($self->{valuesListLabel}, 2, 3, 15, 16, 'fill', 'fill', 0, 0);  
-        $self->{fieldsOptionsTable}->attach($self->{params}->{values}, 3, 4, 15, 16, ['expand', 'fill'], 'fill', 0, 0);  
-        $self->{fieldsOptionsTable}->attach($self->{valuesListLegend}, 3, 4, 16, 17, ['expand', 'fill'], 'fill', 0, 0);  
+        $self->{fieldsOptionsTable}->attach($self->{displayasLabel}, 2, 3, 15, 16, 'fill', 'fill', 0, 0);  
+        $self->{fieldsOptionsTable}->attach($self->{params}->{displayas}, 3, 4, 15, 16, ['expand', 'fill'], 'fill', 0, 0);  
+        $self->{fieldsOptionsTable}->attach($self->{valuesListLabel}, 2, 3, 16, 17, 'fill', 'fill', 0, 0);  
+        $self->{fieldsOptionsTable}->attach($self->{params}->{values}, 3, 4, 16, 17, ['expand', 'fill'], 'fill', 0, 0);  
+        $self->{fieldsOptionsTable}->attach($self->{valuesListLegend}, 3, 4, 17, 18, ['expand', 'fill'], 'fill', 0, 0);  
         
+
         my $hboxFields = new Gtk2::HBox(0,0);
         $hboxFields->set_border_width($GCUtils::margin);
         $self->{fieldsPane} = new Gtk2::HPaned;
@@ -2291,7 +2599,7 @@ use Gtk2;
 
         $vboxOptions->pack_start($optionsTable, 1, 1, 0);
 
-        $notebook->signal_connect('switch-page' => sub {
+        $self->{notebook}->signal_connect('switch-page' => sub {
             my ($widget, $pointer, $number) = @_;
             $self->saveCurrent;
             $self->saveCurrentFilter;
@@ -2344,12 +2652,12 @@ use Gtk2;
         $hboxFilters->pack_start($self->{filtersOptionsTable}, 1, 1, $GCUtils::halfMargin);
         $vboxFilters->pack_start($hboxFilters,1,1,0);
 
-        $notebook->append_page($vboxFields, $parent->{lang}->{ModelFields});
-        $notebook->append_page($vboxOptions, $parent->{lang}->{ModelOptions});
-        $notebook->append_page($vboxFilters, $parent->{lang}->{ModelFilters});
+        $self->{notebook}->append_page($vboxFields, $parent->{lang}->{ModelFields});
+        $self->{notebook}->append_page($vboxOptions, $parent->{lang}->{ModelOptions});
+        $self->{notebook}->append_page($vboxFilters, $parent->{lang}->{ModelFilters});
 
         $self->vbox->pack_start($hboxCollectionName, 0, 0, $GCUtils::margin);
-        $self->vbox->pack_start($notebook, 1, 1, 0);
+        $self->vbox->pack_start($self->{notebook}, 1, 1, 0);
         $self->vbox->show_all;
 
         $self->setSensitive(0);
