@@ -24,7 +24,7 @@ package GCOptions;
 
 use strict;
 use Gtk2;
-    
+
 our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
 
 {
@@ -125,6 +125,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 browser          => "firefox",
                 player           => "mplayer",
                 audio            => "xmms",
+                imageEditor      => "gimp",
                 file             => "",
                 split            => 300,
                 width            => 920,
@@ -132,7 +133,8 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 confirm          => 1,
                 lang             => $lang,
                 status           => 1,
-                splash           => 1, 
+                splash           => 1,
+                tearoffMenus     => 0, 
                 toolbar          => 3,
                 toolbarPosition  => 0,
                 status           => 1,
@@ -147,6 +149,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 emails           => "",
                 view             => 0,
                 columns          => 3,
+                resizeImgList    => 0,
                 listBgPicture    => 1,
                 useOverlays      => 1,
                 mailer           => "Sendmail",
@@ -160,6 +163,9 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 expandersMode    => 'cut',
                 dateFormat       => '%d/%m/%Y',
                 spellCheck       => 1,
+                cdDevice         => '/dev/cd',
+                useStars         => 1,
+                bigPics          => 0,
             ); 
         }; # if
 
@@ -200,6 +206,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
             if ($! == ENOENT)
             {
                 # File does not exist -- not a problem, just continue with defaults.
+                $self->{options} = \%defaults;
             }
             else
             {
@@ -263,7 +270,8 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         my $self = shift;
         my $name = our $AUTOLOAD;
         return if $name =~ /::DESTROY$/;
-        $name =~ s/.*?::(.*)/$1/;
+        my @comp = split('::', $name);
+        $name = $comp[-1];
         if (@_)
         {
             $self->{options}->{$name} = shift;
@@ -393,13 +401,18 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
 
 {
     package GCOptionsDialog;
+
+    use Glib::Object::Subclass
+                Gtk2::Dialog::
+    ;
+    
+    @GCOptionsDialog::ISA = ('GCModalDialog');
+
     use GCPlugins;
 
-    use Gtk2;
     use GCLang;
     use GCStyle;
     use GCMail;
-    use base 'GCModalDialog';
 
     sub on_destroy
     {
@@ -426,17 +439,21 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $self->{browser} = $self->{options}->browser;
         $self->{player} = $self->{options}->player;
         $self->{audio} = $self->{options}->audio;
+        $self->{imageEditor} = $self->{options}->imageEditor;
 
+        $self->{cdDevice}->setValue($self->{options}->cdDevice);
         $self->{images}->setValue($self->{options}->images);
         $self->{confirm}->set_active($self->{options}->confirm);
         $self->{autosave}->set_active($self->{options}->autosave);
         $self->{autoload}->set_active(! $self->{options}->noautoload);
         $self->{splash}->set_active($self->{options}->splash);
+        $self->{tearoffMenus}->set_active($self->{options}->tearoffMenus);
         $self->{options}->spellCheck(1) if ! $self->{options}->exists('spellCheck');
         $self->{spellCheck}->set_active($self->{options}->spellCheck)
             if $self->{spellCheck};
         $self->{useRelativePaths}->set_active($self->{options}->useRelativePaths);
         $self->{status}->set_active($self->{options}->status);
+        $self->{useStars}->set_active($self->{options}->useStars);
         $self->{proxycb}->set_active($self->{options}->proxy);
         $self->{proxyurl}->set_text($self->{options}->proxy);
         $self->{cookieJarcb}->set_active($self->{options}->cookieJar);
@@ -456,6 +473,9 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $self->{options}->columns(3) if ! $self->{options}->exists('columns');
         $self->{columns} = $self->{options}->columns;
 
+        $self->{options}->resizeImgList(0) if ! $self->{options}->exists('resizeImgList');
+        $self->{resizeImgList} = $self->{options}->resizeImgList;
+
         $self->{options}->toolbar(3) if ! $self->{options}->exists('toolbar');
         $self->{toolbarOption}->setValue($self->{options}->toolbar);
 
@@ -477,6 +497,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
 
         $self->{askImport}->set_active($self->{options}->askImport);
         $self->{searchStop}->set_active($self->{options}->searchStop);
+        $self->{bigPics}->set_active($self->{options}->bigPics);
         
         $self->{langOption}->setValue($self->{options}->lang);
         $self->{styleOption}->setValue($self->{options}->style);
@@ -489,6 +510,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
 
         $self->{from}->set_text($self->{options}->from);
         
+        # Picture size for image mode
         $self->{options}->listImgSize(2) if ! $self->{options}->exists('listImgSize');
         $self->{listImgSize} = $self->{options}->listImgSize;
         $self->{options}->listImgSkin($GCStyle::defaultList) if ! $self->{options}->exists('listImgSkin');
@@ -507,10 +529,15 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
 
         $self->{historysize}->set_value($self->{options}->historysize);
 
-        $self->{model}->{preferences}->details($self->{model}->{commonFields}->{title})
+         # Picture size for detailed mode
+        $self->{options}->detailImgSize($self->{options}->listImgSize)
+            if ! $self->{options}->exists('detailImgSize');
+
+       $self->{model}->{preferences}->details($self->{model}->{commonFields}->{title})
             if ! $self->{model}->{preferences}->exists('details');
         $self->{details} = $self->{model}->{preferences}->details;
         
+        $self->{detailImgSize} = $self->{options}->detailImgSize;
         $self->{groupBy} = $self->{model}->{preferences}->groupBy;
         $self->{secondarySort} = $self->{model}->{preferences}->secondarySort;
         $self->{groupedFirst} = $self->{model}->{preferences}->groupedFirst;
@@ -527,15 +554,19 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $self->{options}->browser($self->{browser});
         $self->{options}->player($self->{player});
         $self->{options}->audio($self->{audio});
+        $self->{options}->imageEditor($self->{imageEditor});
 
+        $self->{options}->cdDevice($self->{cdDevice}->getValue);
         $self->{options}->images($self->{images}->getValue);
         $self->{options}->confirm(($self->{confirm}->get_active) ? 1 : 0);
         $self->{options}->autosave(($self->{autosave}->get_active) ? 1 : 0);
         $self->{options}->noautoload(($self->{autoload}->get_active) ? 0 : 1);
         $self->{options}->splash(($self->{splash}->get_active) ? 1 : 0);
+        $self->{options}->tearoffMenus(($self->{tearoffMenus}->get_active) ? 1 : 0);
         $self->{options}->spellCheck(($self->{spellCheck}->get_active) ? 1 : 0)
             if $self->{spellCheck};
         $self->{options}->status(($self->{status}->get_active) ? 1 : 0);
+        $self->{options}->useStars(($self->{useStars}->get_active) ? 1 : 0);
         $self->{options}->useRelativePaths(($self->{useRelativePaths}->get_active) ? 1 : 0);
         $self->{options}->useTitleForPics(($self->{picturesNameTitle}->get_active) ? 1 : 0);
         $self->{options}->transform(($self->{transform}->get_active) ? 1 : 0);
@@ -571,18 +602,21 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         my $currentView = $self->{options}->view;
         $self->{options}->view($self->{viewOption}->getValue);
         
+        my $currentResizeImgList = $self->{options}->resizeImgList;
         my $currentColumns = $self->{options}->columns;
-        my $currentImgSize = $self->{options}->listImgSize;
+        my $currentListImgSize = $self->{options}->listImgSize;
         my $currentImgSkin = $self->{options}->listImgSkin;
         my $currentBg = $self->{options}->listBgColor;
         my $currentFg = $self->{options}->listFgColor;
         my $currentBgPicture = $self->{options}->listBgPicture;
         my $currentUseOverlays = $self->{options}->useOverlays;
+        my $currentDetailImgSize = $self->{options}->detailImgSize;
         my $currentDetails = $self->{model}->{preferences}->details;
         my $currentGroupBy = $self->{model}->{preferences}->groupBy;
         my $currentSecondarySort = $self->{model}->{preferences}->secondarySort;
         my $currentGroupedFirst = $self->{model}->{preferences}->groupedFirst;
         my $currentAddCount = $self->{model}->{preferences}->addCount;
+        $self->{options}->resizeImgList($self->{resizeImgList});
         $self->{options}->columns($self->{columns});
         $self->{options}->listImgSize($self->{listImgSize});
         $self->{options}->listImgSkin($self->{listImgSkin});
@@ -590,6 +624,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $self->{options}->listFgColor($self->{mlfg});
         $self->{options}->useOverlays($self->{useOverlays});
         $self->{options}->listBgPicture($self->{listBgPicture});
+        $self->{options}->detailImgSize($self->{detailImgSize});
         $self->{model}->{preferences}->details($self->{details});
         $self->{model}->{preferences}->groupBy($self->{groupBy});
         $self->{model}->{preferences}->secondarySort($self->{secondarySort});
@@ -602,9 +637,11 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 ($self->{options}->view == 1)
                 &&
                 (
+                  ($currentResizeImgList != $self->{options}->resizeImgList)
+                  ||
                   ($currentColumns != $self->{options}->columns)
                   ||
-                  ($currentImgSize ne $self->{options}->listImgSize)
+                  ($currentListImgSize ne $self->{options}->listImgSize)
                   ||
                   ($currentImgSkin ne $self->{options}->listImgSkin)
                   ||
@@ -622,7 +659,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 ($self->{options}->view == 2)
                 &&
                 (
-                  ($currentImgSize ne $self->{options}->listImgSize)
+                  ($currentDetailImgSize ne $self->{options}->detailImgSize)
                   ||
                   ($currentDetails ne $self->{model}->{preferences}->details)
                   ||
@@ -645,6 +682,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
    
         $self->{options}->askImport(($self->{askImport}->get_active) ? 1 : 0);
         $self->{options}->searchStop(($self->{searchStop}->get_active) ? 1 : 0);
+        $self->{options}->bigPics(($self->{bigPics}->get_active) ? 1 : 0);
         #$self->{options}->alwaysOriginal(($self->{alwaysOriginal}->get_active) ? 1 : 0);
 
         $self->{options}->mailer($self->{mailerOption}->getValue);
@@ -681,6 +719,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $self->{pluginList}->set_sensitive($value);
         $self->{askImport}->set_sensitive($value);
         $self->{searchStop}->set_sensitive($value);
+        $self->{bigPics}->set_sensitive($value);
     }
     
     sub show_all
@@ -707,6 +746,10 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 $self->{dateFormat}->hide_all;
             }
             $self->{status}->hide_all;
+            $self->{useStars}->hide_all;
+            # CD Device
+            $self->{cdDeviceLabel}->hide_all;
+            $self->{cdDevice}->hide_all;
             # Pictures
 #            $self->{labelImagesGroup}->hide_all;
 #            $self->{labelImages}->hide_all;
@@ -717,6 +760,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
             $self->{useRelativePaths}->hide_all;
             # Internet searches
             $self->{searchStop}->hide_all;
+            #$self->{bigPics}->hide_all;
             # Internet access
             $self->{proxycb}->hide_all;
             $self->{proxyurl}->hide_all;
@@ -727,6 +771,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
             $self->{hboxSMTP}->hide_all;
             $self->{hboxMua}->hide_all;
             # Features
+            $self->{tearoffMenus}->hide_all;
             $self->{autoload}->hide_all;
             $self->{OptionsRestoreAccelerators}->hide_all;
             # History
@@ -736,6 +781,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
             $self->{buttonClearHistory}->hide_all;
         }
         $self->{allShown} = 1;
+        $self->{layoutOption}->signal_emit('changed');
     }
 
     sub show
@@ -745,8 +791,6 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $self->initValues;
         $self->show_all if !$self->{allShown};
 
-        $self->{layoutOption}->signal_emit('changed');
-
         $self->activateInternetOptions(! $self->{model}->isPersonal);
 
         $self->{hboxSMTP}->hide if $self->{options}->mailer ne 'SMTP';
@@ -852,10 +896,10 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         ################
         # Main options
         ################
-        my $tableMain = new Gtk2::Table(2,2,0);
-        $tableMain->set_row_spacings(10);
-        $tableMain->set_col_spacings(20);
-        $tableMain->set_border_width(0);
+        my $tableMain = new Gtk2::Table(3,2,0);
+        $tableMain->set_row_spacings($GCUtils::halfMargin);
+        $tableMain->set_col_spacings($GCUtils::margin);
+        $tableMain->set_border_width($GCUtils::margin);
         
         my $labelLang = new GCLabel($parent->{lang}->{OptionsLang});
         $self->{langOption} = new GCMenuList;
@@ -876,6 +920,11 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $tableMain->attach($labelStyle, 0, 1, 2, 3, 'fill', 'fill', 0, 0);
         $tableMain->attach($self->{styleOption}, 1, 2, 2, 3, 'fill', 'fill', 0, 0);
 	
+        $self->{tearoffMenus} = new Gtk2::CheckButton($parent->{lang}->{OptionsTearoffMenus});
+        $self->{tearoffMenus}->set_active($options->tearoffMenus);
+        $self->{tearoffMenus}->set_active(1) if (! $options->exists('tearoffMenus'));
+        $tableMain->attach($self->{tearoffMenus}, 0, 2, 3, 4, 'fill', 'fill', 0, 0);
+
         my $labelWarning = new Gtk2::Label;
         $labelWarning->set_markup('<b>'.$parent->{lang}->{OptionsWarning}.'</b>');
         $labelWarning->set_use_underline(1);
@@ -1008,8 +1057,10 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
 
         $self->{status} = new Gtk2::CheckButton($parent->{lang}->{OptionsStatus});
         $self->{status}->set_active($options->status);
-        $tableDisplay->attach($self->{status}, 2, 6, 5, 6, 'fill', 'fill', 0, 0);
+        $tableDisplay->attach($self->{status}, 2, 4, 5, 6, 'fill', 'fill', 0, 0);
 
+        $self->{useStars} = new Gtk2::CheckButton($parent->{lang}->{OptionsUseStars});
+        $tableDisplay->attach($self->{useStars}, 4, 6, 5, 6, ['expand', 'fill'], 'fill', 0, 0);
 
         my $labelDisplayArticlesGroup = new GCHeaderLabel($parent->{lang}->{OptionsDisplayArticlesGroup});
         $tableDisplay->attach($labelDisplayArticlesGroup, 0, 6, 7, 8, 'fill', 'fill', 0, 0);
@@ -1032,16 +1083,19 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         #################
         my $vboxPath = new Gtk2::VBox(0,0);
 
-        my $tablePath = new Gtk2::Table(13, 4, 0);
+        my $tablePath = new Gtk2::Table(14, 4, 0);
+        my $pathRow = -1;
         $tablePath->set_row_spacings($GCUtils::halfMargin);
         $tablePath->set_col_spacings($GCUtils::margin);
         $tablePath->set_border_width($GCUtils::margin);
 
         my $labelProgramsGroup = new GCHeaderLabel($parent->{lang}->{OptionsPathProgramsGroup});
-        $tablePath->attach($labelProgramsGroup, 0, 4, 0, 1, 'fill', 'fill', 0, 0);
+        $pathRow++;
+        $tablePath->attach($labelProgramsGroup, 0, 4, $pathRow, $pathRow + 1, 'fill', 'fill', 0, 0);
         
         $self->{systemPrograms} = new Gtk2::RadioButton(undef, $parent->{lang}->{OptionsProgramsSystem});
-        $tablePath->attach($self->{systemPrograms}, 2, 4, 1, 2, 'fill', 'fill', 0, 0);
+        $pathRow++;
+        $tablePath->attach($self->{systemPrograms}, 2, 4, $pathRow, $pathRow + 1, 'fill', 'fill', 0, 0);
         $self->{programTypeGroup} = $self->{systemPrograms}->get_group;
         $self->{userPrograms} = new Gtk2::RadioButton($self->{programTypeGroup}, $parent->{lang}->{OptionsProgramsUser});
         $self->{defineProgramsButton} = new GCButton($parent->{lang}->{OptionsProgramsSet});
@@ -1053,47 +1107,64 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         my $hboxDefinePrograms = new Gtk2::HBox(0,0);
         $hboxDefinePrograms->pack_start($self->{userPrograms}, 0, 0, 0);
         $hboxDefinePrograms->pack_start($self->{defineProgramsButton}, 0, 0, 2*$GCUtils::margin);
-        $tablePath->attach($hboxDefinePrograms, 2, 4, 2, 3, 'fill', [], 0, 0);
+        $pathRow++;
+        $tablePath->attach($hboxDefinePrograms, 2, 4, $pathRow, $pathRow + 1, 'fill', [], 0, 0);
         $self->{userPrograms}->signal_connect('toggled' => sub {
             $self->{defineProgramsButton}->lock(! $self->{userPrograms}->get_active);
         });
 
+        $self->{cdDeviceLabel} = new GCLabel($parent->{lang}->{OptionsCdDevice});
+        $self->{cdDevice} = new GCFile($self,
+                                       $self->{parent}->{lang}->{FileChooserOpenDirectory},
+                                       'select-folder');
+        $pathRow++;
+        $tablePath->attach($self->{cdDeviceLabel}, 2, 3, $pathRow, $pathRow + 1, 'fill', 'fill', 0, 0);
+        $tablePath->attach($self->{cdDevice}, 3, 4, $pathRow, $pathRow + 1, 'fill', 'fill', 0, 0);
+
         $self->{labelImagesGroup} = new GCHeaderLabel($parent->{lang}->{OptionsPathImagesGroup});
-        $tablePath->attach($self->{labelImagesGroup}, 0, 4, 4, 5, 'fill', 'fill', 0, 0);
+        $pathRow += 2;
+        $tablePath->attach($self->{labelImagesGroup}, 0, 4, $pathRow, $pathRow + 1, 'fill', 'fill', 0, 0);
         $self->{labelImages} = new GCLabel($parent->{lang}->{OptionsImages});
-        $tablePath->attach($self->{labelImages}, 2, 3, 5, 6, 'fill', 'fill', 0, 0);
+        $pathRow++;
+        $tablePath->attach($self->{labelImages}, 2, 3, $pathRow, $pathRow + 1, 'fill', 'fill', 0, 0);
         $self->{images} = new GCFile($self,
-                                     $self->{parent}->{lang}->{OptionsImagesTitle},
+                                     $self->{parent}->{lang}->{FileChooserOpenDirectory},
                                      'select-folder',
                                      0,
                                      $GCOptions::DEFAULT_IMG_DIR);
         $self->{images}->setWidth(40);
-        $tablePath->attach($self->{images}, 3, 4, 5, 6, ['expand', 'fill'], 'fill', 0, 0);
+        $tablePath->attach($self->{images}, 3, 4, $pathRow, $pathRow + 1, ['expand', 'fill'], 'fill', 0, 0);
 	
         $self->{labelPicturesWorkingDir} = new GCLabel($parent->{lang}->{OptionsPicturesWorkingDir});
-        $tablePath->attach($self->{labelPicturesWorkingDir}, 2, 4, 6, 7, 'fill', 'fill', 2*$GCUtils::margin, 0);
+        $pathRow++;
+        $tablePath->attach($self->{labelPicturesWorkingDir}, 2, 4, $pathRow, $pathRow + 1, 'fill', 'fill', 2*$GCUtils::margin, 0);
         $self->{labelPicturesFileBase} = new GCLabel($parent->{lang}->{OptionsPicturesFileBase});
-        $tablePath->attach($self->{labelPicturesFileBase}, 2, 4, 7, 8, 'fill', 'fill', 2*$GCUtils::margin, 0);
+        $pathRow++;
+        $tablePath->attach($self->{labelPicturesFileBase}, 2, 4, $pathRow, $pathRow + 1, 'fill', 'fill', 2*$GCUtils::margin, 0);
 
         $self->{picturesNameFormat} = new GCLabel($parent->{lang}->{OptionsPicturesFormat});
-        $tablePath->attach($self->{picturesNameFormat}, 2, 4, 9, 10, 'fill', 'fill', 0, 0);
+        $pathRow += 2;
+        $tablePath->attach($self->{picturesNameFormat}, 2, 4, $pathRow, $pathRow + 1, 'fill', 'fill', 0, 0);
         $self->{picturesNameAuto} = new Gtk2::RadioButton(undef, $parent->{lang}->{OptionsPicturesFormatInternal});
-        $tablePath->attach($self->{picturesNameAuto}, 2, 4, 10, 11, 'fill', 'fill', 2*$GCUtils::margin, 0);
+        $pathRow++;
+        $tablePath->attach($self->{picturesNameAuto}, 2, 4, $pathRow, $pathRow + 1, 'fill', 'fill', 2*$GCUtils::margin, 0);
         $self->{picturesNameGroup} = $self->{picturesNameAuto}->get_group;
         $self->{picturesNameTitle} = new Gtk2::RadioButton($self->{picturesNameGroup}, $parent->{lang}->{OptionsPicturesFormatTitle});
-        $tablePath->attach($self->{picturesNameTitle}, 2, 4, 11, 12, 'fill', 'fill', 2*$GCUtils::margin, 0);
+        $pathRow++;
+        $tablePath->attach($self->{picturesNameTitle}, 2, 4, $pathRow, $pathRow + 1, 'fill', 'fill', 2*$GCUtils::margin, 0);
 
         $self->{useRelativePaths} = new Gtk2::CheckButton($parent->{lang}->{OptionsUseRelativePaths});
         $self->{useRelativePaths}->set_active($options->useRelativePaths);
         $self->{useRelativePaths}->set_active(0) if (! $options->exists('useRelativePaths'));
-        $tablePath->attach($self->{useRelativePaths}, 2, 4, 12, 13, 'fill', 'fill', 0, 0);
+        $pathRow++;
+        $tablePath->attach($self->{useRelativePaths}, 2, 4, $pathRow, $pathRow + 1, 'fill', 'fill', 0, 0);
 
         $vboxPath->pack_start($tablePath, 0, 0, 0);
 
         ###################
         # Internet options
         ###################
-        my $tableInternet = new Gtk2::Table(11, 5, 0);
+        my $tableInternet = new Gtk2::Table(12, 5, 0);
         $tableInternet->set_row_spacings($GCUtils::halfMargin);
         $tableInternet->set_col_spacings($GCUtils::margin);
         $tableInternet->set_border_width($GCUtils::margin);
@@ -1123,11 +1194,13 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $tableInternet->attach($self->{pluginOption}, 3, 4, 1, 2, 'fill', 'fill', 0, 0); 
         $tableInternet->attach($self->{pluginList}, 4, 5, 1, 2, 'fill', 'fill', 20, 0);
         $tableInternet->attach($self->{askImport}, 2, 5, 2, 3, 'fill', 'fill', 0, 0); 
+        $self->{bigPics} = new Gtk2::CheckButton($parent->{lang}->{OptionsBigPics});
+        $tableInternet->attach($self->{bigPics}, 2, 5, 3, 4, 'fill', 'fill', 0, 0);
         $self->{searchStop} = new Gtk2::CheckButton($parent->{lang}->{OptionsSearchStop});
-        $tableInternet->attach($self->{searchStop}, 2, 5, 3, 4, 'fill', 'fill', 0, 0) if ($^O !~ /win32/i);
+        $tableInternet->attach($self->{searchStop}, 2, 5, 4, 5, 'fill', 'fill', 0, 0) if ($^O !~ /win32/i);
 
         my $settingsGroupLabel = new GCHeaderLabel($parent->{lang}->{OptionsInternetSettingsGroup});
-        $tableInternet->attach($settingsGroupLabel, 0, 5, 5, 6, 'fill', 'fill', 0, 0); 
+        $tableInternet->attach($settingsGroupLabel, 0, 5, 6, 7, 'fill', 'fill', 0, 0); 
 	
         $self->{proxycb} = new Gtk2::CheckButton($parent->{lang}->{OptionsProxy});
         $self->{proxycb}->set_active($options->proxy);
@@ -1143,8 +1216,8 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 $self->{proxyurl}->set_editable(0);
             }
         });
-        $tableInternet->attach($self->{proxycb}, 2, 3, 6, 7, 'fill', 'fill', 0, 0);
-        $tableInternet->attach($self->{proxyurl}, 3, 4, 6, 7, 'fill', 'shrink', 0, 0);
+        $tableInternet->attach($self->{proxycb}, 2, 3, 7, 8, 'fill', 'fill', 0, 0);
+        $tableInternet->attach($self->{proxyurl}, 3, 4, 7, 8, 'fill', 'shrink', 0, 0);
         
         $self->{cookieJarcb} = new Gtk2::CheckButton($parent->{lang}->{OptionsCookieJar});
         $self->{cookieJarcb}->set_active($options->cookieJar);
@@ -1158,23 +1231,23 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 $self->{cookieJarPath}->lock(1);
             }
         });
-        $tableInternet->attach($self->{cookieJarcb}, 2, 3, 7, 8, 'fill', 'fill', 0, 0);
+        $tableInternet->attach($self->{cookieJarcb}, 2, 3, 8, 9, 'fill', 'fill', 0, 0);
         $self->{cookieJarPath} = new GCFile($self,
                                      $self->{parent}->{lang}->{OptionsCookieJar},
                                      'open',
                                      0 );
-        $tableInternet->attach($self->{cookieJarPath}, 3, 4, 7, 8, 'fill', 'fill', 0, 0);
+        $tableInternet->attach($self->{cookieJarPath}, 3, 4, 8, 9, 'fill', 'fill', 0, 0);
 
         my $labelFrom = new GCLabel($self->{parent}->{lang}->{OptionsFrom});
         $self->{from} = new Gtk2::Entry;
-        $tableInternet->attach($labelFrom, 2, 3, 8, 9, 'fill', 'fill', 0, 0);
-        $tableInternet->attach($self->{from}, 3, 4, 8, 9, 'fill', 'fill', 0, 0);
+        $tableInternet->attach($labelFrom, 2, 3, 9, 10, 'fill', 'fill', 0, 0);
+        $tableInternet->attach($self->{from}, 3, 4, 9, 10, 'fill', 'fill', 0, 0);
 
         $self->{mailerLabel} = new GCLabel($parent->{lang}->{OptionsMailer});
         $self->{mailerOption} = new GCMenuList;
         $self->initMailerOption;
-        $tableInternet->attach($self->{mailerLabel}, 2, 3, 9, 10, 'fill', 'fill', 0, 0);
-        $tableInternet->attach($self->{mailerOption}, 3, 4, 9, 10, 'fill', 'fill', 0, 0);
+        $tableInternet->attach($self->{mailerLabel}, 2, 3, 10, 11, 'fill', 'fill', 0, 0);
+        $tableInternet->attach($self->{mailerOption}, 3, 4, 10, 11, 'fill', 'fill', 0, 0);
         
         $self->{hboxSMTP} = new Gtk2::HBox(0,0);
         my $SMTPLabel = new GCLabel($parent->{lang}->{OptionsSMTP});
@@ -1183,7 +1256,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $self->{smtp}->set_width_chars(20);
         $self->{hboxSMTP}->pack_start($SMTPLabel,0,0,0);
         $self->{hboxSMTP}->pack_start($self->{smtp},0,0,5);
-        $tableInternet->attach($self->{hboxSMTP}, 4, 5, 9, 10, 'fill', 'fill', 0, 0);
+        $tableInternet->attach($self->{hboxSMTP}, 4, 5, 10, 11, 'fill', 'fill', 0, 0);
 
         $self->{mailerOption}->signal_connect('changed' => sub {
             if ('SMTP' eq $self->{mailerOption}->getValue)
@@ -1199,7 +1272,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         my $mailersButton = new GCButton($parent->{lang}->{OptionsConfigureMailers});
         $self->{hboxMua} = new Gtk2::HBox(0,0);
         $self->{hboxMua}->pack_start($mailersButton,0,0,0);
-        $tableInternet->attach($self->{hboxMua}, 2, 4, 10, 11, 'fill', 'fill', 0, 0);
+        $tableInternet->attach($self->{hboxMua}, 2, 4, 11, 12, 'fill', 'fill', 0, 0);
         $mailersButton->signal_connect('clicked' => sub {
             my $dialog = $self->{parent}->getDialog('MailPrograms');
             $self->initMailerOption if $dialog->show;
@@ -1295,6 +1368,12 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $tabs->append_page_menu($vboxInternet, $internetButton, Gtk2::Label->new($parent->{lang}->{OptionsInternet}));
         $tabs->append_page_menu($vboxConvenience, $conveniencesButton, Gtk2::Label->new($parent->{lang}->{OptionsConveniences}));
 
+#        $tabs->append_page($vboxMain, $parent->{lang}->{OptionsMain});
+#        $tabs->append_page($vboxDisplay, $parent->{lang}->{OptionsDisplay});
+#        $tabs->append_page($vboxPath, $parent->{lang}->{OptionsPaths});
+#        $tabs->append_page($vboxInternet, $parent->{lang}->{OptionsInternet});
+#        $tabs->append_page($vboxConvenience, $parent->{lang}->{OptionsConveniences});
+
         $tabs->set_tab_label_packing ($vboxMain, 1, 0, 'start');
         $tabs->set_tab_label_packing ($vboxDisplay, 1, 0, 'start');
         $tabs->set_tab_label_packing ($vboxPath, 1, 0, 'start');
@@ -1303,7 +1382,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
 
         $self->vbox->pack_start($tabs, 1, 1, 0);
 
-        $self->{expert} = new Gtk2::CheckButton('Expert Mode');
+        $self->{expert} = new Gtk2::CheckButton($parent->{lang}->{OptionsExpertMode});
         $self->{expert}->signal_connect('toggled' => sub {
             $self->show_all;
         });
@@ -1326,6 +1405,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
     {
         my $self = shift;
         
+        $self->{resizeImgList}->set_active($self->{parent}->{resizeImgList});
         $self->{columns}->set_value($self->{parent}->{columns});
         $self->{imgSizeOption}->setValue($self->{parent}->{listImgSize});
         $self->{optionStyle}->setValue($self->{parent}->{listImgSkin});
@@ -1340,6 +1420,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
     {
         my $self = shift;
         
+        $self->{parent}->{resizeImgList} = (($self->{resizeImgList}->get_active) ? 1 : 0);
         $self->{parent}->{columns} = $self->{columns}->get_value;
         $self->{parent}->{listImgSize} = $self->{imgSizeOption}->getValue;
         $self->{parent}->{listImgSkin} = $self->{optionStyle}->getValue;
@@ -1401,15 +1482,21 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                                        $parent->{lang}->{ImagesOptionsTitle},
                                       );
 
-        my $tableLayout = new Gtk2::Table(10,4);
+        my $tableLayout = new Gtk2::Table(11,4);
         $tableLayout->set_row_spacings($GCUtils::halfMargin);
         $tableLayout->set_col_spacings($GCUtils::margin);
         $tableLayout->set_border_width($GCUtils::margin);
 
         my $labelColumns = new GCLabel($parent->{lang}->{OptionsColumns});
-        my  $adj = Gtk2::Adjustment->new(0, 1, 10, 1, 1, 0) ;
+        my  $adj = Gtk2::Adjustment->new(0, 1, 20, 1, 1, 0) ;
         $self->{columns} = Gtk2::SpinButton->new($adj, 0, 0);
 
+        $self->{resizeImgList} = new Gtk2::CheckButton($parent->{lang}->{ImagesOptionsResizeImgList});
+        $self->{resizeImgList}->signal_connect('clicked' => sub {
+            $self->{columns}->set_sensitive(! $self->{resizeImgList}->get_active);
+        });
+        $self->{resizeImgList}->set_active($self->{resizeImgList});
+
         my $imgSizeLabel = new GCLabel($parent->{lang}->{ImagesOptionsSizeLabel});
         $self->{imgSizeOption} = new GCMenuList;
         my %imgSizes = %{$parent->{lang}->{ImagesOptionsSizeList}};
@@ -1453,21 +1540,22 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
 
         my $imagesDisplayGroupLabel = new GCHeaderLabel($parent->{lang}->{OptionsImagesDisplayGroup});
         $tableLayout->attach($imagesDisplayGroupLabel, 0, 4, 0, 1, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($labelColumns, 2, 3, 1, 2, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{columns}, 3, 4, 1, 2, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($imgSizeLabel, 2, 3, 2, 3, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{imgSizeOption}, 3, 4, 2, 3, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{resizeImgList}, 2, 4, 1, 2, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($labelColumns, 2, 3, 2, 3, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{columns}, 3, 4, 2, 3, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($imgSizeLabel, 2, 3, 3, 4, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{imgSizeOption}, 3, 4, 3, 4, 'fill', 'fill', 0, 0);
 
         my $imagesStyleGroupLabel = new GCHeaderLabel($parent->{lang}->{OptionsImagesStyleGroup});
-        $tableLayout->attach($imagesStyleGroupLabel, 0, 4, 4, 5, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{useOverlays}, 2, 4, 5, 6, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{listBgPicture}, 2, 4, 6, 7, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{labelStyle}, 2, 3, 7, 8, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{optionStyle}, 3, 4, 7, 8, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{labelBg}, 2, 3, 8, 9, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{buttonBg}, 3, 4, 8, 9, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{labelFg}, 2, 3, 9, 10, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{buttonFg}, 3, 4, 9, 10, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($imagesStyleGroupLabel, 0, 4, 5, 6, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{useOverlays}, 2, 4, 6, 7, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{listBgPicture}, 2, 4, 7, 8, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{labelStyle}, 2, 3, 8, 9, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{optionStyle}, 3, 4, 8, 9, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{labelBg}, 2, 3, 9, 10, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{buttonBg}, 3, 4, 9, 10, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{labelFg}, 2, 3, 10, 11, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{buttonFg}, 3, 4, 10, 11, 'fill', 'fill', 0, 0);
 
         $tableLayout->show_all;
 
@@ -1488,7 +1576,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
     {
         my $self = shift;
         
-        $self->{imgSizeOption}->setValue($self->{parent}->{listImgSize});
+        $self->{imgSizeOption}->setValue($self->{parent}->{detailImgSize});
         $self->{groupByOption}->setValue($self->{parent}->{groupBy});
         $self->{secondarySortOption}->setValue($self->{parent}->{secondarySort});
         $self->{groupedFirst}->setValue($self->{parent}->{groupedFirst});
@@ -1499,7 +1587,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
     {
         my $self = shift;
         
-        $self->{parent}->{listImgSize} = $self->{imgSizeOption}->getValue;
+        $self->{parent}->{detailImgSize} = $self->{imgSizeOption}->getValue;
         $self->{parent}->{groupBy} =  $self->{groupByOption}->getValue;
         $self->{parent}->{secondarySort} =  $self->{secondarySortOption}->getValue;
         $self->{parent}->{groupedFirst} =  $self->{groupedFirst}->getValue;
@@ -1636,21 +1724,24 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                                        $parent->{lang}->{OptionsProgramsSet},
                                       );
 
-        $self->{programs} = ['browser', 'player', 'audio'];
+        $self->{programs} = ['browser', 'player', 'audio', 'imageEditor'];
 
-        my $tablePath = new Gtk2::Table(scalar @{$self->{programs}}, 2);
+        my $tablePath = new Gtk2::Table(scalar @{$self->{programs}} + 1, 4);
         $tablePath->set_row_spacings($GCUtils::halfMargin);
         $tablePath->set_col_spacings($GCUtils::margin);
         $tablePath->set_border_width($GCUtils::margin);
 
-        my $line = 0;
+        $self->{labelPrograms} = new GCHeaderLabel($parent->{lang}->{OptionsPrograms});
+        $tablePath->attach($self->{labelPrograms}, 0, 4, 0, 1, 'fill', 'fill', 0, $GCUtils::halfMargin);
+
+        my $line = 1;
         foreach my $program(@{$self->{programs}})
         {
             my $label = new GCLabel($parent->{lang}->{'Options'.ucfirst($program)});
-            $tablePath->attach($label, 0, 1, $line, $line + 1, 'fill', 'fill', 0, 0);
+            $tablePath->attach($label, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
             $self->{paths}->{$program} = new GCFile($parent, $parent->{lang}->{OptionsProgramTitle});
             $self->{paths}->{$program}->setWidth(40);
-            $tablePath->attach($self->{paths}->{$program}, 1, 2, $line, $line + 1, ['expand', 'fill'], 'fill', 0, 0);
+            $tablePath->attach($self->{paths}->{$program}, 3, 4, $line, $line + 1, ['expand', 'fill'], 'fill', 0, 0);
             $line++;
         }
 
