@@ -30,7 +30,7 @@ use strict;
 
 {
     package GCItemPanel;
-    use base "Gtk2::Frame";
+    @GCItemPanel::ISA = ('Gtk2::Frame');
     
     sub new
     {
@@ -58,7 +58,7 @@ use strict;
         $self->{layout} = $layout;
         $self->set_shadow_type('none');
         
-        $self->{defaultImage} = $parent->{defaultImage};
+        #$self->{defaultImage} = $parent->getDefaultImage;
         $self->{tooltips} = $parent->{tooltips};
         
         $self->{infoBox} = new Gtk2::VBox(1,0);
@@ -105,10 +105,10 @@ use strict;
 
     sub setSpellChecking
     {
-        my ($self, $activate) = @_;
+        my ($self, $activate, $lang) = @_;
         foreach (@{$self->{longTextFields}})
         {
-            $_->setSpellChecking($activate);
+            $_->setSpellChecking($activate, $lang);
         }
     }
 
@@ -188,6 +188,8 @@ use strict;
             {
                 if ($show->{$_})
                 {
+                    # Useful for GCLinkedComponent
+                    $widget->show if !$widget->isa('Gtk2::Widget');
                     #$parentsToHide{$widget->{realParent}} = 0;
                     my $parent = $widget->{realParent};
                     while ($parent)
@@ -293,15 +295,18 @@ use strict;
 
     sub dataChanged
     {
-        my ($self, $info) = @_;
+        my ($self, $info, $withoutPanel) = @_;
 
-        foreach (@{$self->{expanders}})
+        if (!$withoutPanel)
         {
-            $self->setExpanderLabel($_, 1);
+            foreach (@{$self->{expanders}})
+            {
+                $self->setExpanderLabel($_, 1);
+            }
         }
         foreach (@{$self->{formatted}})
         {
-            $self->setFormattedLabel($_, 1, $info);
+            $self->setFormattedLabel($_, 1, $info, $withoutPanel);
         }
     }
 
@@ -325,9 +330,23 @@ use strict;
     
     sub formatLabel
     {
-        my ($self, $format) = @_;
+        my ($self, $format, $info) = @_;
+
+        my $label;
+        # Allow formatting using %fields[format]%
+        if ($info)
+        {
+            ($label = $format) =~ s/%(.*?)(\[(.*?)\])*%/$3 ? sprintf($3,$info->{$1}) : $info->{$1}/eg;
+        }
+        else
+        {
+            ($label = $format) =~ s/%(.*?)(\[(.*?)\])*%/$3 ? sprintf($3,$self->{$1}->getValue(1)) : $self->{$1}->getValue(1)/eg;
+        }
+        if ($label =~ /^=(.*)$/)
+        {
+            $label = eval $1;
+        }
 
-        (my $label = $format) =~ s/%(.*?)%/$self->{$1}->getValue(1)/eg;
         $label =~ s/@(.*?)@/$self->{model}->getDisplayedText($1)/eg;
         return $label;
     }
@@ -364,13 +383,27 @@ use strict;
 
     sub setFormattedLabel
     {
-        my ($self, $label, $init, $info) = @_;
+        my ($self, $label, $init, $info, $withoutPanel) = @_;
 
         my $name = $label->{name};
-        $self->$name($self->formatLabel($label->{format}));
-        # We store here the value so it could be used by caller if needed
-        # The user is GCData::updateCurrent
-        $info->{$name} = $self->$name if defined $info;
+        if ($withoutPanel)
+        {
+            $info->{$name} = $self->formatLabel($label->{format}, $info);
+        }
+        else
+        {
+            $self->$name($self->formatLabel($label->{format}));
+            # We store here the value so it could be used by caller if needed
+            # The user is GCData::updateCurrent
+            $info->{$name} = $self->$name if defined $info;
+        }
+    }
+
+    sub prepareDate
+    {
+        my ($self, $value) = @_;
+
+        return GCUtils::timeToStr($value, $self->{parent}->{options}->dateFormat)
     }
 
     sub addToContainer
@@ -431,12 +464,13 @@ use strict;
             }
             else
             {
-                if ($container->get_children)
+                if (($container->get_children) && (!$container->get_homogeneous))
                 {
                     my $marginBox = new Gtk2::HBox(0,0);
                     $container->pack_start($marginBox, 0, 0, $self->{halfMargin});
                 }
-                $container->pack_start($widget, $expand, $expand, 0);
+                $container->pack_start($widget, $expand, $expand, 0)
+                    if ref($widget) ne 'HASH';
             }
         }
     }
@@ -478,14 +512,17 @@ use strict;
             elsif ($_->{type} eq 'value')
             {
                 $widget = $self->getWidget($_->{for}, $_);
-                $widget->setWidth($_->{width}) if $_->{width};
-                $widget->setHeight($_->{height}) if $_->{height};
-                $widget->expand if (exists $_->{expand}) && ($_->{expand} eq 'true');
-                if ($_->{values} || $self->{model}->{fieldsInfo}->{$_->{for}}->{values})
+                if ($widget)
                 {
-                    $self->{displayedValues}->{$_->{for}} = 
-                            $_->{values}
-                         || $self->{model}->{fieldsInfo}->{$_->{for}}->{values};
+                    $widget->setWidth($_->{width}) if $_->{width};
+                    $widget->setHeight($_->{height}) if $_->{height};
+                    $widget->expand if (exists $_->{expand}) && ($_->{expand} eq 'true');
+                    if ($_->{values} || $self->{model}->{fieldsInfo}->{$_->{for}}->{values})
+                    {
+                        $self->{displayedValues}->{$_->{for}} = 
+                                $_->{values}
+                             || $self->{model}->{fieldsInfo}->{$_->{for}}->{values};
+                    }
                 }
             }
             elsif ($_->{type} eq 'label')
@@ -537,7 +574,9 @@ use strict;
             }
             elsif ($_->{type} eq 'line')
             {
-                $widget = new Gtk2::HBox(0,0);
+                my $homogeneous = (exists $_->{homogeneous} && ($_->{homogeneous} eq 'true'))
+                                ? 1 : 0;
+                $widget = new Gtk2::HBox($homogeneous, $self->{margin});
                 #$widget->set_border_width($self->{halfMargin});
                 $widget->set_size_request(-1, $_->{height}) if $_->{height};
                 $box = $widget;
@@ -651,7 +690,12 @@ use strict;
 
 {
     package GCReadOnlyPanel;
-    use base 'GCItemPanel';
+
+    use Glib::Object::Subclass
+                Gtk2::Frame::
+    ;
+
+    @GCReadOnlyPanel::ISA = ('GCItemPanel');
 
     use File::Basename;
 
@@ -744,9 +788,16 @@ use strict;
     sub getValues
     {
         my ($self, $field) = @_;
-        
-        return $self->{$field}->getValues;
-                
+        if ($field eq $self->{model}->{commonFields}->{borrower}->{name})
+        {
+            my $borrowers = $self->{model}->getValues($self->{model}->{commonFields}->{borrower}->{name});
+            shift @{$borrowers} if !$borrowers->[0]->{displayed};
+            return $borrowers;
+        }
+        else
+        {        
+            return $self->{$field}->getValues;                
+        }
     }
     
 
@@ -770,7 +821,7 @@ use strict;
 
     sub setBorrowers
     {
-        my ($self, $values) = @_;
+        my ($self) = @_;
     }
 
     sub createSpecial
@@ -849,7 +900,7 @@ use strict;
         elsif ($info->{type} eq 'image')
         {
             $widget = new GCItemImage($self->{parent}->{options}, 
-                                      $self->{model}->{defaultImage});
+                                      $self->{parent});
         }
         elsif ($info->{type} eq 'button')
         {
@@ -877,11 +928,15 @@ use strict;
         else
         {
             # See GCColorLabel constructor for the meaning of listType;
+            $widget = new GCColorLabel($self->{styles}->{field}->{bgColor});
             if ($info->{value} eq $self->{model}->{commonFields}->{borrower}->{name})
             {
                 $self->{prepare}->{$info->{value}}->{func} = 'prepareBorrower';
             }
-            $widget = new GCColorLabel($self->{styles}->{field}->{bgColor});
+            elsif ($info->{type} eq 'date')
+            {
+                $self->{prepare}->{$info->{value}}->{func} = 'prepareDate';
+            }
             $self->{style}->{$info->{value}} = 'field';
             $widget->set_selectable(0);
             $widget->set_padding(5,5);
@@ -990,7 +1045,10 @@ use strict;
 {
     package GCFormPanel;
 
-    use base 'GCItemPanel';
+    use Glib::Object::Subclass
+                Gtk2::Frame::
+    ;
+    @GCFormPanel::ISA = ('GCItemPanel');
 
     sub createSpecial
     {
@@ -1093,7 +1151,8 @@ use strict;
     {
         my $self = shift;
 
-        my $dialog = new GCDateSelectionDialog($self->{parent});
+        my $isBack = 0;
+        my $dialog = new GCDateSelectionDialog($self->{parent}, $self->{lang}->{PanelReturned});
         if ($dialog->show)
         {
             my $borrowerField = $self->{model}->{commonFields}->{borrower}->{name};
@@ -1103,6 +1162,10 @@ use strict;
             my @data = ($self->{$borrowerField}->getDisplayedValue,
                         $self->{$lendDateField}->getValue,
                         $dialog->date);
+            foreach (@data[1..2])
+            {
+                $_ = $self->prepareDate($_);
+            }
             $self->{$borrowingsField}->addValues(@data);
             my $previous = $self->getAsHash;
             $self->{$borrowerField}->setValue('none');
@@ -1110,8 +1173,10 @@ use strict;
             my $new = $self->getAsHash;
             $self->{parent}->{itemsView}->changeCurrent($previous, $new, $self->{parent}->{items}->getCurrent, 1)
                 if $self->$coverField;
+            $isBack = 1;
         }
         $self->showMe;
+        return $isBack;
     }
     
     sub lock
@@ -1153,6 +1218,19 @@ use strict;
         }
    }
 
+    sub setBorrowers
+    {
+        my $self = shift;
+
+        return if ! $self->{borrowerControl};
+  
+        my $borrowers = $self->{model}->getValues($self->{model}->{commonFields}->{borrower}->{name});
+        shift @{$borrowers} if !$borrowers->[0]->{displayed};
+        $self->{borrowerControl}->setValues($borrowers);
+
+        return;
+    }
+
     sub sendBorrowerEmail
     {
         use GCDialogs;
@@ -1162,12 +1240,10 @@ use strict;
         my %info;
         $info{title} = $self->{$self->{model}->{commonFields}->{title}}->getValue;
         $info{borrower} = $self->{$self->{model}->{commonFields}->{borrower}->{name}}->getValue;
-        $info{lendDate} = $self->{$self->{model}->{commonFields}->{borrower}->{date}}->getValue;
+        $info{lendDate} = $self->prepareDate(
+            $self->{$self->{model}->{commonFields}->{borrower}->{date}}->getValue
+        );
         $self->{parent}->sendBorrowerEmail(\%info);
-#        my $dialog = new GCMailDialog($self->{parent}, \%info);
-#
-#        $dialog->show;
-#        $self->showMe;
     }
 
     sub selectTitle
@@ -1185,27 +1261,17 @@ use strict;
        $self->{parent}->deleteCurrentItem;
     }
 
-    sub setBorrowers
-    {
-        my $self = shift;
-
-        return if ! $self->{borrowerControl};
-  
-        my $borrowers = $self->{model}->getValues($self->{model}->{commonFields}->{borrower}->{name});
-        shift @{$borrowers} if !$borrowers->[0]->{displayed};
-        $self->{borrowerControl}->setValues($borrowers);
-
-        return;
-
-    }
-    
     sub createItem
     {
         my ($self, $info) = @_;
         
         my $widget;
         
-        if ($info->{type} eq 'short text')
+        if (exists $info->{linkedto})
+        {
+            $widget = new GCLinkedComponent($self->{$info->{linkedto}});
+        }
+        elsif ($info->{type} eq 'short text')
         {
             $widget = new GCShortText;
             $widget->signal_connect('activate', sub {
@@ -1274,27 +1340,36 @@ use strict;
 		}
         elsif ($info->{type} eq 'number')
         {
-            if ((exists $info->{min}) && ($info->{min} ne ''))
+            if (($info->{displayas} eq 'graphical')
+             && ($self->{parent}->{options}->useStars))
             {
-                $widget = new GCNumeric($info->{init}, 
-                                        $info->{min},
-                                        $info->{max},
-                                        $info->{step});
+                $widget = new GCNumeric($info->{init}, 0, $info->{max}, 0, 'graphical');
             }
             else
             {
-                $widget = new GCCheckedText('0-9.');
-                $widget->setReadOnly
-                    if ($info->{value} eq $self->{model}->{commonFields}->{id});
+                if ((exists $info->{min}) && ($info->{min} ne ''))
+                {
+                    $widget = new GCNumeric($info->{init}, 
+                                            $info->{min},
+                                            $info->{max},
+                                            $info->{step},
+                                            'text');
+                }
+                else
+                {
+                    $widget = new GCCheckedText('0-9.');
+                    $widget->setReadOnly
+                        if ($info->{value} eq $self->{model}->{commonFields}->{id});
+                }
+                $widget->signal_connect('activate', sub {
+                    $self->searchItem;
+                }) if $self->{model}->isSearchField($info->{value});
             }
-            $widget->signal_connect('activate', sub {
-                $self->searchItem;
-            }) if $self->{model}->isSearchField($info->{value});
         }
         elsif ($info->{type} eq 'image')
         {
             my $img = new GCItemImage($self->{parent}->{options}, 
-                                      $self->{model}->{defaultImage});
+                                      $self->{parent});
             my $isCover = 0;
             $isCover = 1 if $info->{value} eq $self->{model}->{commonFields}->{cover};
             #$img->setImmediate if $isCover;
@@ -1306,6 +1381,8 @@ use strict;
             {
                 $widget = new GCUrlButton($self->{model}->getDisplayedText($info->{label}),
                                           $self->{parent});
+                $info->{tip} = $self->{lang}->{PanelWebTip}
+                    if $info->{value} eq $self->{model}->{commonFields}->{url};
             }
             else
             {
@@ -1326,9 +1403,8 @@ use strict;
         }
         elsif ($info->{type} eq 'date')
         {
-            $widget = new GCDate($self, $self->{lang});
-            $widget->setFormat($self->{parent}->{options}->dateFormat)
-                if $self->{parent}->{options}->dateFormat;
+            $widget = new GCDate($self, $self->{lang}, 0,
+                                 $self->{parent}->{options}->dateFormat);
             push @{$self->{dateFields}}, $widget;
         }
         elsif ($info->{type} eq 'formatted')
@@ -1343,7 +1419,8 @@ use strict;
             $widget = 0;
         }
         
-         $self->{tooltips}->set_tip($widget, $self->{model}->getDisplayedText($info->{tip}), '')
+        $widget->{name} = $info->{value} if $widget;
+        $self->{tooltips}->set_tip($widget, $self->{model}->getDisplayedText($info->{tip}), '')
             if $info->{tip};
         $widget->activateStateTracking;
         return $widget;
@@ -1360,15 +1437,17 @@ use strict;
         return if our $AUTOLOAD =~ /::DESTROY$/;
         (my $name = $AUTOLOAD) =~ s/.*?::(.*)/$1/;
         return if !$name;
+        my $self = $_[0];
         no strict 'refs';
-        *{$AUTOLOAD} = sub {
-            my $self = shift;
-            return 0 if !$self->{$name};
-            return $self->{$name}->getValue
-                if !(scalar @_);
-            $self->{$name}->setValue(shift);
-            #$self->{$name}->resetChanged;
-        };
+        {
+            *{$AUTOLOAD} = sub {
+                my $self = shift;
+                return 0 if !$self->{$name};
+                return $self->{$name}->getValue
+                    if !(scalar @_);
+                $self->{$name}->setValue(shift);
+            };
+        }
         goto &{$AUTOLOAD};
     }
 }
