@@ -91,10 +91,12 @@ sub loadAllPlugins
         {
             my $self = shift;
             my $command = $self->{command};
+            my $info;
             while (1)
             {
-                my $info = fd_retrieve($command);
-                $self->beginSearch($info);
+                local $Storable::forgive_me = 1;
+                $info = fd_retrieve($command);
+                eval {$self->beginSearch($info)};
             }
         }
         
@@ -133,12 +135,17 @@ sub loadAllPlugins
                     $plugin->setCookieJar($info->{cookieJar});
                     $plugin->{type} = $info->{type};
                     $plugin->{urlField} = $info->{urlField};
+                    $plugin->{bigPics} = $info->{bigPics};
 
                     $self->{currentPlugin} = $plugin;
 
                     $plugin->{title} = $info->{query};
                     $plugin->{searchField} = $info->{field};
+                    $plugin->{pass} = $info->{pass};
+                    $plugin->{nextUrl} = $info->{nextUrl};
+
                     $plugin->load;
+                    local $Storable::forgive_me = 1;
                     store_fd $plugin, $self->{data};
                 }
                 elsif ($info->{type} ne 'exit')
@@ -537,9 +544,10 @@ sub loadAllPlugins
             my $self = shift;
             
             my @data;
+            my $langName = $self->{options}->lang;
             foreach (@{$self->{model}->getPluginsNames})
             {
-                push @data, $_ if $self->{model}->getPlugin($_)->getLang eq $self->{options}->lang;
+                push @data, $_ if $self->{model}->getPlugin($_)->getLang eq $langName;
             }
             $self->setListData(\@data);
         }
@@ -621,6 +629,7 @@ sub loadAllPlugins
         $self->SUPER::show();
         $self->show_all;
         $self->{nextButton}->hide if !$self->{withNext};
+        $self->{multipleSelectionLabel}->hide if ! $self->{multipleSelection};
         my $ended = 0;
         my $code;
         while (!$ended)
@@ -642,7 +651,7 @@ sub loadAllPlugins
                 my $itemIndex = $self->{items}->[$idx[0]]->{'#'};
                 $self->{parent}->getItemInfo($self->{plugin}, $itemIndex, 1);
             }
-            $ended = 1 if ($code eq 'ok') || ($code eq 'cancel') || ($code eq 'delete-event');
+            $ended = 1 if ($code eq 'ok') || ($code eq 'cancel') || ($code eq 'delete-event') || ($code eq 'no');
         }
         $self->hideTooltip;
         $self->hide;
@@ -660,6 +669,7 @@ sub loadAllPlugins
         my ($self, $activate) = @_;
         return if !$self->{results};
         $self->{results}->get_selection->set_mode ($activate ? 'multiple' : 'single');
+        $self->{multipleSelection} = $activate;
     }
 
     sub setWithNext
@@ -678,6 +688,9 @@ sub loadAllPlugins
  
         for my $i (0..$self->{nbCols} - 2)
         {
+            # If plugin is a multi-pass plugin, then update the column headers for this pass
+            $plugin->getReturnedFields() if $plugin->getNumberPasses > 1;
+
             $self->{results}->get_column($i)->set_visible($plugin->hasField($self->{fields}->[$i]));
         }
  
@@ -708,6 +721,7 @@ sub loadAllPlugins
         $self->{results} = 0;
         $self->{withExtra} = 0;
         $self->{withNext} = 0;
+        $self->{multipleSelection} = 0;
         $self->{nextButton} = Gtk2::Button->new_from_stock('gtk-go-forward');
         $parent->{tooltips}->set_tip($self->{nextButton},
                                      $parent->{lang}->{ResultsNextTip});
@@ -725,12 +739,12 @@ sub loadAllPlugins
         $self->vbox->pack_start($self->{scrollPanelList}, 1, 1, 0);
         $self->vbox->pack_start(Gtk2::HSeparator->new, 0, 0, 0);
         my $fillBox = new Gtk2::HBox(0,0);
-        my $label = GCLabel->new('<i>'.$parent->{lang}->{ResultsInfo}.'</i>');
-        $label->set_line_wrap(1);
-        $label->set_justify('center');
-        $label->set_padding($GCUtils::margin, 0);
+        $self->{multipleSelectionLabel} = GCLabel->new('<i>'.$parent->{lang}->{ResultsInfo}.'</i>');
+        $self->{multipleSelectionLabel}->set_line_wrap(1);
+        $self->{multipleSelectionLabel}->set_justify('center');
+        $self->{multipleSelectionLabel}->set_padding($GCUtils::margin, 0);
         $fillBox->pack_start(Gtk2::HBox->new(0,0),1,1,0);
-        $fillBox->pack_start($label, 0, 0, $GCUtils::margin);
+        $fillBox->pack_start($self->{multipleSelectionLabel}, 0, 0, $GCUtils::margin);
         $fillBox->pack_start(Gtk2::HBox->new(0,0),1,1,0);
         $self->vbox->pack_start($fillBox, 0 , 0, $GCUtils::margin);
          
