@@ -41,6 +41,7 @@ use utf8;
         my $self  = $class->SUPER::new();
 
         $ua->agent('Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.5) Gecko/20041111 Firefox/1.0');
+        $ua->default_header('Accept-Encoding' => 'x-gzip');
         $self->{ua} = $ua;
         
         $self->{itemIdx} = -1;
@@ -80,7 +81,21 @@ use utf8;
         $word =~ s/%20/+/g;
 
         my $post;
-        my $html = $self->loadPage($self->getSearchUrl($word));
+        my $html;
+
+        # For multi-pass plugins, the plugin will have set the url to load for 
+        # the next pass as nextUrl. If this doesn't exist, we're either on the 
+        # first pass, or only using a one-pass plugin, so call getSearchUrl
+        # to find the url to retrieve
+        if ($self->{nextUrl})
+        {
+            $html = $self->loadPage($self->{nextUrl});
+        }
+        else
+        {
+            $html = $self->loadPage($self->getSearchUrl($word));    
+        }
+
         $self->{parsingList} = 1;
         $html = $self->preProcess($html);
         decode_entities($html)
@@ -215,7 +230,6 @@ use utf8;
         my $idx = $self->{wantedIdx};
         my $url = $self->getItemUrl($self->{itemsList}[$idx]->{url});
         $self->loadUrl($url);
-
         return $self->{curInfo};
     }
         
@@ -258,7 +272,7 @@ use utf8;
                 $self->{curInfo}->{$_} =~ s/[ \t]*$//gm;
             }
         }
-        
+        $self->{curInfo}->{$self->{urlField}} .= $GCModel::linkNameSeparator.$self->getName;
         return $self->{curInfo};
     }
 
@@ -288,6 +302,13 @@ use utf8;
         $ua->cookie_jar(HTTP::Cookies::Netscape->new(
           'file' => "$self->{cookieJar}"));
     }
+
+    # Used to set the number of passes the plugin requires
+    sub getNumberPasses
+    {
+        # Most plugins only need to search once, so default to one pass
+        return 1;
+    }
 }
 
 1;
