@@ -45,7 +45,7 @@ use GCPlugins::GCPluginsBase;
     
     sub getSearchFieldsArray
     {
-        return ['title'];
+        return ['name'];
     }
 }
 
