@@ -339,11 +339,6 @@ use GCPlugins::GCbooks::GCbooksCommon;
         return "Alapage";
     }
     
-    sub getImageFile
-    {
-        return "alapage.png";
-    }
-
     sub getAuthor
     {
         return 'TPF';
