@@ -65,6 +65,11 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                 $self->{beginParsing} = 1
                     if $attr->{src} =~ /go-button-search/;
             }
+            elsif ($tagname eq 'select')
+            {
+                $self->{parsingEnded} = 1
+                    if $attr->{name} eq 'quantity';
+            }
             return if ! $self->{beginParsing};
             if ($tagname eq 'a')
             {
@@ -161,9 +166,10 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             $origtext =~ s/\s*$//;
             if ($self->{inside}->{title})
             {
-                $origtext =~ m/Amazon.com: (.*?): Books: (.*)$/;
-	            $self->{curInfo}->{title} = $1;
-	            $self->{curInfo}->{authors} = $2;
+                #$origtext =~ m/Amazon.com: (.*?): (.*)(: Books)?$/;
+                $origtext =~ m/Amazon.com\s*:\s*(.*?):\s*([^:]*)(:\s*Books)?\s*$/;
+                $self->{curInfo}->{title} = $1;
+                $self->{curInfo}->{authors} = $2;
             }
             elsif ($self->{insideDesc})
             {
