@@ -149,9 +149,9 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             $origtext =~ s/\s*$//;
             if ($self->{inside}->{title})
             {
-                $origtext =~ m/Amazon.de: (.*?): (B.+?cher|English Books): (.*)$/;
-	            $self->{curInfo}->{title} = $1;
-	            $self->{curInfo}->{authors} = $3;
+                $origtext =~ m/Amazon.de\s*:\s*(.*?):\s*([^:]*):\s*(B.+?cher|English Books)\s*$/;
+                $self->{curInfo}->{title} = $1;
+                $self->{curInfo}->{authors} = $2;
             }
             elsif ($self->{insideDesc})
             {
