@@ -1,4 +1,4 @@
-package GCPlugins::GCbooks::GCAmazonFR;
+﻿package GCPlugins::GCbooks::GCAmazonFR;
 
 ###################################################
 #
@@ -63,10 +63,22 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             if ($tagname eq 'input')
             {
                 $self->{beginParsing} = 1
-                    if $attr->{src} =~ /go-button-books/;
+                    if $attr->{src} =~ /go-button-search/;
             }
             return if ! $self->{beginParsing};
-            if ($tagname eq 'a')
+            if (($tagname eq 'div') && ($attr->{class} eq 'productTitle'))
+            {
+                $self->{isTitle} = 1 ;
+            }
+            elsif (($tagname eq 'span') && ($attr->{class} eq 'ptBrand'))
+            {
+                $self->{isAuthor} = 1 ;
+            }
+            elsif (($tagname eq 'span') && ($attr->{class} eq 'format'))
+            {
+                $self->{isFormat} = 1 ;
+            }
+            elsif ($tagname eq 'a')
             {
                 my $urlId;
                 if ($urlId = $self->isItemUrl($attr->{href}))
@@ -74,6 +86,7 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
 #                if (($attr->{href} =~ m|/dp/[A-Z0-9]*/sr=([0-3]-[0-9]*)/qid=[0-9]*|)
 #                 || ($attr->{href} =~ m|/dp/[A-Z0-9]*/ref=sr_([0-9_]*)/[0-9]*|))
                 {
+                    $self->{isTitle} = 2 if $self->{isTitle} eq '1';
                     return if $self->{alreadyRetrieved}->{$urlId};
                     $self->{alreadyRetrieved}->{$urlId} = 1;
                     $self->{currentRetrieved} = $urlId;
@@ -88,6 +101,11 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             if (($tagname eq "img") && (!$self->{curInfo}->{cover}))
             {
                 $self->{curInfo}->{cover} = $self->extractImage($attr);
+                $self->{curInfo}->{title} = $attr->{alt};
+            }
+            elsif (($tagname eq "a") && ($attr->{href} =~ m/field-author/i))
+            {
+                $self->{isAuthor} = 1 ;
             }
         }
     }
@@ -121,36 +139,38 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                 return;
             }
             return if ! $self->{beginParsing};
-            if ($self->{inside}->{srtitle})
+            if ($self->{isTitle} eq 2)
             {
-                return if length($origtext) < 2;
                 $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+                $self->{isTitle} = 0;
                 return;
             }
-            elsif ($self->{inside}->{author})
+            elsif ($self->{isAuthor})
             {
-                $origtext =~ s/by //;
+                $origtext =~ s/par //;
                 $self->{itemsList}[$self->{itemIdx}]->{authors} = $origtext
                     if ! $self->{itemsList}[$self->{itemIdx}]->{authors};
+                $self->{isAuthor} = 0;
             }
             elsif ($self->{inside}->{publication})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{publication} = $origtext;
             }
-            elsif ($self->{inside}->{format})
+            elsif ($self->{isFormat})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{format} = $origtext;
+                $self->{isFormat} = 0;
             }
         }
        	else
         {
             $origtext =~ s/^\s*//;
             $origtext =~ s/\s*$//;
-            if ($self->{inside}->{title})
+            if ($self->{isAuthor})
             {
-                $origtext =~ m/Amazon.fr\s*:\s*(.*?):\s*Livres( en anglais)?:?\s*(.*)\s*$/;
-	            $self->{curInfo}->{title} = $1;
-	            $self->{curInfo}->{authors} = $3;
+                $self->{curInfo}->{authors} .= $origtext;
+                $self->{curInfo}->{authors} .= ",";
+                $self->{isAuthor} = 0 ;
             }
             elsif ($self->{insideDesc})
             {
@@ -281,6 +301,9 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
 
         $self->{curName} = undef;
         $self->{curUrl} = undef;
+        $self->{isTitle} = 0;
+        $self->{isAuthor} = 0;
+        $self->{isFormat} = 0;
 
         $self->{suffix} = 'fr';
 
@@ -295,12 +318,18 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
         $html =~ s/&nbsp;/ /gi;
         $html =~ s/&#146;/'/gm;
         $html =~ s/&#133;/.../gm;
-        $html =~ s/&#156;/œ/gm;
+        $html =~ s/&#156;/oe/gm;
+        $html =~ s|&#x92;|'|gi;
+        $html =~ s|&#149;|*|gi;
+        $html =~ s|&#133;|...|gi;
+        $html =~ s|&#x85;|...|gi;
+        $html =~ s|&#x8C;|OE|gi;
+        $html =~ s|&#x9C;|oe|gi;
+
         $self->{parsingEnded} = 0;
         if ($self->{parsingList})
         {
-            $html =~ s|^\s+par(.*)$|<author>$1</author>|gm;
-            $html =~ s|<span class="bindingBlock">\(<span class="binding">(.*?)</span> - (.*?[0-9]{4})\)</span>|<format>$1</format><publication>$2</publication>|gsm;
+            $html =~ s|<span class="binding">(.*?)</span> - (.*?[0-9]{4})\)</span>|<format>$1</format><publication>$2</publication>|gsm;
             $self->{parsingEnded} = 1
                 if $html !~ /<title>/;
         }
