@@ -60,7 +60,11 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
 
         if ($self->{parsingList})
         {
-            if ($tagname eq 'input')
+            if (($tagname eq 'meta') && ($attr->{name} eq 'keywords'))
+            {
+                $self->{parsingEnded} = 1;
+            }
+            elsif ($tagname eq 'input')
             {
                 $self->{beginParsing} = 1
                     if $attr->{src} =~ /go-button-search/;
@@ -147,9 +151,9 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             $origtext =~ s/\s*$//;
             if ($self->{inside}->{title})
             {
-                $origtext =~ m/Amazon.co.uk: (.*?): Books: (.*)$/;
-	            $self->{curInfo}->{title} = $1;
-	            $self->{curInfo}->{authors} = $2;
+                $origtext =~ m/Amazon.co.uk\s*:\s*(.*?):\s*([^:]*)(:\s*Books)?\s*$/;
+                $self->{curInfo}->{title} = $1;
+                $self->{curInfo}->{authors} = $2;
             }
             elsif ($self->{insideDesc})
             {
