@@ -400,11 +400,6 @@ use GCPlugins::GCbooks::GCbooksCommon;
         return "Casadelibro";
     }
     
-    sub getImageFile
-    {
-        return "Casadelibro.png";
-    }
-
     sub getAuthor
     {
         return 'TPF';
