@@ -291,11 +291,6 @@ use GCPlugins::GCbooks::GCbooksCommon;
         return "Adlibris";
     }
     
-    sub getImageFile
-    {
-        return "adlibris.png";
-    }
-
     sub getAuthor
     {
         return 'TPF';
