@@ -66,6 +66,12 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                     $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
                 }
             }
+            elsif ($tagname eq 'div')
+            {
+                $self->{inside}->{actors} = 2 if $attr->{class} eq 'binding';
+                $self->{inside}->{srtitle} = 2 if $attr->{class} eq 'productTitle';
+            }
+            
         }
         else
         {
@@ -73,10 +79,10 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
             {
                 if ($self->{insideAge})
                 {
-                    $self->{curInfo}->{age} = 18 if $attr->{alt} eq 'R';
-                    $self->{curInfo}->{age} = 13 if $attr->{alt} =~ /PG\-13/;
-                    $self->{curInfo}->{age} = 5 if $attr->{alt} eq 'PG';
-                    $self->{curInfo}->{age} = 2 if $attr->{alt} eq 'G';
+                    $self->{curInfo}->{age} = 18 if ($attr->{alt} eq 'R') || ($attr->{src} =~ m|G/01/detail/r|);
+                    $self->{curInfo}->{age} = 13 if ($attr->{alt} =~ /PG\-13/) || ($attr->{src} =~ m|G/01/detail/pg-13|);
+                    $self->{curInfo}->{age} = 5 if ($attr->{alt} eq 'PG') || ($attr->{src} =~ m|G/01/detail/pg\.|);
+                    $self->{curInfo}->{age} = 2 if ($attr->{alt} eq 'G') || ($attr->{src} =~ m|G/01/detail/g|);
                     $self->{insideAge} = 0;
                 }
                 if (!$self->{curInfo}->{image})
@@ -86,7 +92,7 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
             }
             elsif ($tagname eq "b")
             {
-            	$self->{insideNameAndDate} = 1 if $attr->{class} eq "sans";
+            	$self->{insideNameAndDate} = 1 if $attr->{class} eq "asinTitle";
             }
         }
     }
@@ -106,12 +112,6 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
 
         if ($self->{parsingList})
         {
-            if (($self->{inside}->{title})
-            && ($origtext !~ /Amazon.com.? DVD Search Results/)
-            && ($origtext !~ /Amazon.com:?\s+.*?DVD$/))
-            {
-                $self->{parsingEnded} = 1;
-            }
             if (
                 (($self->{inside}->{b})
                 || ($self->{inside}->{span}))            
@@ -121,15 +121,18 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                 return;
             }
             return if ! $self->{beginParsing};
-            if ($self->{inside}->{srtitle})
-            {
-                $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
-                return;
-            }
-            elsif ($self->{inside}->{actors})
+            if ($self->{inside}->{actors})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{actors} = $origtext
                     if ! $self->{itemsList}[$self->{itemIdx}]->{actors};
+                $self->{inside}->{actors} = 0 if $self->{inside}->{actors} == 2;
+                return;
+            }
+            elsif ($self->{inside}->{srtitle})
+            {
+                $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+                $self->{inside}->{srtitle} = 0 if $self->{inside}->{srtitle} == 2;
+                return;
             }
         }
        	else
@@ -149,6 +152,7 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
             {
                 $origtext =~ s/^\s//;
                 $origtext =~ s/,.$//;
+                $origtext =~ s/\s+,/,/;
                 $self->{curInfo}->{actors} = $origtext;
                 $self->{insideActors} = 0;
             }
@@ -223,6 +227,7 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
             $html =~ s|([^>])</li>|$1\n|gim;
             $html =~ s|<br ?/?>|\n|gi;
             $html =~ s|<a href="/gp/imdb/[^"]*">(.*?)</a>|$1|gm;
+            $html =~ s|<a href="[^"]*search-alias=dvd&field-keywords=[^"]*">(.*?)</a>|$1|gm;
             #"
         }
 
