@@ -67,6 +67,11 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                     $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
                 }
             }
+            elsif ($tagname eq 'div')
+            {
+                $self->{inside}->{actors} = 2 if $attr->{class} eq 'binding';
+                $self->{inside}->{srtitle} = 2 if $attr->{class} eq 'productTitle';
+            }
         }
         else
         {
@@ -100,12 +105,12 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
 
         if ($self->{parsingList})
         {
-            if (($self->{inside}->{title})
-            && ($origtext !~ /Amazon.de.? DVD Search Results/)
-            && ($origtext !~ /Amazon.de:?\s+.*?DVD$/))
-            {
-                $self->{parsingEnded} = 1;
-            }
+#            if (($self->{inside}->{title})
+#            && ($origtext !~ /Amazon.de.? DVD Search Results/)
+#            && ($origtext !~ /Amazon.de:?\s+.*?DVD$/))
+#            {
+#                $self->{parsingEnded} = 1;
+#            }
             if (
                 (($self->{inside}->{b})
                 || ($self->{inside}->{span}))            
@@ -115,20 +120,18 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                 return;
             }
             return if ! $self->{beginParsing};
-            if ($self->{inside}->{srtitle})
-            {
-                $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
-                return;
-            }
-            elsif ($self->{inside}->{actors})
+            if ($self->{inside}->{actors})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{actors} = $origtext
                     if ! $self->{itemsList}[$self->{itemIdx}]->{actors};
+                $self->{inside}->{actors} = 0 if $self->{inside}->{actors} == 2;
+                return;
             }
-            elsif ($self->{inside}->{director})
+            elsif ($self->{inside}->{srtitle})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{director} = $origtext
-                    if ! $self->{itemsList}[$self->{itemIdx}]->{director};
+                $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+                $self->{inside}->{srtitle} = 0 if $self->{inside}->{srtitle} == 2;
+                return;
             }
         }
        	else
@@ -208,7 +211,6 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
     sub preProcess
     {
         my ($self, $html) = @_;
-
         $html = $self->SUPER::preProcess($html);
         if ($self->{parsingList})
         {
@@ -217,18 +219,21 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
         else
         {
             $html =~ s/(<i>|<\/i>)//gim;
+            $html =~ s/<p>/\n/gim;
+            $html =~ s|</p>|\n|gim;
             $html =~ s/(<ul>|<\/ul>)/\n/gim;
             $html =~ s/<li>([^<])/- $1/gim;
             $html =~ s|([^>])</li>|$1\n|gim;
             $html =~ s|<br ?/?>|\n|gi;
             $html =~ s|<a href="/gp/imdb/[^"]*">(.*?)</a>|$1|gm;
+            $html =~ s|<a href="[^"]*search-alias=dvd&field-keywords=[^"]*">(.*?)</a>|$1|gm;
             #"
             $html =~ s/<a href="\/exec\/obidos\/search-handle-url\/index=dvd-de&field-(?:actor|director|keywords)=[^\/]*\/[-0-9]*">([^<]*)<\/a>/$1/gm;
         }
 
         $self->{parsingEnded} = 0;
         $self->{alreadyRetrieved} = {};
-        $self->{beginParsing} = 0;
+        $self->{beginParsing} = 1;
 
         return $html;
     }
