@@ -64,6 +64,11 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                     $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
                 }
             }
+            elsif ($tagname eq 'div')
+            {
+#                $self->{inside}->{actors} = 2 if $attr->{class} eq 'binding';
+                $self->{inside}->{srtitle} = 2 if $attr->{class} eq 'productTitle';
+            }
         }
         else
         {
@@ -78,6 +83,10 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
             {
             	$self->{insideNameAndDate} = 1 if $attr->{class} eq "sans";
             }
+            elsif (($tagname eq "span") && ($attr->{id} eq "btAsinTitle"))
+            {
+            	$self->{insideNameAndDate} = 1 ;
+            }
         }
     }
 
@@ -114,6 +123,7 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
             if ($self->{inside}->{srtitle})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+                $self->{inside}->{srtitle} = 0 if $self->{inside}->{srtitle} == 2;
                 return;
             }
 #            if ($self->{isMovie})
@@ -162,17 +172,42 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                 $self->{curInfo}->{time} = $origtext;
                 $self->{insideTime} = 0;
             }
+            elsif ($self->{insideDate})
+            {
+                $origtext =~ s/^\s//;
+                $origtext =~ s/\n//g;
+                $self->{curInfo}->{date} = $origtext;
+                $self->{insideDate} = 0;
+            }
             elsif ($self->{insideSynopsis})
             {
-                $self->{curInfo}->{synopsis} = $origtext;
+                $self->{curInfo}->{synopsis} .= "\n" . $origtext;
                 $self->{insideSynopsis} = 0;
             }
+            elsif ($self->{insideAudio})
+            {
+                $origtext =~ s/^\s//;
+                $self->{curInfo}->{audio} = $origtext;
+                $self->{insideAudio} = 0;
+            }
+            elsif ($self->{insideSubTitle})
+            {
+                $origtext =~ s/^\s//;
+                $self->{curInfo}->{subt} = $origtext;
+                $self->{insideSubTitle} = 0;
+            }
             elsif ($self->{inside}->{b})
             {
                 $self->{insideActors} = 1 if $origtext =~ /Acteurs\s*:/;
-				$self->{insideDirector} = 1 if $origtext =~ /R.alisateurs?\s*:/;
-    			$self->{insideSynopsis} = 1 if $origtext =~ /Description/;
-			}        
+                $self->{insideDirector} = 1 if $origtext =~ /R.alisateurs?\s*:/;
+                $self->{insideDate} = 1 if $origtext =~ /Date de sortie/;
+                $self->{insideTime} = 1 if $origtext =~ /Dur.e\s*:/;
+                $self->{insideSynopsis} = 1 if $origtext =~ /Description/;
+                $self->{insideSynopsis} = 1 if $origtext =~ /Synopsis/;
+                $self->{insideSynopsis} = 1 if $origtext =~ /Fiches du cin.ma/;
+                $self->{insideAudio} = 1 if $origtext =~ /Langue\s*:/;
+                $self->{insideSubTitle} = 1 if $origtext =~ /Sous-titres\s*:/;
+            }        
         }
     } 
 
@@ -192,8 +227,6 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
 
         $self->{suffix} = 'fr';
 
-        $self->{alreadyRetrieved} = {};
-        $self->{beginParsing} = 0;
 
         return $self;
     }
@@ -205,7 +238,8 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
         $html = $self->SUPER::preProcess($html);
         if ($self->{parsingList})
         {
-            $html =~ s|^\s+par\s+([^,]*),?\s*(.*)$|<director>$1</director><actors>$2</actors>|gm;
+            $html =~ s|~|par|gim;
+            $html =~ s|> par (.*)$|><actors>$1</actors>|gm;
         }
         else
         {
@@ -217,10 +251,15 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
             $html =~ s|([^>])</li>|$1\n|gim;
             $html =~ s|<br ?/?>|\n|gi;
             $html =~ s|<a href="/gp/imdb/[^"]*">(.*?)</a>|$1|gm;
-            $html =~ s/<a href="\/exec\/obidos\/search-handle-url\/index=dvd-fr&field-(?:actor|director|keywords)=[^\/]*\/[-0-9]*">([^<]*)<\/a>/$1/gm;
+#            $html =~ s/<a href="\/exec\/obidos\/search-handle-url\/index=dvd-fr&field-(?:actor|director|keywords)=[^\/]*\/[-0-9]*">([^<]*)<\/a>/$1/gm;
+            $html =~ s/<a href="\/exec\/obidos\/search-handle-url\/index=dvd-fr&field-(?:actor|director|keywords)=[^\/]*">([^<]*)<\/a>/$1/gm;
             #"
         }
 
+        $self->{parsingEnded} = 0;
+        $self->{alreadyRetrieved} = {};
+        $self->{beginParsing} = 1;
+
         return $html;
     }
     
