@@ -74,6 +74,10 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                  && ($attr->{width} == 150))
                 {
                     $self->{curInfo}->{image} = $attr->{src};
+                    if ($self->{bigPics})
+                    {
+                        $self->{curInfo}->{image} =~ s/\/h200\//\//;
+                    }
                 }
             }
             elsif ($tagname eq 'font')
@@ -136,13 +140,15 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         }
         else
         {
-            if ($self->{inside}->{h1})
+            if ($self->{inside}->{h1}
+            && !$self->{curInfo}->{title})
             {
                 $self->{curInfo}->{title} = $origtext;
             }
-            elsif ($self->{insideOrig})
+            elsif ($self->{inside}->{h2} || $self->{insideOrig})
             {
-                $self->{curInfo}->{original} = $origtext;
+                $self->{curInfo}->{original} = $origtext
+                    if !$self->{curInfo}->{original};
                 $self->{insideOrig} = 0;
             }
             if ($self->{insideInfos})
@@ -162,13 +168,19 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($self->{insideArtists})
             {
-                if ($origtext =~ /R.alisation : (.*)/)
+                print "Testing $origtext\n";
+                if ($origtext =~ /R.alisation\s*:\s*(.*)/)
                 {
+                    print "Saving director $1\n";
                     $self->{curInfo}->{director} = $1 if !$self->{curInfo}->{director};
                 }
                 elsif ($origtext =~ /avec\s*:?\s*(.*)/i)
                 {
-                    $self->{curInfo}->{actors} = $1 if !$self->{curInfo}->{actors};
+                    if (!$self->{curInfo}->{actors})
+                    {
+                        $self->{curInfo}->{actors} = $1;
+                        $self->{curInfo}->{actors} =~ s/\s*\(([^\)]*)\)\s*/;$1/g;
+                    }
                 }
                 $self->{insideArtists} = 0;
             }
@@ -212,6 +224,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         $html =~ s|<A HREF="/modules/Artistes/fiche/[0-9]*[^>]*>(.*?)</A>|$1|gi;
         $html =~ s/<font class=link_news_2>([^<]*)<\/font>/$1/gi;
         $html =~ s/<font class=link4dtext>([^<]*)<br>([^<]*)<\/TD>/<font class=link4dtext>$1 $2<\/font><\/TD>/gi;
+        $html =~ s|<h1>Oops\!</h1>||gi;
 
         return $html;
     }
