@@ -79,7 +79,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 if ($attr->{src} =~ /^\/imgs\/countries/)
                 {
-                    $self->{curInfo}->{country} = $attr->{alt};
+                    $self->{curInfo}->{country} = $attr->{title};
                 }
                 elsif ($attr->{src} =~ /filmaffinity\.com\/imgs\/movies\/full/)
                 {
