@@ -79,7 +79,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 if ($attr->{src} =~ /^\/imgs\/countries/)
                 {
-                    $self->{curInfo}->{country} = $attr->{alt};
+                    $self->{curInfo}->{country} = $attr->{title};
                 }
                 elsif ($attr->{src} =~ /filmaffinity\.com\/imgs\/movies\/full/)
                 {
@@ -121,7 +121,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 }
                 return;
             }
-            if ($self->{inside}->{title} && ($origtext !~ /^Busqueda de /))
+            if ($self->{inside}->{title} && ($origtext !~ /^Búsqueda /))
             {
                 $self->{parsingEnded} = 1;
                 $self->{hasUrl} = 0;
