@@ -64,16 +64,14 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             if ($tagname eq 'div')
             { 
                 $self->{isTitle} = 1
-                    if ($attr->{id} eq 'filmTitle');
+                    if ($attr->{class} eq 'film-title');
                 $self->{isImage} = 1
-                    if ($attr->{id} eq 'filmPhoto');
-                $self->{isActors} = 1
-                    if ($attr->{class} eq 'filmActor');
+                    if ($attr->{class} eq 'film-poster');
             }
             elsif ($tagname eq 'span')
             {
                 $self->{isOrig} = 1
-                    if (($attr->{class} eq 'otherTitle') && !$self->{curInfo}->{original});
+                    if (($attr->{class} eq 'aka')); 
             }
             elsif ($tagname eq 'a')
             {
@@ -93,16 +91,17 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($tagname eq 'td')
             {
-                $self->{isPreDate} = 1
-                    if ($attr->{class} eq 'gr3');
+                $self->{isActors} = 1
+                    if ($attr->{class} eq 'film-actor');
+                $self->{isRoles} = 1
+                    if ($attr->{class} eq 'film-protagonist');
             }
-            elsif ($tagname eq 'b')
+            elsif ($tagname eq 'strong')
             {
-                if ($self->{isPreDate})
-                {
+		if ($self->{isPreDate}) { 
                     $self->{isDate} = 1;
-                    $self->{isPreDate} = 0;
-                }
+ 		    $self->{isPreDate} = 0;
+ 		}
             }
             elsif ($tagname eq 'img')
             {
@@ -112,6 +111,11 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                     $self->{isImage} = 0;
                 }
             }
+	    elsif ($tagname eq 'p')
+	    {
+                $self->{isPreDate} = 1
+                    if ($attr->{class} eq 'film-premieres');
+            }
         }
     }
 
@@ -197,20 +201,24 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 $origtext =~ m/re.yseria\s*(.+?)\s*scenariusz/gms;
                 $self->{curInfo}->{director} = $1;
                 $self->{curInfo}->{director} =~ s/\s+/ /g;
-                
-                $origtext =~ m/od lat: ([0-9]*)/;
-                $self->{curInfo}->{age} = $1;
-
                 $origtext =~ m/czas trwania: ([0-9]*)/;
                 $self->{curInfo}->{time} = $1;
             }
             elsif ($self->{isActors})
             {
-                $self->{curInfo}->{actors} .= $self->{curInfo}->{actors} ? ", " . $origtext : $origtext
-                    if ($self->{actorsCounter} < $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS);
-                $self->{actorsCounter}++;
+                if ($self->{actorsCounter} < $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS) {
+                  push @{$self->{curInfo}->{actors}}, [$origtext];
+                  $self->{actorsCounter}++;
+                }
                 $self->{isActors} = 0;
             }            
+            elsif ($self->{isRoles})
+            {
+               push @{$self->{curInfo}->{actors}->[$self->{actorsCounter} - 1]}, $origtext
+                   if ($self->{actorsCounter} <= $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS);
+                $self->{isRoles} = 0;
+            }
+
         }
     } 
 
@@ -232,7 +240,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         $self->{isMovie} = 0;
         $self->{curName} = undef;
         $self->{curUrl} = undef;
-
+        
         return $self;
     }
 
@@ -242,7 +250,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 
         $self->{parsingEnded} = 0;
         $self->{insideResults} = 0;
-        $self->{actorsCounter} = 0;
 
         if ($self->{parsingList})
         {
@@ -250,14 +257,13 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         }
         else
         {
-            $html =~ s|<div style="margin: 0px 15px 5px 15px; font-family: Verdana, Geneva, Arial, Helvetica, sans-serif; font-size: 11px;">(.*?)</div>|<details>$1</details></div>|gms;
-            #$html =~ s|<\!-- z backup -->(.*?)</div>|<details>$1</details></div>|gms;
+            $html =~ s|<p class="film-info">(.*?)</p>|<details>$1</details></p>|gms;
             my $details = $1;
             $details =~ s|<a[^>]*>([^<]*)</a>|$1|gms;
+            $details =~ s|<abbr[^>]*>([^<]*)</abbr>|$1|gms;
             $html =~ s|<details>(.*?)</details>|<details>$details</details>|gms;
+            
         }
-        $html =~ s|<span style='color: #8D0000;'>(.*?)</span>|$1|gm;
-        $html =~ s|<span style="font-size: 15px">(.*?)</span>|$1|gm;
 
         return $html;
     }
@@ -265,7 +271,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     sub getSearchUrl
     {
 		my ($self, $word) = @_;
-	
         return "http://www.filmweb.pl/szukaj?q=$word&c=film"
     }
     
@@ -293,7 +298,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my $self = shift;
     
-        #return "UTF-8";
         return "ISO-8859-2";
     }
 
