@@ -1,4 +1,4 @@
-coripackage GCPlugins::GCfilms::GCMoviecovers;
+package GCPlugins::GCfilms::GCMoviecovers;
 
 ###################################################
 #
@@ -224,11 +224,6 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         return "MovieCovers.com";
     }
     
-    sub getImageFile
-    {
-        return "";
-    }
-
     sub getAuthor
     {
         return 'Patrick Fratczak';
