@@ -25,7 +25,6 @@ package GCPlugins::GCfilms::GCOFDb;
 use strict;
 use utf8;
 
-use GCPlugins::GCfilms::GCfilmsCommon;
 use GCPlugins::GCfilms::GCfilmsCommon;
 
 {
@@ -43,12 +42,13 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($tagname eq "a")
             {
-                if ($attr->{href} =~ m/view\.php\?page=film&fid=[0-9]*/)
+                if (($attr->{href} =~ m/view\.php\?page=film&fid=[0-9]*/)
+                 || ($attr->{href} =~ m|^film/[0-9]*|))
                 {
                     $self->{isMovie} = 1;
-              		$self->{isInfo} = 1;
-              		$self->{itemIdx}++;
-              		$self->{itemsList}[$self->{itemIdx}]->{url} = $attr->{href};
+                    $self->{isInfo} = 1;
+                    $self->{itemIdx}++;
+                    $self->{itemsList}[$self->{itemIdx}]->{url} = $attr->{href};
                 }
             }
             elsif ($tagname eq "div")
@@ -63,52 +63,53 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($tagname eq "font")
             {
-							if ($attr->{face} eq "Arial,Helvetica,sans-serif")
-							{
-									if ($attr->{size} eq "3")
-									{
-	              		$self->{insideName} = 1;
-									}
-									elsif ($attr->{size} eq "2")
-									{
-										$self->{insideInfosNames} = 1 if $attr->{class} eq "Normal";
-										$self->{insideInfos} = 1 if $attr->{class} eq "Daten";
-									}
-							}
-						}
-						elsif (($tagname eq "img") && ($attr->{src} =~ m/^images\/film\/[0-9]+\/[0-9]*.jpg/))
-						{
-							$self->{curInfo}->{image} = 'http://www.ofdb.de/' . $attr->{src};
-						}
-						elsif ($tagname eq "a")
-						{
-                            if ($attr->{href} =~ m/view\.php\?page=blaettern&Kat=Land&Text=(.*)/)
-                            {
-                                my $country = GCUtils::urlDecode($1);
-                                $self->{curInfo}->{country} .= ', ' if $self->{curInfo}->{country};
-                                $self->{curInfo}->{country} .= $country; 
-                            }
-							$self->{curInfo}->{date} = $1
-    							if ($attr->{href} =~ m/view\.php\?page=blaettern&Kat=Jahr&Text=([0-9]{4})/);
-						}
-						elsif (($tagname eq "div") && ($attr->{class} eq "synopsis"))
-						{
-							$self->{insideSynopsis} = 1;
-						}
+                if ($attr->{face} eq "Arial,Helvetica,sans-serif")
+                {
+                    if ($attr->{size} eq "3")
+                    {
+                        $self->{insideName} = 1;
+                    }
+                    elsif ($attr->{size} eq "2")
+                    {
+                        $self->{insideInfosNames} = 1 if $attr->{class} eq "Normal";
+                        $self->{insideInfos} = 1 if $attr->{class} eq "Daten";
+                    }
+                }
+            }
+            elsif (($tagname eq "img") && ($attr->{src} =~ m|img\.ofdb\.de/film/[0-9]+/[0-9]*.jpg|))
+            {
+                $self->{curInfo}->{image} = $attr->{src}
+                    if ! $self->{curInfo}->{image};
+            }
+            elsif ($tagname eq "a")
+            {
+                if ($attr->{href} =~ m/view\.php\?page=blaettern&Kat=Land&Text=(.*)/)
+                {
+                    my $country = GCUtils::urlDecode($1);
+                    $self->{curInfo}->{country} .= ', ' if $self->{curInfo}->{country};
+                    $self->{curInfo}->{country} .= $country; 
+                }
+                $self->{curInfo}->{date} = $1
+                    if ($attr->{href} =~ m/view\.php\?page=blaettern&Kat=Jahr&Text=([0-9]{4})/);
+            }
+            elsif (($tagname eq "div") && ($attr->{class} eq "synopsis"))
+            {
+                $self->{insideSynopsis} = 1;
+            }
         }
     }
 
     sub end
     {
-		my ($self, $tagname) = @_;
-
-				if ($tagname eq "tr")
-				{
-					$self->{insideDirector} = 0;
-					$self->{insideActors} = 0;
-					$self->{insideGenre} = 0;
-					$self->{insideInfos} = 0;
-				}
+        my ($self, $tagname) = @_;
+        
+        if ($tagname eq "tr")
+        {
+            $self->{insideDirector} = 0;
+            $self->{insideActors} = 0;
+            $self->{insideGenre} = 0;
+            $self->{insideInfos} = 0;
+        }
 
         $self->{inside}->{$tagname}--;
     }
@@ -128,11 +129,11 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 $self->{isInfo} = 1;
                 return;
             }
-						elsif ($self->{isYear})
-						{
-								$self->{itemsList}[$self->{itemIdx}]->{"year"} = $origtext;
-								$self->{isYear} = 0;
-						}
+            elsif ($self->{isYear})
+            {
+                $self->{itemsList}[$self->{itemIdx}]->{"year"} = $origtext;
+                $self->{isYear} = 0;
+            }
         }
         else
         {
@@ -182,7 +183,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 $origtext =~ m/(http.*?)(\s|$)/;
                 my $page = $self->loadPage($1);
-                $page =~ m/<font face="Arial,Helvetica,sans-serif" size="2" class="Blocksatz">.*?<\/a><\/b><br><br>(.*?)<\/font>/ms;
+                $page =~ m|<font face="Arial,Helvetica,sans-serif" size="2" class="Blocksatz">.*?</a><br>[^<]*</b>(?:</b>)?<br><br>(.*?)</font>|ms;
                 $self->{curInfo}->{synopsis} = $1;
                 $self->{curInfo}->{synopsis} =~ s/<br \/>/<br>/gi;
                 $self->{curInfo}->{synopsis} =~ s/\n//gm;
@@ -217,10 +218,18 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my ($self, $html) = @_;
        
+        if ($self->{parsingList})
+        {
+            $html =~ s|<font\s*size="\d+">([^<]*)</font>|$1|gms;
+            $html =~ s|onmouseover="[^"]*"||gms;
+            #"
+        }
         $html =~ s/[0-9]*\. (<a href='view\.php\?page=film&fid=[0-9]*'>[^<]*)<font size='1'> \/ [^<]*<\/font> \(([0-9]{4})\)<\/a><br>/$1<\/a><div class="year">$2<\/div>/g;
         $html =~ s/<a href="view\.php\?page=liste&Name=[^"]*">([^<]*)<\/a>/$1/g;
         $html =~ s/<a href="view\.php\?page=genre&Genre=[^"]*">([^<]*)<\/a>/$1/g;
         $html =~ s/<font face="Arial,Helvetica,sans-serif" size="2" class="Blocksatz"><p class="Blocksatz"><b>Inhalt:<\/b>\s?([^<]*)<a href="(view\.php\?page=inhalt&fid=[0-9]*&sid=[0-9]*)">\s?<b>\[mehr\]<\/b><\/a><\/p><\/font>/<div class="synopsis">$1\nhttp:\/\/www.ofdb.de\/$2<\/div>/;
+        $html =~ s|<font face="Arial,Helvetica,sans-serif" size="2" class="Blocksatz"><p\s*class="Blocksatz"><b>Inhalt:</b>\s?([^<]*)<a href="(plot/[0-9]*[^"]*)">\s?<b>\[mehr\]</b></a></p></font>|<div class="synopsis">$1\nhttp://www.ofdb.de/$2</div>|gm;
+        #"
         $html =~ s/%DF/ss/;
 
         return $html;
@@ -228,14 +237,14 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     
     sub getSearchUrl
     {
-		my ($self, $word) = @_;
+        my ($self, $word) = @_;
 	
         return "http://www.ofdb.de/view.php?page=suchergebnis&Kat=DTitel&SText=$word";
     }
     
     sub getItemUrl
     {
-		my ($self, $url) = @_;
+        my ($self, $url) = @_;
 		
         return 'http://www.ofdb.de/' . $url;
     }
