@@ -87,9 +87,11 @@ use GCPlugins::GCgames::GCgamesAmazonCommon;
             $html =~ s|<li>|\n*|gi;
             $html =~ s|<br>|\n|gi;
             $html =~ s|<br />|\n|gi;
+            $html =~ s|\x{92}|'|gi;
             $html =~ s|&#146;|'|gi;
             $html =~ s|&#149;|*|gi;
             $html =~ s|&#133;|...|gi;
+            $html =~ s|\x{85}|...|gi;
             $html =~ s|\x{8C}|OE|gi;
             $html =~ s|\x{9C}|oe|gi;
 
