@@ -53,8 +53,8 @@ use GCPlugins::GCgames::GCgamesAmazonCommon;
         }
         else
         {
-            $html =~ s/>Description du produit</><tpfdescription><\/tpfdescription></g;
-            $html =~ s/>Descriptions du produit</><tpfdescription><\/tpfdescription></g;
+            $html =~ s/>Description du produit</><tpfdescription><\/tpfdescription></;
+            $html =~ s/>Descriptions du produit</><tpfdescription><\/tpfdescription></;
             # Le descriptif pouvant contenir des balises html je le repere maintenant
             my $found = index($html,"<tpfdescription>");
             if ( $found >= 0 )
@@ -88,9 +88,12 @@ use GCPlugins::GCgames::GCgamesAmazonCommon;
             $html =~ s|<li>|*|gi;
             $html =~ s|<br>|\n|gi;
             $html =~ s|<br />|\n|gi;
+            $html =~ s|\x{92}|'|gi;
             $html =~ s|&#146;|'|gi;
             $html =~ s|&#149;|*|gi;
+            $html =~ s|&#156;|oe|gi;
             $html =~ s|&#133;|...|gi;
+            $html =~ s|\x{85}|...|gi;
             $html =~ s|\x{8C}|OE|gi;
             $html =~ s|\x{9C}|oe|gi;
             # Bug sur Shadow of Memories pour PS2
