@@ -53,7 +53,8 @@ use GCPlugins::GCgames::GCgamesAmazonCommon;
         }
         else
         {
-            $html =~ s/>Reviews</><tpfdescription><\/tpfdescription></g;
+            $html =~ s/>Product Description</><tpfdescription><\/tpfdescription></;
+            $html =~ s/>Reviews</><tpfdescription><\/tpfdescription></;
             # Le descriptif pouvant contenir des balises html je le repere maintenant
             my $found = index($html,"<tpfdescription>");
             if ( $found >= 0 )
@@ -87,9 +88,11 @@ use GCPlugins::GCgames::GCgamesAmazonCommon;
             $html =~ s|<li>|*|gi;
             $html =~ s|<br>|\n|gi;
             $html =~ s|<br />|\n|gi;
+            $html =~ s|\x{92}|'|gi;
             $html =~ s|&#146;|'|gi;
             $html =~ s|&#149;|*|gi;
             $html =~ s|&#133;|...|gi;
+            $html =~ s|\x{85}|...|gi;
             $html =~ s|\x{8C}|OE|gi;
             $html =~ s|\x{9C}|oe|gi;
 
