@@ -43,9 +43,11 @@ use GCPlugins::GCgames::GCgamesCommon;
             if ($tagname eq 'div')
             {
                 $self->{isGame} = 1
-                    if $attr->{class} =~ /f18$/;
-                $self->{isDate} = 1
-                    if $attr->{class} eq 'f11 fwb';
+                    if $attr->{class} =~ /result_title/;
+            }
+            elsif ($tagname eq 'tpfdatetpf')
+            {
+                $self->{isDate} = 1;
             }
             elsif (($tagname eq 'a') && ($self->{isGame}))
             {
@@ -58,12 +60,12 @@ use GCPlugins::GCgames::GCgamesCommon;
         {
             if ($tagname eq 'div')
             {
-                if ($attr->{class} eq 'module_head')
+                if ($attr->{class} eq 'module')
                 {
                     $self->{section} = '';
                     $self->{isSection} = 1;
                 }
-                if ($attr->{class} eq 'tar p5')
+                if ($attr->{class} eq 'quick_links')
                 {
                     # To be sure we don't get extra data
                     $self->{section} = '';
@@ -73,9 +75,9 @@ use GCPlugins::GCgames::GCgamesCommon;
             elsif ($tagname eq 'td')
             {
                 $self->{isCheat} = 1
-                    if $attr->{class} eq 'w50p fwb p5';
+                    if $attr->{class} eq 'cheat';
                 $self->{isDesc} = 1
-                    if $attr->{class} eq 'w50p p5';
+                    if $attr->{class} eq '';
             }
         }
         else
@@ -84,8 +86,10 @@ use GCPlugins::GCgames::GCgamesCommon;
             {
                 $self->{curInfo}->{boxpic} = ' '
                     if $attr->{src} =~ /no_preview/;
-                $self->{curInfo}->{boxpic} = $attr->{src}
-                    if (! $self->{curInfo}->{boxpic}) && ($attr->{src} =~ /[^xo]boxs[^c]/);
+                if ((! $self->{curInfo}->{boxpic}) && ($attr->{src} =~ /[^xo]boxs[^c]/))
+                {
+                   $self->{curInfo}->{boxpic} = $attr->{src};
+                }
                 if ($attr->{src} =~ /thumb/)
                 {
                     my $pic = $attr->{src};
@@ -97,10 +101,41 @@ use GCPlugins::GCgames::GCgamesCommon;
                     }
                 }
             }
-            elsif ($tagname eq 'h1')
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'boxshot'))
+            {
+                $self->{isBox} = 1;
+            }
+            elsif (($tagname eq 'a') && ($self->{isBox} eq 1))
+            {
+                my $html = $self->loadPage($attr->{href});
+                my $found = index($html,"id=\"main_image\" src=\"");
+                if ( $found >= 0 )
+                {
+                   $html = substr($html, $found +length('id="main_image" src="'),length($html)- $found -length('id="main_image" src="'));
+
+                   my @array = split(/"/,$html);
+                   #"
+                   if ($self->{bigPics})
+                   {
+                      $self->{curInfo}->{boxpic} = $array[0];
+                   }
+                   $self->{curInfo}->{backpic} = $array[0];
+                   $self->{curInfo}->{backpic} =~ s/_front/_back/;
+               }
+               $self->{isBox} = 0;
+            }
+            elsif ($tagname eq 'h2')
             {
                 $self->{isName} = 1 if ! $self->{curInfo}->{name};
             }
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'label'))
+            {
+                $self->{isInfo} = 1;
+            }
+            elsif (($tagname eq 'p') && ($self->{isPlayers} eq 1))
+            {
+                $self->{isPlayers} = 2;
+            }
             elsif ($tagname eq 'p')
             {
                 $self->{isDesc} = 1 if $attr->{class} eq 'review deck';
@@ -109,14 +144,43 @@ use GCPlugins::GCgames::GCgamesCommon;
             {
                 $self->{isDesc} = 1 if $attr->{class} eq 'f12 dots pb5 mb5';
             }
-            elsif ($tagname eq 'span')
-            {
-                $self->{isInfo} = 1 if $attr->{class} eq 'txt2';
-            }
             elsif ($tagname eq 'title')
             {
                 $self->{isPlatform} = 1;
             }
+            elsif (($tagname eq 'li') && ($attr->{class} eq 'publisher'))
+            {
+                $self->{isEditor} = 1;
+            }
+            elsif (($tagname eq 'a') && ($self->{isEditor} eq 1))
+            {
+                $self->{isEditor} = 2;
+            }
+            elsif (($tagname eq 'li') && ($attr->{class} eq 'developer'))
+            {
+                $self->{isDeveloper} = 1;
+            }
+            elsif (($tagname eq 'a') && ($self->{isDeveloper} eq 1))
+            {
+                $self->{isDeveloper} = 2;
+            }
+            elsif (($tagname eq 'li') && ($attr->{class} eq 'genre'))
+            {
+                $self->{isGenre} = 1;
+            }
+            elsif (($tagname eq 'a') && ($self->{isGenre}))
+            {
+                $self->{curInfo}->{genre} = $attr->{title};
+                $self->{isGenre} = 0;
+            }
+            elsif (($tagname eq 'li') && ($attr->{class} eq 'date'))
+            {
+                $self->{isReleased} = 1;
+            }
+            elsif (($tagname eq 'a') && ($self->{isReleased} eq 1))
+            {
+                $self->{isReleased} = 2;
+            }
         }
     }
 
@@ -219,10 +283,7 @@ use GCPlugins::GCgames::GCgamesCommon;
             }
             elsif ($self->{isInfo})
             {
-                $self->{isReleased} = 1 if $origtext =~ /Release Date:\s*/;
-                $self->{isEditor} = 1 if $origtext =~ /By:\s*/;
-                $self->{isGenre} = 1 if $origtext =~ /Genre:\s*/;
-                $self->{isPlayers} = 1 if $origtext =~ /Players:\s*/;
+                $self->{isPlayers} = 1 if $origtext =~ /Number of Players:\s*/;
                 $self->{isInfo} = 0;
             }
             elsif ($self->{isPlatform})
@@ -236,22 +297,22 @@ use GCPlugins::GCgames::GCgamesCommon;
                 $origtext =~ s/^\s*//;
                 $origtext =~ s/\s*$//;
                 return if !$origtext;
-                if ($self->{isReleased})
+                if ($self->{isReleased} eq 2)
                 {
                     $self->{curInfo}->{released} = $origtext;
                     $self->{isReleased} = 0;
                 }
-                elsif ($self->{isEditor})
+                elsif ($self->{isEditor} eq 2)
                 {
                     $self->{curInfo}->{editor} = $origtext;
                     $self->{isEditor} = 0;
                 }
-                elsif ($self->{isGenre})
+                elsif ($self->{isDeveloper} eq 2)
                 {
-                    $self->{curInfo}->{genre} = $origtext;
-                    $self->{isGenre} = 0;
+                    $self->{curInfo}->{developer} = $origtext;
+                    $self->{isDeveloper} = 0;
                 }
-                elsif ($self->{isPlayers})
+                elsif ($self->{isPlayers} eq 2)
                 {
                     $origtext =~ s/(Players?)?\s*\(.*?$//;
                     $self->{curInfo}->{players} = $origtext;
@@ -292,6 +353,12 @@ use GCPlugins::GCgames::GCgamesCommon;
         $self->{isDesc} = 0;
         $self->{section} = '';
         $self->{isSection} = 0;
+        $self->{isDeveloper} = 0;
+        $self->{isGenre} = 0;
+        $self->{isEditor} = 0;
+        $self->{isReleased} = 0;
+        $self->{isPlayers} = 0;
+        $self->{isBox} = 0;
 
         return $self;
     }
@@ -306,6 +373,7 @@ use GCPlugins::GCgames::GCgamesCommon;
         }
         elsif ($self->{parsingList})
         {
+            $html =~ s|Release Date|<tpfdatetpf>Release Date|g;
         }
         else
         {
