@@ -81,43 +81,34 @@ use GCPlugins::GCgames::GCgamesCommon;
         }
         else
         {
-            if ($tagname eq 'div')
+           if ($attr->{id} eq 'fiche_technique_jeu')
             {
-                if ($attr->{class} eq 'colleft')
-                {
-                    $self->{isInfo} = 1;
-                    $self->{is} = '';
-                }
-                elsif ($attr->{class} eq 'titrejeu1')
-                {
-                    $self->{is} = 'name';
-                }
-                elsif ($attr->{class} eq 'photofiche')
-                {
-                    $self->{isBox} = 1;
-                }
+                $self->{isInfo} = 1;
+                $self->{is} = '';
             }
-            elsif ($tagname eq 'img')
+            elsif (($self->{isInfo} eq '1') && ($tagname eq 'th'))
             {
-                if ($self->{isBox})
-                {
-                    $self->{curInfo}->{boxpic} = $attr->{src}
-                        if $attr->{src} =~ /^http/;
-                    $self->{isBox} = 0;
-                }
-                if ($self->{isScreen})
-                {
-                    $attr->{src} =~ /.*?id=([0-9]*)/;
-                    my $image = "http://img.jeuxvideo.fr/photo/$1.jpg";
-                    $self->{curInfo}->{screenshot2} = $image if !$self->{curInfo}->{screenshot2}
-                                                             &&  $self->{curInfo}->{screenshot1};
-                    $self->{curInfo}->{screenshot1} = $image if !$self->{curInfo}->{screenshot1};
-                }
+                $self->{isInfo} = 2;
             }
-            elsif ($tagname eq 'a')
+            elsif ($attr->{id} eq 'wid_sortie')
             {
-                $self->{isScreen} = 1
-                    if $attr->{title} eq 'Toutes les Captures';
+                $self->{is} = 'released';
+            }
+            elsif ($attr->{class} eq 'titre_page')
+            {
+                $self->{is} = 'name';
+            }
+            elsif ($attr->{class} eq 'cf_pochette ombre')
+            {
+                $self->{curInfo}->{boxpic} = $attr->{src}
+                    if $attr->{src} =~ /^http/;
+            }
+            elsif ($attr->{class} eq 'thickbox')
+            {
+                $attr->{href} =~ /.*?id=([0-9]*)/;
+                $self->{curInfo}->{screenshot2} = $attr->{href} if !$self->{curInfo}->{screenshot2}
+                                                         &&  $self->{curInfo}->{screenshot1};
+                $self->{curInfo}->{screenshot1} = $attr->{href} if !$self->{curInfo}->{screenshot1};
             }
         }
     }
@@ -132,13 +123,6 @@ use GCPlugins::GCgames::GCgamesCommon;
             $self->{isGame} = 0
                 if ($tagname eq 'tr');
         }
-        elsif ($self->{parsingTips})
-        {
-        }
-        else
-        {
-            $self->{isScreen} = 0 if $tagname eq 'a';
-        }
     }
 
     sub text
@@ -174,27 +158,29 @@ use GCPlugins::GCgames::GCgamesCommon;
         }
         else
         {
-            if ($self->{isInfo})
+            if ($self->{isInfo} eq 2)
             {
                 $self->{is} = 'platform' if $origtext =~ /Plateforme/;
                 $self->{is} = 'genre' if $origtext =~ /Genre/;
                 $self->{is} = 'editor' if $origtext =~ /Editeur/;
                 $self->{is} = 'developer' if $origtext =~ /D.veloppeur/;
-                $self->{is} = 'players' if $origtext =~ /Mode de jeu/;
-                $self->{is} = 'released' if $origtext =~ /Date de sortie/;
-                $self->{isInfo} = 0;
+                $self->{is} = 'players' if $origtext =~ /Type de jeu/;
+                $self->{isInfo} = 1;
             }
-            elsif ($self->{is})
+            elsif (($self->{is}) && ($origtext))
             {
                 $origtext =~ s/^\s*//;
-                if ($self->{is} eq 'players')
+                if ($origtext)
                 {
-                    $origtext =~ s/Exclusivement Solo/1/;
-                    $origtext =~ s/\s*joueurs?//i;
+                   if ($self->{is} eq 'players')
+                   {
+                       $origtext =~ s/Exclusivement Solo/1/;
+                       $origtext =~ s/\s*joueurs?//i;
+                   }
+
+                   $self->{curInfo}->{$self->{is}} = $origtext;
+                   $self->{is} = '';
                 }
-                
-                $self->{curInfo}->{$self->{is}} = $origtext;
-                $self->{is} = '';
             }
         }
     } 
@@ -227,8 +213,6 @@ use GCPlugins::GCgames::GCgamesCommon;
         $self->{isDate} = 0;
         $self->{isGenre} = 0;
         $self->{isInfo} = 0;
-        $self->{isBox} = 0;
-        $self->{isScreen} = 0;
         $self->{isTip} = 0;
         $self->{is} = '';
 
