@@ -198,7 +198,7 @@ use GCPlugins::GCgames::GCgamesCommon;
                     {
                         /^gameTitle$/ && ($self->{isName} = 1, last);
                         /^gamePlatform/ && ($self->{isPlatform} = 1, last);
-                        /^coreGameCover/ && ($self->{isBox} = 1, last);
+                        #/^coreGameCover/ && ($self->{isBox} = 1, last);
                         /^coreGameRelease/ && ($self->{isEditor} = 1, last);
                     }
 
@@ -239,112 +239,62 @@ use GCPlugins::GCgames::GCgamesCommon;
             {
                     $self->{is} = 'genre';
             }
-            elsif ( ($tagname eq 'img') && ($self->{isBox}) && ($attr->{alt} eq 'No Cover on File') )
+            elsif ($tagname eq 'img')
             {
-                    $self->{isBox} = 0;
-            }
-            elsif ( ($tagname eq 'a') && ($self->{isBox}) )
-            {
-                    my $html = $self->loadPage('http://www.mobygames.com'.$attr->{href});
-                    my $found = index($html,".jpg");
-                    if ( $found >= 0 )
-                    {
-                       $html = substr($html, 0, $found + length(".jpg") );
-                       $html = reverse($html);
-                       $html = substr($html, 0, index($html,"\"=crs "));
-                       $html = reverse($html);
-                       $self->{curInfo}->{boxpic} = $html;
-                    }
-
-                    $self->{isBox} = 0;
+                if ($attr->{src} =~ m|covers/small|)
+                {
+                    $attr->{src} =~ s|/small/|/large/|
+                        if $self->{bigPics};
+                    $self->{curInfo}->{boxpic} = $attr->{src};
+                    # From here we try to get back cover
+                    my $covers = $self->loadPage($self->{rootUrl}.'/cover-art');
+                    $covers =~ m|<img alt=".*?Back Cover".*?src="([^"]*)"|;
+                    $self->{curInfo}->{backpic} = $1;
+                    $self->{curInfo}->{backpic} =~ s|/small/|/large/|
+                        if $self->{bigPics};                   
+                }
             }
             elsif ($tagname eq 'html')
             {
-                    my $html = $self->loadPage($self->{curInfo}->{$self->{urlField}}.'/techinfo');
-                    my $player_offline = $self->extractPlayer($html, "Number&nbsp;of Players: Offline" );
-                    my $player_online = $self->extractPlayer($html, "Number&nbsp;of Players: Online" );
-                    my $player_total = $self->extractPlayer($html, "Number&nbsp;of Players Supported" );
+                my $html = $self->loadPage($self->{curInfo}->{$self->{urlField}}.'/techinfo');
+                my $player_offline = $self->extractPlayer($html, "Number&nbsp;of Players: Offline" );
+                my $player_online = $self->extractPlayer($html, "Number&nbsp;of Players: Online" );
+                my $player_total = $self->extractPlayer($html, "Number&nbsp;of Players Supported" );
 
-                    if ($player_total)
+                if ($player_total)
+                {
+                   $self->{curInfo}->{players} = $player_total;
+                }
+                else
+                {
+                    if ($player_offline)
                     {
-                       $self->{curInfo}->{players} = $player_total;
+                        $self->{curInfo}->{players} = 'Offline: '.$player_offline;
                     }
-                    else
+                    if ($player_online)
                     {
-                       if ($player_offline)
-                       {
-                          $self->{curInfo}->{players} = 'Offline: '.$player_offline;
-                       }
-                       if ($player_online)
-                       {
-                          if ( $self->{curInfo}->{players} )
-                          {
-                             $self->{curInfo}->{players} .= '; Online: '.$player_online;
-                          }
-                          else
-                          {
-                             $self->{curInfo}->{players} = 'Online: '.$player_online;
-                          }
-                       }
+                        if ( $self->{curInfo}->{players} )
+                        {
+                            $self->{curInfo}->{players} .= '; Online: '.$player_online;
+                        }
+                        else
+                        {
+                            $self->{curInfo}->{players} = 'Online: '.$player_online;
+                        }
                     }
+                }
 
-                    $html = $self->loadPage($self->{curInfo}->{$self->{urlField}}.'/screenshots');
-                    my $found = index($html,"\"><img alt=\"[");
-                    if ( $found >= 0 )
-                    {
-                       $self->{curInfo}->{screenshot1} = substr($html, 0, $found);
-                       $self->{curInfo}->{screenshot1} = reverse($self->{curInfo}->{screenshot1});
-                       $self->{curInfo}->{screenshot1} = substr($self->{curInfo}->{screenshot1}, 0, index($self->{curInfo}->{screenshot1},"\"=ferh a<>\""));
-                       $self->{curInfo}->{screenshot1} = reverse($self->{curInfo}->{screenshot1});
-                       $self->{curInfo}->{screenshot1} = 'http://www.mobygames.com'.$self->{curInfo}->{screenshot1};
-
-                       my $html_Screen = $self->loadPage($self->{curInfo}->{screenshot1});
-                       my $found2 = index($html_Screen,"<strong>Screenshot: </strong>");
-                       if ( $found2 >= 0 )
-                       {
-                          $html_Screen = substr($html_Screen, $found2 + length('<strong>Screenshot: </strong>'),length($html_Screen)- $found2 -length('<strong>Screenshot: </strong>') );
-                          $html_Screen = substr($html_Screen,index($html_Screen," src=\"") + length(" src=\""),index($html_Screen," src=\"")-index($html_Screen," src=\"")-length(" src=\"") );
-                          $self->{curInfo}->{screenshot1} = substr($html_Screen,0, index($html_Screen,"\"") );
-                          if ( !($self->{curInfo}->{screenshot1} =~ m/http:\/\/www.mobygames.com/i) )
-                          {
-                             $self->{curInfo}->{screenshot1} = 'http://www.mobygames.com'.$self->{curInfo}->{screenshot1};
-                          }
-
-                       }
-
-                       $html = substr($html, $found -2 + length('\"><img alt=\"['),length($html)- $found -length('\"><img alt=\"[') + 2);
-                       my $found1 = index($html,"\"><img alt=\"[");
-                       if ( $found1 >= 0 )
-                       {
-                       $self->{curInfo}->{screenshot2} = substr($html, 0, $found1);
-                       $self->{curInfo}->{screenshot2} = reverse($self->{curInfo}->{screenshot2});
-                       $self->{curInfo}->{screenshot2} = substr($self->{curInfo}->{screenshot2}, 0, index($self->{curInfo}->{screenshot2},"\"=ferh a<>\""));
-                       $self->{curInfo}->{screenshot2} = reverse($self->{curInfo}->{screenshot2});
-                       $self->{curInfo}->{screenshot2} = 'http://www.mobygames.com'.$self->{curInfo}->{screenshot2};
-
-
-                          $html_Screen = $self->loadPage($self->{curInfo}->{screenshot2});
-                          $found2 = index($html_Screen,"<strong>Screenshot: </strong>");
-                          if ( $found2 >= 0 )
-                          {
-                             $html_Screen = substr($html_Screen, $found2 + length('<strong>Screenshot: </strong>'),length($html_Screen)- $found2 -length('<strong>Screenshot: </strong>') );
-                             $html_Screen = substr($html_Screen,index($html_Screen," src=\"") + length(" src=\""),index($html_Screen," src=\"")-index($html_Screen," src=\"")-length(" src=\"") );
-                             $self->{curInfo}->{screenshot2} = substr($html_Screen,0, index($html_Screen,"\"") );
-                             if ( !($self->{curInfo}->{screenshot2} =~ m/http:\/\/www.mobygames.com/i) )
-                             {
-                                $self->{curInfo}->{screenshot2} = 'http://www.mobygames.com'.$self->{curInfo}->{screenshot2};
-                             }
-
-                          }
-
-                       }
-
-                    }
-
-
-                    $self->{isBox} = 0;
+                $html = $self->loadPage($self->{curInfo}->{$self->{urlField}}.'/screenshots');
+                my $screen = 1;
+                while ($html =~ m|src="(http://www.mobygames.com/images/shots/thumbnail[^"]*?)"|g)
+                {
+                    $self->{curInfo}->{'screenshot'.$screen} = $1;
+                    $self->{curInfo}->{'screenshot'.$screen} =~ s|/thumbnail/|/original/|
+                        if $self->{bigPics};
+                    $screen++;
+                    last if $screen > 2;
+                }
             }
-
         }
     }
 
@@ -490,7 +440,7 @@ use GCPlugins::GCgames::GCgamesCommon;
     sub preProcess
     {
         my ($self, $html) = @_;
-
+        $self->{rootUrl} = $self->{loadedUrl};
         return $html;
     }
     
@@ -510,7 +460,7 @@ use GCPlugins::GCgames::GCgamesCommon;
 
     sub getName
     {
-        return 'mobygames.com';
+        return 'MobyGames';
     }
     
     sub getAuthor
