@@ -109,8 +109,8 @@ use GCPlugins::GCstar::GCAmazonCommon;
                    }
                 }
 
-                # Sur Amazon.com je n ai pas reussi a trouver un critere pertinent pour la recherche des genres
-                if ($self->{suffix} eq 'com')
+                # Sur Amazon.com et amazon.co.jp je n ai pas reussi a trouver un critere pertinent pour la recherche des genres
+                if (($self->{suffix} eq 'com') || ($self->{suffix} eq 'co.jp') )
                 {
                    $self->{curInfo}->{genre} = '';
                 }
@@ -167,12 +167,7 @@ use GCPlugins::GCstar::GCAmazonCommon;
         {
             if ($self->{isPlatform})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{platform} = $origtext;
-                $self->{itemsList}[$self->{itemIdx}]->{platform} =~ s/SONY //i;
-                if ($self->{itemsList}[$self->{itemIdx}]->{platform} =~ m/windows/i)
-                {
-                   $self->{itemsList}[$self->{itemIdx}]->{platform} = 'PC';
-                }
+                $self->{itemsList}[$self->{itemIdx}]->{platform} = $self->transformPlatform($origtext);
                 $self->{isPlatform} = 0;
             }
         }
@@ -193,12 +188,7 @@ use GCPlugins::GCstar::GCAmazonCommon;
             {
                 if ($origtext ne '' )
                 {
-                   $self->{curInfo}->{platform} = $origtext;
-                   $self->{curInfo}->{platform} =~ s/SONY //i;
-                   if ($self->{curInfo}->{platform} =~ m/windows/i)
-                   {
-                      $self->{curInfo}->{platform} = 'PC';
-                   }
+                   $self->{curInfo}->{platform} = $self->transformPlatform($origtext);
                    $self->{isPlatform} = 0;
                 }
             }
@@ -210,6 +200,19 @@ use GCPlugins::GCstar::GCAmazonCommon;
         }
     } 
 
+    sub transformPlatform
+    {
+        my ($self, $platform) = @_;
+        
+        $platform =~ s/^([\w ]*)\W{2}.*$/$1/ms;
+        $platform =~ s/SONY //i;
+        if ($platform =~ m/windows/i)
+        {
+           $platform = 'PC';
+        }
+        return $platform;
+    }
+
     sub getTipsUrl
     {
         my $self = shift;
