@@ -36,10 +36,10 @@ use GCPlugins::GCPluginsBase;
         return 'http://images.amazon.com/images/'.$1.'/'.$2.$3.'MZZZZZZZ.'.$5
             if ($url =~ m%^http://.*?images[.-]amazon\.com/images/(P)/([A-Z0-9]*)(\.[0-9]+\.)?[-A-Za-z0-9_.,]*?ZZZZZZZ(.*?)\.(jpg|gif)%);
         return 'http://images.amazon.com/images/'.$1.'/'.$2.'.'.$3
-            if ($url =~ m%^http://.*?images[.-]amazon\.com/images/(I|G)/([-A-Z0-9a-z+]*)\._.*?_\.(jpg|gif)%);
+            if ($url =~ m%^http://.*?images[.-]amazon\.com/images/(I|G)/([-\%A-Z0-9a-z+]*)\._.*?_\.(jpg|gif)%);
         if ($attr->{id} eq 'prodImage')
         {
-            $url =~ s/\._AA[0-9]*_//;
+            $url =~ s/_AA[0-9]*_//;
             return $url;
         }
         return '';
