@@ -349,11 +349,11 @@ sub scaleMaxPixbuf
                 $newHeight = $newWidth * $ratio;
             }
 
-    		$pixbuf = $pixbuf->scale_simple($newWidth, $newHeight, $algorithm);
+            $pixbuf = $pixbuf->scale_simple($newWidth, $newHeight, $algorithm);
         }
-	}
+    }
 
-	return $pixbuf;
+    return $pixbuf;
 }
 
 sub findPosition
@@ -414,15 +414,20 @@ use File::Basename;
 
 sub getDisplayedImage
 {
-    my ($displayedImage, $default, $file) = @_;
+    my ($displayedImage, $default, $file, $fileDir) = @_;
 
     if (!File::Spec->file_name_is_absolute($displayedImage))
     {
         my $dir;
-        $dir = '.';
-        $dir = dirname($file)
-            if $file;
-        if (-f $dir.'/'.$displayedImage)
+        if ($file)
+        {
+            $dir = ($fileDir || dirname($file));
+        }
+        else
+        {
+            $dir = '.';
+        }
+        if (-f "$dir/$displayedImage")
         {
             $displayedImage = $dir.'/'.$displayedImage;
         }
@@ -430,7 +435,6 @@ sub getDisplayedImage
         {
             $displayedImage = $default unless (-e $displayedImage);
         }
-        $displayedImage = $default if ! -f $displayedImage;
     }
     $displayedImage = $default if ! -f $displayedImage;
 
